Interface FinchClientAsync
-
- All Implemented Interfaces:
public interface FinchClientAsyncA client for interacting with the Finch REST API asynchronously. You can also switch to synchronous execution via the sync method.
This client performs best when you create a single instance and reuse it for all interactions with the REST API. This is because each client holds its own connection pool and thread pools. Reusing connections and threads reduces latency and saves memory. The client also handles rate limiting per client. This means that creating and using multiple instances at the same time will not respect rate limits.
The threads and connections that are held will be released automatically if they remain idle. But if you are writing an application that needs to aggressively release unused resources, then you may call close.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceFinchClientAsync.WithRawResponseA view of FinchClientAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract FinchClientsync()Returns a version of this client that uses synchronous execution. abstract FinchClientAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract FinchClientAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract AccessTokenServiceAsyncaccessTokens()abstract HrisServiceAsynchris()abstract ProviderServiceAsyncproviders()abstract AccountServiceAsyncaccount()abstract WebhookServiceAsyncwebhooks()abstract RequestForwardingServiceAsyncrequestForwarding()abstract JobServiceAsyncjobs()abstract SandboxServiceAsyncsandbox()abstract PayrollServiceAsyncpayroll()abstract ConnectServiceAsyncconnect()abstract CompletableFuture<String>getAccessToken(String clientId, String clientSecret, String code, String redirectUri)abstract StringgetAuthUrl(String products, String redirectUri, Boolean sandbox)abstract FinchClientAsyncwithAccessToken(String accessToken)abstract Unitclose()Closes this client, relinquishing any underlying resources. -
-
Method Detail
-
sync
abstract FinchClient sync()
Returns a version of this client that uses synchronous execution.
The returned client shares its resources, like its connection pool and thread pools, with this client.
-
withRawResponse
abstract FinchClientAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract FinchClientAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
accessTokens
abstract AccessTokenServiceAsync accessTokens()
-
hris
abstract HrisServiceAsync hris()
-
providers
abstract ProviderServiceAsync providers()
-
account
abstract AccountServiceAsync account()
-
webhooks
abstract WebhookServiceAsync webhooks()
-
requestForwarding
abstract RequestForwardingServiceAsync requestForwarding()
-
jobs
abstract JobServiceAsync jobs()
-
sandbox
abstract SandboxServiceAsync sandbox()
-
payroll
abstract PayrollServiceAsync payroll()
-
connect
abstract ConnectServiceAsync connect()
-
getAccessToken
@Deprecated(message = "use client.accessTokens().create instead", replaceWith = @ReplaceWith(imports = {}, expression = "accessTokens().create()")) abstract CompletableFuture<String> getAccessToken(String clientId, String clientSecret, String code, String redirectUri)
-
getAuthUrl
abstract String getAuthUrl(String products, String redirectUri, Boolean sandbox)
-
withAccessToken
abstract FinchClientAsync withAccessToken(String accessToken)
-
close
abstract Unit close()
Closes this client, relinquishing any underlying resources.
This is purposefully not inherited from AutoCloseable because the client is long-lived and usually should not be synchronously closed via try-with-resources.
It's also usually not necessary to call this method at all. the default HTTP client automatically releases threads and connections if they remain idle, but if you are writing an application that needs to aggressively release unused resources, then you may call this method.
-
-
-
-