Package com.tryfinch.api.client
Interface FinchClientAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface FinchClientAsync.WithRawResponseA view of FinchClientAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract FinchClientAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract AccessTokenServiceAsync.WithRawResponseaccessTokens()abstract HrisServiceAsync.WithRawResponsehris()abstract ProviderServiceAsync.WithRawResponseproviders()abstract AccountServiceAsync.WithRawResponseaccount()abstract RequestForwardingServiceAsync.WithRawResponserequestForwarding()abstract JobServiceAsync.WithRawResponsejobs()abstract SandboxServiceAsync.WithRawResponsesandbox()abstract PayrollServiceAsync.WithRawResponsepayroll()abstract ConnectServiceAsync.WithRawResponseconnect()-
-
Method Detail
-
withOptions
abstract FinchClientAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
accessTokens
abstract AccessTokenServiceAsync.WithRawResponse accessTokens()
-
hris
abstract HrisServiceAsync.WithRawResponse hris()
-
providers
abstract ProviderServiceAsync.WithRawResponse providers()
-
account
abstract AccountServiceAsync.WithRawResponse account()
-
requestForwarding
abstract RequestForwardingServiceAsync.WithRawResponse requestForwarding()
-
jobs
abstract JobServiceAsync.WithRawResponse jobs()
-
sandbox
abstract SandboxServiceAsync.WithRawResponse sandbox()
-
payroll
abstract PayrollServiceAsync.WithRawResponse payroll()
-
connect
abstract ConnectServiceAsync.WithRawResponse connect()
-
-
-
-