Class FinchClientAsyncImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.client.FinchClientAsync
public final class FinchClientAsyncImpl implements FinchClientAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinchClientAsyncImpl.WithRawResponseImpl
-
Constructor Summary
Constructors Constructor Description FinchClientAsyncImpl(ClientOptions clientOptions)
-
Method Summary
-
-
Constructor Detail
-
FinchClientAsyncImpl
FinchClientAsyncImpl(ClientOptions clientOptions)
-
-
Method Detail
-
sync
FinchClient sync()
Returns a version of this client that uses synchronous execution.
The returned client shares its resources, like its connection pool and thread pools, with this client.
-
withRawResponse
FinchClientAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
FinchClientAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
accessTokens
AccessTokenServiceAsync accessTokens()
-
hris
HrisServiceAsync hris()
-
providers
ProviderServiceAsync providers()
-
account
AccountServiceAsync account()
-
webhooks
WebhookServiceAsync webhooks()
-
requestForwarding
RequestForwardingServiceAsync requestForwarding()
-
jobs
JobServiceAsync jobs()
-
sandbox
SandboxServiceAsync sandbox()
-
payroll
PayrollServiceAsync payroll()
-
connect
ConnectServiceAsync connect()
-
getAccessToken
@Deprecated(message = "use client.accessTokens().create instead", replaceWith = @ReplaceWith(imports = {}, expression = "accessTokens().create()")) CompletableFuture<String> getAccessToken(String clientId, String clientSecret, String code, String redirectUri)
-
getAuthUrl
String getAuthUrl(String products, String redirectUri, Boolean sandbox)
-
withAccessToken
FinchClientAsync withAccessToken(String accessToken)
-
close
Unit close()
Closes this client, relinquishing any underlying resources.
This is purposefully not inherited from AutoCloseable because the client is long-lived and usually should not be synchronously closed via try-with-resources.
It's also usually not necessary to call this method at all. the default HTTP client automatically releases threads and connections if they remain idle, but if you are writing an application that needs to aggressively release unused resources, then you may call this method.
-
-
-
-