Package com.tryfinch.api.client
Class FinchClientAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.client.FinchClientAsync.WithRawResponse
public final class FinchClientAsyncImpl.WithRawResponseImpl implements FinchClientAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description FinchClientAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. AccessTokenServiceAsync.WithRawResponseaccessTokens()HrisServiceAsync.WithRawResponsehris()ProviderServiceAsync.WithRawResponseproviders()AccountServiceAsync.WithRawResponseaccount()RequestForwardingServiceAsync.WithRawResponserequestForwarding()JobServiceAsync.WithRawResponsejobs()SandboxServiceAsync.WithRawResponsesandbox()PayrollServiceAsync.WithRawResponsepayroll()ConnectServiceAsync.WithRawResponseconnect()-
-
Method Detail
-
withOptions
FinchClientAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
accessTokens
AccessTokenServiceAsync.WithRawResponse accessTokens()
-
providers
ProviderServiceAsync.WithRawResponse providers()
-
account
AccountServiceAsync.WithRawResponse account()
-
requestForwarding
RequestForwardingServiceAsync.WithRawResponse requestForwarding()
-
sandbox
SandboxServiceAsync.WithRawResponse sandbox()
-
payroll
PayrollServiceAsync.WithRawResponse payroll()
-
connect
ConnectServiceAsync.WithRawResponse connect()
-
-
-
-