Class FinchClientImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.client.FinchClient
public final class FinchClientImpl implements FinchClient
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinchClientImpl.WithRawResponseImpl
-
Constructor Summary
Constructors Constructor Description FinchClientImpl(ClientOptions clientOptions)
-
Method Summary
Modifier and Type Method Description FinchClientAsyncasync()Returns a version of this client that uses asynchronous execution. FinchClient.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. FinchClientwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. AccessTokenServiceaccessTokens()HrisServicehris()ProviderServiceproviders()AccountServiceaccount()WebhookServicewebhooks()RequestForwardingServicerequestForwarding()JobServicejobs()SandboxServicesandbox()PayrollServicepayroll()ConnectServiceconnect()StringgetAccessToken(String clientId, String clientSecret, String code, String redirectUri)StringgetAuthUrl(String products, String redirectUri, Boolean sandbox)FinchClientwithAccessToken(String accessToken)Unitclose()Closes this client, relinquishing any underlying resources. -
-
Constructor Detail
-
FinchClientImpl
FinchClientImpl(ClientOptions clientOptions)
-
-
Method Detail
-
async
FinchClientAsync async()
Returns a version of this client that uses asynchronous execution.
The returned client shares its resources, like its connection pool and thread pools, with this client.
-
withRawResponse
FinchClient.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
FinchClient withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
accessTokens
AccessTokenService accessTokens()
-
hris
HrisService hris()
-
providers
ProviderService providers()
-
account
AccountService account()
-
webhooks
WebhookService webhooks()
-
requestForwarding
RequestForwardingService requestForwarding()
-
jobs
JobService jobs()
-
sandbox
SandboxService sandbox()
-
payroll
PayrollService payroll()
-
connect
ConnectService connect()
-
getAccessToken
@Deprecated(message = "use client.accessTokens().create instead", replaceWith = @ReplaceWith(imports = {}, expression = "accessTokens().create()")) String getAccessToken(String clientId, String clientSecret, String code, String redirectUri)
-
getAuthUrl
String getAuthUrl(String products, String redirectUri, Boolean sandbox)
-
withAccessToken
FinchClient withAccessToken(String accessToken)
-
close
Unit close()
Closes this client, relinquishing any underlying resources.
This is purposefully not inherited from AutoCloseable because the client is long-lived and usually should not be synchronously closed via try-with-resources.
It's also usually not necessary to call this method at all. the default HTTP client automatically releases threads and connections if they remain idle, but if you are writing an application that needs to aggressively release unused resources, then you may call this method.
-
-
-
-