Package com.tryfinch.api.client
Class FinchClientImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.client.FinchClient.WithRawResponse
public final class FinchClientImpl.WithRawResponseImpl implements FinchClient.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description FinchClient.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. AccessTokenService.WithRawResponseaccessTokens()HrisService.WithRawResponsehris()ProviderService.WithRawResponseproviders()AccountService.WithRawResponseaccount()RequestForwardingService.WithRawResponserequestForwarding()JobService.WithRawResponsejobs()SandboxService.WithRawResponsesandbox()PayrollService.WithRawResponsepayroll()ConnectService.WithRawResponseconnect()-
-
Method Detail
-
withOptions
FinchClient.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
accessTokens
AccessTokenService.WithRawResponse accessTokens()
-
hris
HrisService.WithRawResponse hris()
-
providers
ProviderService.WithRawResponse providers()
-
account
AccountService.WithRawResponse account()
-
requestForwarding
RequestForwardingService.WithRawResponse requestForwarding()
-
jobs
JobService.WithRawResponse jobs()
-
sandbox
SandboxService.WithRawResponse sandbox()
-
payroll
PayrollService.WithRawResponse payroll()
-
connect
ConnectService.WithRawResponse connect()
-
-
-
-