Class FinchOkHttpClient.Builder
-
- All Implemented Interfaces:
public final class FinchOkHttpClient.BuilderA builder for FinchOkHttpClient.
-
-
Method Summary
Modifier and Type Method Description final FinchOkHttpClient.BuilderdispatcherExecutorService(ExecutorService dispatcherExecutorService)The executor service to use for running HTTP requests. final FinchOkHttpClient.BuilderdispatcherExecutorService(Optional<ExecutorService> dispatcherExecutorService)Alias for calling Builder.dispatcherExecutorService with dispatcherExecutorService.orElse(null).final FinchOkHttpClient.Builderproxy(Proxy proxy)final FinchOkHttpClient.Builderproxy(Optional<Proxy> proxy)Alias for calling Builder.proxy with proxy.orElse(null).final FinchOkHttpClient.BuilderproxyAuthenticator(ProxyAuthenticator proxyAuthenticator)Provides credentials when an HTTP proxy responds with 407 Proxy Authentication Required.final FinchOkHttpClient.BuilderproxyAuthenticator(Optional<ProxyAuthenticator> proxyAuthenticator)Alias for calling Builder.proxyAuthenticator with proxyAuthenticator.orElse(null).final FinchOkHttpClient.BuildermaxIdleConnections(Integer maxIdleConnections)The maximum number of idle connections kept by the underlying OkHttp connection pool. final FinchOkHttpClient.BuildermaxIdleConnections(Integer maxIdleConnections)Alias for Builder.maxIdleConnections. final FinchOkHttpClient.BuildermaxIdleConnections(Optional<Integer> maxIdleConnections)Alias for calling Builder.maxIdleConnections with maxIdleConnections.orElse(null).final FinchOkHttpClient.BuilderkeepAliveDuration(Duration keepAliveDuration)The keep-alive duration for idle connections in the underlying OkHttp connection pool. final FinchOkHttpClient.BuilderkeepAliveDuration(Optional<Duration> keepAliveDuration)Alias for calling Builder.keepAliveDuration with keepAliveDuration.orElse(null).final FinchOkHttpClient.BuildersslSocketFactory(SSLSocketFactory sslSocketFactory)The socket factory used to secure HTTPS connections. final FinchOkHttpClient.BuildersslSocketFactory(Optional<SSLSocketFactory> sslSocketFactory)Alias for calling Builder.sslSocketFactory with sslSocketFactory.orElse(null).final FinchOkHttpClient.BuildertrustManager(X509TrustManager trustManager)The trust manager used to secure HTTPS connections. final FinchOkHttpClient.BuildertrustManager(Optional<X509TrustManager> trustManager)Alias for calling Builder.trustManager with trustManager.orElse(null).final FinchOkHttpClient.BuilderhostnameVerifier(HostnameVerifier hostnameVerifier)The verifier used to confirm that response certificates apply to requested hostnames for HTTPS connections. final FinchOkHttpClient.BuilderhostnameVerifier(Optional<HostnameVerifier> hostnameVerifier)Alias for calling Builder.hostnameVerifier with hostnameVerifier.orElse(null).final FinchOkHttpClient.BuildercheckJacksonVersionCompatibility(Boolean checkJacksonVersionCompatibility)Whether to throw an exception if any of the Jackson versions detected at runtime are incompatible with the SDK's minimum supported Jackson version (2.13.4). final FinchOkHttpClient.BuilderjsonMapper(JsonMapper jsonMapper)The Jackson JSON mapper to use for serializing and deserializing JSON. final FinchOkHttpClient.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)The executor to use for running AsyncStreamResponse.Handler callbacks. final FinchOkHttpClient.Buildersleeper(Sleeper sleeper)The interface to use for delaying execution, like during retries. final FinchOkHttpClient.Builderclock(Clock clock)The clock to use for operations that require timing, like retries. final FinchOkHttpClient.BuilderbaseUrl(String baseUrl)The base URL to use for every request. final FinchOkHttpClient.BuilderbaseUrl(Optional<String> baseUrl)Alias for calling Builder.baseUrl with baseUrl.orElse(null).final FinchOkHttpClient.BuilderresponseValidation(Boolean responseValidation)Whether to call validateon every response before returning it.final FinchOkHttpClient.Buildertimeout(Timeout timeout)Sets the maximum time allowed for various parts of an HTTP call's lifecycle, excluding retries. final FinchOkHttpClient.Buildertimeout(Duration timeout)Sets the maximum time allowed for a complete HTTP call, not including retries. final FinchOkHttpClient.BuildermaxRetries(Integer maxRetries)The maximum number of times to retry failed requests, with a short exponential backoff between requests. final FinchOkHttpClient.BuilderlogLevel(LogLevel logLevel)The level at which to log request and response information. final FinchOkHttpClient.BuilderaccessToken(String accessToken)final FinchOkHttpClient.BuilderaccessToken(Optional<String> accessToken)Alias for calling Builder.accessToken with accessToken.orElse(null).final FinchOkHttpClient.BuilderclientId(String clientId)final FinchOkHttpClient.BuilderclientId(Optional<String> clientId)Alias for calling Builder.clientId with clientId.orElse(null).final FinchOkHttpClient.BuilderclientSecret(String clientSecret)final FinchOkHttpClient.BuilderclientSecret(Optional<String> clientSecret)Alias for calling Builder.clientSecret with clientSecret.orElse(null).final FinchOkHttpClient.BuilderwebhookSecret(String webhookSecret)final FinchOkHttpClient.BuilderwebhookSecret(Optional<String> webhookSecret)Alias for calling Builder.webhookSecret with webhookSecret.orElse(null).final FinchOkHttpClient.Builderheaders(Headers headers)final FinchOkHttpClient.Builderheaders(Map<String, Iterable<String>> headers)final FinchOkHttpClient.BuilderputHeader(String name, String value)final FinchOkHttpClient.BuilderputHeaders(String name, Iterable<String> values)final FinchOkHttpClient.BuilderputAllHeaders(Headers headers)final FinchOkHttpClient.BuilderputAllHeaders(Map<String, Iterable<String>> headers)final FinchOkHttpClient.BuilderreplaceHeaders(String name, String value)final FinchOkHttpClient.BuilderreplaceHeaders(String name, Iterable<String> values)final FinchOkHttpClient.BuilderreplaceAllHeaders(Headers headers)final FinchOkHttpClient.BuilderreplaceAllHeaders(Map<String, Iterable<String>> headers)final FinchOkHttpClient.BuilderremoveHeaders(String name)final FinchOkHttpClient.BuilderremoveAllHeaders(Set<String> names)final FinchOkHttpClient.BuilderqueryParams(QueryParams queryParams)final FinchOkHttpClient.BuilderqueryParams(Map<String, Iterable<String>> queryParams)final FinchOkHttpClient.BuilderputQueryParam(String key, String value)final FinchOkHttpClient.BuilderputQueryParams(String key, Iterable<String> values)final FinchOkHttpClient.BuilderputAllQueryParams(QueryParams queryParams)final FinchOkHttpClient.BuilderputAllQueryParams(Map<String, Iterable<String>> queryParams)final FinchOkHttpClient.BuilderreplaceQueryParams(String key, String value)final FinchOkHttpClient.BuilderreplaceQueryParams(String key, Iterable<String> values)final FinchOkHttpClient.BuilderreplaceAllQueryParams(QueryParams queryParams)final FinchOkHttpClient.BuilderreplaceAllQueryParams(Map<String, Iterable<String>> queryParams)final FinchOkHttpClient.BuilderremoveQueryParams(String key)final FinchOkHttpClient.BuilderremoveAllQueryParams(Set<String> keys)final FinchOkHttpClient.BuilderfromEnv()Updates configuration using system properties and environment variables. final FinchClientbuild()Returns an immutable instance of FinchClient. -
-
Method Detail
-
dispatcherExecutorService
final FinchOkHttpClient.Builder dispatcherExecutorService(ExecutorService dispatcherExecutorService)
The executor service to use for running HTTP requests.
Defaults to OkHttp's default executor service.
This class takes ownership of the executor service and shuts it down when closed.
-
dispatcherExecutorService
final FinchOkHttpClient.Builder dispatcherExecutorService(Optional<ExecutorService> dispatcherExecutorService)
Alias for calling Builder.dispatcherExecutorService with
dispatcherExecutorService.orElse(null).
-
proxy
final FinchOkHttpClient.Builder proxy(Proxy proxy)
-
proxy
final FinchOkHttpClient.Builder proxy(Optional<Proxy> proxy)
Alias for calling Builder.proxy with
proxy.orElse(null).
-
proxyAuthenticator
final FinchOkHttpClient.Builder proxyAuthenticator(ProxyAuthenticator proxyAuthenticator)
Provides credentials when an HTTP proxy responds with
407 Proxy Authentication Required.
-
proxyAuthenticator
final FinchOkHttpClient.Builder proxyAuthenticator(Optional<ProxyAuthenticator> proxyAuthenticator)
Alias for calling Builder.proxyAuthenticator with
proxyAuthenticator.orElse(null).
-
maxIdleConnections
final FinchOkHttpClient.Builder maxIdleConnections(Integer maxIdleConnections)
The maximum number of idle connections kept by the underlying OkHttp connection pool.
If this is set, then keepAliveDuration must also be set.
If unset, then OkHttp's default is used.
-
maxIdleConnections
final FinchOkHttpClient.Builder maxIdleConnections(Integer maxIdleConnections)
Alias for Builder.maxIdleConnections.
This unboxed primitive overload exists for backwards compatibility.
-
maxIdleConnections
final FinchOkHttpClient.Builder maxIdleConnections(Optional<Integer> maxIdleConnections)
Alias for calling Builder.maxIdleConnections with
maxIdleConnections.orElse(null).
-
keepAliveDuration
final FinchOkHttpClient.Builder keepAliveDuration(Duration keepAliveDuration)
The keep-alive duration for idle connections in the underlying OkHttp connection pool.
If this is set, then maxIdleConnections must also be set.
If unset, then OkHttp's default is used.
-
keepAliveDuration
final FinchOkHttpClient.Builder keepAliveDuration(Optional<Duration> keepAliveDuration)
Alias for calling Builder.keepAliveDuration with
keepAliveDuration.orElse(null).
-
sslSocketFactory
final FinchOkHttpClient.Builder sslSocketFactory(SSLSocketFactory sslSocketFactory)
The socket factory used to secure HTTPS connections.
If this is set, then trustManager must also be set.
If unset, then the system default is used. Most applications should not call this method, and instead use the system default. The default include special optimizations that can be lost if the implementation is modified.
-
sslSocketFactory
final FinchOkHttpClient.Builder sslSocketFactory(Optional<SSLSocketFactory> sslSocketFactory)
Alias for calling Builder.sslSocketFactory with
sslSocketFactory.orElse(null).
-
trustManager
final FinchOkHttpClient.Builder trustManager(X509TrustManager trustManager)
The trust manager used to secure HTTPS connections.
If this is set, then sslSocketFactory must also be set.
If unset, then the system default is used. Most applications should not call this method, and instead use the system default. The default include special optimizations that can be lost if the implementation is modified.
-
trustManager
final FinchOkHttpClient.Builder trustManager(Optional<X509TrustManager> trustManager)
Alias for calling Builder.trustManager with
trustManager.orElse(null).
-
hostnameVerifier
final FinchOkHttpClient.Builder hostnameVerifier(HostnameVerifier hostnameVerifier)
The verifier used to confirm that response certificates apply to requested hostnames for HTTPS connections.
If unset, then a default hostname verifier is used.
-
hostnameVerifier
final FinchOkHttpClient.Builder hostnameVerifier(Optional<HostnameVerifier> hostnameVerifier)
Alias for calling Builder.hostnameVerifier with
hostnameVerifier.orElse(null).
-
checkJacksonVersionCompatibility
final FinchOkHttpClient.Builder checkJacksonVersionCompatibility(Boolean checkJacksonVersionCompatibility)
Whether to throw an exception if any of the Jackson versions detected at runtime are incompatible with the SDK's minimum supported Jackson version (2.13.4).
Defaults to true. Use extreme caution when disabling this option. There is no guarantee that the SDK will work correctly when using an incompatible Jackson version.
-
jsonMapper
final FinchOkHttpClient.Builder jsonMapper(JsonMapper jsonMapper)
The Jackson JSON mapper to use for serializing and deserializing JSON.
Defaults to com.tryfinch.api.core.jsonMapper. The default is usually sufficient and rarely needs to be overridden.
-
streamHandlerExecutor
final FinchOkHttpClient.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
The executor to use for running AsyncStreamResponse.Handler callbacks.
Defaults to a dedicated cached thread pool.
This class takes ownership of the executor and shuts it down, if possible, when closed.
-
sleeper
final FinchOkHttpClient.Builder sleeper(Sleeper sleeper)
The interface to use for delaying execution, like during retries.
This is primarily useful for using fake delays in tests.
Defaults to real execution delays.
This class takes ownership of the sleeper and closes it when closed.
-
clock
final FinchOkHttpClient.Builder clock(Clock clock)
The clock to use for operations that require timing, like retries.
This is primarily useful for using a fake clock in tests.
Defaults to Clock.systemUTC.
-
baseUrl
final FinchOkHttpClient.Builder baseUrl(String baseUrl)
The base URL to use for every request.
Defaults to the production environment:
https://api.tryfinch.com.
-
baseUrl
final FinchOkHttpClient.Builder baseUrl(Optional<String> baseUrl)
Alias for calling Builder.baseUrl with
baseUrl.orElse(null).
-
responseValidation
final FinchOkHttpClient.Builder responseValidation(Boolean responseValidation)
Whether to call
validateon every response before returning it.Setting this to
trueis not forwards compatible with new types from the API for existing fields.Defaults to false, which means the shape of the response will not be validated upfront. Instead, validation will only occur for the parts of the response that are accessed.
-
timeout
final FinchOkHttpClient.Builder timeout(Timeout timeout)
Sets the maximum time allowed for various parts of an HTTP call's lifecycle, excluding retries.
Defaults to Timeout.default.
-
timeout
final FinchOkHttpClient.Builder timeout(Duration timeout)
Sets the maximum time allowed for a complete HTTP call, not including retries.
See Timeout.request for more details.
For fine-grained control, pass a Timeout object.
-
maxRetries
final FinchOkHttpClient.Builder maxRetries(Integer maxRetries)
The maximum number of times to retry failed requests, with a short exponential backoff between requests.
Only the following error types are retried:
Connection errors (for example, due to a network connectivity problem)
408 Request Timeout
409 Conflict
429 Rate Limit
5xx Internal
The API may also explicitly instruct the SDK to retry or not retry a request.
Defaults to 2.
-
logLevel
final FinchOkHttpClient.Builder logLevel(LogLevel logLevel)
The level at which to log request and response information.
fromEnv will set the level from environment variables. See LogLevel.fromEnv.
Defaults to LogLevel.fromEnv.
-
accessToken
final FinchOkHttpClient.Builder accessToken(String accessToken)
-
accessToken
final FinchOkHttpClient.Builder accessToken(Optional<String> accessToken)
Alias for calling Builder.accessToken with
accessToken.orElse(null).
-
clientId
final FinchOkHttpClient.Builder clientId(String clientId)
-
clientId
final FinchOkHttpClient.Builder clientId(Optional<String> clientId)
Alias for calling Builder.clientId with
clientId.orElse(null).
-
clientSecret
final FinchOkHttpClient.Builder clientSecret(String clientSecret)
-
clientSecret
final FinchOkHttpClient.Builder clientSecret(Optional<String> clientSecret)
Alias for calling Builder.clientSecret with
clientSecret.orElse(null).
-
webhookSecret
final FinchOkHttpClient.Builder webhookSecret(String webhookSecret)
-
webhookSecret
final FinchOkHttpClient.Builder webhookSecret(Optional<String> webhookSecret)
Alias for calling Builder.webhookSecret with
webhookSecret.orElse(null).
-
headers
final FinchOkHttpClient.Builder headers(Headers headers)
-
putHeader
final FinchOkHttpClient.Builder putHeader(String name, String value)
-
putHeaders
final FinchOkHttpClient.Builder putHeaders(String name, Iterable<String> values)
-
putAllHeaders
final FinchOkHttpClient.Builder putAllHeaders(Headers headers)
-
putAllHeaders
final FinchOkHttpClient.Builder putAllHeaders(Map<String, Iterable<String>> headers)
-
replaceHeaders
final FinchOkHttpClient.Builder replaceHeaders(String name, String value)
-
replaceHeaders
final FinchOkHttpClient.Builder replaceHeaders(String name, Iterable<String> values)
-
replaceAllHeaders
final FinchOkHttpClient.Builder replaceAllHeaders(Headers headers)
-
replaceAllHeaders
final FinchOkHttpClient.Builder replaceAllHeaders(Map<String, Iterable<String>> headers)
-
removeHeaders
final FinchOkHttpClient.Builder removeHeaders(String name)
-
removeAllHeaders
final FinchOkHttpClient.Builder removeAllHeaders(Set<String> names)
-
queryParams
final FinchOkHttpClient.Builder queryParams(QueryParams queryParams)
-
queryParams
final FinchOkHttpClient.Builder queryParams(Map<String, Iterable<String>> queryParams)
-
putQueryParam
final FinchOkHttpClient.Builder putQueryParam(String key, String value)
-
putQueryParams
final FinchOkHttpClient.Builder putQueryParams(String key, Iterable<String> values)
-
putAllQueryParams
final FinchOkHttpClient.Builder putAllQueryParams(QueryParams queryParams)
-
putAllQueryParams
final FinchOkHttpClient.Builder putAllQueryParams(Map<String, Iterable<String>> queryParams)
-
replaceQueryParams
final FinchOkHttpClient.Builder replaceQueryParams(String key, String value)
-
replaceQueryParams
final FinchOkHttpClient.Builder replaceQueryParams(String key, Iterable<String> values)
-
replaceAllQueryParams
final FinchOkHttpClient.Builder replaceAllQueryParams(QueryParams queryParams)
-
replaceAllQueryParams
final FinchOkHttpClient.Builder replaceAllQueryParams(Map<String, Iterable<String>> queryParams)
-
removeQueryParams
final FinchOkHttpClient.Builder removeQueryParams(String key)
-
removeAllQueryParams
final FinchOkHttpClient.Builder removeAllQueryParams(Set<String> keys)
-
fromEnv
final FinchOkHttpClient.Builder fromEnv()
Updates configuration using system properties and environment variables.
-
build
final FinchClient build()
Returns an immutable instance of FinchClient.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-