Package com.tryfinch.api.client.okhttp
Class FinchOkHttpClientAsync
-
- All Implemented Interfaces:
public final class FinchOkHttpClientAsyncA class that allows building an instance of FinchClientAsync with OkHttpClient as the underlying HttpClient.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinchOkHttpClientAsync.BuilderA builder for FinchOkHttpClientAsync.
-
Method Summary
Modifier and Type Method Description final static FinchOkHttpClientAsync.Builderbuilder()Returns a mutable builder for constructing an instance of FinchClientAsync. final static FinchClientAsyncfromEnv()Returns a client configured using system properties and environment variables. -
-
Method Detail
-
builder
final static FinchOkHttpClientAsync.Builder builder()
Returns a mutable builder for constructing an instance of FinchClientAsync.
-
fromEnv
final static FinchClientAsync fromEnv()
Returns a client configured using system properties and environment variables.
-
-
-
-