Class FinchOkHttpClientAsync.Builder
-
- All Implemented Interfaces:
public final class FinchOkHttpClientAsync.BuilderA builder for FinchOkHttpClientAsync.
-
-
Method Summary
-
-
Method Detail
-
dispatcherExecutorService
final FinchOkHttpClientAsync.Builder dispatcherExecutorService(ExecutorService dispatcherExecutorService)
The executor service to use for running HTTP requests.
Defaults to OkHttp's default executor service.
This class takes ownership of the executor service and shuts it down when closed.
-
dispatcherExecutorService
final FinchOkHttpClientAsync.Builder dispatcherExecutorService(Optional<ExecutorService> dispatcherExecutorService)
Alias for calling Builder.dispatcherExecutorService with
dispatcherExecutorService.orElse(null).
-
proxy
final FinchOkHttpClientAsync.Builder proxy(Proxy proxy)
-
proxy
final FinchOkHttpClientAsync.Builder proxy(Optional<Proxy> proxy)
Alias for calling Builder.proxy with
proxy.orElse(null).
-
sslSocketFactory
final FinchOkHttpClientAsync.Builder sslSocketFactory(SSLSocketFactory sslSocketFactory)
The socket factory used to secure HTTPS connections.
If this is set, then trustManager must also be set.
If unset, then the system default is used. Most applications should not call this method, and instead use the system default. The default include special optimizations that can be lost if the implementation is modified.
-
sslSocketFactory
final FinchOkHttpClientAsync.Builder sslSocketFactory(Optional<SSLSocketFactory> sslSocketFactory)
Alias for calling Builder.sslSocketFactory with
sslSocketFactory.orElse(null).
-
trustManager
final FinchOkHttpClientAsync.Builder trustManager(X509TrustManager trustManager)
The trust manager used to secure HTTPS connections.
If this is set, then sslSocketFactory must also be set.
If unset, then the system default is used. Most applications should not call this method, and instead use the system default. The default include special optimizations that can be lost if the implementation is modified.
-
trustManager
final FinchOkHttpClientAsync.Builder trustManager(Optional<X509TrustManager> trustManager)
Alias for calling Builder.trustManager with
trustManager.orElse(null).
-
hostnameVerifier
final FinchOkHttpClientAsync.Builder hostnameVerifier(HostnameVerifier hostnameVerifier)
The verifier used to confirm that response certificates apply to requested hostnames for HTTPS connections.
If unset, then a default hostname verifier is used.
-
hostnameVerifier
final FinchOkHttpClientAsync.Builder hostnameVerifier(Optional<HostnameVerifier> hostnameVerifier)
Alias for calling Builder.hostnameVerifier with
hostnameVerifier.orElse(null).
-
checkJacksonVersionCompatibility
final FinchOkHttpClientAsync.Builder checkJacksonVersionCompatibility(Boolean checkJacksonVersionCompatibility)
Whether to throw an exception if any of the Jackson versions detected at runtime are incompatible with the SDK's minimum supported Jackson version (2.13.4).
Defaults to true. Use extreme caution when disabling this option. There is no guarantee that the SDK will work correctly when using an incompatible Jackson version.
-
jsonMapper
final FinchOkHttpClientAsync.Builder jsonMapper(JsonMapper jsonMapper)
The Jackson JSON mapper to use for serializing and deserializing JSON.
Defaults to com.tryfinch.api.core.jsonMapper. The default is usually sufficient and rarely needs to be overridden.
-
streamHandlerExecutor
final FinchOkHttpClientAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
The executor to use for running AsyncStreamResponse.Handler callbacks.
Defaults to a dedicated cached thread pool.
This class takes ownership of the executor and shuts it down, if possible, when closed.
-
sleeper
final FinchOkHttpClientAsync.Builder sleeper(Sleeper sleeper)
The interface to use for delaying execution, like during retries.
This is primarily useful for using fake delays in tests.
Defaults to real execution delays.
This class takes ownership of the sleeper and closes it when closed.
-
clock
final FinchOkHttpClientAsync.Builder clock(Clock clock)
The clock to use for operations that require timing, like retries.
This is primarily useful for using a fake clock in tests.
Defaults to Clock.systemUTC.
-
baseUrl
final FinchOkHttpClientAsync.Builder baseUrl(String baseUrl)
The base URL to use for every request.
Defaults to the production environment:
https://api.tryfinch.com.
-
baseUrl
final FinchOkHttpClientAsync.Builder baseUrl(Optional<String> baseUrl)
Alias for calling Builder.baseUrl with
baseUrl.orElse(null).
-
responseValidation
final FinchOkHttpClientAsync.Builder responseValidation(Boolean responseValidation)
Whether to call
validateon every response before returning it.Defaults to false, which means the shape of the response will not be validated upfront. Instead, validation will only occur for the parts of the response that are accessed.
-
timeout
final FinchOkHttpClientAsync.Builder timeout(Timeout timeout)
Sets the maximum time allowed for various parts of an HTTP call's lifecycle, excluding retries.
Defaults to Timeout.default.
-
timeout
final FinchOkHttpClientAsync.Builder timeout(Duration timeout)
Sets the maximum time allowed for a complete HTTP call, not including retries.
See Timeout.request for more details.
For fine-grained control, pass a Timeout object.
-
maxRetries
final FinchOkHttpClientAsync.Builder maxRetries(Integer maxRetries)
The maximum number of times to retry failed requests, with a short exponential backoff between requests.
Only the following error types are retried:
Connection errors (for example, due to a network connectivity problem)
408 Request Timeout
409 Conflict
429 Rate Limit
5xx Internal
The API may also explicitly instruct the SDK to retry or not retry a request.
Defaults to 2.
-
accessToken
final FinchOkHttpClientAsync.Builder accessToken(String accessToken)
-
accessToken
final FinchOkHttpClientAsync.Builder accessToken(Optional<String> accessToken)
Alias for calling Builder.accessToken with
accessToken.orElse(null).
-
clientId
final FinchOkHttpClientAsync.Builder clientId(String clientId)
-
clientId
final FinchOkHttpClientAsync.Builder clientId(Optional<String> clientId)
Alias for calling Builder.clientId with
clientId.orElse(null).
-
clientSecret
final FinchOkHttpClientAsync.Builder clientSecret(String clientSecret)
-
clientSecret
final FinchOkHttpClientAsync.Builder clientSecret(Optional<String> clientSecret)
Alias for calling Builder.clientSecret with
clientSecret.orElse(null).
-
webhookSecret
final FinchOkHttpClientAsync.Builder webhookSecret(String webhookSecret)
-
webhookSecret
final FinchOkHttpClientAsync.Builder webhookSecret(Optional<String> webhookSecret)
Alias for calling Builder.webhookSecret with
webhookSecret.orElse(null).
-
headers
final FinchOkHttpClientAsync.Builder headers(Headers headers)
-
putHeader
final FinchOkHttpClientAsync.Builder putHeader(String name, String value)
-
putHeaders
final FinchOkHttpClientAsync.Builder putHeaders(String name, Iterable<String> values)
-
putAllHeaders
final FinchOkHttpClientAsync.Builder putAllHeaders(Headers headers)
-
putAllHeaders
final FinchOkHttpClientAsync.Builder putAllHeaders(Map<String, Iterable<String>> headers)
-
replaceHeaders
final FinchOkHttpClientAsync.Builder replaceHeaders(String name, String value)
-
replaceHeaders
final FinchOkHttpClientAsync.Builder replaceHeaders(String name, Iterable<String> values)
-
replaceAllHeaders
final FinchOkHttpClientAsync.Builder replaceAllHeaders(Headers headers)
-
replaceAllHeaders
final FinchOkHttpClientAsync.Builder replaceAllHeaders(Map<String, Iterable<String>> headers)
-
removeHeaders
final FinchOkHttpClientAsync.Builder removeHeaders(String name)
-
removeAllHeaders
final FinchOkHttpClientAsync.Builder removeAllHeaders(Set<String> names)
-
queryParams
final FinchOkHttpClientAsync.Builder queryParams(QueryParams queryParams)
-
queryParams
final FinchOkHttpClientAsync.Builder queryParams(Map<String, Iterable<String>> queryParams)
-
putQueryParam
final FinchOkHttpClientAsync.Builder putQueryParam(String key, String value)
-
putQueryParams
final FinchOkHttpClientAsync.Builder putQueryParams(String key, Iterable<String> values)
-
putAllQueryParams
final FinchOkHttpClientAsync.Builder putAllQueryParams(QueryParams queryParams)
-
putAllQueryParams
final FinchOkHttpClientAsync.Builder putAllQueryParams(Map<String, Iterable<String>> queryParams)
-
replaceQueryParams
final FinchOkHttpClientAsync.Builder replaceQueryParams(String key, String value)
-
replaceQueryParams
final FinchOkHttpClientAsync.Builder replaceQueryParams(String key, Iterable<String> values)
-
replaceAllQueryParams
final FinchOkHttpClientAsync.Builder replaceAllQueryParams(QueryParams queryParams)
-
replaceAllQueryParams
final FinchOkHttpClientAsync.Builder replaceAllQueryParams(Map<String, Iterable<String>> queryParams)
-
removeQueryParams
final FinchOkHttpClientAsync.Builder removeQueryParams(String key)
-
removeAllQueryParams
final FinchOkHttpClientAsync.Builder removeAllQueryParams(Set<String> keys)
-
fromEnv
final FinchOkHttpClientAsync.Builder fromEnv()
Updates configuration using system properties and environment variables.
-
build
final FinchClientAsync build()
Returns an immutable instance of FinchClientAsync.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-