Package com.tryfinch.api.client.okhttp
See: Description
-
Class Summary Class Description Builder A builder for FinchOkHttpClient. FinchOkHttpClient A class that allows building an instance of FinchClient with OkHttpClient as the underlying HttpClient. Builder A builder for FinchOkHttpClientAsync. FinchOkHttpClientAsync A class that allows building an instance of FinchClientAsync with OkHttpClient as the underlying HttpClient. Builder OkHttpClient