Class AccessTokenCreateParams
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Params
public final class AccessTokenCreateParams implements Params
Exchange the authorization code for an access token
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccessTokenCreateParams.BuilderA builder for AccessTokenCreateParams.
public final classAccessTokenCreateParams.CreateAccessTokenRequest
-
Method Summary
Modifier and Type Method Description final Stringcode()The authorization code received from the authorization server final Optional<String>clientId()The client ID for your application final Optional<String>clientSecret()The client secret for your application final Optional<String>redirectUri()The redirect URI used in the authorization request (optional) final JsonField<String>_code()Returns the raw JSON value of code. final JsonField<String>_clientId()Returns the raw JSON value of clientId. final JsonField<String>_clientSecret()Returns the raw JSON value of clientSecret. final JsonField<String>_redirectUri()Returns the raw JSON value of redirectUri. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final AccessTokenCreateParams.BuildertoBuilder()final AccessTokenCreateParams.CreateAccessTokenRequest_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccessTokenCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of AccessTokenCreateParams. -
-
Method Detail
-
clientSecret
final Optional<String> clientSecret()
The client secret for your application
-
redirectUri
final Optional<String> redirectUri()
The redirect URI used in the authorization request (optional)
-
_code
final JsonField<String> _code()
Returns the raw JSON value of code.
Unlike code, this method doesn't throw if the JSON field has an unexpected type.
-
_clientId
final JsonField<String> _clientId()
Returns the raw JSON value of clientId.
Unlike clientId, this method doesn't throw if the JSON field has an unexpected type.
-
_clientSecret
final JsonField<String> _clientSecret()
Returns the raw JSON value of clientSecret.
Unlike clientSecret, this method doesn't throw if the JSON field has an unexpected type.
-
_redirectUri
final JsonField<String> _redirectUri()
Returns the raw JSON value of redirectUri.
Unlike redirectUri, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final AccessTokenCreateParams.Builder toBuilder()
-
_body
final AccessTokenCreateParams.CreateAccessTokenRequest _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static AccessTokenCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of AccessTokenCreateParams.
The following fields are required:
.code()
-
-
-
-