Package com.tryfinch.api.models
Class AccessTokenCreateParams.Body
-
- All Implemented Interfaces:
public final class AccessTokenCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccessTokenCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringcode()final Optional<String>clientId()final Optional<String>clientSecret()final Optional<String>redirectUri()final JsonField<String>_code()Returns the raw JSON value of code. final JsonField<String>_clientId()Returns the raw JSON value of clientId. final JsonField<String>_clientSecret()Returns the raw JSON value of clientSecret. final JsonField<String>_redirectUri()Returns the raw JSON value of redirectUri. final Map<String, JsonValue>_additionalProperties()final AccessTokenCreateParams.Body.BuildertoBuilder()final AccessTokenCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccessTokenCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
clientSecret
final Optional<String> clientSecret()
-
redirectUri
final Optional<String> redirectUri()
-
_code
final JsonField<String> _code()
Returns the raw JSON value of code.
Unlike code, this method doesn't throw if the JSON field has an unexpected type.
-
_clientId
final JsonField<String> _clientId()
Returns the raw JSON value of clientId.
Unlike clientId, this method doesn't throw if the JSON field has an unexpected type.
-
_clientSecret
final JsonField<String> _clientSecret()
Returns the raw JSON value of clientSecret.
Unlike clientSecret, this method doesn't throw if the JSON field has an unexpected type.
-
_redirectUri
final JsonField<String> _redirectUri()
Returns the raw JSON value of redirectUri.
Unlike redirectUri, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccessTokenCreateParams.Body.Builder toBuilder()
-
validate
final AccessTokenCreateParams.Body validate()
-
builder
final static AccessTokenCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.code()
-
-
-
-