Class AccessTokenCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class AccessTokenCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
code
final AccessTokenCreateParams.Body.Builder code(String code)
-
code
final AccessTokenCreateParams.Body.Builder code(JsonField<String> code)
Sets Builder.code to an arbitrary JSON value.
You should usually call Builder.code with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
clientId
final AccessTokenCreateParams.Body.Builder clientId(String clientId)
-
clientId
final AccessTokenCreateParams.Body.Builder clientId(JsonField<String> clientId)
Sets Builder.clientId to an arbitrary JSON value.
You should usually call Builder.clientId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
clientSecret
final AccessTokenCreateParams.Body.Builder clientSecret(String clientSecret)
-
clientSecret
final AccessTokenCreateParams.Body.Builder clientSecret(JsonField<String> clientSecret)
Sets Builder.clientSecret to an arbitrary JSON value.
You should usually call Builder.clientSecret with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
redirectUri
final AccessTokenCreateParams.Body.Builder redirectUri(String redirectUri)
-
redirectUri
final AccessTokenCreateParams.Body.Builder redirectUri(JsonField<String> redirectUri)
Sets Builder.redirectUri to an arbitrary JSON value.
You should usually call Builder.redirectUri with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccessTokenCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccessTokenCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccessTokenCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccessTokenCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccessTokenCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccessTokenCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.code()
-
-
-
-