Class AccessTokenCreateParams.CreateAccessTokenRequest
-
- All Implemented Interfaces:
public final class AccessTokenCreateParams.CreateAccessTokenRequest
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccessTokenCreateParams.CreateAccessTokenRequest.BuilderA builder for CreateAccessTokenRequest.
-
Method Summary
Modifier and Type Method Description final Stringcode()The authorization code received from the authorization server final Optional<String>clientId()The client ID for your application final Optional<String>clientSecret()The client secret for your application final Optional<String>redirectUri()The redirect URI used in the authorization request (optional) final JsonField<String>_code()Returns the raw JSON value of code. final JsonField<String>_clientId()Returns the raw JSON value of clientId. final JsonField<String>_clientSecret()Returns the raw JSON value of clientSecret. final JsonField<String>_redirectUri()Returns the raw JSON value of redirectUri. final Map<String, JsonValue>_additionalProperties()final AccessTokenCreateParams.CreateAccessTokenRequest.BuildertoBuilder()final AccessTokenCreateParams.CreateAccessTokenRequestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccessTokenCreateParams.CreateAccessTokenRequest.Builderbuilder()Returns a mutable builder for constructing an instance of CreateAccessTokenRequest. -
-
Method Detail
-
clientSecret
final Optional<String> clientSecret()
The client secret for your application
-
redirectUri
final Optional<String> redirectUri()
The redirect URI used in the authorization request (optional)
-
_code
final JsonField<String> _code()
Returns the raw JSON value of code.
Unlike code, this method doesn't throw if the JSON field has an unexpected type.
-
_clientId
final JsonField<String> _clientId()
Returns the raw JSON value of clientId.
Unlike clientId, this method doesn't throw if the JSON field has an unexpected type.
-
_clientSecret
final JsonField<String> _clientSecret()
Returns the raw JSON value of clientSecret.
Unlike clientSecret, this method doesn't throw if the JSON field has an unexpected type.
-
_redirectUri
final JsonField<String> _redirectUri()
Returns the raw JSON value of redirectUri.
Unlike redirectUri, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccessTokenCreateParams.CreateAccessTokenRequest.Builder toBuilder()
-
validate
final AccessTokenCreateParams.CreateAccessTokenRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccessTokenCreateParams.CreateAccessTokenRequest.Builder builder()
Returns a mutable builder for constructing an instance of CreateAccessTokenRequest.
The following fields are required:
.code()
-
-
-
-