Class AccessTokenCreateParams.CreateAccessTokenRequest.Builder
-
- All Implemented Interfaces:
public final class AccessTokenCreateParams.CreateAccessTokenRequest.BuilderA builder for CreateAccessTokenRequest.
-
-
Method Summary
-
-
Method Detail
-
code
final AccessTokenCreateParams.CreateAccessTokenRequest.Builder code(String code)
The authorization code received from the authorization server
-
code
final AccessTokenCreateParams.CreateAccessTokenRequest.Builder code(JsonField<String> code)
Sets Builder.code to an arbitrary JSON value.
You should usually call Builder.code with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
clientId
final AccessTokenCreateParams.CreateAccessTokenRequest.Builder clientId(String clientId)
The client ID for your application
-
clientId
final AccessTokenCreateParams.CreateAccessTokenRequest.Builder clientId(JsonField<String> clientId)
Sets Builder.clientId to an arbitrary JSON value.
You should usually call Builder.clientId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
clientSecret
final AccessTokenCreateParams.CreateAccessTokenRequest.Builder clientSecret(String clientSecret)
The client secret for your application
-
clientSecret
final AccessTokenCreateParams.CreateAccessTokenRequest.Builder clientSecret(JsonField<String> clientSecret)
Sets Builder.clientSecret to an arbitrary JSON value.
You should usually call Builder.clientSecret with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
redirectUri
final AccessTokenCreateParams.CreateAccessTokenRequest.Builder redirectUri(String redirectUri)
The redirect URI used in the authorization request (optional)
-
redirectUri
final AccessTokenCreateParams.CreateAccessTokenRequest.Builder redirectUri(JsonField<String> redirectUri)
Sets Builder.redirectUri to an arbitrary JSON value.
You should usually call Builder.redirectUri with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccessTokenCreateParams.CreateAccessTokenRequest.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccessTokenCreateParams.CreateAccessTokenRequest.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccessTokenCreateParams.CreateAccessTokenRequest.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccessTokenCreateParams.CreateAccessTokenRequest.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccessTokenCreateParams.CreateAccessTokenRequest.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccessTokenCreateParams.CreateAccessTokenRequest build()
Returns an immutable instance of CreateAccessTokenRequest.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.code()
-
-
-
-