Class AccountCreateResponse.Builder
-
- All Implemented Interfaces:
public final class AccountCreateResponse.BuilderA builder for AccountCreateResponse.
-
-
Method Summary
-
-
Method Detail
-
accessToken
final AccountCreateResponse.Builder accessToken(String accessToken)
-
accessToken
final AccountCreateResponse.Builder accessToken(JsonField<String> accessToken)
Sets Builder.accessToken to an arbitrary JSON value.
You should usually call Builder.accessToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountId
@Deprecated(message = "deprecated") final AccountCreateResponse.Builder accountId(String accountId)
DEPRECATED Use
connection_idto associate a connection with an access token
-
accountId
@Deprecated(message = "deprecated") final AccountCreateResponse.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
authenticationType
final AccountCreateResponse.Builder authenticationType(AccountCreateResponse.AuthenticationType authenticationType)
-
authenticationType
final AccountCreateResponse.Builder authenticationType(JsonField<AccountCreateResponse.AuthenticationType> authenticationType)
Sets Builder.authenticationType to an arbitrary JSON value.
You should usually call Builder.authenticationType with a well-typed AuthenticationType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
companyId
@Deprecated(message = "deprecated") final AccountCreateResponse.Builder companyId(String companyId)
DEPRECATED Use
connection_idto associate a connection with an access token
-
companyId
@Deprecated(message = "deprecated") final AccountCreateResponse.Builder companyId(JsonField<String> companyId)
Sets Builder.companyId to an arbitrary JSON value.
You should usually call Builder.companyId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
connectionId
final AccountCreateResponse.Builder connectionId(String connectionId)
The ID of the new connection
-
connectionId
final AccountCreateResponse.Builder connectionId(JsonField<String> connectionId)
Sets Builder.connectionId to an arbitrary JSON value.
You should usually call Builder.connectionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entityId
final AccountCreateResponse.Builder entityId(String entityId)
The ID of the entity for this connection
-
entityId
final AccountCreateResponse.Builder entityId(JsonField<String> entityId)
Sets Builder.entityId to an arbitrary JSON value.
You should usually call Builder.entityId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
products
final AccountCreateResponse.Builder products(List<String> products)
-
products
final AccountCreateResponse.Builder products(JsonField<List<String>> products)
Sets Builder.products to an arbitrary JSON value.
You should usually call Builder.products with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addProduct
final AccountCreateResponse.Builder addProduct(String product)
-
providerId
final AccountCreateResponse.Builder providerId(String providerId)
The ID of the provider associated with the
access_token
-
providerId
final AccountCreateResponse.Builder providerId(JsonField<String> providerId)
Sets Builder.providerId to an arbitrary JSON value.
You should usually call Builder.providerId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountCreateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountCreateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountCreateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountCreateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountCreateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountCreateResponse build()
Returns an immutable instance of AccountCreateResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accessToken() .accountId() .authenticationType() .companyId() .connectionId() .entityId() .products() .providerId()
-
-
-
-