Class AccountDisconnectEntityParams
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Params
public final class AccountDisconnectEntityParams implements Params
Disconnect entity(s) from a connection without affecting other entities associated with the same connection.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountDisconnectEntityParams.BuilderA builder for AccountDisconnectEntityParams.
public final classAccountDisconnectEntityParams.DisconnectEntityRequest
-
Method Summary
Modifier and Type Method Description final List<String>entityIds()Array of entity UUIDs to disconnect. final JsonField<List<String>>_entityIds()Returns the raw JSON value of entityIds. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final AccountDisconnectEntityParams.BuildertoBuilder()final AccountDisconnectEntityParams.DisconnectEntityRequest_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountDisconnectEntityParams.Builderbuilder()Returns a mutable builder for constructing an instance of AccountDisconnectEntityParams. -
-
Method Detail
-
entityIds
final List<String> entityIds()
Array of entity UUIDs to disconnect. At least one entity ID must be provided.
-
_entityIds
final JsonField<List<String>> _entityIds()
Returns the raw JSON value of entityIds.
Unlike entityIds, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final AccountDisconnectEntityParams.Builder toBuilder()
-
_body
final AccountDisconnectEntityParams.DisconnectEntityRequest _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static AccountDisconnectEntityParams.Builder builder()
Returns a mutable builder for constructing an instance of AccountDisconnectEntityParams.
The following fields are required:
.entityIds()
-
-
-
-