Package com.tryfinch.api.models
Class AccountDisconnectEntityParams.DisconnectEntityRequest
-
- All Implemented Interfaces:
public final class AccountDisconnectEntityParams.DisconnectEntityRequest
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountDisconnectEntityParams.DisconnectEntityRequest.BuilderA builder for DisconnectEntityRequest.
-
Method Summary
Modifier and Type Method Description final List<String>entityIds()Array of entity UUIDs to disconnect. final JsonField<List<String>>_entityIds()Returns the raw JSON value of entityIds. final Map<String, JsonValue>_additionalProperties()final AccountDisconnectEntityParams.DisconnectEntityRequest.BuildertoBuilder()final AccountDisconnectEntityParams.DisconnectEntityRequestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountDisconnectEntityParams.DisconnectEntityRequest.Builderbuilder()Returns a mutable builder for constructing an instance of DisconnectEntityRequest. -
-
Method Detail
-
entityIds
final List<String> entityIds()
Array of entity UUIDs to disconnect. At least one entity ID must be provided.
-
_entityIds
final JsonField<List<String>> _entityIds()
Returns the raw JSON value of entityIds.
Unlike entityIds, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountDisconnectEntityParams.DisconnectEntityRequest.Builder toBuilder()
-
validate
final AccountDisconnectEntityParams.DisconnectEntityRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccountDisconnectEntityParams.DisconnectEntityRequest.Builder builder()
Returns a mutable builder for constructing an instance of DisconnectEntityRequest.
The following fields are required:
.entityIds()
-
-
-
-