Package com.tryfinch.api.models
Class AccountDisconnectEntityParams.DisconnectEntityRequest.Builder
-
- All Implemented Interfaces:
public final class AccountDisconnectEntityParams.DisconnectEntityRequest.BuilderA builder for DisconnectEntityRequest.
-
-
Method Summary
-
-
Method Detail
-
entityIds
final AccountDisconnectEntityParams.DisconnectEntityRequest.Builder entityIds(List<String> entityIds)
Array of entity UUIDs to disconnect. At least one entity ID must be provided.
-
entityIds
final AccountDisconnectEntityParams.DisconnectEntityRequest.Builder entityIds(JsonField<List<String>> entityIds)
Sets Builder.entityIds to an arbitrary JSON value.
You should usually call Builder.entityIds with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEntityId
final AccountDisconnectEntityParams.DisconnectEntityRequest.Builder addEntityId(String entityId)
-
additionalProperties
final AccountDisconnectEntityParams.DisconnectEntityRequest.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountDisconnectEntityParams.DisconnectEntityRequest.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountDisconnectEntityParams.DisconnectEntityRequest.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountDisconnectEntityParams.DisconnectEntityRequest.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountDisconnectEntityParams.DisconnectEntityRequest.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountDisconnectEntityParams.DisconnectEntityRequest build()
Returns an immutable instance of DisconnectEntityRequest.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.entityIds()
-
-
-
-