Package com.tryfinch.api.models
Class AccountIntrospectParams
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Params
public final class AccountIntrospectParams implements Params
Read account information associated with an
access_token
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountIntrospectParams.BuilderA builder for AccountIntrospectParams.
-
Method Summary
Modifier and Type Method Description final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final AccountIntrospectParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountIntrospectParamsnone()final static AccountIntrospectParams.Builderbuilder()Returns a mutable builder for constructing an instance of AccountIntrospectParams. -
-
Method Detail
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final AccountIntrospectParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static AccountIntrospectParams none()
-
builder
final static AccountIntrospectParams.Builder builder()
Returns a mutable builder for constructing an instance of AccountIntrospectParams.
-
-
-
-