Class AccountUpdateEvent.Builder
-
- All Implemented Interfaces:
public final class AccountUpdateEvent.BuilderA builder for AccountUpdateEvent.
-
-
Method Summary
-
-
Method Detail
-
accountId
@Deprecated(message = "deprecated") final AccountUpdateEvent.Builder accountId(String accountId)
DEPRECATED Unique Finch ID of the employer account used to make this connection. Use
connection_idinstead to identify the connection associated with this event.
-
accountId
@Deprecated(message = "deprecated") final AccountUpdateEvent.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
companyId
@Deprecated(message = "deprecated") final AccountUpdateEvent.Builder companyId(String companyId)
DEPRECATED Unique Finch ID of the company for which data has been updated. Use
connection_idinstead to identify the connection associated with this event.
-
companyId
@Deprecated(message = "deprecated") final AccountUpdateEvent.Builder companyId(JsonField<String> companyId)
Sets Builder.companyId to an arbitrary JSON value.
You should usually call Builder.companyId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
connectionId
final AccountUpdateEvent.Builder connectionId(String connectionId)
Unique Finch ID of the connection associated with the webhook event.
-
connectionId
final AccountUpdateEvent.Builder connectionId(JsonField<String> connectionId)
Sets Builder.connectionId to an arbitrary JSON value.
You should usually call Builder.connectionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entityId
final AccountUpdateEvent.Builder entityId(String entityId)
Unique Finch id of the entity for which data has been updated.
-
entityId
final AccountUpdateEvent.Builder entityId(JsonField<String> entityId)
Sets Builder.entityId to an arbitrary JSON value.
You should usually call Builder.entityId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
data
final AccountUpdateEvent.Builder data(AccountUpdateEvent.Data data)
-
data
final AccountUpdateEvent.Builder data(JsonField<AccountUpdateEvent.Data> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed Data value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final AccountUpdateEvent.Builder eventType(AccountUpdateEvent.EventType eventType)
-
eventType
final AccountUpdateEvent.Builder eventType(JsonField<AccountUpdateEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountUpdateEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountUpdateEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountUpdateEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountUpdateEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountUpdateEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountUpdateEvent build()
Returns an immutable instance of AccountUpdateEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountId() .companyId()
-
-
-
-