Class AccountUpdateEvent.Data.AuthenticationMethod
-
- All Implemented Interfaces:
public final class AccountUpdateEvent.Data.AuthenticationMethod
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountUpdateEvent.Data.AuthenticationMethod.BuilderA builder for AuthenticationMethod.
public final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFieldsThe supported data fields returned by our HR and payroll endpoints
public final classAccountUpdateEvent.Data.AuthenticationMethod.TypeThe type of authentication method.
-
Method Summary
-
-
Method Detail
-
benefitsSupport
final Optional<BenefitsSupport> benefitsSupport()
Each benefit type and their supported features. If the benefit type is not supported, the property will be null
-
supportedFields
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields> supportedFields()
The supported data fields returned by our HR and payroll endpoints
-
type
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.Type> type()
The type of authentication method.
-
_benefitsSupport
final JsonField<BenefitsSupport> _benefitsSupport()
Returns the raw JSON value of benefitsSupport.
Unlike benefitsSupport, this method doesn't throw if the JSON field has an unexpected type.
-
_supportedFields
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields> _supportedFields()
Returns the raw JSON value of supportedFields.
Unlike supportedFields, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountUpdateEvent.Data.AuthenticationMethod.Builder toBuilder()
-
validate
final AccountUpdateEvent.Data.AuthenticationMethod validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccountUpdateEvent.Data.AuthenticationMethod.Builder builder()
Returns a mutable builder for constructing an instance of AuthenticationMethod.
-
-
-
-