Class AccountUpdateEvent.Data.AuthenticationMethod.Builder
-
- All Implemented Interfaces:
public final class AccountUpdateEvent.Data.AuthenticationMethod.BuilderA builder for AuthenticationMethod.
-
-
Method Summary
-
-
Method Detail
-
benefitsSupport
final AccountUpdateEvent.Data.AuthenticationMethod.Builder benefitsSupport(BenefitsSupport benefitsSupport)
Each benefit type and their supported features. If the benefit type is not supported, the property will be null
-
benefitsSupport
final AccountUpdateEvent.Data.AuthenticationMethod.Builder benefitsSupport(Optional<BenefitsSupport> benefitsSupport)
Alias for calling Builder.benefitsSupport with
benefitsSupport.orElse(null).
-
benefitsSupport
final AccountUpdateEvent.Data.AuthenticationMethod.Builder benefitsSupport(JsonField<BenefitsSupport> benefitsSupport)
Sets Builder.benefitsSupport to an arbitrary JSON value.
You should usually call Builder.benefitsSupport with a well-typed BenefitsSupport value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
supportedFields
final AccountUpdateEvent.Data.AuthenticationMethod.Builder supportedFields(AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields supportedFields)
The supported data fields returned by our HR and payroll endpoints
-
supportedFields
final AccountUpdateEvent.Data.AuthenticationMethod.Builder supportedFields(Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields> supportedFields)
Alias for calling Builder.supportedFields with
supportedFields.orElse(null).
-
supportedFields
final AccountUpdateEvent.Data.AuthenticationMethod.Builder supportedFields(JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields> supportedFields)
Sets Builder.supportedFields to an arbitrary JSON value.
You should usually call Builder.supportedFields with a well-typed SupportedFields value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final AccountUpdateEvent.Data.AuthenticationMethod.Builder type(AccountUpdateEvent.Data.AuthenticationMethod.Type type)
The type of authentication method.
-
type
final AccountUpdateEvent.Data.AuthenticationMethod.Builder type(JsonField<AccountUpdateEvent.Data.AuthenticationMethod.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountUpdateEvent.Data.AuthenticationMethod.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountUpdateEvent.Data.AuthenticationMethod.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountUpdateEvent.Data.AuthenticationMethod build()
Returns an immutable instance of AuthenticationMethod.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-