Class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields
-
- All Implemented Interfaces:
public final class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFieldsThe supported data fields returned by our HR and payroll endpoints
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.BuilderA builder for SupportedFields.
public final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFieldspublic final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFieldspublic final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFieldspublic final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFieldspublic final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayGroupFieldspublic final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFieldspublic final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields
-
Method Summary
-
-
Method Detail
-
company
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields> company()
-
directory
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields> directory()
-
employment
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields> employment()
-
individual
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields> individual()
-
payGroup
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayGroupFields> payGroup()
-
payStatement
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields> payStatement()
-
payment
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields> payment()
-
_company
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields> _company()
Returns the raw JSON value of company.
Unlike company, this method doesn't throw if the JSON field has an unexpected type.
-
_directory
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields> _directory()
Returns the raw JSON value of directory.
Unlike directory, this method doesn't throw if the JSON field has an unexpected type.
-
_employment
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields> _employment()
Returns the raw JSON value of employment.
Unlike employment, this method doesn't throw if the JSON field has an unexpected type.
-
_individual
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields> _individual()
Returns the raw JSON value of individual.
Unlike individual, this method doesn't throw if the JSON field has an unexpected type.
-
_payGroup
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayGroupFields> _payGroup()
Returns the raw JSON value of payGroup.
Unlike payGroup, this method doesn't throw if the JSON field has an unexpected type.
-
_payStatement
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields> _payStatement()
Returns the raw JSON value of payStatement.
Unlike payStatement, this method doesn't throw if the JSON field has an unexpected type.
-
_payment
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields> _payment()
Returns the raw JSON value of payment.
Unlike payment, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.Builder builder()
Returns a mutable builder for constructing an instance of SupportedFields.
-
-
-
-