Class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.Builder
-
- All Implemented Interfaces:
public final class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.BuilderA builder for SupportedFields.
-
-
Method Summary
-
-
Method Detail
-
company
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.Builder company(AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields company)
-
company
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.Builder company(JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields> company)
Sets Builder.company to an arbitrary JSON value.
You should usually call Builder.company with a well-typed SupportedCompanyFields value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
directory
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.Builder directory(AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields directory)
-
directory
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.Builder directory(JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields> directory)
Sets Builder.directory to an arbitrary JSON value.
You should usually call Builder.directory with a well-typed SupportedDirectoryFields value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
employment
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.Builder employment(AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields employment)
-
employment
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.Builder employment(JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields> employment)
Sets Builder.employment to an arbitrary JSON value.
You should usually call Builder.employment with a well-typed SupportedEmploymentFields value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
individual
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.Builder individual(AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields individual)
-
individual
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.Builder individual(JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields> individual)
Sets Builder.individual to an arbitrary JSON value.
You should usually call Builder.individual with a well-typed SupportedIndividualFields value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
payGroup
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.Builder payGroup(AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayGroupFields payGroup)
-
payGroup
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.Builder payGroup(JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayGroupFields> payGroup)
Sets Builder.payGroup to an arbitrary JSON value.
You should usually call Builder.payGroup with a well-typed SupportedPayGroupFields value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
payStatement
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.Builder payStatement(AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields payStatement)
-
payStatement
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.Builder payStatement(JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields> payStatement)
Sets Builder.payStatement to an arbitrary JSON value.
You should usually call Builder.payStatement with a well-typed SupportedPayStatementFields value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
payment
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.Builder payment(AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields payment)
-
payment
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.Builder payment(JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields> payment)
Sets Builder.payment to an arbitrary JSON value.
You should usually call Builder.payment with a well-typed SupportedPaymentFields value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields build()
Returns an immutable instance of SupportedFields.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-