Class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields
-
- All Implemented Interfaces:
public final class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.BuilderA builder for SupportedCompanyFields.
public final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accountspublic final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Departmentspublic final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Entitypublic final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Locations
-
Method Summary
-
-
Method Detail
-
accounts
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accounts> accounts()
-
departments
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Departments> departments()
-
entity
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Entity> entity()
-
locations
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Locations> locations()
-
primaryEmail
final Optional<Boolean> primaryEmail()
-
primaryPhoneNumber
final Optional<Boolean> primaryPhoneNumber()
-
_id
final JsonField<Boolean> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accounts
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accounts> _accounts()
Returns the raw JSON value of accounts.
Unlike accounts, this method doesn't throw if the JSON field has an unexpected type.
-
_departments
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Departments> _departments()
Returns the raw JSON value of departments.
Unlike departments, this method doesn't throw if the JSON field has an unexpected type.
-
_ein
final JsonField<Boolean> _ein()
Returns the raw JSON value of ein.
Unlike ein, this method doesn't throw if the JSON field has an unexpected type.
-
_entity
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Entity> _entity()
Returns the raw JSON value of entity.
Unlike entity, this method doesn't throw if the JSON field has an unexpected type.
-
_legalName
final JsonField<Boolean> _legalName()
Returns the raw JSON value of legalName.
Unlike legalName, this method doesn't throw if the JSON field has an unexpected type.
-
_locations
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Locations> _locations()
Returns the raw JSON value of locations.
Unlike locations, this method doesn't throw if the JSON field has an unexpected type.
-
_primaryEmail
final JsonField<Boolean> _primaryEmail()
Returns the raw JSON value of primaryEmail.
Unlike primaryEmail, this method doesn't throw if the JSON field has an unexpected type.
-
_primaryPhoneNumber
final JsonField<Boolean> _primaryPhoneNumber()
Returns the raw JSON value of primaryPhoneNumber.
Unlike primaryPhoneNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Builder toBuilder()
-
validate
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Builder builder()
Returns a mutable builder for constructing an instance of SupportedCompanyFields.
-
-
-
-