Class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accounts.Builder
-
- All Implemented Interfaces:
public final class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accounts.BuilderA builder for Accounts.
-
-
Method Summary
-
-
Method Detail
-
accountName
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accounts.Builder accountName(Boolean accountName)
-
accountName
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accounts.Builder accountName(JsonField<Boolean> accountName)
Sets Builder.accountName to an arbitrary JSON value.
You should usually call Builder.accountName with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountNumber
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accounts.Builder accountNumber(Boolean accountNumber)
-
accountNumber
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accounts.Builder accountNumber(JsonField<Boolean> accountNumber)
Sets Builder.accountNumber to an arbitrary JSON value.
You should usually call Builder.accountNumber with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountType
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accounts.Builder accountType(Boolean accountType)
-
accountType
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accounts.Builder accountType(JsonField<Boolean> accountType)
Sets Builder.accountType to an arbitrary JSON value.
You should usually call Builder.accountType with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
institutionName
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accounts.Builder institutionName(Boolean institutionName)
-
institutionName
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accounts.Builder institutionName(JsonField<Boolean> institutionName)
Sets Builder.institutionName to an arbitrary JSON value.
You should usually call Builder.institutionName with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
routingNumber
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accounts.Builder routingNumber(Boolean routingNumber)
-
routingNumber
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accounts.Builder routingNumber(JsonField<Boolean> routingNumber)
Sets Builder.routingNumber to an arbitrary JSON value.
You should usually call Builder.routingNumber with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accounts.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accounts.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accounts.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accounts.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accounts.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accounts build()
Returns an immutable instance of Accounts.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-