Class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Builder
-
- All Implemented Interfaces:
public final class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.BuilderA builder for SupportedCompanyFields.
-
-
Method Summary
-
-
Method Detail
-
id
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Builder id(Boolean id)
-
id
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Builder id(JsonField<Boolean> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accounts
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Builder accounts(AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accounts accounts)
-
accounts
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Builder accounts(JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accounts> accounts)
Sets Builder.accounts to an arbitrary JSON value.
You should usually call Builder.accounts with a well-typed Accounts value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
departments
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Builder departments(AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Departments departments)
-
departments
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Builder departments(JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Departments> departments)
Sets Builder.departments to an arbitrary JSON value.
You should usually call Builder.departments with a well-typed Departments value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ein
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Builder ein(Boolean ein)
-
ein
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Builder ein(JsonField<Boolean> ein)
Sets Builder.ein to an arbitrary JSON value.
You should usually call Builder.ein with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entity
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Builder entity(AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Entity entity)
-
entity
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Builder entity(JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Entity> entity)
Sets Builder.entity to an arbitrary JSON value.
You should usually call Builder.entity with a well-typed Entity value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
legalName
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Builder legalName(Boolean legalName)
-
legalName
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Builder legalName(JsonField<Boolean> legalName)
Sets Builder.legalName to an arbitrary JSON value.
You should usually call Builder.legalName with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
locations
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Builder locations(AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Locations locations)
-
locations
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Builder locations(JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Locations> locations)
Sets Builder.locations to an arbitrary JSON value.
You should usually call Builder.locations with a well-typed Locations value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
primaryEmail
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Builder primaryEmail(Boolean primaryEmail)
-
primaryEmail
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Builder primaryEmail(JsonField<Boolean> primaryEmail)
Sets Builder.primaryEmail to an arbitrary JSON value.
You should usually call Builder.primaryEmail with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
primaryPhoneNumber
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Builder primaryPhoneNumber(Boolean primaryPhoneNumber)
-
primaryPhoneNumber
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Builder primaryPhoneNumber(JsonField<Boolean> primaryPhoneNumber)
Sets Builder.primaryPhoneNumber to an arbitrary JSON value.
You should usually call Builder.primaryPhoneNumber with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields build()
Returns an immutable instance of SupportedCompanyFields.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-