Package com.tryfinch.api.models
Class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Entity
-
- All Implemented Interfaces:
public final class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Entity
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Entity.BuilderA builder for Entity.
-
Method Summary
Modifier and Type Method Description final Optional<Boolean>subtype()final Optional<Boolean>type()final JsonField<Boolean>_subtype()Returns the raw JSON value of subtype. final JsonField<Boolean>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Entity.BuildertoBuilder()final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Entityvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Entity.Builderbuilder()Returns a mutable builder for constructing an instance of Entity. -
-
Method Detail
-
_subtype
final JsonField<Boolean> _subtype()
Returns the raw JSON value of subtype.
Unlike subtype, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<Boolean> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Entity.Builder toBuilder()
-
validate
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Entity validate()
-
builder
final static AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Entity.Builder builder()
Returns a mutable builder for constructing an instance of Entity.
-
-
-
-