Package com.tryfinch.api.models
Class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields
-
- All Implemented Interfaces:
public final class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.BuilderA builder for SupportedDirectoryFields.
public final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individualspublic final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Paging
-
Method Summary
-
-
Method Detail
-
individuals
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals> individuals()
-
paging
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Paging> paging()
-
_individuals
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals> _individuals()
Returns the raw JSON value of individuals.
Unlike individuals, this method doesn't throw if the JSON field has an unexpected type.
-
_paging
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Paging> _paging()
Returns the raw JSON value of paging.
Unlike paging, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Builder toBuilder()
-
validate
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Builder builder()
Returns a mutable builder for constructing an instance of SupportedDirectoryFields.
-
-
-
-