Class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals
-
- All Implemented Interfaces:
public final class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.BuilderA builder for Individuals.
public final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.Manager
-
Method Summary
-
-
Method Detail
-
department
final Optional<Boolean> department()
-
manager
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.Manager> manager()
-
middleName
final Optional<Boolean> middleName()
-
_id
final JsonField<Boolean> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_department
final JsonField<Boolean> _department()
Returns the raw JSON value of department.
Unlike department, this method doesn't throw if the JSON field has an unexpected type.
-
_firstName
final JsonField<Boolean> _firstName()
Returns the raw JSON value of firstName.
Unlike firstName, this method doesn't throw if the JSON field has an unexpected type.
-
_isActive
final JsonField<Boolean> _isActive()
Returns the raw JSON value of isActive.
Unlike isActive, this method doesn't throw if the JSON field has an unexpected type.
-
_lastName
final JsonField<Boolean> _lastName()
Returns the raw JSON value of lastName.
Unlike lastName, this method doesn't throw if the JSON field has an unexpected type.
-
_manager
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.Manager> _manager()
Returns the raw JSON value of manager.
Unlike manager, this method doesn't throw if the JSON field has an unexpected type.
-
_middleName
final JsonField<Boolean> _middleName()
Returns the raw JSON value of middleName.
Unlike middleName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.Builder toBuilder()
-
validate
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals validate()
-
builder
final static AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.Builder builder()
Returns a mutable builder for constructing an instance of Individuals.
-
-
-
-