Class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.Builder
-
- All Implemented Interfaces:
public final class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.BuilderA builder for Individuals.
-
-
Method Summary
-
-
Method Detail
-
id
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.Builder id(Boolean id)
-
id
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.Builder id(JsonField<Boolean> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
department
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.Builder department(Boolean department)
-
department
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.Builder department(JsonField<Boolean> department)
Sets Builder.department to an arbitrary JSON value.
You should usually call Builder.department with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
firstName
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.Builder firstName(Boolean firstName)
-
firstName
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.Builder firstName(JsonField<Boolean> firstName)
Sets Builder.firstName to an arbitrary JSON value.
You should usually call Builder.firstName with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
isActive
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.Builder isActive(Boolean isActive)
-
isActive
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.Builder isActive(JsonField<Boolean> isActive)
Sets Builder.isActive to an arbitrary JSON value.
You should usually call Builder.isActive with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastName
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.Builder lastName(Boolean lastName)
-
lastName
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.Builder lastName(JsonField<Boolean> lastName)
Sets Builder.lastName to an arbitrary JSON value.
You should usually call Builder.lastName with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
manager
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.Builder manager(AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.Manager manager)
-
manager
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.Builder manager(JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.Manager> manager)
Sets Builder.manager to an arbitrary JSON value.
You should usually call Builder.manager with a well-typed Manager value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
middleName
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.Builder middleName(Boolean middleName)
-
middleName
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.Builder middleName(JsonField<Boolean> middleName)
Sets Builder.middleName to an arbitrary JSON value.
You should usually call Builder.middleName with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals build()
Returns an immutable instance of Individuals.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-