Package com.tryfinch.api.models
Class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Paging
-
- All Implemented Interfaces:
public final class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Paging
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Paging.BuilderA builder for Paging.
-
Method Summary
Modifier and Type Method Description final Optional<Boolean>count()final Optional<Boolean>offset()final JsonField<Boolean>_count()Returns the raw JSON value of count. final JsonField<Boolean>_offset()Returns the raw JSON value of offset. final Map<String, JsonValue>_additionalProperties()final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Paging.BuildertoBuilder()final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Pagingvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Paging.Builderbuilder()Returns a mutable builder for constructing an instance of Paging. -
-
Method Detail
-
_count
final JsonField<Boolean> _count()
Returns the raw JSON value of count.
Unlike count, this method doesn't throw if the JSON field has an unexpected type.
-
_offset
final JsonField<Boolean> _offset()
Returns the raw JSON value of offset.
Unlike offset, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Paging.Builder toBuilder()
-
validate
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Paging validate()
-
builder
final static AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Paging.Builder builder()
Returns a mutable builder for constructing an instance of Paging.
-
-
-
-