Class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields
-
- All Implemented Interfaces:
public final class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.BuilderA builder for SupportedEmploymentFields.
public final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Departmentpublic final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Employmentpublic final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Incomepublic final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Locationpublic final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Manager
-
Method Summary
-
-
Method Detail
-
customFields
final Optional<Boolean> customFields()
-
department
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Department> department()
-
employment
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Employment> employment()
-
employmentStatus
final Optional<Boolean> employmentStatus()
-
income
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Income> income()
-
incomeHistory
final Optional<Boolean> incomeHistory()
-
location
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Location> location()
-
manager
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Manager> manager()
-
middleName
final Optional<Boolean> middleName()
-
_id
final JsonField<Boolean> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_classCode
final JsonField<Boolean> _classCode()
Returns the raw JSON value of classCode.
Unlike classCode, this method doesn't throw if the JSON field has an unexpected type.
-
_customFields
final JsonField<Boolean> _customFields()
Returns the raw JSON value of customFields.
Unlike customFields, this method doesn't throw if the JSON field has an unexpected type.
-
_department
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Department> _department()
Returns the raw JSON value of department.
Unlike department, this method doesn't throw if the JSON field has an unexpected type.
-
_employment
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Employment> _employment()
Returns the raw JSON value of employment.
Unlike employment, this method doesn't throw if the JSON field has an unexpected type.
-
_employmentStatus
final JsonField<Boolean> _employmentStatus()
Returns the raw JSON value of employmentStatus.
Unlike employmentStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_endDate
final JsonField<Boolean> _endDate()
Returns the raw JSON value of endDate.
Unlike endDate, this method doesn't throw if the JSON field has an unexpected type.
-
_firstName
final JsonField<Boolean> _firstName()
Returns the raw JSON value of firstName.
Unlike firstName, this method doesn't throw if the JSON field has an unexpected type.
-
_income
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Income> _income()
Returns the raw JSON value of income.
Unlike income, this method doesn't throw if the JSON field has an unexpected type.
-
_incomeHistory
final JsonField<Boolean> _incomeHistory()
Returns the raw JSON value of incomeHistory.
Unlike incomeHistory, this method doesn't throw if the JSON field has an unexpected type.
-
_isActive
final JsonField<Boolean> _isActive()
Returns the raw JSON value of isActive.
Unlike isActive, this method doesn't throw if the JSON field has an unexpected type.
-
_lastName
final JsonField<Boolean> _lastName()
Returns the raw JSON value of lastName.
Unlike lastName, this method doesn't throw if the JSON field has an unexpected type.
-
_location
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Location> _location()
Returns the raw JSON value of location.
Unlike location, this method doesn't throw if the JSON field has an unexpected type.
-
_manager
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Manager> _manager()
Returns the raw JSON value of manager.
Unlike manager, this method doesn't throw if the JSON field has an unexpected type.
-
_middleName
final JsonField<Boolean> _middleName()
Returns the raw JSON value of middleName.
Unlike middleName, this method doesn't throw if the JSON field has an unexpected type.
-
_startDate
final JsonField<Boolean> _startDate()
Returns the raw JSON value of startDate.
Unlike startDate, this method doesn't throw if the JSON field has an unexpected type.
-
_title
final JsonField<Boolean> _title()
Returns the raw JSON value of title.
Unlike title, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder toBuilder()
-
validate
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder builder()
Returns a mutable builder for constructing an instance of SupportedEmploymentFields.
-
-
-
-