Class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder
-
- All Implemented Interfaces:
public final class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.BuilderA builder for SupportedEmploymentFields.
-
-
Method Summary
-
-
Method Detail
-
id
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder id(Boolean id)
-
id
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder id(JsonField<Boolean> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
classCode
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder classCode(Boolean classCode)
-
classCode
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder classCode(JsonField<Boolean> classCode)
Sets Builder.classCode to an arbitrary JSON value.
You should usually call Builder.classCode with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customFields
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder customFields(Boolean customFields)
-
customFields
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder customFields(JsonField<Boolean> customFields)
Sets Builder.customFields to an arbitrary JSON value.
You should usually call Builder.customFields with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
department
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder department(AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Department department)
-
department
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder department(JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Department> department)
Sets Builder.department to an arbitrary JSON value.
You should usually call Builder.department with a well-typed Department value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
employment
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder employment(AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Employment employment)
-
employment
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder employment(JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Employment> employment)
Sets Builder.employment to an arbitrary JSON value.
You should usually call Builder.employment with a well-typed Employment value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
employmentStatus
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder employmentStatus(Boolean employmentStatus)
-
employmentStatus
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder employmentStatus(JsonField<Boolean> employmentStatus)
Sets Builder.employmentStatus to an arbitrary JSON value.
You should usually call Builder.employmentStatus with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
endDate
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder endDate(Boolean endDate)
-
endDate
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder endDate(JsonField<Boolean> endDate)
Sets Builder.endDate to an arbitrary JSON value.
You should usually call Builder.endDate with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
firstName
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder firstName(Boolean firstName)
-
firstName
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder firstName(JsonField<Boolean> firstName)
Sets Builder.firstName to an arbitrary JSON value.
You should usually call Builder.firstName with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
income
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder income(AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Income income)
-
income
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder income(JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Income> income)
Sets Builder.income to an arbitrary JSON value.
You should usually call Builder.income with a well-typed Income value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
incomeHistory
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder incomeHistory(Boolean incomeHistory)
-
incomeHistory
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder incomeHistory(JsonField<Boolean> incomeHistory)
Sets Builder.incomeHistory to an arbitrary JSON value.
You should usually call Builder.incomeHistory with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
isActive
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder isActive(Boolean isActive)
-
isActive
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder isActive(JsonField<Boolean> isActive)
Sets Builder.isActive to an arbitrary JSON value.
You should usually call Builder.isActive with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastName
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder lastName(Boolean lastName)
-
lastName
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder lastName(JsonField<Boolean> lastName)
Sets Builder.lastName to an arbitrary JSON value.
You should usually call Builder.lastName with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
location
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder location(AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Location location)
-
location
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder location(JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Location> location)
Sets Builder.location to an arbitrary JSON value.
You should usually call Builder.location with a well-typed Location value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
manager
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder manager(AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Manager manager)
-
manager
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder manager(JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Manager> manager)
Sets Builder.manager to an arbitrary JSON value.
You should usually call Builder.manager with a well-typed Manager value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
middleName
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder middleName(Boolean middleName)
-
middleName
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder middleName(JsonField<Boolean> middleName)
Sets Builder.middleName to an arbitrary JSON value.
You should usually call Builder.middleName with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
startDate
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder startDate(Boolean startDate)
-
startDate
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder startDate(JsonField<Boolean> startDate)
Sets Builder.startDate to an arbitrary JSON value.
You should usually call Builder.startDate with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
title
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder title(Boolean title)
-
title
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder title(JsonField<Boolean> title)
Sets Builder.title to an arbitrary JSON value.
You should usually call Builder.title with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields build()
Returns an immutable instance of SupportedEmploymentFields.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-