Class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields
-
- All Implemented Interfaces:
public final class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.BuilderA builder for SupportedIndividualFields.
public final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Emailspublic final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumberspublic final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Residence
-
Method Summary
-
-
Method Detail
-
emails
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Emails> emails()
-
encryptedSsn
final Optional<Boolean> encryptedSsn()
-
middleName
final Optional<Boolean> middleName()
-
phoneNumbers
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers> phoneNumbers()
-
preferredName
final Optional<Boolean> preferredName()
-
residence
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Residence> residence()
-
_id
final JsonField<Boolean> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_dob
final JsonField<Boolean> _dob()
Returns the raw JSON value of dob.
Unlike dob, this method doesn't throw if the JSON field has an unexpected type.
-
_emails
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Emails> _emails()
Returns the raw JSON value of emails.
Unlike emails, this method doesn't throw if the JSON field has an unexpected type.
-
_encryptedSsn
final JsonField<Boolean> _encryptedSsn()
Returns the raw JSON value of encryptedSsn.
Unlike encryptedSsn, this method doesn't throw if the JSON field has an unexpected type.
-
_ethnicity
final JsonField<Boolean> _ethnicity()
Returns the raw JSON value of ethnicity.
Unlike ethnicity, this method doesn't throw if the JSON field has an unexpected type.
-
_firstName
final JsonField<Boolean> _firstName()
Returns the raw JSON value of firstName.
Unlike firstName, this method doesn't throw if the JSON field has an unexpected type.
-
_gender
final JsonField<Boolean> _gender()
Returns the raw JSON value of gender.
Unlike gender, this method doesn't throw if the JSON field has an unexpected type.
-
_lastName
final JsonField<Boolean> _lastName()
Returns the raw JSON value of lastName.
Unlike lastName, this method doesn't throw if the JSON field has an unexpected type.
-
_middleName
final JsonField<Boolean> _middleName()
Returns the raw JSON value of middleName.
Unlike middleName, this method doesn't throw if the JSON field has an unexpected type.
-
_phoneNumbers
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers> _phoneNumbers()
Returns the raw JSON value of phoneNumbers.
Unlike phoneNumbers, this method doesn't throw if the JSON field has an unexpected type.
-
_preferredName
final JsonField<Boolean> _preferredName()
Returns the raw JSON value of preferredName.
Unlike preferredName, this method doesn't throw if the JSON field has an unexpected type.
-
_residence
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Residence> _residence()
Returns the raw JSON value of residence.
Unlike residence, this method doesn't throw if the JSON field has an unexpected type.
-
_ssn
final JsonField<Boolean> _ssn()
Returns the raw JSON value of ssn.
Unlike ssn, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder toBuilder()
-
validate
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder builder()
Returns a mutable builder for constructing an instance of SupportedIndividualFields.
-
-
-
-