Class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder
-
- All Implemented Interfaces:
public final class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.BuilderA builder for SupportedIndividualFields.
-
-
Method Summary
-
-
Method Detail
-
id
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder id(Boolean id)
-
id
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder id(JsonField<Boolean> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
dob
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder dob(Boolean dob)
-
dob
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder dob(JsonField<Boolean> dob)
Sets Builder.dob to an arbitrary JSON value.
You should usually call Builder.dob with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
emails
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder emails(AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Emails emails)
-
emails
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder emails(JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Emails> emails)
Sets Builder.emails to an arbitrary JSON value.
You should usually call Builder.emails with a well-typed Emails value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
encryptedSsn
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder encryptedSsn(Boolean encryptedSsn)
-
encryptedSsn
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder encryptedSsn(JsonField<Boolean> encryptedSsn)
Sets Builder.encryptedSsn to an arbitrary JSON value.
You should usually call Builder.encryptedSsn with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ethnicity
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder ethnicity(Boolean ethnicity)
-
ethnicity
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder ethnicity(JsonField<Boolean> ethnicity)
Sets Builder.ethnicity to an arbitrary JSON value.
You should usually call Builder.ethnicity with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
firstName
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder firstName(Boolean firstName)
-
firstName
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder firstName(JsonField<Boolean> firstName)
Sets Builder.firstName to an arbitrary JSON value.
You should usually call Builder.firstName with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
gender
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder gender(Boolean gender)
-
gender
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder gender(JsonField<Boolean> gender)
Sets Builder.gender to an arbitrary JSON value.
You should usually call Builder.gender with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastName
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder lastName(Boolean lastName)
-
lastName
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder lastName(JsonField<Boolean> lastName)
Sets Builder.lastName to an arbitrary JSON value.
You should usually call Builder.lastName with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
middleName
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder middleName(Boolean middleName)
-
middleName
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder middleName(JsonField<Boolean> middleName)
Sets Builder.middleName to an arbitrary JSON value.
You should usually call Builder.middleName with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
phoneNumbers
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder phoneNumbers(AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers phoneNumbers)
-
phoneNumbers
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder phoneNumbers(JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers> phoneNumbers)
Sets Builder.phoneNumbers to an arbitrary JSON value.
You should usually call Builder.phoneNumbers with a well-typed PhoneNumbers value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
preferredName
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder preferredName(Boolean preferredName)
-
preferredName
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder preferredName(JsonField<Boolean> preferredName)
Sets Builder.preferredName to an arbitrary JSON value.
You should usually call Builder.preferredName with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
residence
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder residence(AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Residence residence)
-
residence
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder residence(JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Residence> residence)
Sets Builder.residence to an arbitrary JSON value.
You should usually call Builder.residence with a well-typed Residence value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ssn
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder ssn(Boolean ssn)
-
ssn
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder ssn(JsonField<Boolean> ssn)
Sets Builder.ssn to an arbitrary JSON value.
You should usually call Builder.ssn with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields build()
Returns an immutable instance of SupportedIndividualFields.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-