Package com.tryfinch.api.models
Class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers
-
- All Implemented Interfaces:
public final class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers.BuilderA builder for PhoneNumbers.
-
Method Summary
Modifier and Type Method Description final Optional<Boolean>data()final Optional<Boolean>type()final JsonField<Boolean>_data()Returns the raw JSON value of data. final JsonField<Boolean>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers.BuildertoBuilder()final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbersvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers.Builderbuilder()Returns a mutable builder for constructing an instance of PhoneNumbers. -
-
Method Detail
-
_data
final JsonField<Boolean> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<Boolean> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers.Builder toBuilder()
-
validate
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers.Builder builder()
Returns a mutable builder for constructing an instance of PhoneNumbers.
-
-
-
-