Package com.tryfinch.api.models
Class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers.Builder
-
- All Implemented Interfaces:
public final class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers.BuilderA builder for PhoneNumbers.
-
-
Method Summary
-
-
Method Detail
-
data
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers.Builder data(Boolean data)
-
data
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers.Builder data(JsonField<Boolean> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers.Builder type(Boolean type)
-
type
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers.Builder type(JsonField<Boolean> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers build()
Returns an immutable instance of PhoneNumbers.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-