Class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Residence.Builder
-
- All Implemented Interfaces:
public final class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Residence.BuilderA builder for Residence.
-
-
Method Summary
-
-
Method Detail
-
city
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Residence.Builder city(Boolean city)
-
city
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Residence.Builder city(JsonField<Boolean> city)
Sets Builder.city to an arbitrary JSON value.
You should usually call Builder.city with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
country
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Residence.Builder country(Boolean country)
-
country
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Residence.Builder country(JsonField<Boolean> country)
Sets Builder.country to an arbitrary JSON value.
You should usually call Builder.country with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
line1
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Residence.Builder line1(Boolean line1)
-
line1
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Residence.Builder line1(JsonField<Boolean> line1)
Sets Builder.line1 to an arbitrary JSON value.
You should usually call Builder.line1 with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
line2
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Residence.Builder line2(Boolean line2)
-
line2
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Residence.Builder line2(JsonField<Boolean> line2)
Sets Builder.line2 to an arbitrary JSON value.
You should usually call Builder.line2 with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
postalCode
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Residence.Builder postalCode(Boolean postalCode)
-
postalCode
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Residence.Builder postalCode(JsonField<Boolean> postalCode)
Sets Builder.postalCode to an arbitrary JSON value.
You should usually call Builder.postalCode with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
state
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Residence.Builder state(Boolean state)
-
state
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Residence.Builder state(JsonField<Boolean> state)
Sets Builder.state to an arbitrary JSON value.
You should usually call Builder.state with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Residence.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Residence.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Residence.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Residence.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Residence.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedIndividualFields.Residence build()
Returns an immutable instance of Residence.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-