Class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements
-
- All Implemented Interfaces:
public final class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.BuilderA builder for PayStatements.
public final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Earningspublic final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.EmployeeDeductionspublic final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.EmployerContributionspublic final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Taxes
-
Method Summary
-
-
Method Detail
-
earnings
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Earnings> earnings()
-
employeeDeductions
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.EmployeeDeductions> employeeDeductions()
-
employerContributions
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.EmployerContributions> employerContributions()
-
individualId
final Optional<Boolean> individualId()
-
paymentMethod
final Optional<Boolean> paymentMethod()
-
taxes
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Taxes> taxes()
-
totalHours
final Optional<Boolean> totalHours()
-
_earnings
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Earnings> _earnings()
Returns the raw JSON value of earnings.
Unlike earnings, this method doesn't throw if the JSON field has an unexpected type.
-
_employeeDeductions
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.EmployeeDeductions> _employeeDeductions()
Returns the raw JSON value of employeeDeductions.
Unlike employeeDeductions, this method doesn't throw if the JSON field has an unexpected type.
-
_employerContributions
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.EmployerContributions> _employerContributions()
Returns the raw JSON value of employerContributions.
Unlike employerContributions, this method doesn't throw if the JSON field has an unexpected type.
-
_grossPay
final JsonField<Boolean> _grossPay()
Returns the raw JSON value of grossPay.
Unlike grossPay, this method doesn't throw if the JSON field has an unexpected type.
-
_individualId
final JsonField<Boolean> _individualId()
Returns the raw JSON value of individualId.
Unlike individualId, this method doesn't throw if the JSON field has an unexpected type.
-
_netPay
final JsonField<Boolean> _netPay()
Returns the raw JSON value of netPay.
Unlike netPay, this method doesn't throw if the JSON field has an unexpected type.
-
_paymentMethod
final JsonField<Boolean> _paymentMethod()
Returns the raw JSON value of paymentMethod.
Unlike paymentMethod, this method doesn't throw if the JSON field has an unexpected type.
-
_taxes
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Taxes> _taxes()
Returns the raw JSON value of taxes.
Unlike taxes, this method doesn't throw if the JSON field has an unexpected type.
-
_totalHours
final JsonField<Boolean> _totalHours()
Returns the raw JSON value of totalHours.
Unlike totalHours, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<Boolean> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Builder toBuilder()
-
validate
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Builder builder()
Returns a mutable builder for constructing an instance of PayStatements.
-
-
-
-