Class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Builder
-
- All Implemented Interfaces:
public final class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.BuilderA builder for PayStatements.
-
-
Method Summary
-
-
Method Detail
-
earnings
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Builder earnings(AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Earnings earnings)
-
earnings
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Builder earnings(JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Earnings> earnings)
Sets Builder.earnings to an arbitrary JSON value.
You should usually call Builder.earnings with a well-typed Earnings value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
employeeDeductions
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Builder employeeDeductions(AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.EmployeeDeductions employeeDeductions)
-
employeeDeductions
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Builder employeeDeductions(JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.EmployeeDeductions> employeeDeductions)
Sets Builder.employeeDeductions to an arbitrary JSON value.
You should usually call Builder.employeeDeductions with a well-typed EmployeeDeductions value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
employerContributions
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Builder employerContributions(AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.EmployerContributions employerContributions)
-
employerContributions
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Builder employerContributions(JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.EmployerContributions> employerContributions)
Sets Builder.employerContributions to an arbitrary JSON value.
You should usually call Builder.employerContributions with a well-typed EmployerContributions value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
grossPay
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Builder grossPay(Boolean grossPay)
-
grossPay
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Builder grossPay(JsonField<Boolean> grossPay)
Sets Builder.grossPay to an arbitrary JSON value.
You should usually call Builder.grossPay with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
individualId
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Builder individualId(Boolean individualId)
-
individualId
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Builder individualId(JsonField<Boolean> individualId)
Sets Builder.individualId to an arbitrary JSON value.
You should usually call Builder.individualId with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
netPay
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Builder netPay(Boolean netPay)
-
netPay
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Builder netPay(JsonField<Boolean> netPay)
Sets Builder.netPay to an arbitrary JSON value.
You should usually call Builder.netPay with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
paymentMethod
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Builder paymentMethod(Boolean paymentMethod)
-
paymentMethod
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Builder paymentMethod(JsonField<Boolean> paymentMethod)
Sets Builder.paymentMethod to an arbitrary JSON value.
You should usually call Builder.paymentMethod with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
taxes
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Builder taxes(AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Taxes taxes)
-
taxes
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Builder taxes(JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Taxes> taxes)
Sets Builder.taxes to an arbitrary JSON value.
You should usually call Builder.taxes with a well-typed Taxes value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalHours
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Builder totalHours(Boolean totalHours)
-
totalHours
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Builder totalHours(JsonField<Boolean> totalHours)
Sets Builder.totalHours to an arbitrary JSON value.
You should usually call Builder.totalHours with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Builder type(Boolean type)
-
type
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Builder type(JsonField<Boolean> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPayStatementFields.PayStatements build()
Returns an immutable instance of PayStatements.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-