Class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder
-
- All Implemented Interfaces:
public final class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.BuilderA builder for SupportedPaymentFields.
-
-
Method Summary
-
-
Method Detail
-
id
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder id(Boolean id)
-
id
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder id(JsonField<Boolean> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
companyDebit
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder companyDebit(Boolean companyDebit)
-
companyDebit
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder companyDebit(JsonField<Boolean> companyDebit)
Sets Builder.companyDebit to an arbitrary JSON value.
You should usually call Builder.companyDebit with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debitDate
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder debitDate(Boolean debitDate)
-
debitDate
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder debitDate(JsonField<Boolean> debitDate)
Sets Builder.debitDate to an arbitrary JSON value.
You should usually call Builder.debitDate with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
employeeTaxes
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder employeeTaxes(Boolean employeeTaxes)
-
employeeTaxes
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder employeeTaxes(JsonField<Boolean> employeeTaxes)
Sets Builder.employeeTaxes to an arbitrary JSON value.
You should usually call Builder.employeeTaxes with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
employerTaxes
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder employerTaxes(Boolean employerTaxes)
-
employerTaxes
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder employerTaxes(JsonField<Boolean> employerTaxes)
Sets Builder.employerTaxes to an arbitrary JSON value.
You should usually call Builder.employerTaxes with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
grossPay
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder grossPay(Boolean grossPay)
-
grossPay
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder grossPay(JsonField<Boolean> grossPay)
Sets Builder.grossPay to an arbitrary JSON value.
You should usually call Builder.grossPay with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
individualIds
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder individualIds(Boolean individualIds)
-
individualIds
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder individualIds(JsonField<Boolean> individualIds)
Sets Builder.individualIds to an arbitrary JSON value.
You should usually call Builder.individualIds with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
netPay
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder netPay(Boolean netPay)
-
netPay
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder netPay(JsonField<Boolean> netPay)
Sets Builder.netPay to an arbitrary JSON value.
You should usually call Builder.netPay with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
payDate
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder payDate(Boolean payDate)
-
payDate
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder payDate(JsonField<Boolean> payDate)
Sets Builder.payDate to an arbitrary JSON value.
You should usually call Builder.payDate with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
payFrequencies
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder payFrequencies(Boolean payFrequencies)
-
payFrequencies
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder payFrequencies(JsonField<Boolean> payFrequencies)
Sets Builder.payFrequencies to an arbitrary JSON value.
You should usually call Builder.payFrequencies with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
payGroupIds
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder payGroupIds(Boolean payGroupIds)
-
payGroupIds
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder payGroupIds(JsonField<Boolean> payGroupIds)
Sets Builder.payGroupIds to an arbitrary JSON value.
You should usually call Builder.payGroupIds with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
payPeriod
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder payPeriod(AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.PayPeriod payPeriod)
-
payPeriod
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder payPeriod(JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.PayPeriod> payPeriod)
Sets Builder.payPeriod to an arbitrary JSON value.
You should usually call Builder.payPeriod with a well-typed PayPeriod value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields build()
Returns an immutable instance of SupportedPaymentFields.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-