Package com.tryfinch.api.models
Class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.PayPeriod
-
- All Implemented Interfaces:
public final class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.PayPeriod
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.PayPeriod.BuilderA builder for PayPeriod.
-
Method Summary
Modifier and Type Method Description final Optional<Boolean>endDate()final Optional<Boolean>startDate()final JsonField<Boolean>_endDate()Returns the raw JSON value of endDate. final JsonField<Boolean>_startDate()Returns the raw JSON value of startDate. final Map<String, JsonValue>_additionalProperties()final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.PayPeriod.BuildertoBuilder()final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.PayPeriodvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.PayPeriod.Builderbuilder()Returns a mutable builder for constructing an instance of PayPeriod. -
-
Method Detail
-
_endDate
final JsonField<Boolean> _endDate()
Returns the raw JSON value of endDate.
Unlike endDate, this method doesn't throw if the JSON field has an unexpected type.
-
_startDate
final JsonField<Boolean> _startDate()
Returns the raw JSON value of startDate.
Unlike startDate, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.PayPeriod.Builder toBuilder()
-
validate
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.PayPeriod validate()
-
builder
final static AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.PayPeriod.Builder builder()
Returns a mutable builder for constructing an instance of PayPeriod.
-
-
-
-