Class AccountUpdateResponse.Builder
-
- All Implemented Interfaces:
public final class AccountUpdateResponse.BuilderA builder for AccountUpdateResponse.
-
-
Method Summary
-
-
Method Detail
-
accountId
@Deprecated(message = "deprecated") final AccountUpdateResponse.Builder accountId(String accountId)
DEPRECATED Use
connection_idto associate a connection with an access token
-
accountId
@Deprecated(message = "deprecated") final AccountUpdateResponse.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
authenticationType
final AccountUpdateResponse.Builder authenticationType(AccountUpdateResponse.AuthenticationType authenticationType)
-
authenticationType
final AccountUpdateResponse.Builder authenticationType(JsonField<AccountUpdateResponse.AuthenticationType> authenticationType)
Sets Builder.authenticationType to an arbitrary JSON value.
You should usually call Builder.authenticationType with a well-typed AuthenticationType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
companyId
@Deprecated(message = "deprecated") final AccountUpdateResponse.Builder companyId(String companyId)
DEPRECATED Use
connection_idto associate a connection with an access token
-
companyId
@Deprecated(message = "deprecated") final AccountUpdateResponse.Builder companyId(JsonField<String> companyId)
Sets Builder.companyId to an arbitrary JSON value.
You should usually call Builder.companyId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
connectionId
final AccountUpdateResponse.Builder connectionId(String connectionId)
The ID of the new connection
-
connectionId
final AccountUpdateResponse.Builder connectionId(JsonField<String> connectionId)
Sets Builder.connectionId to an arbitrary JSON value.
You should usually call Builder.connectionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entityId
final AccountUpdateResponse.Builder entityId(String entityId)
The ID of the entity whose status was updated
-
entityId
final AccountUpdateResponse.Builder entityId(JsonField<String> entityId)
Sets Builder.entityId to an arbitrary JSON value.
You should usually call Builder.entityId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
products
final AccountUpdateResponse.Builder products(List<String> products)
-
products
final AccountUpdateResponse.Builder products(JsonField<List<String>> products)
Sets Builder.products to an arbitrary JSON value.
You should usually call Builder.products with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addProduct
final AccountUpdateResponse.Builder addProduct(String product)
-
providerId
final AccountUpdateResponse.Builder providerId(String providerId)
The ID of the provider associated with the
access_token
-
providerId
final AccountUpdateResponse.Builder providerId(JsonField<String> providerId)
Sets Builder.providerId to an arbitrary JSON value.
You should usually call Builder.providerId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountUpdateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountUpdateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountUpdateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountUpdateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountUpdateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountUpdateResponse build()
Returns an immutable instance of AccountUpdateResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountId() .authenticationType() .companyId() .connectionId() .entityId() .products() .providerId()
-
-
-
-