Class AutomatedAsyncJob
-
- All Implemented Interfaces:
public final class AutomatedAsyncJob
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAutomatedAsyncJob.BuilderA builder for AutomatedAsyncJob.
public final classAutomatedAsyncJob.ParamsThe input parameters for the job.
public final classAutomatedAsyncJob.Statuspublic final classAutomatedAsyncJob.TypeThe type of automated job
-
Method Summary
Modifier and Type Method Description final Optional<OffsetDateTime>completedAt()The datetime the job completed. final OffsetDateTimecreatedAt()The datetime when the job was created. final StringjobId()The id of the job that has been created. final StringjobUrl()The url that can be used to retrieve the job status final Optional<AutomatedAsyncJob.Params>params()The input parameters for the job. final Optional<OffsetDateTime>scheduledAt()The datetime a job is scheduled to be run. final Optional<OffsetDateTime>startedAt()The datetime a job entered into the job queue. final AutomatedAsyncJob.Statusstatus()final AutomatedAsyncJob.Typetype()The type of automated job final JsonField<OffsetDateTime>_completedAt()Returns the raw JSON value of completedAt. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_jobId()Returns the raw JSON value of jobId. final JsonField<String>_jobUrl()Returns the raw JSON value of jobUrl. final JsonField<AutomatedAsyncJob.Params>_params()Returns the raw JSON value of params. final JsonField<OffsetDateTime>_scheduledAt()Returns the raw JSON value of scheduledAt. final JsonField<OffsetDateTime>_startedAt()Returns the raw JSON value of startedAt. final JsonField<AutomatedAsyncJob.Status>_status()Returns the raw JSON value of status. final JsonField<AutomatedAsyncJob.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final AutomatedAsyncJob.BuildertoBuilder()final AutomatedAsyncJobvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AutomatedAsyncJob.Builderbuilder()Returns a mutable builder for constructing an instance of AutomatedAsyncJob. -
-
Method Detail
-
completedAt
final Optional<OffsetDateTime> completedAt()
The datetime the job completed.
-
createdAt
final OffsetDateTime createdAt()
The datetime when the job was created. for scheduled jobs, this will be the initial connection time. For ad-hoc jobs, this will be the time the creation request was received.
-
params
final Optional<AutomatedAsyncJob.Params> params()
The input parameters for the job.
-
scheduledAt
final Optional<OffsetDateTime> scheduledAt()
The datetime a job is scheduled to be run. For scheduled jobs, this datetime can be in the future if the job has not yet been enqueued. For ad-hoc jobs, this field will be null.
-
startedAt
final Optional<OffsetDateTime> startedAt()
The datetime a job entered into the job queue.
-
status
final AutomatedAsyncJob.Status status()
-
type
final AutomatedAsyncJob.Type type()
The type of automated job
-
_completedAt
final JsonField<OffsetDateTime> _completedAt()
Returns the raw JSON value of completedAt.
Unlike completedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_jobId
final JsonField<String> _jobId()
Returns the raw JSON value of jobId.
Unlike jobId, this method doesn't throw if the JSON field has an unexpected type.
-
_jobUrl
final JsonField<String> _jobUrl()
Returns the raw JSON value of jobUrl.
Unlike jobUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_params
final JsonField<AutomatedAsyncJob.Params> _params()
Returns the raw JSON value of params.
Unlike params, this method doesn't throw if the JSON field has an unexpected type.
-
_scheduledAt
final JsonField<OffsetDateTime> _scheduledAt()
Returns the raw JSON value of scheduledAt.
Unlike scheduledAt, this method doesn't throw if the JSON field has an unexpected type.
-
_startedAt
final JsonField<OffsetDateTime> _startedAt()
Returns the raw JSON value of startedAt.
Unlike startedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<AutomatedAsyncJob.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<AutomatedAsyncJob.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AutomatedAsyncJob.Builder toBuilder()
-
validate
final AutomatedAsyncJob validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AutomatedAsyncJob.Builder builder()
Returns a mutable builder for constructing an instance of AutomatedAsyncJob.
The following fields are required:
.completedAt() .createdAt() .jobId() .jobUrl() .params() .scheduledAt() .startedAt() .status() .type()
-
-
-
-