Class AutomatedAsyncJob.Builder
-
- All Implemented Interfaces:
public final class AutomatedAsyncJob.BuilderA builder for AutomatedAsyncJob.
-
-
Method Summary
-
-
Method Detail
-
completedAt
final AutomatedAsyncJob.Builder completedAt(OffsetDateTime completedAt)
The datetime the job completed.
-
completedAt
final AutomatedAsyncJob.Builder completedAt(Optional<OffsetDateTime> completedAt)
Alias for calling Builder.completedAt with
completedAt.orElse(null).
-
completedAt
final AutomatedAsyncJob.Builder completedAt(JsonField<OffsetDateTime> completedAt)
Sets Builder.completedAt to an arbitrary JSON value.
You should usually call Builder.completedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final AutomatedAsyncJob.Builder createdAt(OffsetDateTime createdAt)
The datetime when the job was created. for scheduled jobs, this will be the initial connection time. For ad-hoc jobs, this will be the time the creation request was received.
-
createdAt
final AutomatedAsyncJob.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
jobId
final AutomatedAsyncJob.Builder jobId(String jobId)
The id of the job that has been created.
-
jobId
final AutomatedAsyncJob.Builder jobId(JsonField<String> jobId)
Sets Builder.jobId to an arbitrary JSON value.
You should usually call Builder.jobId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
jobUrl
final AutomatedAsyncJob.Builder jobUrl(String jobUrl)
The url that can be used to retrieve the job status
-
jobUrl
final AutomatedAsyncJob.Builder jobUrl(JsonField<String> jobUrl)
Sets Builder.jobUrl to an arbitrary JSON value.
You should usually call Builder.jobUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
params
final AutomatedAsyncJob.Builder params(AutomatedAsyncJob.Params params)
The input parameters for the job.
-
params
final AutomatedAsyncJob.Builder params(Optional<AutomatedAsyncJob.Params> params)
Alias for calling Builder.params with
params.orElse(null).
-
params
final AutomatedAsyncJob.Builder params(JsonField<AutomatedAsyncJob.Params> params)
Sets Builder.params to an arbitrary JSON value.
You should usually call Builder.params with a well-typed Params value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
scheduledAt
final AutomatedAsyncJob.Builder scheduledAt(OffsetDateTime scheduledAt)
The datetime a job is scheduled to be run. For scheduled jobs, this datetime can be in the future if the job has not yet been enqueued. For ad-hoc jobs, this field will be null.
-
scheduledAt
final AutomatedAsyncJob.Builder scheduledAt(Optional<OffsetDateTime> scheduledAt)
Alias for calling Builder.scheduledAt with
scheduledAt.orElse(null).
-
scheduledAt
final AutomatedAsyncJob.Builder scheduledAt(JsonField<OffsetDateTime> scheduledAt)
Sets Builder.scheduledAt to an arbitrary JSON value.
You should usually call Builder.scheduledAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
startedAt
final AutomatedAsyncJob.Builder startedAt(OffsetDateTime startedAt)
The datetime a job entered into the job queue.
-
startedAt
final AutomatedAsyncJob.Builder startedAt(Optional<OffsetDateTime> startedAt)
Alias for calling Builder.startedAt with
startedAt.orElse(null).
-
startedAt
final AutomatedAsyncJob.Builder startedAt(JsonField<OffsetDateTime> startedAt)
Sets Builder.startedAt to an arbitrary JSON value.
You should usually call Builder.startedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final AutomatedAsyncJob.Builder status(AutomatedAsyncJob.Status status)
-
status
final AutomatedAsyncJob.Builder status(JsonField<AutomatedAsyncJob.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final AutomatedAsyncJob.Builder type(AutomatedAsyncJob.Type type)
The type of automated job
-
type
final AutomatedAsyncJob.Builder type(JsonField<AutomatedAsyncJob.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AutomatedAsyncJob.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AutomatedAsyncJob.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AutomatedAsyncJob.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AutomatedAsyncJob.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AutomatedAsyncJob.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AutomatedAsyncJob build()
Returns an immutable instance of AutomatedAsyncJob.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.completedAt() .createdAt() .jobId() .jobUrl() .params() .scheduledAt() .startedAt() .status() .type()
-
-
-
-