Package com.tryfinch.api.models
Class AutomatedAsyncJob.Params
-
- All Implemented Interfaces:
public final class AutomatedAsyncJob.ParamsThe input parameters for the job.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAutomatedAsyncJob.Params.BuilderA builder for Params.
-
Method Summary
Modifier and Type Method Description final Optional<String>individualId()The ID of the individual that the job was completed for. final JsonField<String>_individualId()Returns the raw JSON value of individualId. final Map<String, JsonValue>_additionalProperties()final AutomatedAsyncJob.Params.BuildertoBuilder()final AutomatedAsyncJob.Paramsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AutomatedAsyncJob.Params.Builderbuilder()Returns a mutable builder for constructing an instance of Params. -
-
Method Detail
-
individualId
final Optional<String> individualId()
The ID of the individual that the job was completed for.
-
_individualId
final JsonField<String> _individualId()
Returns the raw JSON value of individualId.
Unlike individualId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AutomatedAsyncJob.Params.Builder toBuilder()
-
validate
final AutomatedAsyncJob.Params validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AutomatedAsyncJob.Params.Builder builder()
Returns a mutable builder for constructing an instance of Params.
-
-
-
-