Class AutomatedCreateResponse
-
- All Implemented Interfaces:
public final class AutomatedCreateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAutomatedCreateResponse.BuilderA builder for AutomatedCreateResponse.
-
Method Summary
Modifier and Type Method Description final LongallowedRefreshes()The number of allowed refreshes per hour (per hour, fixed window) final LongremainingRefreshes()The number of remaining refreshes available (per hour, fixed window) final Optional<String>jobId()The id of the job that has been created. final Optional<String>jobUrl()The url that can be used to retrieve the job status final Optional<String>retryAt()ISO 8601 timestamp indicating when to retry the request final JsonField<Long>_allowedRefreshes()Returns the raw JSON value of allowedRefreshes. final JsonField<Long>_remainingRefreshes()Returns the raw JSON value of remainingRefreshes. final JsonField<String>_jobId()Returns the raw JSON value of jobId. final JsonField<String>_jobUrl()Returns the raw JSON value of jobUrl. final JsonField<String>_retryAt()Returns the raw JSON value of retryAt. final Map<String, JsonValue>_additionalProperties()final AutomatedCreateResponse.BuildertoBuilder()final AutomatedCreateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AutomatedCreateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of AutomatedCreateResponse. -
-
Method Detail
-
allowedRefreshes
final Long allowedRefreshes()
The number of allowed refreshes per hour (per hour, fixed window)
-
remainingRefreshes
final Long remainingRefreshes()
The number of remaining refreshes available (per hour, fixed window)
-
_allowedRefreshes
final JsonField<Long> _allowedRefreshes()
Returns the raw JSON value of allowedRefreshes.
Unlike allowedRefreshes, this method doesn't throw if the JSON field has an unexpected type.
-
_remainingRefreshes
final JsonField<Long> _remainingRefreshes()
Returns the raw JSON value of remainingRefreshes.
Unlike remainingRefreshes, this method doesn't throw if the JSON field has an unexpected type.
-
_jobId
final JsonField<String> _jobId()
Returns the raw JSON value of jobId.
Unlike jobId, this method doesn't throw if the JSON field has an unexpected type.
-
_jobUrl
final JsonField<String> _jobUrl()
Returns the raw JSON value of jobUrl.
Unlike jobUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_retryAt
final JsonField<String> _retryAt()
Returns the raw JSON value of retryAt.
Unlike retryAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AutomatedCreateResponse.Builder toBuilder()
-
validate
final AutomatedCreateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AutomatedCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of AutomatedCreateResponse.
The following fields are required:
.allowedRefreshes() .remainingRefreshes()
-
-
-
-