Class AutomatedCreateResponse.Builder
-
- All Implemented Interfaces:
public final class AutomatedCreateResponse.BuilderA builder for AutomatedCreateResponse.
-
-
Method Summary
-
-
Method Detail
-
allowedRefreshes
final AutomatedCreateResponse.Builder allowedRefreshes(Long allowedRefreshes)
The number of allowed refreshes per hour (per hour, fixed window)
-
allowedRefreshes
final AutomatedCreateResponse.Builder allowedRefreshes(JsonField<Long> allowedRefreshes)
Sets Builder.allowedRefreshes to an arbitrary JSON value.
You should usually call Builder.allowedRefreshes with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
remainingRefreshes
final AutomatedCreateResponse.Builder remainingRefreshes(Long remainingRefreshes)
The number of remaining refreshes available (per hour, fixed window)
-
remainingRefreshes
final AutomatedCreateResponse.Builder remainingRefreshes(JsonField<Long> remainingRefreshes)
Sets Builder.remainingRefreshes to an arbitrary JSON value.
You should usually call Builder.remainingRefreshes with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
jobId
final AutomatedCreateResponse.Builder jobId(String jobId)
The id of the job that has been created.
-
jobId
final AutomatedCreateResponse.Builder jobId(JsonField<String> jobId)
Sets Builder.jobId to an arbitrary JSON value.
You should usually call Builder.jobId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
jobUrl
final AutomatedCreateResponse.Builder jobUrl(String jobUrl)
The url that can be used to retrieve the job status
-
jobUrl
final AutomatedCreateResponse.Builder jobUrl(JsonField<String> jobUrl)
Sets Builder.jobUrl to an arbitrary JSON value.
You should usually call Builder.jobUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
retryAt
final AutomatedCreateResponse.Builder retryAt(String retryAt)
ISO 8601 timestamp indicating when to retry the request
-
retryAt
final AutomatedCreateResponse.Builder retryAt(JsonField<String> retryAt)
Sets Builder.retryAt to an arbitrary JSON value.
You should usually call Builder.retryAt with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AutomatedCreateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AutomatedCreateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AutomatedCreateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AutomatedCreateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AutomatedCreateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AutomatedCreateResponse build()
Returns an immutable instance of AutomatedCreateResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.allowedRefreshes() .remainingRefreshes()
-
-
-
-