Package com.tryfinch.api.models
Class AutomatedListResponse
-
- All Implemented Interfaces:
public final class AutomatedListResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAutomatedListResponse.BuilderA builder for AutomatedListResponse.
public final classAutomatedListResponse.Meta
-
Method Summary
Modifier and Type Method Description final List<AutomatedAsyncJob>data()final AutomatedListResponse.Metameta()final JsonField<List<AutomatedAsyncJob>>_data()Returns the raw JSON value of data. final JsonField<AutomatedListResponse.Meta>_meta()Returns the raw JSON value of meta. final Map<String, JsonValue>_additionalProperties()final AutomatedListResponse.BuildertoBuilder()final AutomatedListResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AutomatedListResponse.Builderbuilder()Returns a mutable builder for constructing an instance of AutomatedListResponse. -
-
Method Detail
-
data
final List<AutomatedAsyncJob> data()
-
meta
final AutomatedListResponse.Meta meta()
-
_data
final JsonField<List<AutomatedAsyncJob>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_meta
final JsonField<AutomatedListResponse.Meta> _meta()
Returns the raw JSON value of meta.
Unlike meta, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AutomatedListResponse.Builder toBuilder()
-
validate
final AutomatedListResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AutomatedListResponse.Builder builder()
Returns a mutable builder for constructing an instance of AutomatedListResponse.
The following fields are required:
.data() .meta()
-
-
-
-