Package com.tryfinch.api.models
Class AutomatedListResponse.Builder
-
- All Implemented Interfaces:
public final class AutomatedListResponse.BuilderA builder for AutomatedListResponse.
-
-
Method Summary
-
-
Method Detail
-
data
final AutomatedListResponse.Builder data(List<AutomatedAsyncJob> data)
-
data
final AutomatedListResponse.Builder data(JsonField<List<AutomatedAsyncJob>> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed
List<AutomatedAsyncJob>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addData
final AutomatedListResponse.Builder addData(AutomatedAsyncJob data)
Adds a single AutomatedAsyncJob to Builder.data.
-
meta
final AutomatedListResponse.Builder meta(AutomatedListResponse.Meta meta)
-
meta
final AutomatedListResponse.Builder meta(JsonField<AutomatedListResponse.Meta> meta)
Sets Builder.meta to an arbitrary JSON value.
You should usually call Builder.meta with a well-typed Meta value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AutomatedListResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AutomatedListResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AutomatedListResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AutomatedListResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AutomatedListResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AutomatedListResponse build()
Returns an immutable instance of AutomatedListResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.data() .meta()
-
-
-
-