Class AutomatedListResponse.Meta
-
- All Implemented Interfaces:
public final class AutomatedListResponse.Meta
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAutomatedListResponse.Meta.BuilderA builder for Meta.
public final classAutomatedListResponse.Meta.QuotasInformation about remaining quotas for this connection. Only applicable for customers opted in to use Finch's Data Sync Refresh endpoint (
POST /jobs/automated). Please contact a Finch representative for more details.
-
Method Summary
Modifier and Type Method Description final Optional<AutomatedListResponse.Meta.Quotas>quotas()Information about remaining quotas for this connection. final JsonField<AutomatedListResponse.Meta.Quotas>_quotas()Returns the raw JSON value of quotas. final Map<String, JsonValue>_additionalProperties()final AutomatedListResponse.Meta.BuildertoBuilder()final AutomatedListResponse.Metavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AutomatedListResponse.Meta.Builderbuilder()Returns a mutable builder for constructing an instance of Meta. -
-
Method Detail
-
quotas
final Optional<AutomatedListResponse.Meta.Quotas> quotas()
Information about remaining quotas for this connection. Only applicable for customers opted in to use Finch's Data Sync Refresh endpoint (
POST /jobs/automated). Please contact a Finch representative for more details.
-
_quotas
final JsonField<AutomatedListResponse.Meta.Quotas> _quotas()
Returns the raw JSON value of quotas.
Unlike quotas, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AutomatedListResponse.Meta.Builder toBuilder()
-
validate
final AutomatedListResponse.Meta validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AutomatedListResponse.Meta.Builder builder()
Returns a mutable builder for constructing an instance of Meta.
-
-
-
-