Package com.tryfinch.api.models
Class AutomatedListResponse.Meta.Builder
-
- All Implemented Interfaces:
public final class AutomatedListResponse.Meta.BuilderA builder for Meta.
-
-
Method Summary
Modifier and Type Method Description final AutomatedListResponse.Meta.Builderquotas(AutomatedListResponse.Meta.Quotas quotas)Information about remaining quotas for this connection. final AutomatedListResponse.Meta.Builderquotas(JsonField<AutomatedListResponse.Meta.Quotas> quotas)Sets Builder.quotas to an arbitrary JSON value. final AutomatedListResponse.Meta.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final AutomatedListResponse.Meta.BuilderputAdditionalProperty(String key, JsonValue value)final AutomatedListResponse.Meta.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final AutomatedListResponse.Meta.BuilderremoveAdditionalProperty(String key)final AutomatedListResponse.Meta.BuilderremoveAllAdditionalProperties(Set<String> keys)final AutomatedListResponse.Metabuild()Returns an immutable instance of Meta. -
-
Method Detail
-
quotas
final AutomatedListResponse.Meta.Builder quotas(AutomatedListResponse.Meta.Quotas quotas)
Information about remaining quotas for this connection. Only applicable for customers opted in to use Finch's Data Sync Refresh endpoint (
POST /jobs/automated). Please contact a Finch representative for more details.
-
quotas
final AutomatedListResponse.Meta.Builder quotas(JsonField<AutomatedListResponse.Meta.Quotas> quotas)
Sets Builder.quotas to an arbitrary JSON value.
You should usually call Builder.quotas with a well-typed Quotas value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AutomatedListResponse.Meta.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AutomatedListResponse.Meta.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AutomatedListResponse.Meta.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AutomatedListResponse.Meta.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AutomatedListResponse.Meta.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AutomatedListResponse.Meta build()
Returns an immutable instance of Meta.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-