Package com.tryfinch.api.models
Class AutomatedListResponse.Meta.Quotas
-
- All Implemented Interfaces:
public final class AutomatedListResponse.Meta.QuotasInformation about remaining quotas for this connection. Only applicable for customers opted in to use Finch's Data Sync Refresh endpoint (
POST /jobs/automated). Please contact a Finch representative for more details.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAutomatedListResponse.Meta.Quotas.BuilderA builder for Quotas.
public final classAutomatedListResponse.Meta.Quotas.DataSyncAll
-
Method Summary
Modifier and Type Method Description final Optional<AutomatedListResponse.Meta.Quotas.DataSyncAll>dataSyncAll()final JsonField<AutomatedListResponse.Meta.Quotas.DataSyncAll>_dataSyncAll()Returns the raw JSON value of dataSyncAll. final Map<String, JsonValue>_additionalProperties()final AutomatedListResponse.Meta.Quotas.BuildertoBuilder()final AutomatedListResponse.Meta.Quotasvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AutomatedListResponse.Meta.Quotas.Builderbuilder()Returns a mutable builder for constructing an instance of Quotas. -
-
Method Detail
-
dataSyncAll
final Optional<AutomatedListResponse.Meta.Quotas.DataSyncAll> dataSyncAll()
-
_dataSyncAll
final JsonField<AutomatedListResponse.Meta.Quotas.DataSyncAll> _dataSyncAll()
Returns the raw JSON value of dataSyncAll.
Unlike dataSyncAll, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AutomatedListResponse.Meta.Quotas.Builder toBuilder()
-
validate
final AutomatedListResponse.Meta.Quotas validate()
-
builder
final static AutomatedListResponse.Meta.Quotas.Builder builder()
Returns a mutable builder for constructing an instance of Quotas.
-
-
-
-