Package com.tryfinch.api.models
Class BenefitContribution
-
- All Implemented Interfaces:
public final class BenefitContribution
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBenefitContribution.BuilderA builder for BenefitContribution.
public final classBenefitContribution.TypeContribution type.
-
Method Summary
Modifier and Type Method Description final Optional<Long>amount()Contribution amount in cents (if fixed) or basis points (ifpercent).final Optional<BenefitContribution.Type>type()Contribution type. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<BenefitContribution.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final BenefitContribution.BuildertoBuilder()final BenefitContributionvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BenefitContribution.Builderbuilder()Returns a mutable builder for constructing an instance of BenefitContribution. -
-
Method Detail
-
amount
final Optional<Long> amount()
Contribution amount in cents (if
fixed) or basis points (ifpercent).
-
type
final Optional<BenefitContribution.Type> type()
Contribution type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<BenefitContribution.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BenefitContribution.Builder toBuilder()
-
validate
final BenefitContribution validate()
-
builder
final static BenefitContribution.Builder builder()
Returns a mutable builder for constructing an instance of BenefitContribution.
The following fields are required:
.amount() .type()
-
-
-
-