Package com.tryfinch.api.models
Class BenefitContribution.BenefitContributionFixed
-
- All Implemented Interfaces:
public final class BenefitContribution.BenefitContributionFixed
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBenefitContribution.BenefitContributionFixed.BuilderA builder for BenefitContributionFixed.
public final classBenefitContribution.BenefitContributionFixed.TypeFixed contribution type.
-
Method Summary
Modifier and Type Method Description final Longamount()Contribution amount in cents. final BenefitContribution.BenefitContributionFixed.Typetype()Fixed contribution type. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<BenefitContribution.BenefitContributionFixed.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final BenefitContribution.BenefitContributionFixed.BuildertoBuilder()final BenefitContribution.BenefitContributionFixedvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BenefitContribution.BenefitContributionFixed.Builderbuilder()Returns a mutable builder for constructing an instance of BenefitContributionFixed. -
-
Method Detail
-
type
final BenefitContribution.BenefitContributionFixed.Type type()
Fixed contribution type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<BenefitContribution.BenefitContributionFixed.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BenefitContribution.BenefitContributionFixed.Builder toBuilder()
-
validate
final BenefitContribution.BenefitContributionFixed validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BenefitContribution.BenefitContributionFixed.Builder builder()
Returns a mutable builder for constructing an instance of BenefitContributionFixed.
The following fields are required:
.amount() .type()
-
-
-
-