Package com.tryfinch.api.models
Class BenefitContribution.BenefitContributionFixed.Builder
-
- All Implemented Interfaces:
public final class BenefitContribution.BenefitContributionFixed.BuilderA builder for BenefitContributionFixed.
-
-
Method Summary
-
-
Method Detail
-
amount
final BenefitContribution.BenefitContributionFixed.Builder amount(Long amount)
Contribution amount in cents.
-
amount
final BenefitContribution.BenefitContributionFixed.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final BenefitContribution.BenefitContributionFixed.Builder type(BenefitContribution.BenefitContributionFixed.Type type)
Fixed contribution type.
-
type
final BenefitContribution.BenefitContributionFixed.Builder type(JsonField<BenefitContribution.BenefitContributionFixed.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final BenefitContribution.BenefitContributionFixed.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BenefitContribution.BenefitContributionFixed.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BenefitContribution.BenefitContributionFixed.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BenefitContribution.BenefitContributionFixed.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BenefitContribution.BenefitContributionFixed.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BenefitContribution.BenefitContributionFixed build()
Returns an immutable instance of BenefitContributionFixed.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.amount() .type()
-
-
-
-