Package com.tryfinch.api.models
Class BenefitContribution.BenefitContributionPercent
-
- All Implemented Interfaces:
public final class BenefitContribution.BenefitContributionPercent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBenefitContribution.BenefitContributionPercent.BuilderA builder for BenefitContributionPercent.
public final classBenefitContribution.BenefitContributionPercent.TypePercentage contribution type.
-
Method Summary
Modifier and Type Method Description final Longamount()Contribution amount in basis points (1/100th of a percent). final BenefitContribution.BenefitContributionPercent.Typetype()Percentage contribution type. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<BenefitContribution.BenefitContributionPercent.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final BenefitContribution.BenefitContributionPercent.BuildertoBuilder()final BenefitContribution.BenefitContributionPercentvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BenefitContribution.BenefitContributionPercent.Builderbuilder()Returns a mutable builder for constructing an instance of BenefitContributionPercent. -
-
Method Detail
-
type
final BenefitContribution.BenefitContributionPercent.Type type()
Percentage contribution type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<BenefitContribution.BenefitContributionPercent.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BenefitContribution.BenefitContributionPercent.Builder toBuilder()
-
validate
final BenefitContribution.BenefitContributionPercent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BenefitContribution.BenefitContributionPercent.Builder builder()
Returns a mutable builder for constructing an instance of BenefitContributionPercent.
The following fields are required:
.amount() .type()
-
-
-
-