Package com.tryfinch.api.models
Class BenefitContribution.UnionMember0
-
- All Implemented Interfaces:
public final class BenefitContribution.UnionMember0
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBenefitContribution.UnionMember0.BuilderA builder for UnionMember0.
public final classBenefitContribution.UnionMember0.TypeFixed contribution type.
-
Method Summary
Modifier and Type Method Description final Longamount()Contribution amount in cents. final BenefitContribution.UnionMember0.Typetype()Fixed contribution type. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<BenefitContribution.UnionMember0.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final BenefitContribution.UnionMember0.BuildertoBuilder()final BenefitContribution.UnionMember0validate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BenefitContribution.UnionMember0.Builderbuilder()Returns a mutable builder for constructing an instance of UnionMember0. -
-
Method Detail
-
type
final BenefitContribution.UnionMember0.Type type()
Fixed contribution type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<BenefitContribution.UnionMember0.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BenefitContribution.UnionMember0.Builder toBuilder()
-
validate
final BenefitContribution.UnionMember0 validate()
-
builder
final static BenefitContribution.UnionMember0.Builder builder()
Returns a mutable builder for constructing an instance of UnionMember0.
The following fields are required:
.amount() .type()
-
-
-
-