Package com.tryfinch.api.models
Class BenefitContribution.UnionMember1
-
- All Implemented Interfaces:
public final class BenefitContribution.UnionMember1
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBenefitContribution.UnionMember1.BuilderA builder for UnionMember1.
public final classBenefitContribution.UnionMember1.TypePercentage contribution type.
-
Method Summary
Modifier and Type Method Description final Longamount()Contribution amount in basis points (1/100th of a percent). final BenefitContribution.UnionMember1.Typetype()Percentage contribution type. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<BenefitContribution.UnionMember1.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final BenefitContribution.UnionMember1.BuildertoBuilder()final BenefitContribution.UnionMember1validate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BenefitContribution.UnionMember1.Builderbuilder()Returns a mutable builder for constructing an instance of UnionMember1. -
-
Method Detail
-
type
final BenefitContribution.UnionMember1.Type type()
Percentage contribution type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<BenefitContribution.UnionMember1.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BenefitContribution.UnionMember1.Builder toBuilder()
-
validate
final BenefitContribution.UnionMember1 validate()
-
builder
final static BenefitContribution.UnionMember1.Builder builder()
Returns a mutable builder for constructing an instance of UnionMember1.
The following fields are required:
.amount() .type()
-
-
-
-