Package com.tryfinch.api.models
Class BenefitContribution.UnionMember2
-
- All Implemented Interfaces:
public final class BenefitContribution.UnionMember2
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBenefitContribution.UnionMember2.BuilderA builder for UnionMember2.
public final classBenefitContribution.UnionMember2.Tierpublic final classBenefitContribution.UnionMember2.TypeTiered contribution type (only valid for company_contribution).
-
Method Summary
Modifier and Type Method Description final List<BenefitContribution.UnionMember2.Tier>tiers()Array of tier objects defining employer match tiers based on employee contribution thresholds. final BenefitContribution.UnionMember2.Typetype()Tiered contribution type (only valid for company_contribution). final JsonField<List<BenefitContribution.UnionMember2.Tier>>_tiers()Returns the raw JSON value of tiers. final JsonField<BenefitContribution.UnionMember2.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final BenefitContribution.UnionMember2.BuildertoBuilder()final BenefitContribution.UnionMember2validate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BenefitContribution.UnionMember2.Builderbuilder()Returns a mutable builder for constructing an instance of UnionMember2. -
-
Method Detail
-
tiers
final List<BenefitContribution.UnionMember2.Tier> tiers()
Array of tier objects defining employer match tiers based on employee contribution thresholds.
-
type
final BenefitContribution.UnionMember2.Type type()
Tiered contribution type (only valid for company_contribution).
-
_tiers
final JsonField<List<BenefitContribution.UnionMember2.Tier>> _tiers()
Returns the raw JSON value of tiers.
Unlike tiers, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<BenefitContribution.UnionMember2.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BenefitContribution.UnionMember2.Builder toBuilder()
-
validate
final BenefitContribution.UnionMember2 validate()
-
builder
final static BenefitContribution.UnionMember2.Builder builder()
Returns a mutable builder for constructing an instance of UnionMember2.
The following fields are required:
.tiers() .type()
-
-
-
-