Class BenefitFeaturesAndOperations.BenefitFeature
-
- All Implemented Interfaces:
public final class BenefitFeaturesAndOperations.BenefitFeature
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBenefitFeaturesAndOperations.BenefitFeature.BuilderA builder for BenefitFeature.
public final classBenefitFeaturesAndOperations.BenefitFeature.CompanyContributionpublic final classBenefitFeaturesAndOperations.BenefitFeature.EmployeeDeductionpublic final classBenefitFeaturesAndOperations.BenefitFeature.HsaContributionLimit
-
Method Summary
-
-
Method Detail
-
annualMaximum
final Optional<Boolean> annualMaximum()
Whether the provider supports an annual maximum for this benefit.
-
catchUp
final Optional<Boolean> catchUp()
Whether the provider supports catch up for this benefit. This field will only be true for retirement benefits.
-
companyContribution
final Optional<List<BenefitFeaturesAndOperations.BenefitFeature.CompanyContribution>> companyContribution()
Supported contribution types. An empty array indicates contributions are not supported.
-
description
final Optional<String> description()
-
employeeDeduction
final Optional<List<BenefitFeaturesAndOperations.BenefitFeature.EmployeeDeduction>> employeeDeduction()
Supported deduction types. An empty array indicates deductions are not supported.
-
frequencies
final Optional<List<BenefitFrequency>> frequencies()
The list of frequencies supported by the provider for this benefit
-
hsaContributionLimit
final Optional<List<BenefitFeaturesAndOperations.BenefitFeature.HsaContributionLimit>> hsaContributionLimit()
Whether the provider supports HSA contribution limits. Empty if this feature is not supported for the benefit. This array only has values for HSA benefits.
-
_annualMaximum
final JsonField<Boolean> _annualMaximum()
Returns the raw JSON value of annualMaximum.
Unlike annualMaximum, this method doesn't throw if the JSON field has an unexpected type.
-
_catchUp
final JsonField<Boolean> _catchUp()
Returns the raw JSON value of catchUp.
Unlike catchUp, this method doesn't throw if the JSON field has an unexpected type.
-
_companyContribution
final JsonField<List<BenefitFeaturesAndOperations.BenefitFeature.CompanyContribution>> _companyContribution()
Returns the raw JSON value of companyContribution.
Unlike companyContribution, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_employeeDeduction
final JsonField<List<BenefitFeaturesAndOperations.BenefitFeature.EmployeeDeduction>> _employeeDeduction()
Returns the raw JSON value of employeeDeduction.
Unlike employeeDeduction, this method doesn't throw if the JSON field has an unexpected type.
-
_frequencies
final JsonField<List<BenefitFrequency>> _frequencies()
Returns the raw JSON value of frequencies.
Unlike frequencies, this method doesn't throw if the JSON field has an unexpected type.
-
_hsaContributionLimit
final JsonField<List<BenefitFeaturesAndOperations.BenefitFeature.HsaContributionLimit>> _hsaContributionLimit()
Returns the raw JSON value of hsaContributionLimit.
Unlike hsaContributionLimit, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BenefitFeaturesAndOperations.BenefitFeature.Builder toBuilder()
-
validate
final BenefitFeaturesAndOperations.BenefitFeature validate()
-
builder
final static BenefitFeaturesAndOperations.BenefitFeature.Builder builder()
Returns a mutable builder for constructing an instance of BenefitFeature.
-
-
-
-