Package com.tryfinch.api.models
Class BenefitFeaturesAndOperations.Builder
-
- All Implemented Interfaces:
public final class BenefitFeaturesAndOperations.BuilderA builder for BenefitFeaturesAndOperations.
-
-
Method Summary
-
-
Method Detail
-
supportedFeatures
final BenefitFeaturesAndOperations.Builder supportedFeatures(SupportedBenefit supportedFeatures)
-
supportedFeatures
final BenefitFeaturesAndOperations.Builder supportedFeatures(JsonField<SupportedBenefit> supportedFeatures)
Sets Builder.supportedFeatures to an arbitrary JSON value.
You should usually call Builder.supportedFeatures with a well-typed SupportedBenefit value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
supportedOperations
final BenefitFeaturesAndOperations.Builder supportedOperations(SupportPerBenefitType supportedOperations)
-
supportedOperations
final BenefitFeaturesAndOperations.Builder supportedOperations(JsonField<SupportPerBenefitType> supportedOperations)
Sets Builder.supportedOperations to an arbitrary JSON value.
You should usually call Builder.supportedOperations with a well-typed SupportPerBenefitType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final BenefitFeaturesAndOperations.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BenefitFeaturesAndOperations.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BenefitFeaturesAndOperations.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BenefitFeaturesAndOperations.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BenefitFeaturesAndOperations.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BenefitFeaturesAndOperations build()
Returns an immutable instance of BenefitFeaturesAndOperations.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-