Class BenefitsSupport.Builder
-
- All Implemented Interfaces:
public final class BenefitsSupport.BuilderA builder for BenefitsSupport.
-
-
Method Summary
-
-
Method Detail
-
commuter
final BenefitsSupport.Builder commuter(BenefitFeaturesAndOperations commuter)
-
commuter
final BenefitsSupport.Builder commuter(Optional<BenefitFeaturesAndOperations> commuter)
Alias for calling Builder.commuter with
commuter.orElse(null).
-
commuter
final BenefitsSupport.Builder commuter(JsonField<BenefitFeaturesAndOperations> commuter)
Sets Builder.commuter to an arbitrary JSON value.
You should usually call Builder.commuter with a well-typed BenefitFeaturesAndOperations value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customPostTax
final BenefitsSupport.Builder customPostTax(BenefitFeaturesAndOperations customPostTax)
-
customPostTax
final BenefitsSupport.Builder customPostTax(Optional<BenefitFeaturesAndOperations> customPostTax)
Alias for calling Builder.customPostTax with
customPostTax.orElse(null).
-
customPostTax
final BenefitsSupport.Builder customPostTax(JsonField<BenefitFeaturesAndOperations> customPostTax)
Sets Builder.customPostTax to an arbitrary JSON value.
You should usually call Builder.customPostTax with a well-typed BenefitFeaturesAndOperations value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customPreTax
final BenefitsSupport.Builder customPreTax(BenefitFeaturesAndOperations customPreTax)
-
customPreTax
final BenefitsSupport.Builder customPreTax(Optional<BenefitFeaturesAndOperations> customPreTax)
Alias for calling Builder.customPreTax with
customPreTax.orElse(null).
-
customPreTax
final BenefitsSupport.Builder customPreTax(JsonField<BenefitFeaturesAndOperations> customPreTax)
Sets Builder.customPreTax to an arbitrary JSON value.
You should usually call Builder.customPreTax with a well-typed BenefitFeaturesAndOperations value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fsaDependentCare
final BenefitsSupport.Builder fsaDependentCare(BenefitFeaturesAndOperations fsaDependentCare)
-
fsaDependentCare
final BenefitsSupport.Builder fsaDependentCare(Optional<BenefitFeaturesAndOperations> fsaDependentCare)
Alias for calling Builder.fsaDependentCare with
fsaDependentCare.orElse(null).
-
fsaDependentCare
final BenefitsSupport.Builder fsaDependentCare(JsonField<BenefitFeaturesAndOperations> fsaDependentCare)
Sets Builder.fsaDependentCare to an arbitrary JSON value.
You should usually call Builder.fsaDependentCare with a well-typed BenefitFeaturesAndOperations value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fsaMedical
final BenefitsSupport.Builder fsaMedical(BenefitFeaturesAndOperations fsaMedical)
-
fsaMedical
final BenefitsSupport.Builder fsaMedical(Optional<BenefitFeaturesAndOperations> fsaMedical)
Alias for calling Builder.fsaMedical with
fsaMedical.orElse(null).
-
fsaMedical
final BenefitsSupport.Builder fsaMedical(JsonField<BenefitFeaturesAndOperations> fsaMedical)
Sets Builder.fsaMedical to an arbitrary JSON value.
You should usually call Builder.fsaMedical with a well-typed BenefitFeaturesAndOperations value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
hsaPost
final BenefitsSupport.Builder hsaPost(BenefitFeaturesAndOperations hsaPost)
-
hsaPost
final BenefitsSupport.Builder hsaPost(Optional<BenefitFeaturesAndOperations> hsaPost)
Alias for calling Builder.hsaPost with
hsaPost.orElse(null).
-
hsaPost
final BenefitsSupport.Builder hsaPost(JsonField<BenefitFeaturesAndOperations> hsaPost)
Sets Builder.hsaPost to an arbitrary JSON value.
You should usually call Builder.hsaPost with a well-typed BenefitFeaturesAndOperations value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
hsaPre
final BenefitsSupport.Builder hsaPre(BenefitFeaturesAndOperations hsaPre)
-
hsaPre
final BenefitsSupport.Builder hsaPre(Optional<BenefitFeaturesAndOperations> hsaPre)
Alias for calling Builder.hsaPre with
hsaPre.orElse(null).
-
hsaPre
final BenefitsSupport.Builder hsaPre(JsonField<BenefitFeaturesAndOperations> hsaPre)
Sets Builder.hsaPre to an arbitrary JSON value.
You should usually call Builder.hsaPre with a well-typed BenefitFeaturesAndOperations value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
s125Dental
final BenefitsSupport.Builder s125Dental(BenefitFeaturesAndOperations s125Dental)
-
s125Dental
final BenefitsSupport.Builder s125Dental(Optional<BenefitFeaturesAndOperations> s125Dental)
Alias for calling Builder.s125Dental with
s125Dental.orElse(null).
-
s125Dental
final BenefitsSupport.Builder s125Dental(JsonField<BenefitFeaturesAndOperations> s125Dental)
Sets Builder.s125Dental to an arbitrary JSON value.
You should usually call Builder.s125Dental with a well-typed BenefitFeaturesAndOperations value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
s125Medical
final BenefitsSupport.Builder s125Medical(BenefitFeaturesAndOperations s125Medical)
-
s125Medical
final BenefitsSupport.Builder s125Medical(Optional<BenefitFeaturesAndOperations> s125Medical)
Alias for calling Builder.s125Medical with
s125Medical.orElse(null).
-
s125Medical
final BenefitsSupport.Builder s125Medical(JsonField<BenefitFeaturesAndOperations> s125Medical)
Sets Builder.s125Medical to an arbitrary JSON value.
You should usually call Builder.s125Medical with a well-typed BenefitFeaturesAndOperations value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
s125Vision
final BenefitsSupport.Builder s125Vision(BenefitFeaturesAndOperations s125Vision)
-
s125Vision
final BenefitsSupport.Builder s125Vision(Optional<BenefitFeaturesAndOperations> s125Vision)
Alias for calling Builder.s125Vision with
s125Vision.orElse(null).
-
s125Vision
final BenefitsSupport.Builder s125Vision(JsonField<BenefitFeaturesAndOperations> s125Vision)
Sets Builder.s125Vision to an arbitrary JSON value.
You should usually call Builder.s125Vision with a well-typed BenefitFeaturesAndOperations value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
simple
final BenefitsSupport.Builder simple(BenefitFeaturesAndOperations simple)
-
simple
final BenefitsSupport.Builder simple(Optional<BenefitFeaturesAndOperations> simple)
Alias for calling Builder.simple with
simple.orElse(null).
-
simple
final BenefitsSupport.Builder simple(JsonField<BenefitFeaturesAndOperations> simple)
Sets Builder.simple to an arbitrary JSON value.
You should usually call Builder.simple with a well-typed BenefitFeaturesAndOperations value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
simpleIra
final BenefitsSupport.Builder simpleIra(BenefitFeaturesAndOperations simpleIra)
-
simpleIra
final BenefitsSupport.Builder simpleIra(Optional<BenefitFeaturesAndOperations> simpleIra)
Alias for calling Builder.simpleIra with
simpleIra.orElse(null).
-
simpleIra
final BenefitsSupport.Builder simpleIra(JsonField<BenefitFeaturesAndOperations> simpleIra)
Sets Builder.simpleIra to an arbitrary JSON value.
You should usually call Builder.simpleIra with a well-typed BenefitFeaturesAndOperations value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final BenefitsSupport.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BenefitsSupport.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BenefitsSupport.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BenefitsSupport.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BenefitsSupport.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BenefitsSupport build()
Returns an immutable instance of BenefitsSupport.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-