Class Company.Builder
-
- All Implemented Interfaces:
public final class Company.BuilderA builder for Company.
-
-
Method Summary
Modifier and Type Method Description final Company.Builderid(String id)A stable Finch id(UUID v4) for the company.final Company.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final Company.Builderaccounts(List<Company.Account> accounts)An array of bank account objects associated with the payroll/HRIS system. final Company.Builderaccounts(Optional<List<Company.Account>> accounts)Alias for calling Builder.accounts with accounts.orElse(null).final Company.Builderaccounts(JsonField<List<Company.Account>> accounts)Sets Builder.accounts to an arbitrary JSON value. final Company.BuilderaddAccount(Company.Account account)Adds a single Account to accounts. final Company.Builderdepartments(List<Company.Department> departments)The array of company departments. final Company.Builderdepartments(Optional<List<Company.Department>> departments)Alias for calling Builder.departments with departments.orElse(null).final Company.Builderdepartments(JsonField<List<Company.Department>> departments)Sets Builder.departments to an arbitrary JSON value. final Company.BuilderaddDepartment(Company.Department department)Adds a single Department to departments. final Company.Builderein(String ein)The employer identification number. final Company.Builderein(Optional<String> ein)Alias for calling Builder.ein with ein.orElse(null).final Company.Builderein(JsonField<String> ein)Sets Builder.ein to an arbitrary JSON value. final Company.Builderentity(Company.Entity entity)The entity type object. final Company.Builderentity(Optional<Company.Entity> entity)Alias for calling Builder.entity with entity.orElse(null).final Company.Builderentity(JsonField<Company.Entity> entity)Sets Builder.entity to an arbitrary JSON value. final Company.BuilderlegalName(String legalName)The legal name of the company. final Company.BuilderlegalName(Optional<String> legalName)Alias for calling Builder.legalName with legalName.orElse(null).final Company.BuilderlegalName(JsonField<String> legalName)Sets Builder.legalName to an arbitrary JSON value. final Company.Builderlocations(List<Location> locations)final Company.Builderlocations(Optional<List<Location>> locations)Alias for calling Builder.locations with locations.orElse(null).final Company.Builderlocations(JsonField<List<Location>> locations)Sets Builder.locations to an arbitrary JSON value. final Company.BuilderaddLocation(Location location)Adds a single Location to locations. final Company.BuilderprimaryEmail(String primaryEmail)The email of the main administrator on the account. final Company.BuilderprimaryEmail(Optional<String> primaryEmail)Alias for calling Builder.primaryEmail with primaryEmail.orElse(null).final Company.BuilderprimaryEmail(JsonField<String> primaryEmail)Sets Builder.primaryEmail to an arbitrary JSON value. final Company.BuilderprimaryPhoneNumber(String primaryPhoneNumber)The phone number of the main administrator on the account. final Company.BuilderprimaryPhoneNumber(Optional<String> primaryPhoneNumber)Alias for calling Builder.primaryPhoneNumber with primaryPhoneNumber.orElse(null).final Company.BuilderprimaryPhoneNumber(JsonField<String> primaryPhoneNumber)Sets Builder.primaryPhoneNumber to an arbitrary JSON value. final Company.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Company.BuilderputAdditionalProperty(String key, JsonValue value)final Company.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Company.BuilderremoveAdditionalProperty(String key)final Company.BuilderremoveAllAdditionalProperties(Set<String> keys)final Companybuild()Returns an immutable instance of Company. -
-
Method Detail
-
id
final Company.Builder id(String id)
A stable Finch
id(UUID v4) for the company.
-
id
final Company.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accounts
final Company.Builder accounts(List<Company.Account> accounts)
An array of bank account objects associated with the payroll/HRIS system.
-
accounts
final Company.Builder accounts(Optional<List<Company.Account>> accounts)
Alias for calling Builder.accounts with
accounts.orElse(null).
-
accounts
final Company.Builder accounts(JsonField<List<Company.Account>> accounts)
Sets Builder.accounts to an arbitrary JSON value.
You should usually call Builder.accounts with a well-typed
List<Account>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addAccount
final Company.Builder addAccount(Company.Account account)
-
departments
final Company.Builder departments(List<Company.Department> departments)
The array of company departments.
-
departments
final Company.Builder departments(Optional<List<Company.Department>> departments)
Alias for calling Builder.departments with
departments.orElse(null).
-
departments
final Company.Builder departments(JsonField<List<Company.Department>> departments)
Sets Builder.departments to an arbitrary JSON value.
You should usually call Builder.departments with a well-typed
List<Department?>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addDepartment
final Company.Builder addDepartment(Company.Department department)
Adds a single Department to departments.
-
ein
final Company.Builder ein(String ein)
The employer identification number.
-
ein
final Company.Builder ein(Optional<String> ein)
Alias for calling Builder.ein with
ein.orElse(null).
-
ein
final Company.Builder ein(JsonField<String> ein)
Sets Builder.ein to an arbitrary JSON value.
You should usually call Builder.ein with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entity
final Company.Builder entity(Company.Entity entity)
The entity type object.
-
entity
final Company.Builder entity(Optional<Company.Entity> entity)
Alias for calling Builder.entity with
entity.orElse(null).
-
entity
final Company.Builder entity(JsonField<Company.Entity> entity)
Sets Builder.entity to an arbitrary JSON value.
You should usually call Builder.entity with a well-typed Entity value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
legalName
final Company.Builder legalName(String legalName)
The legal name of the company.
-
legalName
final Company.Builder legalName(Optional<String> legalName)
Alias for calling Builder.legalName with
legalName.orElse(null).
-
legalName
final Company.Builder legalName(JsonField<String> legalName)
Sets Builder.legalName to an arbitrary JSON value.
You should usually call Builder.legalName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
locations
final Company.Builder locations(List<Location> locations)
-
locations
final Company.Builder locations(Optional<List<Location>> locations)
Alias for calling Builder.locations with
locations.orElse(null).
-
locations
final Company.Builder locations(JsonField<List<Location>> locations)
Sets Builder.locations to an arbitrary JSON value.
You should usually call Builder.locations with a well-typed
List<Location?>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addLocation
final Company.Builder addLocation(Location location)
-
primaryEmail
final Company.Builder primaryEmail(String primaryEmail)
The email of the main administrator on the account.
-
primaryEmail
final Company.Builder primaryEmail(Optional<String> primaryEmail)
Alias for calling Builder.primaryEmail with
primaryEmail.orElse(null).
-
primaryEmail
final Company.Builder primaryEmail(JsonField<String> primaryEmail)
Sets Builder.primaryEmail to an arbitrary JSON value.
You should usually call Builder.primaryEmail with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
primaryPhoneNumber
final Company.Builder primaryPhoneNumber(String primaryPhoneNumber)
The phone number of the main administrator on the account. Format: E.164, with extension where applicable, e.g.
+NNNNNNNNNNN xExtension
-
primaryPhoneNumber
final Company.Builder primaryPhoneNumber(Optional<String> primaryPhoneNumber)
Alias for calling Builder.primaryPhoneNumber with
primaryPhoneNumber.orElse(null).
-
primaryPhoneNumber
final Company.Builder primaryPhoneNumber(JsonField<String> primaryPhoneNumber)
Sets Builder.primaryPhoneNumber to an arbitrary JSON value.
You should usually call Builder.primaryPhoneNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Company.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Company.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Company.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Company.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Company.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-