Package com.tryfinch.api.models
Class Company.Department
-
- All Implemented Interfaces:
public final class Company.Department
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCompany.Department.BuilderA builder for Department.
public final classCompany.Department.ParentThe parent department, if present.
-
Method Summary
Modifier and Type Method Description final Optional<String>name()The department name. final Optional<Company.Department.Parent>parent()The parent department, if present. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<Company.Department.Parent>_parent()Returns the raw JSON value of parent. final Map<String, JsonValue>_additionalProperties()final Company.Department.BuildertoBuilder()final Company.Departmentvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Company.Department.Builderbuilder()Returns a mutable builder for constructing an instance of Department. -
-
Method Detail
-
parent
final Optional<Company.Department.Parent> parent()
The parent department, if present.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_parent
final JsonField<Company.Department.Parent> _parent()
Returns the raw JSON value of parent.
Unlike parent, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Company.Department.Builder toBuilder()
-
validate
final Company.Department validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Company.Department.Builder builder()
Returns a mutable builder for constructing an instance of Department.
The following fields are required:
.name() .parent()
-
-
-
-