Package com.tryfinch.api.models
Class Company.Entity
-
- All Implemented Interfaces:
public final class Company.EntityThe entity type object.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCompany.Entity.BuilderA builder for Entity.
public final classCompany.Entity.SubtypeThe tax payer subtype of the company.
public final classCompany.Entity.TypeThe tax payer type of the company.
-
Method Summary
Modifier and Type Method Description final Optional<Company.Entity.Subtype>subtype()The tax payer subtype of the company. final Optional<Company.Entity.Type>type()The tax payer type of the company. final JsonField<Company.Entity.Subtype>_subtype()Returns the raw JSON value of subtype. final JsonField<Company.Entity.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final Company.Entity.BuildertoBuilder()final Company.Entityvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Company.Entity.Builderbuilder()Returns a mutable builder for constructing an instance of Entity. -
-
Method Detail
-
subtype
final Optional<Company.Entity.Subtype> subtype()
The tax payer subtype of the company.
-
type
final Optional<Company.Entity.Type> type()
The tax payer type of the company.
-
_subtype
final JsonField<Company.Entity.Subtype> _subtype()
Returns the raw JSON value of subtype.
Unlike subtype, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<Company.Entity.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Company.Entity.Builder toBuilder()
-
validate
final Company.Entity validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Company.Entity.Builder builder()
Returns a mutable builder for constructing an instance of Entity.
The following fields are required:
.subtype() .type()
-
-
-
-