Class Company.Entity.Builder
-
- All Implemented Interfaces:
public final class Company.Entity.BuilderA builder for Entity.
-
-
Method Summary
-
-
Method Detail
-
subtype
final Company.Entity.Builder subtype(Company.Entity.Subtype subtype)
The tax payer subtype of the company.
-
subtype
final Company.Entity.Builder subtype(Optional<Company.Entity.Subtype> subtype)
Alias for calling Builder.subtype with
subtype.orElse(null).
-
subtype
final Company.Entity.Builder subtype(JsonField<Company.Entity.Subtype> subtype)
Sets Builder.subtype to an arbitrary JSON value.
You should usually call Builder.subtype with a well-typed Subtype value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final Company.Entity.Builder type(Company.Entity.Type type)
The tax payer type of the company.
-
type
final Company.Entity.Builder type(Optional<Company.Entity.Type> type)
Alias for calling Builder.type with
type.orElse(null).
-
type
final Company.Entity.Builder type(JsonField<Company.Entity.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Company.Entity.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Company.Entity.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Company.Entity.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Company.Entity.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Company.Entity.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Company.Entity build()
Returns an immutable instance of Entity.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.subtype() .type()
-
-
-
-