Class CompanyBenefit
-
- All Implemented Interfaces:
public final class CompanyBenefit
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCompanyBenefit.BuilderA builder for CompanyBenefit.
public final classCompanyBenefit.BenefitCompanyMatchContributionThe company match for this benefit.
-
Method Summary
Modifier and Type Method Description final StringbenefitId()The id of the benefit. final Optional<String>description()final Optional<BenefitFrequency>frequency()The frequency of the benefit deduction/contribution. final Optional<BenefitType>type()Type of benefit. final Optional<CompanyBenefit.BenefitCompanyMatchContribution>companyContribution()The company match for this benefit. final JsonField<String>_benefitId()Returns the raw JSON value of benefitId. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<BenefitFrequency>_frequency()Returns the raw JSON value of frequency. final JsonField<BenefitType>_type()Returns the raw JSON value of type. final JsonField<CompanyBenefit.BenefitCompanyMatchContribution>_companyContribution()Returns the raw JSON value of companyContribution. final Map<String, JsonValue>_additionalProperties()final CompanyBenefit.BuildertoBuilder()final CompanyBenefitvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CompanyBenefit.Builderbuilder()Returns a mutable builder for constructing an instance of CompanyBenefit. -
-
Method Detail
-
description
final Optional<String> description()
-
frequency
final Optional<BenefitFrequency> frequency()
The frequency of the benefit deduction/contribution.
-
type
final Optional<BenefitType> type()
Type of benefit.
-
companyContribution
final Optional<CompanyBenefit.BenefitCompanyMatchContribution> companyContribution()
The company match for this benefit.
-
_benefitId
final JsonField<String> _benefitId()
Returns the raw JSON value of benefitId.
Unlike benefitId, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_frequency
final JsonField<BenefitFrequency> _frequency()
Returns the raw JSON value of frequency.
Unlike frequency, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<BenefitType> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_companyContribution
final JsonField<CompanyBenefit.BenefitCompanyMatchContribution> _companyContribution()
Returns the raw JSON value of companyContribution.
Unlike companyContribution, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CompanyBenefit.Builder toBuilder()
-
validate
final CompanyBenefit validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CompanyBenefit.Builder builder()
Returns a mutable builder for constructing an instance of CompanyBenefit.
The following fields are required:
.benefitId() .description() .frequency() .type()
-
-
-
-