Class CompanyEvent
-
- All Implemented Interfaces:
public final class CompanyEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCompanyEvent.BuilderA builder for CompanyEvent.
public final classCompanyEvent.Datapublic final classCompanyEvent.EventType
-
Method Summary
Modifier and Type Method Description final BaseWebhookEventtoBaseWebhookEvent()final StringaccountId()DEPRECATED Unique Finch ID of the employer account used to make this connection. final StringcompanyId()DEPRECATED Unique Finch ID of the company for which data has been updated. final Optional<String>connectionId()Unique Finch ID of the connection associated with the webhook event. final Optional<String>entityId()Unique Finch id of the entity for which data has been updated. final Optional<CompanyEvent.Data>data()final Optional<CompanyEvent.EventType>eventType()final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<String>_companyId()Returns the raw JSON value of companyId. final JsonField<String>_connectionId()Returns the raw JSON value of connectionId. final JsonField<String>_entityId()Returns the raw JSON value of entityId. final JsonField<CompanyEvent.Data>_data()Returns the raw JSON value of data. final JsonField<CompanyEvent.EventType>_eventType()Returns the raw JSON value of eventType. final Map<String, JsonValue>_additionalProperties()final CompanyEvent.BuildertoBuilder()final CompanyEventvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CompanyEvent.Builderbuilder()Returns a mutable builder for constructing an instance of CompanyEvent. -
-
Method Detail
-
toBaseWebhookEvent
final BaseWebhookEvent toBaseWebhookEvent()
-
accountId
@Deprecated(message = "deprecated") final String accountId()
DEPRECATED Unique Finch ID of the employer account used to make this connection. Use
connection_idinstead to identify the connection associated with this event.
-
companyId
@Deprecated(message = "deprecated") final String companyId()
DEPRECATED Unique Finch ID of the company for which data has been updated. Use
connection_idinstead to identify the connection associated with this event.
-
connectionId
final Optional<String> connectionId()
Unique Finch ID of the connection associated with the webhook event.
-
entityId
final Optional<String> entityId()
Unique Finch id of the entity for which data has been updated.
-
data
final Optional<CompanyEvent.Data> data()
-
eventType
final Optional<CompanyEvent.EventType> eventType()
-
_accountId
@Deprecated(message = "deprecated") final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_companyId
@Deprecated(message = "deprecated") final JsonField<String> _companyId()
Returns the raw JSON value of companyId.
Unlike companyId, this method doesn't throw if the JSON field has an unexpected type.
-
_connectionId
final JsonField<String> _connectionId()
Returns the raw JSON value of connectionId.
Unlike connectionId, this method doesn't throw if the JSON field has an unexpected type.
-
_entityId
final JsonField<String> _entityId()
Returns the raw JSON value of entityId.
Unlike entityId, this method doesn't throw if the JSON field has an unexpected type.
-
_data
final JsonField<CompanyEvent.Data> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<CompanyEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CompanyEvent.Builder toBuilder()
-
validate
final CompanyEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CompanyEvent.Builder builder()
Returns a mutable builder for constructing an instance of CompanyEvent.
The following fields are required:
.accountId() .companyId()
-
-
-
-