Package com.tryfinch.api.models
Class CompanyEvent.Data
-
- All Implemented Interfaces:
public final class CompanyEvent.Data
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCompanyEvent.Data.BuilderA builder for Data.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final CompanyEvent.Data.BuildertoBuilder()final CompanyEvent.Datavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CompanyEvent.Data.Builderbuilder()Returns a mutable builder for constructing an instance of Data. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CompanyEvent.Data.Builder toBuilder()
-
validate
final CompanyEvent.Data validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CompanyEvent.Data.Builder builder()
Returns a mutable builder for constructing an instance of Data.
-
-
-
-