Class CompanyUpdateResponse
-
- All Implemented Interfaces:
public final class CompanyUpdateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCompanyUpdateResponse.BuilderA builder for CompanyUpdateResponse.
public final classCompanyUpdateResponse.Accountpublic final classCompanyUpdateResponse.Departmentpublic final classCompanyUpdateResponse.EntityThe entity type object.
-
Method Summary
Modifier and Type Method Description final Optional<List<CompanyUpdateResponse.Account>>accounts()An array of bank account objects associated with the payroll/HRIS system. final Optional<List<CompanyUpdateResponse.Department>>departments()The array of company departments. final Optional<String>ein()The employer identification number. final Optional<CompanyUpdateResponse.Entity>entity()The entity type object. final Optional<String>legalName()The legal name of the company. final Optional<List<Location>>locations()final Optional<String>primaryEmail()The email of the main administrator on the account. final Optional<String>primaryPhoneNumber()The phone number of the main administrator on the account. final JsonField<List<CompanyUpdateResponse.Account>>_accounts()Returns the raw JSON value of accounts. final JsonField<List<CompanyUpdateResponse.Department>>_departments()Returns the raw JSON value of departments. final JsonField<String>_ein()Returns the raw JSON value of ein. final JsonField<CompanyUpdateResponse.Entity>_entity()Returns the raw JSON value of entity. final JsonField<String>_legalName()Returns the raw JSON value of legalName. final JsonField<List<Location>>_locations()Returns the raw JSON value of locations. final JsonField<String>_primaryEmail()Returns the raw JSON value of primaryEmail. final JsonField<String>_primaryPhoneNumber()Returns the raw JSON value of primaryPhoneNumber. final Map<String, JsonValue>_additionalProperties()final CompanyUpdateResponse.BuildertoBuilder()final CompanyUpdateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CompanyUpdateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of CompanyUpdateResponse. -
-
Method Detail
-
accounts
final Optional<List<CompanyUpdateResponse.Account>> accounts()
An array of bank account objects associated with the payroll/HRIS system.
-
departments
final Optional<List<CompanyUpdateResponse.Department>> departments()
The array of company departments.
-
entity
final Optional<CompanyUpdateResponse.Entity> entity()
The entity type object.
-
primaryEmail
final Optional<String> primaryEmail()
The email of the main administrator on the account.
-
primaryPhoneNumber
final Optional<String> primaryPhoneNumber()
The phone number of the main administrator on the account. Format: E.164, with extension where applicable, e.g.
+NNNNNNNNNNN xExtension
-
_accounts
final JsonField<List<CompanyUpdateResponse.Account>> _accounts()
Returns the raw JSON value of accounts.
Unlike accounts, this method doesn't throw if the JSON field has an unexpected type.
-
_departments
final JsonField<List<CompanyUpdateResponse.Department>> _departments()
Returns the raw JSON value of departments.
Unlike departments, this method doesn't throw if the JSON field has an unexpected type.
-
_ein
final JsonField<String> _ein()
Returns the raw JSON value of ein.
Unlike ein, this method doesn't throw if the JSON field has an unexpected type.
-
_entity
final JsonField<CompanyUpdateResponse.Entity> _entity()
Returns the raw JSON value of entity.
Unlike entity, this method doesn't throw if the JSON field has an unexpected type.
-
_legalName
final JsonField<String> _legalName()
Returns the raw JSON value of legalName.
Unlike legalName, this method doesn't throw if the JSON field has an unexpected type.
-
_locations
final JsonField<List<Location>> _locations()
Returns the raw JSON value of locations.
Unlike locations, this method doesn't throw if the JSON field has an unexpected type.
-
_primaryEmail
final JsonField<String> _primaryEmail()
Returns the raw JSON value of primaryEmail.
Unlike primaryEmail, this method doesn't throw if the JSON field has an unexpected type.
-
_primaryPhoneNumber
final JsonField<String> _primaryPhoneNumber()
Returns the raw JSON value of primaryPhoneNumber.
Unlike primaryPhoneNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CompanyUpdateResponse.Builder toBuilder()
-
validate
final CompanyUpdateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CompanyUpdateResponse.Builder builder()
Returns a mutable builder for constructing an instance of CompanyUpdateResponse.
The following fields are required:
.accounts() .departments() .ein() .entity() .legalName() .locations() .primaryEmail() .primaryPhoneNumber()
-
-
-
-