Class CompanyUpdateResponse.Account
-
- All Implemented Interfaces:
public final class CompanyUpdateResponse.Account
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCompanyUpdateResponse.Account.BuilderA builder for Account.
public final classCompanyUpdateResponse.Account.AccountTypeThe type of bank account.
-
Method Summary
Modifier and Type Method Description final Optional<String>accountName()The name of the bank associated in the payroll/HRIS system. final Optional<String>accountNumber()10-12 digit number to specify the bank account final Optional<CompanyUpdateResponse.Account.AccountType>accountType()The type of bank account. final Optional<String>institutionName()Name of the banking institution. final Optional<String>routingNumber()A nine-digit code that's based on the U.S. final JsonField<String>_accountName()Returns the raw JSON value of accountName. final JsonField<String>_accountNumber()Returns the raw JSON value of accountNumber. final JsonField<CompanyUpdateResponse.Account.AccountType>_accountType()Returns the raw JSON value of accountType. final JsonField<String>_institutionName()Returns the raw JSON value of institutionName. final JsonField<String>_routingNumber()Returns the raw JSON value of routingNumber. final Map<String, JsonValue>_additionalProperties()final CompanyUpdateResponse.Account.BuildertoBuilder()final CompanyUpdateResponse.Accountvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CompanyUpdateResponse.Account.Builderbuilder()Returns a mutable builder for constructing an instance of Account. -
-
Method Detail
-
accountName
final Optional<String> accountName()
The name of the bank associated in the payroll/HRIS system.
-
accountNumber
final Optional<String> accountNumber()
10-12 digit number to specify the bank account
-
accountType
final Optional<CompanyUpdateResponse.Account.AccountType> accountType()
The type of bank account.
-
institutionName
final Optional<String> institutionName()
Name of the banking institution.
-
routingNumber
final Optional<String> routingNumber()
A nine-digit code that's based on the U.S. Bank location where your account was opened.
-
_accountName
final JsonField<String> _accountName()
Returns the raw JSON value of accountName.
Unlike accountName, this method doesn't throw if the JSON field has an unexpected type.
-
_accountNumber
final JsonField<String> _accountNumber()
Returns the raw JSON value of accountNumber.
Unlike accountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_accountType
final JsonField<CompanyUpdateResponse.Account.AccountType> _accountType()
Returns the raw JSON value of accountType.
Unlike accountType, this method doesn't throw if the JSON field has an unexpected type.
-
_institutionName
final JsonField<String> _institutionName()
Returns the raw JSON value of institutionName.
Unlike institutionName, this method doesn't throw if the JSON field has an unexpected type.
-
_routingNumber
final JsonField<String> _routingNumber()
Returns the raw JSON value of routingNumber.
Unlike routingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CompanyUpdateResponse.Account.Builder toBuilder()
-
validate
final CompanyUpdateResponse.Account validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CompanyUpdateResponse.Account.Builder builder()
Returns a mutable builder for constructing an instance of Account.
-
-
-
-