Class CompanyUpdateResponse.Builder
-
- All Implemented Interfaces:
public final class CompanyUpdateResponse.BuilderA builder for CompanyUpdateResponse.
-
-
Method Summary
-
-
Method Detail
-
accounts
final CompanyUpdateResponse.Builder accounts(List<CompanyUpdateResponse.Account> accounts)
An array of bank account objects associated with the payroll/HRIS system.
-
accounts
final CompanyUpdateResponse.Builder accounts(Optional<List<CompanyUpdateResponse.Account>> accounts)
Alias for calling Builder.accounts with
accounts.orElse(null).
-
accounts
final CompanyUpdateResponse.Builder accounts(JsonField<List<CompanyUpdateResponse.Account>> accounts)
Sets Builder.accounts to an arbitrary JSON value.
You should usually call Builder.accounts with a well-typed
List<Account>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addAccount
final CompanyUpdateResponse.Builder addAccount(CompanyUpdateResponse.Account account)
-
departments
final CompanyUpdateResponse.Builder departments(List<CompanyUpdateResponse.Department> departments)
The array of company departments.
-
departments
final CompanyUpdateResponse.Builder departments(Optional<List<CompanyUpdateResponse.Department>> departments)
Alias for calling Builder.departments with
departments.orElse(null).
-
departments
final CompanyUpdateResponse.Builder departments(JsonField<List<CompanyUpdateResponse.Department>> departments)
Sets Builder.departments to an arbitrary JSON value.
You should usually call Builder.departments with a well-typed
List<Department?>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addDepartment
final CompanyUpdateResponse.Builder addDepartment(CompanyUpdateResponse.Department department)
Adds a single Department to departments.
-
ein
final CompanyUpdateResponse.Builder ein(String ein)
The employer identification number.
-
ein
final CompanyUpdateResponse.Builder ein(Optional<String> ein)
Alias for calling Builder.ein with
ein.orElse(null).
-
ein
final CompanyUpdateResponse.Builder ein(JsonField<String> ein)
Sets Builder.ein to an arbitrary JSON value.
You should usually call Builder.ein with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entity
final CompanyUpdateResponse.Builder entity(CompanyUpdateResponse.Entity entity)
The entity type object.
-
entity
final CompanyUpdateResponse.Builder entity(Optional<CompanyUpdateResponse.Entity> entity)
Alias for calling Builder.entity with
entity.orElse(null).
-
entity
final CompanyUpdateResponse.Builder entity(JsonField<CompanyUpdateResponse.Entity> entity)
Sets Builder.entity to an arbitrary JSON value.
You should usually call Builder.entity with a well-typed Entity value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
legalName
final CompanyUpdateResponse.Builder legalName(String legalName)
The legal name of the company.
-
legalName
final CompanyUpdateResponse.Builder legalName(Optional<String> legalName)
Alias for calling Builder.legalName with
legalName.orElse(null).
-
legalName
final CompanyUpdateResponse.Builder legalName(JsonField<String> legalName)
Sets Builder.legalName to an arbitrary JSON value.
You should usually call Builder.legalName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
locations
final CompanyUpdateResponse.Builder locations(List<Location> locations)
-
locations
final CompanyUpdateResponse.Builder locations(Optional<List<Location>> locations)
Alias for calling Builder.locations with
locations.orElse(null).
-
locations
final CompanyUpdateResponse.Builder locations(JsonField<List<Location>> locations)
Sets Builder.locations to an arbitrary JSON value.
You should usually call Builder.locations with a well-typed
List<Location?>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addLocation
final CompanyUpdateResponse.Builder addLocation(Location location)
-
primaryEmail
final CompanyUpdateResponse.Builder primaryEmail(String primaryEmail)
The email of the main administrator on the account.
-
primaryEmail
final CompanyUpdateResponse.Builder primaryEmail(Optional<String> primaryEmail)
Alias for calling Builder.primaryEmail with
primaryEmail.orElse(null).
-
primaryEmail
final CompanyUpdateResponse.Builder primaryEmail(JsonField<String> primaryEmail)
Sets Builder.primaryEmail to an arbitrary JSON value.
You should usually call Builder.primaryEmail with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
primaryPhoneNumber
final CompanyUpdateResponse.Builder primaryPhoneNumber(String primaryPhoneNumber)
The phone number of the main administrator on the account. Format: E.164, with extension where applicable, e.g.
+NNNNNNNNNNN xExtension
-
primaryPhoneNumber
final CompanyUpdateResponse.Builder primaryPhoneNumber(Optional<String> primaryPhoneNumber)
Alias for calling Builder.primaryPhoneNumber with
primaryPhoneNumber.orElse(null).
-
primaryPhoneNumber
final CompanyUpdateResponse.Builder primaryPhoneNumber(JsonField<String> primaryPhoneNumber)
Sets Builder.primaryPhoneNumber to an arbitrary JSON value.
You should usually call Builder.primaryPhoneNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CompanyUpdateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CompanyUpdateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CompanyUpdateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CompanyUpdateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CompanyUpdateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CompanyUpdateResponse build()
Returns an immutable instance of CompanyUpdateResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accounts() .departments() .ein() .entity() .legalName() .locations() .primaryEmail() .primaryPhoneNumber()
-
-
-
-