Package com.tryfinch.api.models
Class CompanyUpdateResponse.Department.Parent
-
- All Implemented Interfaces:
public final class CompanyUpdateResponse.Department.ParentThe parent department, if present.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCompanyUpdateResponse.Department.Parent.BuilderA builder for Parent.
-
Method Summary
Modifier and Type Method Description final Optional<String>name()The parent department's name. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final CompanyUpdateResponse.Department.Parent.BuildertoBuilder()final CompanyUpdateResponse.Department.Parentvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CompanyUpdateResponse.Department.Parent.Builderbuilder()Returns a mutable builder for constructing an instance of Parent. -
-
Method Detail
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CompanyUpdateResponse.Department.Parent.Builder toBuilder()
-
validate
final CompanyUpdateResponse.Department.Parent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CompanyUpdateResponse.Department.Parent.Builder builder()
Returns a mutable builder for constructing an instance of Parent.
-
-
-
-