Package com.tryfinch.api.models
Class CompanyUpdateResponse.Entity
-
- All Implemented Interfaces:
public final class CompanyUpdateResponse.EntityThe entity type object.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCompanyUpdateResponse.Entity.BuilderA builder for Entity.
public final classCompanyUpdateResponse.Entity.SubtypeThe tax payer subtype of the company.
public final classCompanyUpdateResponse.Entity.TypeThe tax payer type of the company.
-
Method Summary
Modifier and Type Method Description final Optional<CompanyUpdateResponse.Entity.Subtype>subtype()The tax payer subtype of the company. final Optional<CompanyUpdateResponse.Entity.Type>type()The tax payer type of the company. final JsonField<CompanyUpdateResponse.Entity.Subtype>_subtype()Returns the raw JSON value of subtype. final JsonField<CompanyUpdateResponse.Entity.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final CompanyUpdateResponse.Entity.BuildertoBuilder()final CompanyUpdateResponse.Entityvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CompanyUpdateResponse.Entity.Builderbuilder()Returns a mutable builder for constructing an instance of Entity. -
-
Method Detail
-
subtype
final Optional<CompanyUpdateResponse.Entity.Subtype> subtype()
The tax payer subtype of the company.
-
type
final Optional<CompanyUpdateResponse.Entity.Type> type()
The tax payer type of the company.
-
_subtype
final JsonField<CompanyUpdateResponse.Entity.Subtype> _subtype()
Returns the raw JSON value of subtype.
Unlike subtype, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<CompanyUpdateResponse.Entity.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CompanyUpdateResponse.Entity.Builder toBuilder()
-
validate
final CompanyUpdateResponse.Entity validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CompanyUpdateResponse.Entity.Builder builder()
Returns a mutable builder for constructing an instance of Entity.
-
-
-
-