Class CompanyUpdateResponse.Entity.Builder
-
- All Implemented Interfaces:
public final class CompanyUpdateResponse.Entity.BuilderA builder for Entity.
-
-
Method Summary
-
-
Method Detail
-
subtype
final CompanyUpdateResponse.Entity.Builder subtype(CompanyUpdateResponse.Entity.Subtype subtype)
The tax payer subtype of the company.
-
subtype
final CompanyUpdateResponse.Entity.Builder subtype(Optional<CompanyUpdateResponse.Entity.Subtype> subtype)
Alias for calling Builder.subtype with
subtype.orElse(null).
-
subtype
final CompanyUpdateResponse.Entity.Builder subtype(JsonField<CompanyUpdateResponse.Entity.Subtype> subtype)
Sets Builder.subtype to an arbitrary JSON value.
You should usually call Builder.subtype with a well-typed Subtype value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final CompanyUpdateResponse.Entity.Builder type(CompanyUpdateResponse.Entity.Type type)
The tax payer type of the company.
-
type
final CompanyUpdateResponse.Entity.Builder type(Optional<CompanyUpdateResponse.Entity.Type> type)
Alias for calling Builder.type with
type.orElse(null).
-
type
final CompanyUpdateResponse.Entity.Builder type(JsonField<CompanyUpdateResponse.Entity.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CompanyUpdateResponse.Entity.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CompanyUpdateResponse.Entity.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CompanyUpdateResponse.Entity.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CompanyUpdateResponse.Entity.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CompanyUpdateResponse.Entity.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CompanyUpdateResponse.Entity build()
Returns an immutable instance of Entity.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-