Class ConnectSessionNewParams.Body
-
- All Implemented Interfaces:
public final class ConnectSessionNewParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classConnectSessionNewParams.Body.BuilderA builder for Body.
-
Method Summary
-
-
Method Detail
-
customerId
final String customerId()
-
customerName
final String customerName()
-
products
final List<ConnectSessionNewParams.ConnectProducts> products()
-
customerEmail
final Optional<String> customerEmail()
-
integration
final Optional<ConnectSessionNewParams.Integration> integration()
-
minutesToExpire
final Optional<Double> minutesToExpire()
The number of minutes until the session expires (defaults to 129,600, which is 90 days)
-
redirectUri
final Optional<String> redirectUri()
-
sandbox
final Optional<ConnectSessionNewParams.Sandbox> sandbox()
-
_customerId
final JsonField<String> _customerId()
Returns the raw JSON value of customerId.
Unlike customerId, this method doesn't throw if the JSON field has an unexpected type.
-
_customerName
final JsonField<String> _customerName()
Returns the raw JSON value of customerName.
Unlike customerName, this method doesn't throw if the JSON field has an unexpected type.
-
_products
final JsonField<List<ConnectSessionNewParams.ConnectProducts>> _products()
Returns the raw JSON value of products.
Unlike products, this method doesn't throw if the JSON field has an unexpected type.
-
_customerEmail
final JsonField<String> _customerEmail()
Returns the raw JSON value of customerEmail.
Unlike customerEmail, this method doesn't throw if the JSON field has an unexpected type.
-
_integration
final JsonField<ConnectSessionNewParams.Integration> _integration()
Returns the raw JSON value of integration.
Unlike integration, this method doesn't throw if the JSON field has an unexpected type.
-
_manual
final JsonField<Boolean> _manual()
Returns the raw JSON value of manual.
Unlike manual, this method doesn't throw if the JSON field has an unexpected type.
-
_minutesToExpire
final JsonField<Double> _minutesToExpire()
Returns the raw JSON value of minutesToExpire.
Unlike minutesToExpire, this method doesn't throw if the JSON field has an unexpected type.
-
_redirectUri
final JsonField<String> _redirectUri()
Returns the raw JSON value of redirectUri.
Unlike redirectUri, this method doesn't throw if the JSON field has an unexpected type.
-
_sandbox
final JsonField<ConnectSessionNewParams.Sandbox> _sandbox()
Returns the raw JSON value of sandbox.
Unlike sandbox, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ConnectSessionNewParams.Body.Builder toBuilder()
-
validate
final ConnectSessionNewParams.Body validate()
-
builder
final static ConnectSessionNewParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.customerId() .customerName() .products()
-
-
-
-