Class ConnectSessionNewParams.CreateConnectSessionRequest.Builder
-
- All Implemented Interfaces:
public final class ConnectSessionNewParams.CreateConnectSessionRequest.BuilderA builder for CreateConnectSessionRequest.
-
-
Method Summary
-
-
Method Detail
-
customerId
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder customerId(String customerId)
Unique identifier for the customer
-
customerId
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder customerId(JsonField<String> customerId)
Sets Builder.customerId to an arbitrary JSON value.
You should usually call Builder.customerId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customerName
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder customerName(String customerName)
Name of the customer
-
customerName
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder customerName(JsonField<String> customerName)
Sets Builder.customerName to an arbitrary JSON value.
You should usually call Builder.customerName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
products
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder products(List<ConnectSessionNewParams.ConnectProducts> products)
The Finch products to request access to. Use
benefitsto access deductions endpoints —deductionis a deprecated alias that is still accepted but should not be combined withbenefits.
-
products
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder products(JsonField<List<ConnectSessionNewParams.ConnectProducts>> products)
Sets Builder.products to an arbitrary JSON value.
You should usually call Builder.products with a well-typed
List<ConnectProducts>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addProduct
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder addProduct(ConnectSessionNewParams.ConnectProducts product)
Adds a single ConnectProducts to products.
-
customerEmail
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder customerEmail(String customerEmail)
Email address of the customer
-
customerEmail
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder customerEmail(Optional<String> customerEmail)
Alias for calling Builder.customerEmail with
customerEmail.orElse(null).
-
customerEmail
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder customerEmail(JsonField<String> customerEmail)
Sets Builder.customerEmail to an arbitrary JSON value.
You should usually call Builder.customerEmail with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
integration
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder integration(ConnectSessionNewParams.Integration integration)
Integration configuration for the connect session
-
integration
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder integration(Optional<ConnectSessionNewParams.Integration> integration)
Alias for calling Builder.integration with
integration.orElse(null).
-
integration
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder integration(JsonField<ConnectSessionNewParams.Integration> integration)
Sets Builder.integration to an arbitrary JSON value.
You should usually call Builder.integration with a well-typed Integration value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
manual
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder manual(Boolean manual)
Enable manual authentication mode
-
manual
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder manual(Boolean manual)
Alias for Builder.manual.
This unboxed primitive overload exists for backwards compatibility.
-
manual
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder manual(Optional<Boolean> manual)
Alias for calling Builder.manual with
manual.orElse(null).
-
manual
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder manual(JsonField<Boolean> manual)
Sets Builder.manual to an arbitrary JSON value.
You should usually call Builder.manual with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
minutesToExpire
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder minutesToExpire(Double minutesToExpire)
The number of minutes until the session expires (defaults to 129,600, which is 90 days)
-
minutesToExpire
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder minutesToExpire(Double minutesToExpire)
Alias for Builder.minutesToExpire.
This unboxed primitive overload exists for backwards compatibility.
-
minutesToExpire
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder minutesToExpire(Optional<Double> minutesToExpire)
Alias for calling Builder.minutesToExpire with
minutesToExpire.orElse(null).
-
minutesToExpire
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder minutesToExpire(JsonField<Double> minutesToExpire)
Sets Builder.minutesToExpire to an arbitrary JSON value.
You should usually call Builder.minutesToExpire with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
redirectUri
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder redirectUri(String redirectUri)
The URI to redirect to after the Connect flow is completed
-
redirectUri
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder redirectUri(Optional<String> redirectUri)
Alias for calling Builder.redirectUri with
redirectUri.orElse(null).
-
redirectUri
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder redirectUri(JsonField<String> redirectUri)
Sets Builder.redirectUri to an arbitrary JSON value.
You should usually call Builder.redirectUri with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sandbox
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder sandbox(ConnectSessionNewParams.Sandbox sandbox)
Sandbox mode for testing
-
sandbox
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder sandbox(Optional<ConnectSessionNewParams.Sandbox> sandbox)
Alias for calling Builder.sandbox with
sandbox.orElse(null).
-
sandbox
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder sandbox(JsonField<ConnectSessionNewParams.Sandbox> sandbox)
Sets Builder.sandbox to an arbitrary JSON value.
You should usually call Builder.sandbox with a well-typed Sandbox value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ConnectSessionNewParams.CreateConnectSessionRequest build()
Returns an immutable instance of CreateConnectSessionRequest.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.customerId() .customerName() .products()
-
-
-
-