Class ConnectSessionReauthenticateParams
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Params
public final class ConnectSessionReauthenticateParams implements Params
Create a new Connect session for reauthenticating an existing connection
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classConnectSessionReauthenticateParams.BuilderA builder for ConnectSessionReauthenticateParams.
public final classConnectSessionReauthenticateParams.ReauthenticateRequestpublic final classConnectSessionReauthenticateParams.ConnectProducts
-
Method Summary
Modifier and Type Method Description final StringconnectionId()The ID of the existing connection to reauthenticate final Optional<Long>minutesToExpire()The number of minutes until the session expires (defaults to 43,200, which is 30 days) final Optional<List<ConnectSessionReauthenticateParams.ConnectProducts>>products()The products to request access to (optional for reauthentication). final Optional<String>redirectUri()The URI to redirect to after the Connect flow is completed final JsonField<String>_connectionId()Returns the raw JSON value of connectionId. final JsonField<Long>_minutesToExpire()Returns the raw JSON value of minutesToExpire. final JsonField<List<ConnectSessionReauthenticateParams.ConnectProducts>>_products()Returns the raw JSON value of products. final JsonField<String>_redirectUri()Returns the raw JSON value of redirectUri. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ConnectSessionReauthenticateParams.BuildertoBuilder()final ConnectSessionReauthenticateParams.ReauthenticateRequest_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ConnectSessionReauthenticateParams.Builderbuilder()Returns a mutable builder for constructing an instance of ConnectSessionReauthenticateParams. -
-
Method Detail
-
connectionId
final String connectionId()
The ID of the existing connection to reauthenticate
-
minutesToExpire
final Optional<Long> minutesToExpire()
The number of minutes until the session expires (defaults to 43,200, which is 30 days)
-
products
final Optional<List<ConnectSessionReauthenticateParams.ConnectProducts>> products()
The products to request access to (optional for reauthentication). Use
benefitsto access deductions endpoints —deductionis a deprecated alias that is still accepted but should not be combined withbenefits.
-
redirectUri
final Optional<String> redirectUri()
The URI to redirect to after the Connect flow is completed
-
_connectionId
final JsonField<String> _connectionId()
Returns the raw JSON value of connectionId.
Unlike connectionId, this method doesn't throw if the JSON field has an unexpected type.
-
_minutesToExpire
final JsonField<Long> _minutesToExpire()
Returns the raw JSON value of minutesToExpire.
Unlike minutesToExpire, this method doesn't throw if the JSON field has an unexpected type.
-
_products
final JsonField<List<ConnectSessionReauthenticateParams.ConnectProducts>> _products()
Returns the raw JSON value of products.
Unlike products, this method doesn't throw if the JSON field has an unexpected type.
-
_redirectUri
final JsonField<String> _redirectUri()
Returns the raw JSON value of redirectUri.
Unlike redirectUri, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ConnectSessionReauthenticateParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static ConnectSessionReauthenticateParams.Builder builder()
Returns a mutable builder for constructing an instance of ConnectSessionReauthenticateParams.
The following fields are required:
.connectionId()
-
-
-
-