Class ConnectSessionReauthenticateParams.Body
-
- All Implemented Interfaces:
public final class ConnectSessionReauthenticateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classConnectSessionReauthenticateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringconnectionId()The ID of the existing connection to reauthenticate final Optional<Long>minutesToExpire()The number of minutes until the session expires (defaults to 43,200, which is 30 days) final Optional<List<ConnectSessionReauthenticateParams.ConnectProducts>>products()The products to request access to (optional for reauthentication) final Optional<String>redirectUri()The URI to redirect to after the Connect flow is completed final JsonField<String>_connectionId()Returns the raw JSON value of connectionId. final JsonField<Long>_minutesToExpire()Returns the raw JSON value of minutesToExpire. final JsonField<List<ConnectSessionReauthenticateParams.ConnectProducts>>_products()Returns the raw JSON value of products. final JsonField<String>_redirectUri()Returns the raw JSON value of redirectUri. final Map<String, JsonValue>_additionalProperties()final ConnectSessionReauthenticateParams.Body.BuildertoBuilder()final ConnectSessionReauthenticateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ConnectSessionReauthenticateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
connectionId
final String connectionId()
The ID of the existing connection to reauthenticate
-
minutesToExpire
final Optional<Long> minutesToExpire()
The number of minutes until the session expires (defaults to 43,200, which is 30 days)
-
products
final Optional<List<ConnectSessionReauthenticateParams.ConnectProducts>> products()
The products to request access to (optional for reauthentication)
-
redirectUri
final Optional<String> redirectUri()
The URI to redirect to after the Connect flow is completed
-
_connectionId
final JsonField<String> _connectionId()
Returns the raw JSON value of connectionId.
Unlike connectionId, this method doesn't throw if the JSON field has an unexpected type.
-
_minutesToExpire
final JsonField<Long> _minutesToExpire()
Returns the raw JSON value of minutesToExpire.
Unlike minutesToExpire, this method doesn't throw if the JSON field has an unexpected type.
-
_products
final JsonField<List<ConnectSessionReauthenticateParams.ConnectProducts>> _products()
Returns the raw JSON value of products.
Unlike products, this method doesn't throw if the JSON field has an unexpected type.
-
_redirectUri
final JsonField<String> _redirectUri()
Returns the raw JSON value of redirectUri.
Unlike redirectUri, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ConnectSessionReauthenticateParams.Body.Builder toBuilder()
-
validate
final ConnectSessionReauthenticateParams.Body validate()
-
builder
final static ConnectSessionReauthenticateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.connectionId()
-
-
-
-