Class ConnectSessionReauthenticateParams.ReauthenticateRequest
-
- All Implemented Interfaces:
public final class ConnectSessionReauthenticateParams.ReauthenticateRequest
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classConnectSessionReauthenticateParams.ReauthenticateRequest.BuilderA builder for ReauthenticateRequest.
-
Method Summary
Modifier and Type Method Description final StringconnectionId()The ID of the existing connection to reauthenticate final Optional<Long>minutesToExpire()The number of minutes until the session expires (defaults to 43,200, which is 30 days) final Optional<List<ConnectSessionReauthenticateParams.ConnectProducts>>products()The products to request access to (optional for reauthentication). final Optional<String>redirectUri()The URI to redirect to after the Connect flow is completed final JsonField<String>_connectionId()Returns the raw JSON value of connectionId. final JsonField<Long>_minutesToExpire()Returns the raw JSON value of minutesToExpire. final JsonField<List<ConnectSessionReauthenticateParams.ConnectProducts>>_products()Returns the raw JSON value of products. final JsonField<String>_redirectUri()Returns the raw JSON value of redirectUri. final Map<String, JsonValue>_additionalProperties()final ConnectSessionReauthenticateParams.ReauthenticateRequest.BuildertoBuilder()final ConnectSessionReauthenticateParams.ReauthenticateRequestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ConnectSessionReauthenticateParams.ReauthenticateRequest.Builderbuilder()Returns a mutable builder for constructing an instance of ReauthenticateRequest. -
-
Method Detail
-
connectionId
final String connectionId()
The ID of the existing connection to reauthenticate
-
minutesToExpire
final Optional<Long> minutesToExpire()
The number of minutes until the session expires (defaults to 43,200, which is 30 days)
-
products
final Optional<List<ConnectSessionReauthenticateParams.ConnectProducts>> products()
The products to request access to (optional for reauthentication). Use
benefitsto access deductions endpoints —deductionis a deprecated alias that is still accepted but should not be combined withbenefits.
-
redirectUri
final Optional<String> redirectUri()
The URI to redirect to after the Connect flow is completed
-
_connectionId
final JsonField<String> _connectionId()
Returns the raw JSON value of connectionId.
Unlike connectionId, this method doesn't throw if the JSON field has an unexpected type.
-
_minutesToExpire
final JsonField<Long> _minutesToExpire()
Returns the raw JSON value of minutesToExpire.
Unlike minutesToExpire, this method doesn't throw if the JSON field has an unexpected type.
-
_products
final JsonField<List<ConnectSessionReauthenticateParams.ConnectProducts>> _products()
Returns the raw JSON value of products.
Unlike products, this method doesn't throw if the JSON field has an unexpected type.
-
_redirectUri
final JsonField<String> _redirectUri()
Returns the raw JSON value of redirectUri.
Unlike redirectUri, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ConnectSessionReauthenticateParams.ReauthenticateRequest.Builder toBuilder()
-
validate
final ConnectSessionReauthenticateParams.ReauthenticateRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ConnectSessionReauthenticateParams.ReauthenticateRequest.Builder builder()
Returns a mutable builder for constructing an instance of ReauthenticateRequest.
The following fields are required:
.connectionId()
-
-
-
-