Class ConnectSessionReauthenticateParams.ReauthenticateRequest.Builder
-
- All Implemented Interfaces:
public final class ConnectSessionReauthenticateParams.ReauthenticateRequest.BuilderA builder for ReauthenticateRequest.
-
-
Method Summary
-
-
Method Detail
-
connectionId
final ConnectSessionReauthenticateParams.ReauthenticateRequest.Builder connectionId(String connectionId)
The ID of the existing connection to reauthenticate
-
connectionId
final ConnectSessionReauthenticateParams.ReauthenticateRequest.Builder connectionId(JsonField<String> connectionId)
Sets Builder.connectionId to an arbitrary JSON value.
You should usually call Builder.connectionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
minutesToExpire
final ConnectSessionReauthenticateParams.ReauthenticateRequest.Builder minutesToExpire(Long minutesToExpire)
The number of minutes until the session expires (defaults to 43,200, which is 30 days)
-
minutesToExpire
final ConnectSessionReauthenticateParams.ReauthenticateRequest.Builder minutesToExpire(JsonField<Long> minutesToExpire)
Sets Builder.minutesToExpire to an arbitrary JSON value.
You should usually call Builder.minutesToExpire with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
products
final ConnectSessionReauthenticateParams.ReauthenticateRequest.Builder products(List<ConnectSessionReauthenticateParams.ConnectProducts> products)
The products to request access to (optional for reauthentication). Use
benefitsto access deductions endpoints —deductionis a deprecated alias that is still accepted but should not be combined withbenefits.
-
products
final ConnectSessionReauthenticateParams.ReauthenticateRequest.Builder products(Optional<List<ConnectSessionReauthenticateParams.ConnectProducts>> products)
Alias for calling Builder.products with
products.orElse(null).
-
products
final ConnectSessionReauthenticateParams.ReauthenticateRequest.Builder products(JsonField<List<ConnectSessionReauthenticateParams.ConnectProducts>> products)
Sets Builder.products to an arbitrary JSON value.
You should usually call Builder.products with a well-typed
List<ConnectProducts>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addProduct
final ConnectSessionReauthenticateParams.ReauthenticateRequest.Builder addProduct(ConnectSessionReauthenticateParams.ConnectProducts product)
Adds a single ConnectProducts to products.
-
redirectUri
final ConnectSessionReauthenticateParams.ReauthenticateRequest.Builder redirectUri(String redirectUri)
The URI to redirect to after the Connect flow is completed
-
redirectUri
final ConnectSessionReauthenticateParams.ReauthenticateRequest.Builder redirectUri(Optional<String> redirectUri)
Alias for calling Builder.redirectUri with
redirectUri.orElse(null).
-
redirectUri
final ConnectSessionReauthenticateParams.ReauthenticateRequest.Builder redirectUri(JsonField<String> redirectUri)
Sets Builder.redirectUri to an arbitrary JSON value.
You should usually call Builder.redirectUri with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ConnectSessionReauthenticateParams.ReauthenticateRequest.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ConnectSessionReauthenticateParams.ReauthenticateRequest.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ConnectSessionReauthenticateParams.ReauthenticateRequest.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ConnectSessionReauthenticateParams.ReauthenticateRequest.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ConnectSessionReauthenticateParams.ReauthenticateRequest.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ConnectSessionReauthenticateParams.ReauthenticateRequest build()
Returns an immutable instance of ReauthenticateRequest.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.connectionId()
-
-
-
-