Class ConnectionCreateResponse
-
- All Implemented Interfaces:
public final class ConnectionCreateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classConnectionCreateResponse.BuilderA builder for ConnectionCreateResponse.
public final classConnectionCreateResponse.AuthenticationType
-
Method Summary
Modifier and Type Method Description final StringaccessToken()final StringaccountId()DEPRECATED Use connection_idto associate a connection with an access tokenfinal ConnectionCreateResponse.AuthenticationTypeauthenticationType()final StringcompanyId()DEPRECATED Use connection_idto associate a connection with an access tokenfinal StringconnectionId()The ID of the new connection final StringentityId()The ID of the entity for this connection final List<String>products()final StringproviderId()The ID of the provider associated with the access_token.final Optional<String>tokenType()final JsonField<String>_accessToken()Returns the raw JSON value of accessToken. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<ConnectionCreateResponse.AuthenticationType>_authenticationType()Returns the raw JSON value of authenticationType. final JsonField<String>_companyId()Returns the raw JSON value of companyId. final JsonField<String>_connectionId()Returns the raw JSON value of connectionId. final JsonField<String>_entityId()Returns the raw JSON value of entityId. final JsonField<List<String>>_products()Returns the raw JSON value of products. final JsonField<String>_providerId()Returns the raw JSON value of providerId. final JsonField<String>_tokenType()Returns the raw JSON value of tokenType. final Map<String, JsonValue>_additionalProperties()final ConnectionCreateResponse.BuildertoBuilder()final ConnectionCreateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ConnectionCreateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ConnectionCreateResponse. -
-
Method Detail
-
accessToken
final String accessToken()
-
accountId
@Deprecated(message = "deprecated") final String accountId()
DEPRECATED Use
connection_idto associate a connection with an access token
-
authenticationType
final ConnectionCreateResponse.AuthenticationType authenticationType()
-
companyId
@Deprecated(message = "deprecated") final String companyId()
DEPRECATED Use
connection_idto associate a connection with an access token
-
connectionId
final String connectionId()
The ID of the new connection
-
providerId
final String providerId()
The ID of the provider associated with the
access_token.
-
_accessToken
final JsonField<String> _accessToken()
Returns the raw JSON value of accessToken.
Unlike accessToken, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
@Deprecated(message = "deprecated") final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_authenticationType
final JsonField<ConnectionCreateResponse.AuthenticationType> _authenticationType()
Returns the raw JSON value of authenticationType.
Unlike authenticationType, this method doesn't throw if the JSON field has an unexpected type.
-
_companyId
@Deprecated(message = "deprecated") final JsonField<String> _companyId()
Returns the raw JSON value of companyId.
Unlike companyId, this method doesn't throw if the JSON field has an unexpected type.
-
_connectionId
final JsonField<String> _connectionId()
Returns the raw JSON value of connectionId.
Unlike connectionId, this method doesn't throw if the JSON field has an unexpected type.
-
_entityId
final JsonField<String> _entityId()
Returns the raw JSON value of entityId.
Unlike entityId, this method doesn't throw if the JSON field has an unexpected type.
-
_products
final JsonField<List<String>> _products()
Returns the raw JSON value of products.
Unlike products, this method doesn't throw if the JSON field has an unexpected type.
-
_providerId
final JsonField<String> _providerId()
Returns the raw JSON value of providerId.
Unlike providerId, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenType
final JsonField<String> _tokenType()
Returns the raw JSON value of tokenType.
Unlike tokenType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ConnectionCreateResponse.Builder toBuilder()
-
validate
final ConnectionCreateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ConnectionCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of ConnectionCreateResponse.
The following fields are required:
.accessToken() .accountId() .authenticationType() .companyId() .connectionId() .entityId() .products() .providerId()
-
-
-
-