Class ConnectionCreateResponse.Builder
-
- All Implemented Interfaces:
public final class ConnectionCreateResponse.BuilderA builder for ConnectionCreateResponse.
-
-
Method Summary
-
-
Method Detail
-
accessToken
final ConnectionCreateResponse.Builder accessToken(String accessToken)
-
accessToken
final ConnectionCreateResponse.Builder accessToken(JsonField<String> accessToken)
Sets Builder.accessToken to an arbitrary JSON value.
You should usually call Builder.accessToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountId
@Deprecated(message = "deprecated") final ConnectionCreateResponse.Builder accountId(String accountId)
DEPRECATED Use
connection_idto associate a connection with an access token
-
accountId
@Deprecated(message = "deprecated") final ConnectionCreateResponse.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
authenticationType
final ConnectionCreateResponse.Builder authenticationType(ConnectionCreateResponse.AuthenticationType authenticationType)
-
authenticationType
final ConnectionCreateResponse.Builder authenticationType(JsonField<ConnectionCreateResponse.AuthenticationType> authenticationType)
Sets Builder.authenticationType to an arbitrary JSON value.
You should usually call Builder.authenticationType with a well-typed AuthenticationType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
companyId
@Deprecated(message = "deprecated") final ConnectionCreateResponse.Builder companyId(String companyId)
DEPRECATED Use
connection_idto associate a connection with an access token
-
companyId
@Deprecated(message = "deprecated") final ConnectionCreateResponse.Builder companyId(JsonField<String> companyId)
Sets Builder.companyId to an arbitrary JSON value.
You should usually call Builder.companyId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
connectionId
final ConnectionCreateResponse.Builder connectionId(String connectionId)
The ID of the new connection
-
connectionId
final ConnectionCreateResponse.Builder connectionId(JsonField<String> connectionId)
Sets Builder.connectionId to an arbitrary JSON value.
You should usually call Builder.connectionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entityId
final ConnectionCreateResponse.Builder entityId(String entityId)
The ID of the entity for this connection
-
entityId
final ConnectionCreateResponse.Builder entityId(JsonField<String> entityId)
Sets Builder.entityId to an arbitrary JSON value.
You should usually call Builder.entityId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
products
final ConnectionCreateResponse.Builder products(List<String> products)
-
products
final ConnectionCreateResponse.Builder products(JsonField<List<String>> products)
Sets Builder.products to an arbitrary JSON value.
You should usually call Builder.products with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addProduct
final ConnectionCreateResponse.Builder addProduct(String product)
-
providerId
final ConnectionCreateResponse.Builder providerId(String providerId)
The ID of the provider associated with the
access_token.
-
providerId
final ConnectionCreateResponse.Builder providerId(JsonField<String> providerId)
Sets Builder.providerId to an arbitrary JSON value.
You should usually call Builder.providerId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tokenType
final ConnectionCreateResponse.Builder tokenType(String tokenType)
-
tokenType
final ConnectionCreateResponse.Builder tokenType(JsonField<String> tokenType)
Sets Builder.tokenType to an arbitrary JSON value.
You should usually call Builder.tokenType with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ConnectionCreateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ConnectionCreateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ConnectionCreateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ConnectionCreateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ConnectionCreateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ConnectionCreateResponse build()
Returns an immutable instance of ConnectionCreateResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accessToken() .accountId() .authenticationType() .companyId() .connectionId() .entityId() .products() .providerId()
-
-
-
-