Class CreateAccessTokenResponse.Builder
-
- All Implemented Interfaces:
public final class CreateAccessTokenResponse.BuilderA builder for CreateAccessTokenResponse.
-
-
Method Summary
-
-
Method Detail
-
accessToken
final CreateAccessTokenResponse.Builder accessToken(String accessToken)
The access token for the connection
-
accessToken
final CreateAccessTokenResponse.Builder accessToken(JsonField<String> accessToken)
Sets Builder.accessToken to an arbitrary JSON value.
You should usually call Builder.accessToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
clientType
final CreateAccessTokenResponse.Builder clientType(CreateAccessTokenResponse.ClientType clientType)
The type of application associated with a token.
-
clientType
final CreateAccessTokenResponse.Builder clientType(JsonField<CreateAccessTokenResponse.ClientType> clientType)
Sets Builder.clientType to an arbitrary JSON value.
You should usually call Builder.clientType with a well-typed ClientType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
connectionId
final CreateAccessTokenResponse.Builder connectionId(String connectionId)
The Finch UUID of the connection associated with the
access_token
-
connectionId
final CreateAccessTokenResponse.Builder connectionId(JsonField<String> connectionId)
Sets Builder.connectionId to an arbitrary JSON value.
You should usually call Builder.connectionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
connectionType
final CreateAccessTokenResponse.Builder connectionType(CreateAccessTokenResponse.ConnectionType connectionType)
The type of the connection associated with the token.
provider- connection to an external providerfinch- finch-generated data.
-
connectionType
final CreateAccessTokenResponse.Builder connectionType(JsonField<CreateAccessTokenResponse.ConnectionType> connectionType)
Sets Builder.connectionType to an arbitrary JSON value.
You should usually call Builder.connectionType with a well-typed ConnectionType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entityIds
final CreateAccessTokenResponse.Builder entityIds(List<String> entityIds)
An array of entity IDs that can be accessed with this access token
-
entityIds
final CreateAccessTokenResponse.Builder entityIds(JsonField<List<String>> entityIds)
Sets Builder.entityIds to an arbitrary JSON value.
You should usually call Builder.entityIds with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEntityId
final CreateAccessTokenResponse.Builder addEntityId(String entityId)
-
products
final CreateAccessTokenResponse.Builder products(List<String> products)
An array of the authorized products associated with the
access_token
-
products
final CreateAccessTokenResponse.Builder products(JsonField<List<String>> products)
Sets Builder.products to an arbitrary JSON value.
You should usually call Builder.products with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addProduct
final CreateAccessTokenResponse.Builder addProduct(String product)
-
providerId
final CreateAccessTokenResponse.Builder providerId(String providerId)
The ID of the provider associated with the
access_token
-
providerId
final CreateAccessTokenResponse.Builder providerId(JsonField<String> providerId)
Sets Builder.providerId to an arbitrary JSON value.
You should usually call Builder.providerId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tokenType
final CreateAccessTokenResponse.Builder tokenType(String tokenType)
The RFC 8693 token type (Finch uses
bearertokens)
-
tokenType
final CreateAccessTokenResponse.Builder tokenType(JsonField<String> tokenType)
Sets Builder.tokenType to an arbitrary JSON value.
You should usually call Builder.tokenType with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountId
@Deprecated(message = "deprecated") final CreateAccessTokenResponse.Builder accountId(String accountId)
DEPRECATED Use
connection_idto identify the connection instead of this account ID
-
accountId
@Deprecated(message = "deprecated") final CreateAccessTokenResponse.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
companyId
@Deprecated(message = "deprecated") final CreateAccessTokenResponse.Builder companyId(String companyId)
DEPRECATED Use
connection_idto identify the connection instead of this company ID
-
companyId
@Deprecated(message = "deprecated") final CreateAccessTokenResponse.Builder companyId(JsonField<String> companyId)
Sets Builder.companyId to an arbitrary JSON value.
You should usually call Builder.companyId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customerId
final CreateAccessTokenResponse.Builder customerId(String customerId)
The ID of your customer you provided to Finch when a connect session was created for this connection
-
customerId
final CreateAccessTokenResponse.Builder customerId(Optional<String> customerId)
Alias for calling Builder.customerId with
customerId.orElse(null).
-
customerId
final CreateAccessTokenResponse.Builder customerId(JsonField<String> customerId)
Sets Builder.customerId to an arbitrary JSON value.
You should usually call Builder.customerId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customerName
final CreateAccessTokenResponse.Builder customerName(String customerName)
The name of your customer you provided to Finch when a connect session was created for this connection
-
customerName
final CreateAccessTokenResponse.Builder customerName(Optional<String> customerName)
Alias for calling Builder.customerName with
customerName.orElse(null).
-
customerName
final CreateAccessTokenResponse.Builder customerName(JsonField<String> customerName)
Sets Builder.customerName to an arbitrary JSON value.
You should usually call Builder.customerName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CreateAccessTokenResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CreateAccessTokenResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CreateAccessTokenResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CreateAccessTokenResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CreateAccessTokenResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CreateAccessTokenResponse build()
Returns an immutable instance of CreateAccessTokenResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accessToken() .clientType() .connectionId() .connectionType() .entityIds() .products() .providerId() .tokenType()
-
-
-
-