Package com.tryfinch.api.models
Class CreateCompanyBenefitsResponse
-
- All Implemented Interfaces:
public final class CreateCompanyBenefitsResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCreateCompanyBenefitsResponse.BuilderA builder for CreateCompanyBenefitsResponse.
-
Method Summary
Modifier and Type Method Description final StringbenefitId()The id of the benefit. final StringjobId()final JsonField<String>_benefitId()Returns the raw JSON value of benefitId. final JsonField<String>_jobId()Returns the raw JSON value of jobId. final Map<String, JsonValue>_additionalProperties()final CreateCompanyBenefitsResponse.BuildertoBuilder()final CreateCompanyBenefitsResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CreateCompanyBenefitsResponse.Builderbuilder()Returns a mutable builder for constructing an instance of CreateCompanyBenefitsResponse. -
-
Method Detail
-
_benefitId
final JsonField<String> _benefitId()
Returns the raw JSON value of benefitId.
Unlike benefitId, this method doesn't throw if the JSON field has an unexpected type.
-
_jobId
final JsonField<String> _jobId()
Returns the raw JSON value of jobId.
Unlike jobId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CreateCompanyBenefitsResponse.Builder toBuilder()
-
validate
final CreateCompanyBenefitsResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CreateCompanyBenefitsResponse.Builder builder()
Returns a mutable builder for constructing an instance of CreateCompanyBenefitsResponse.
The following fields are required:
.benefitId() .jobId()
-
-
-
-