Package com.tryfinch.api.models
Class CreateCompanyBenefitsResponse.Builder
-
- All Implemented Interfaces:
public final class CreateCompanyBenefitsResponse.BuilderA builder for CreateCompanyBenefitsResponse.
-
-
Method Summary
-
-
Method Detail
-
benefitId
final CreateCompanyBenefitsResponse.Builder benefitId(String benefitId)
The id of the benefit.
-
benefitId
final CreateCompanyBenefitsResponse.Builder benefitId(JsonField<String> benefitId)
Sets Builder.benefitId to an arbitrary JSON value.
You should usually call Builder.benefitId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
jobId
final CreateCompanyBenefitsResponse.Builder jobId(String jobId)
-
jobId
final CreateCompanyBenefitsResponse.Builder jobId(JsonField<String> jobId)
Sets Builder.jobId to an arbitrary JSON value.
You should usually call Builder.jobId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CreateCompanyBenefitsResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CreateCompanyBenefitsResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CreateCompanyBenefitsResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CreateCompanyBenefitsResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CreateCompanyBenefitsResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CreateCompanyBenefitsResponse build()
Returns an immutable instance of CreateCompanyBenefitsResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.benefitId() .jobId()
-
-
-
-