Package com.tryfinch.api.models
Class DirectoryListIndividualsResponse
-
- All Implemented Interfaces:
public final class DirectoryListIndividualsResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDirectoryListIndividualsResponse.BuilderA builder for DirectoryListIndividualsResponse.
-
Method Summary
Modifier and Type Method Description final List<IndividualInDirectory>individuals()The array of employees. final Pagingpaging()final JsonField<List<IndividualInDirectory>>_individuals()Returns the raw JSON value of individuals. final JsonField<Paging>_paging()Returns the raw JSON value of paging. final Map<String, JsonValue>_additionalProperties()final DirectoryListIndividualsResponse.BuildertoBuilder()final DirectoryListIndividualsResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DirectoryListIndividualsResponse.Builderbuilder()Returns a mutable builder for constructing an instance of DirectoryListIndividualsResponse. -
-
Method Detail
-
individuals
final List<IndividualInDirectory> individuals()
The array of employees.
-
_individuals
final JsonField<List<IndividualInDirectory>> _individuals()
Returns the raw JSON value of individuals.
Unlike individuals, this method doesn't throw if the JSON field has an unexpected type.
-
_paging
final JsonField<Paging> _paging()
Returns the raw JSON value of paging.
Unlike paging, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DirectoryListIndividualsResponse.Builder toBuilder()
-
validate
final DirectoryListIndividualsResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DirectoryListIndividualsResponse.Builder builder()
Returns a mutable builder for constructing an instance of DirectoryListIndividualsResponse.
The following fields are required:
.individuals() .paging()
-
-
-
-