Package com.tryfinch.api.models
Class DisconnectEntityResponse
-
- All Implemented Interfaces:
public final class DisconnectEntityResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDisconnectEntityResponse.BuilderA builder for DisconnectEntityResponse.
-
Method Summary
Modifier and Type Method Description final Stringstatus()If the request is successful, Finch will return "success" (HTTP 200 status). final JsonField<String>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final DisconnectEntityResponse.BuildertoBuilder()final DisconnectEntityResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DisconnectEntityResponse.Builderbuilder()Returns a mutable builder for constructing an instance of DisconnectEntityResponse. -
-
Method Detail
-
status
final String status()
If the request is successful, Finch will return "success" (HTTP 200 status).
-
_status
final JsonField<String> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DisconnectEntityResponse.Builder toBuilder()
-
validate
final DisconnectEntityResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DisconnectEntityResponse.Builder builder()
Returns a mutable builder for constructing an instance of DisconnectEntityResponse.
The following fields are required:
.status()
-
-
-
-