Package com.tryfinch.api.models
Class DisconnectResponse
-
- All Implemented Interfaces:
public final class DisconnectResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDisconnectResponse.BuilderA builder for DisconnectResponse.
-
Method Summary
Modifier and Type Method Description final Stringstatus()If the request is successful, Finch will return "success" (HTTP 200 status). final JsonField<String>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final DisconnectResponse.BuildertoBuilder()final DisconnectResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DisconnectResponse.Builderbuilder()Returns a mutable builder for constructing an instance of DisconnectResponse. -
-
Method Detail
-
status
final String status()
If the request is successful, Finch will return "success" (HTTP 200 status).
-
_status
final JsonField<String> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DisconnectResponse.Builder toBuilder()
-
validate
final DisconnectResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DisconnectResponse.Builder builder()
Returns a mutable builder for constructing an instance of DisconnectResponse.
The following fields are required:
.status()
-
-
-
-