Package com.tryfinch.api.models
Class DocumentListResponse
-
- All Implemented Interfaces:
public final class DocumentListResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDocumentListResponse.BuilderA builder for DocumentListResponse.
-
Method Summary
Modifier and Type Method Description final List<DocumentResponse>documents()final Pagingpaging()final JsonField<List<DocumentResponse>>_documents()Returns the raw JSON value of documents. final JsonField<Paging>_paging()Returns the raw JSON value of paging. final Map<String, JsonValue>_additionalProperties()final DocumentListResponse.BuildertoBuilder()final DocumentListResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DocumentListResponse.Builderbuilder()Returns a mutable builder for constructing an instance of DocumentListResponse. -
-
Method Detail
-
documents
final List<DocumentResponse> documents()
-
_documents
final JsonField<List<DocumentResponse>> _documents()
Returns the raw JSON value of documents.
Unlike documents, this method doesn't throw if the JSON field has an unexpected type.
-
_paging
final JsonField<Paging> _paging()
Returns the raw JSON value of paging.
Unlike paging, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DocumentListResponse.Builder toBuilder()
-
validate
final DocumentListResponse validate()
-
builder
final static DocumentListResponse.Builder builder()
Returns a mutable builder for constructing an instance of DocumentListResponse.
The following fields are required:
.documents() .paging()
-
-
-
-