Class DocumentResponse.Builder
-
- All Implemented Interfaces:
public final class DocumentResponse.BuilderA builder for DocumentResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final DocumentResponse.Builder id(String id)
A stable Finch id for the document.
-
id
final DocumentResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
individualId
final DocumentResponse.Builder individualId(String individualId)
The ID of the individual associated with the document. This will be null for employer-level documents.
-
individualId
final DocumentResponse.Builder individualId(Optional<String> individualId)
Alias for calling Builder.individualId with
individualId.orElse(null).
-
individualId
final DocumentResponse.Builder individualId(JsonField<String> individualId)
Sets Builder.individualId to an arbitrary JSON value.
You should usually call Builder.individualId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final DocumentResponse.Builder type(DocumentResponse.Type type)
The type of document.
-
type
final DocumentResponse.Builder type(JsonField<DocumentResponse.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
url
final DocumentResponse.Builder url(String url)
A URL to access the document. Format:
https://api.tryfinch.com/employer/documents/:document_id.
-
url
final DocumentResponse.Builder url(JsonField<String> url)
Sets Builder.url to an arbitrary JSON value.
You should usually call Builder.url with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
year
final DocumentResponse.Builder year(Double year)
The year the document applies to, if available.
-
year
final DocumentResponse.Builder year(JsonField<Double> year)
Sets Builder.year to an arbitrary JSON value.
You should usually call Builder.year with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final DocumentResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DocumentResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DocumentResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DocumentResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DocumentResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DocumentResponse build()
Returns an immutable instance of DocumentResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .individualId() .type() .url() .year()
-
-
-
-