Package com.tryfinch.api.models
Interface DocumentRetreiveResponse.Visitor
-
- All Implemented Interfaces:
public interface DocumentRetreiveResponse.Visitor<T extends Object>An interface that defines how to map each variant of DocumentRetreiveResponse to a value of type T.
-
-
Method Summary
Modifier and Type Method Description abstract TvisitW42020(W42020 w42020)A 2020 version of the W-4 tax form containing information on an individual's filing status, dependents, and withholding details. abstract TvisitW42005(W42005 w42005)A 2005 version of the W-4 tax form containing information on an individual's filing status, dependents, and withholding details. Tunknown(JsonValue json)Maps an unknown variant of DocumentRetreiveResponse to a value of type T. -
-
Method Detail
-
visitW42020
abstract T visitW42020(W42020 w42020)
A 2020 version of the W-4 tax form containing information on an individual's filing status, dependents, and withholding details.
-
visitW42005
abstract T visitW42005(W42005 w42005)
A 2005 version of the W-4 tax form containing information on an individual's filing status, dependents, and withholding details.
-
unknown
T unknown(JsonValue json)
Maps an unknown variant of DocumentRetreiveResponse to a value of type T.
An instance of DocumentRetreiveResponse can contain an unknown variant if it was deserialized from data that doesn't match any known variant. For example, if the SDK is on an older version than the API, then the API may respond with new variants that the SDK is unaware of.
-
-
-
-