Class EmploymentData.BatchError.Builder
-
- All Implemented Interfaces:
public final class EmploymentData.BatchError.BuilderA builder for BatchError.
-
-
Method Summary
-
-
Method Detail
-
code
final EmploymentData.BatchError.Builder code(Double code)
-
code
final EmploymentData.BatchError.Builder code(JsonField<Double> code)
Sets Builder.code to an arbitrary JSON value.
You should usually call Builder.code with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
message
final EmploymentData.BatchError.Builder message(String message)
-
message
final EmploymentData.BatchError.Builder message(JsonField<String> message)
Sets Builder.message to an arbitrary JSON value.
You should usually call Builder.message with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final EmploymentData.BatchError.Builder name(String name)
-
name
final EmploymentData.BatchError.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
finchCode
final EmploymentData.BatchError.Builder finchCode(String finchCode)
-
finchCode
final EmploymentData.BatchError.Builder finchCode(JsonField<String> finchCode)
Sets Builder.finchCode to an arbitrary JSON value.
You should usually call Builder.finchCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EmploymentData.BatchError.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EmploymentData.BatchError.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EmploymentData.BatchError.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EmploymentData.BatchError.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EmploymentData.BatchError.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EmploymentData.BatchError build()
Returns an immutable instance of BatchError.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.code() .message() .name()
-
-
-
-