Class EmploymentData.Employment.Builder
-
- All Implemented Interfaces:
public final class EmploymentData.Employment.BuilderA builder for Employment.
-
-
Method Summary
-
-
Method Detail
-
subtype
final EmploymentData.Employment.Builder subtype(EmploymentData.Employment.Subtype subtype)
The secondary employment type of the individual. Options:
full_time,part_time,intern,temp,seasonalandindividual_contractor.
-
subtype
final EmploymentData.Employment.Builder subtype(Optional<EmploymentData.Employment.Subtype> subtype)
Alias for calling Builder.subtype with
subtype.orElse(null).
-
subtype
final EmploymentData.Employment.Builder subtype(JsonField<EmploymentData.Employment.Subtype> subtype)
Sets Builder.subtype to an arbitrary JSON value.
You should usually call Builder.subtype with a well-typed Subtype value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final EmploymentData.Employment.Builder type(EmploymentData.Employment.Type type)
The main employment type of the individual.
-
type
final EmploymentData.Employment.Builder type(Optional<EmploymentData.Employment.Type> type)
Alias for calling Builder.type with
type.orElse(null).
-
type
final EmploymentData.Employment.Builder type(JsonField<EmploymentData.Employment.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EmploymentData.Employment.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EmploymentData.Employment.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EmploymentData.Employment.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EmploymentData.Employment.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EmploymentData.Employment.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EmploymentData.Employment build()
Returns an immutable instance of Employment.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-