Package com.tryfinch.api.models
Class EmploymentData.EmploymentDataResponseBody.CustomField
-
- All Implemented Interfaces:
public final class EmploymentData.EmploymentDataResponseBody.CustomField
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEmploymentData.EmploymentDataResponseBody.CustomField.BuilderA builder for CustomField.
public final classEmploymentData.EmploymentDataResponseBody.CustomField.Value
-
Method Summary
Modifier and Type Method Description final Optional<String>name()final Optional<EmploymentData.EmploymentDataResponseBody.CustomField.Value>value()final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<EmploymentData.EmploymentDataResponseBody.CustomField.Value>_value()Returns the raw JSON value of value. final Map<String, JsonValue>_additionalProperties()final EmploymentData.EmploymentDataResponseBody.CustomField.BuildertoBuilder()final EmploymentData.EmploymentDataResponseBody.CustomFieldvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EmploymentData.EmploymentDataResponseBody.CustomField.Builderbuilder()Returns a mutable builder for constructing an instance of CustomField. -
-
Method Detail
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_value
final JsonField<EmploymentData.EmploymentDataResponseBody.CustomField.Value> _value()
Returns the raw JSON value of value.
Unlike value, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EmploymentData.EmploymentDataResponseBody.CustomField.Builder toBuilder()
-
validate
final EmploymentData.EmploymentDataResponseBody.CustomField validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EmploymentData.EmploymentDataResponseBody.CustomField.Builder builder()
Returns a mutable builder for constructing an instance of CustomField.
-
-
-
-