Package com.tryfinch.api.models
Class EmploymentData.EmploymentDataResponseBody.Manager
-
- All Implemented Interfaces:
public final class EmploymentData.EmploymentDataResponseBody.ManagerThe manager object representing the manager of the individual within the org.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEmploymentData.EmploymentDataResponseBody.Manager.BuilderA builder for Manager.
-
Method Summary
Modifier and Type Method Description final Stringid()A stable Finch id(UUID v4) for an individual in the company.final JsonField<String>_id()Returns the raw JSON value of id. final Map<String, JsonValue>_additionalProperties()final EmploymentData.EmploymentDataResponseBody.Manager.BuildertoBuilder()final EmploymentData.EmploymentDataResponseBody.Managervalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EmploymentData.EmploymentDataResponseBody.Manager.Builderbuilder()Returns a mutable builder for constructing an instance of Manager. -
-
Method Detail
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EmploymentData.EmploymentDataResponseBody.Manager.Builder toBuilder()
-
validate
final EmploymentData.EmploymentDataResponseBody.Manager validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EmploymentData.EmploymentDataResponseBody.Manager.Builder builder()
Returns a mutable builder for constructing an instance of Manager.
The following fields are required:
.id()
-
-
-
-