Class EmploymentData.UnionMember0.Builder
-
- All Implemented Interfaces:
public final class EmploymentData.UnionMember0.BuilderA builder for UnionMember0.
-
-
Method Summary
-
-
Method Detail
-
id
final EmploymentData.UnionMember0.Builder id(String id)
A stable Finch
id(UUID v4) for an individual in the company.
-
id
final EmploymentData.UnionMember0.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
classCode
final EmploymentData.UnionMember0.Builder classCode(String classCode)
Worker's compensation classification code for this employee
-
classCode
final EmploymentData.UnionMember0.Builder classCode(Optional<String> classCode)
Alias for calling Builder.classCode with
classCode.orElse(null).
-
classCode
final EmploymentData.UnionMember0.Builder classCode(JsonField<String> classCode)
Sets Builder.classCode to an arbitrary JSON value.
You should usually call Builder.classCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
department
final EmploymentData.UnionMember0.Builder department(EmploymentData.UnionMember0.Department department)
The department object.
-
department
final EmploymentData.UnionMember0.Builder department(Optional<EmploymentData.UnionMember0.Department> department)
Alias for calling Builder.department with
department.orElse(null).
-
department
final EmploymentData.UnionMember0.Builder department(JsonField<EmploymentData.UnionMember0.Department> department)
Sets Builder.department to an arbitrary JSON value.
You should usually call Builder.department with a well-typed Department value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
employment
final EmploymentData.UnionMember0.Builder employment(EmploymentData.UnionMember0.Employment employment)
The employment object.
-
employment
final EmploymentData.UnionMember0.Builder employment(Optional<EmploymentData.UnionMember0.Employment> employment)
Alias for calling Builder.employment with
employment.orElse(null).
-
employment
final EmploymentData.UnionMember0.Builder employment(JsonField<EmploymentData.UnionMember0.Employment> employment)
Sets Builder.employment to an arbitrary JSON value.
You should usually call Builder.employment with a well-typed Employment value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
employmentStatus
final EmploymentData.UnionMember0.Builder employmentStatus(EmploymentData.UnionMember0.EmploymentStatus employmentStatus)
The detailed employment status of the individual. Available options:
active,deceased,leave,onboarding,prehire,retired,terminated.
-
employmentStatus
final EmploymentData.UnionMember0.Builder employmentStatus(Optional<EmploymentData.UnionMember0.EmploymentStatus> employmentStatus)
Alias for calling Builder.employmentStatus with
employmentStatus.orElse(null).
-
employmentStatus
final EmploymentData.UnionMember0.Builder employmentStatus(JsonField<EmploymentData.UnionMember0.EmploymentStatus> employmentStatus)
Sets Builder.employmentStatus to an arbitrary JSON value.
You should usually call Builder.employmentStatus with a well-typed EmploymentStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
endDate
final EmploymentData.UnionMember0.Builder endDate(String endDate)
-
endDate
final EmploymentData.UnionMember0.Builder endDate(Optional<String> endDate)
Alias for calling Builder.endDate with
endDate.orElse(null).
-
endDate
final EmploymentData.UnionMember0.Builder endDate(JsonField<String> endDate)
Sets Builder.endDate to an arbitrary JSON value.
You should usually call Builder.endDate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
firstName
final EmploymentData.UnionMember0.Builder firstName(String firstName)
The legal first name of the individual.
-
firstName
final EmploymentData.UnionMember0.Builder firstName(Optional<String> firstName)
Alias for calling Builder.firstName with
firstName.orElse(null).
-
firstName
final EmploymentData.UnionMember0.Builder firstName(JsonField<String> firstName)
Sets Builder.firstName to an arbitrary JSON value.
You should usually call Builder.firstName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
isActive
final EmploymentData.UnionMember0.Builder isActive(Boolean isActive)
trueif the individual an an active employee or contractor at the company.
-
isActive
final EmploymentData.UnionMember0.Builder isActive(Boolean isActive)
Alias for Builder.isActive.
This unboxed primitive overload exists for backwards compatibility.
-
isActive
final EmploymentData.UnionMember0.Builder isActive(Optional<Boolean> isActive)
Alias for calling Builder.isActive with
isActive.orElse(null).
-
isActive
final EmploymentData.UnionMember0.Builder isActive(JsonField<Boolean> isActive)
Sets Builder.isActive to an arbitrary JSON value.
You should usually call Builder.isActive with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastName
final EmploymentData.UnionMember0.Builder lastName(String lastName)
The legal last name of the individual.
-
lastName
final EmploymentData.UnionMember0.Builder lastName(Optional<String> lastName)
Alias for calling Builder.lastName with
lastName.orElse(null).
-
lastName
final EmploymentData.UnionMember0.Builder lastName(JsonField<String> lastName)
Sets Builder.lastName to an arbitrary JSON value.
You should usually call Builder.lastName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
latestRehireDate
final EmploymentData.UnionMember0.Builder latestRehireDate(String latestRehireDate)
-
latestRehireDate
final EmploymentData.UnionMember0.Builder latestRehireDate(Optional<String> latestRehireDate)
Alias for calling Builder.latestRehireDate with
latestRehireDate.orElse(null).
-
latestRehireDate
final EmploymentData.UnionMember0.Builder latestRehireDate(JsonField<String> latestRehireDate)
Sets Builder.latestRehireDate to an arbitrary JSON value.
You should usually call Builder.latestRehireDate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
location
final EmploymentData.UnionMember0.Builder location(Location location)
-
location
final EmploymentData.UnionMember0.Builder location(Optional<Location> location)
Alias for calling Builder.location with
location.orElse(null).
-
location
final EmploymentData.UnionMember0.Builder location(JsonField<Location> location)
Sets Builder.location to an arbitrary JSON value.
You should usually call Builder.location with a well-typed Location value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
manager
final EmploymentData.UnionMember0.Builder manager(EmploymentData.UnionMember0.Manager manager)
The manager object representing the manager of the individual within the org.
-
manager
final EmploymentData.UnionMember0.Builder manager(Optional<EmploymentData.UnionMember0.Manager> manager)
Alias for calling Builder.manager with
manager.orElse(null).
-
manager
final EmploymentData.UnionMember0.Builder manager(JsonField<EmploymentData.UnionMember0.Manager> manager)
Sets Builder.manager to an arbitrary JSON value.
You should usually call Builder.manager with a well-typed Manager value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
middleName
final EmploymentData.UnionMember0.Builder middleName(String middleName)
The legal middle name of the individual.
-
middleName
final EmploymentData.UnionMember0.Builder middleName(Optional<String> middleName)
Alias for calling Builder.middleName with
middleName.orElse(null).
-
middleName
final EmploymentData.UnionMember0.Builder middleName(JsonField<String> middleName)
Sets Builder.middleName to an arbitrary JSON value.
You should usually call Builder.middleName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
startDate
final EmploymentData.UnionMember0.Builder startDate(String startDate)
-
startDate
final EmploymentData.UnionMember0.Builder startDate(Optional<String> startDate)
Alias for calling Builder.startDate with
startDate.orElse(null).
-
startDate
final EmploymentData.UnionMember0.Builder startDate(JsonField<String> startDate)
Sets Builder.startDate to an arbitrary JSON value.
You should usually call Builder.startDate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
title
final EmploymentData.UnionMember0.Builder title(String title)
The current title of the individual.
-
title
final EmploymentData.UnionMember0.Builder title(Optional<String> title)
Alias for calling Builder.title with
title.orElse(null).
-
title
final EmploymentData.UnionMember0.Builder title(JsonField<String> title)
Sets Builder.title to an arbitrary JSON value.
You should usually call Builder.title with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customFields
final EmploymentData.UnionMember0.Builder customFields(List<EmploymentData.UnionMember0.CustomField> customFields)
Custom fields for the individual. These are fields which are defined by the employer in the system. Custom fields are not currently supported for assisted connections.
-
customFields
final EmploymentData.UnionMember0.Builder customFields(Optional<List<EmploymentData.UnionMember0.CustomField>> customFields)
Alias for calling Builder.customFields with
customFields.orElse(null).
-
customFields
final EmploymentData.UnionMember0.Builder customFields(JsonField<List<EmploymentData.UnionMember0.CustomField>> customFields)
Sets Builder.customFields to an arbitrary JSON value.
You should usually call Builder.customFields with a well-typed
List<CustomField>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addCustomField
final EmploymentData.UnionMember0.Builder addCustomField(EmploymentData.UnionMember0.CustomField customField)
Adds a single CustomField to customFields.
-
income
final EmploymentData.UnionMember0.Builder income(Income income)
The employee's income as reported by the provider. This may not always be annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc, depending on what information the provider returns.
-
income
final EmploymentData.UnionMember0.Builder income(Optional<Income> income)
Alias for calling Builder.income with
income.orElse(null).
-
income
final EmploymentData.UnionMember0.Builder income(JsonField<Income> income)
Sets Builder.income to an arbitrary JSON value.
You should usually call Builder.income with a well-typed Income value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
incomeHistory
final EmploymentData.UnionMember0.Builder incomeHistory(List<Income> incomeHistory)
The array of income history.
-
incomeHistory
final EmploymentData.UnionMember0.Builder incomeHistory(Optional<List<Income>> incomeHistory)
Alias for calling Builder.incomeHistory with
incomeHistory.orElse(null).
-
incomeHistory
final EmploymentData.UnionMember0.Builder incomeHistory(JsonField<List<Income>> incomeHistory)
Sets Builder.incomeHistory to an arbitrary JSON value.
You should usually call Builder.incomeHistory with a well-typed
List<Income?>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addIncomeHistory
final EmploymentData.UnionMember0.Builder addIncomeHistory(Income incomeHistory)
Adds a single Income to Builder.incomeHistory.
-
sourceId
final EmploymentData.UnionMember0.Builder sourceId(String sourceId)
The source system's unique employment identifier for this individual
-
sourceId
final EmploymentData.UnionMember0.Builder sourceId(Optional<String> sourceId)
Alias for calling Builder.sourceId with
sourceId.orElse(null).
-
sourceId
final EmploymentData.UnionMember0.Builder sourceId(JsonField<String> sourceId)
Sets Builder.sourceId to an arbitrary JSON value.
You should usually call Builder.sourceId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
workId
@Deprecated(message = "deprecated") final EmploymentData.UnionMember0.Builder workId(String workId)
This field is deprecated in favour of
source_id
-
workId
@Deprecated(message = "deprecated") final EmploymentData.UnionMember0.Builder workId(Optional<String> workId)
Alias for calling Builder.workId with
workId.orElse(null).
-
workId
@Deprecated(message = "deprecated") final EmploymentData.UnionMember0.Builder workId(JsonField<String> workId)
Sets Builder.workId to an arbitrary JSON value.
You should usually call Builder.workId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EmploymentData.UnionMember0.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EmploymentData.UnionMember0.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EmploymentData.UnionMember0.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EmploymentData.UnionMember0.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EmploymentData.UnionMember0.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EmploymentData.UnionMember0 build()
Returns an immutable instance of UnionMember0.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .classCode() .department() .employment() .employmentStatus() .endDate() .firstName() .isActive() .lastName() .latestRehireDate() .location() .manager() .middleName() .startDate() .title()
-
-
-
-