Package com.tryfinch.api.models
Class EmploymentData.UnionMember0.CustomField.Value
-
- All Implemented Interfaces:
public final class EmploymentData.UnionMember0.CustomField.Value
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceEmploymentData.UnionMember0.CustomField.Value.VisitorAn interface that defines how to map each variant of Value to a value of type T.
-
Method Summary
-
-
Method Detail
-
jsonValues
final Optional<List<JsonValue>> jsonValues()
-
isJsonValues
final Boolean isJsonValues()
-
asJsonValues
final List<JsonValue> asJsonValues()
-
accept
final <T extends Any> T accept(EmploymentData.UnionMember0.CustomField.Value.Visitor<T> visitor)
-
validate
final EmploymentData.UnionMember0.CustomField.Value validate()
-
ofString
final static EmploymentData.UnionMember0.CustomField.Value ofString(String string)
-
ofJsonValues
final static EmploymentData.UnionMember0.CustomField.Value ofJsonValues(List<JsonValue> jsonValues)
-
ofJson
final static EmploymentData.UnionMember0.CustomField.Value ofJson(JsonValue json)
-
ofNumber
final static EmploymentData.UnionMember0.CustomField.Value ofNumber(Double number)
-
ofBool
final static EmploymentData.UnionMember0.CustomField.Value ofBool(Boolean bool)
-
-
-
-