Package com.tryfinch.api.models
Interface EmploymentData.Visitor
-
- All Implemented Interfaces:
public interface EmploymentData.Visitor<T extends Object>An interface that defines how to map each variant of EmploymentData to a value of type T.
-
-
Method Summary
Modifier and Type Method Description abstract TvisitResponseBody(EmploymentData.EmploymentDataResponseBody responseBody)abstract TvisitBatchError(EmploymentData.BatchError batchError)Tunknown(JsonValue json)Maps an unknown variant of EmploymentData to a value of type T. -
-
Method Detail
-
visitResponseBody
abstract T visitResponseBody(EmploymentData.EmploymentDataResponseBody responseBody)
-
visitBatchError
abstract T visitBatchError(EmploymentData.BatchError batchError)
-
unknown
T unknown(JsonValue json)
Maps an unknown variant of EmploymentData to a value of type T.
An instance of EmploymentData can contain an unknown variant if it was deserialized from data that doesn't match any known variant. For example, if the SDK is on an older version than the API, then the API may respond with new variants that the SDK is unaware of.
-
-
-
-