Class EmploymentDataResponse
-
- All Implemented Interfaces:
public final class EmploymentDataResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEmploymentDataResponse.BuilderA builder for EmploymentDataResponse.
-
Method Summary
Modifier and Type Method Description final EmploymentDatabody()final Longcode()final StringindividualId()A stable Finch id(UUID v4) for an individual in the company.final JsonField<EmploymentData>_body()Returns the raw JSON value of body. final JsonField<Long>_code()Returns the raw JSON value of code. final JsonField<String>_individualId()Returns the raw JSON value of individualId. final Map<String, JsonValue>_additionalProperties()final EmploymentDataResponse.BuildertoBuilder()final EmploymentDataResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EmploymentDataResponse.Builderbuilder()Returns a mutable builder for constructing an instance of EmploymentDataResponse. -
-
Method Detail
-
body
final EmploymentData body()
-
individualId
final String individualId()
A stable Finch
id(UUID v4) for an individual in the company.
-
_body
final JsonField<EmploymentData> _body()
Returns the raw JSON value of body.
Unlike body, this method doesn't throw if the JSON field has an unexpected type.
-
_code
final JsonField<Long> _code()
Returns the raw JSON value of code.
Unlike code, this method doesn't throw if the JSON field has an unexpected type.
-
_individualId
final JsonField<String> _individualId()
Returns the raw JSON value of individualId.
Unlike individualId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EmploymentDataResponse.Builder toBuilder()
-
validate
final EmploymentDataResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EmploymentDataResponse.Builder builder()
Returns a mutable builder for constructing an instance of EmploymentDataResponse.
The following fields are required:
.body() .code() .individualId()
-
-
-
-