Class EmploymentDataResponse.Builder
-
- All Implemented Interfaces:
public final class EmploymentDataResponse.BuilderA builder for EmploymentDataResponse.
-
-
Method Summary
-
-
Method Detail
-
body
final EmploymentDataResponse.Builder body(EmploymentData body)
-
body
final EmploymentDataResponse.Builder body(JsonField<EmploymentData> body)
Sets Builder.body to an arbitrary JSON value.
You should usually call Builder.body with a well-typed EmploymentData value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
body
final EmploymentDataResponse.Builder body(EmploymentData.EmploymentDataResponseBody responseBody)
Alias for calling body with
EmploymentData.ofResponseBody(responseBody).
-
body
final EmploymentDataResponse.Builder body(EmploymentData.BatchError batchError)
Alias for calling body with
EmploymentData.ofBatchError(batchError).
-
code
final EmploymentDataResponse.Builder code(Long code)
-
code
final EmploymentDataResponse.Builder code(JsonField<Long> code)
Sets Builder.code to an arbitrary JSON value.
You should usually call Builder.code with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
individualId
final EmploymentDataResponse.Builder individualId(String individualId)
A stable Finch
id(UUID v4) for an individual in the company.
-
individualId
final EmploymentDataResponse.Builder individualId(JsonField<String> individualId)
Sets Builder.individualId to an arbitrary JSON value.
You should usually call Builder.individualId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EmploymentDataResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EmploymentDataResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EmploymentDataResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EmploymentDataResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EmploymentDataResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EmploymentDataResponse build()
Returns an immutable instance of EmploymentDataResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.body() .code() .individualId()
-
-
-
-