Package com.tryfinch.api.models
Class EmploymentEvent.Data
-
- All Implemented Interfaces:
public final class EmploymentEvent.Data
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEmploymentEvent.Data.BuilderA builder for Data.
-
Method Summary
Modifier and Type Method Description final Optional<String>individualId()The ID of the individual related to the event. final JsonField<String>_individualId()Returns the raw JSON value of individualId. final Map<String, JsonValue>_additionalProperties()final EmploymentEvent.Data.BuildertoBuilder()final EmploymentEvent.Datavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EmploymentEvent.Data.Builderbuilder()Returns a mutable builder for constructing an instance of Data. -
-
Method Detail
-
individualId
final Optional<String> individualId()
The ID of the individual related to the event.
-
_individualId
final JsonField<String> _individualId()
Returns the raw JSON value of individualId.
Unlike individualId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EmploymentEvent.Data.Builder toBuilder()
-
validate
final EmploymentEvent.Data validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EmploymentEvent.Data.Builder builder()
Returns a mutable builder for constructing an instance of Data.
-
-
-
-