Class EmploymentUpdateResponse
-
- All Implemented Interfaces:
public final class EmploymentUpdateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEmploymentUpdateResponse.BuilderA builder for EmploymentUpdateResponse.
public final classEmploymentUpdateResponse.CustomFieldpublic final classEmploymentUpdateResponse.DepartmentThe department object.
public final classEmploymentUpdateResponse.EmploymentThe employment object.
public final classEmploymentUpdateResponse.EmploymentStatusThe detailed employment status of the individual.
public final classEmploymentUpdateResponse.FlsaStatusThe FLSA status of the individual. Available options:
exempt,non_exempt,unknown.public final classEmploymentUpdateResponse.ManagerThe manager object representing the manager of the individual within the org.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()A stable Finch id(UUID v4) for an individual in the company.final Optional<String>classCode()Worker's compensation classification code for this employee final Optional<List<EmploymentUpdateResponse.CustomField>>customFields()Custom fields for the individual. final Optional<EmploymentUpdateResponse.Department>department()The department object. final Optional<EmploymentUpdateResponse.Employment>employment()The employment object. final Optional<EmploymentUpdateResponse.EmploymentStatus>employmentStatus()The detailed employment status of the individual. final Optional<String>endDate()final Optional<String>firstName()The legal first name of the individual. final Optional<EmploymentUpdateResponse.FlsaStatus>flsaStatus()The FLSA status of the individual. final Optional<Income>income()The employee's income as reported by the provider. final Optional<List<Income>>incomeHistory()The array of income history. final Optional<Boolean>isActive()trueif the individual an an active employee or contractor at the company.final Optional<String>lastName()The legal last name of the individual. final Optional<String>latestRehireDate()final Optional<Location>location()final Optional<EmploymentUpdateResponse.Manager>manager()The manager object representing the manager of the individual within the org. final Optional<String>middleName()The legal middle name of the individual. final Optional<String>sourceId()The source system's unique employment identifier for this individual final Optional<String>startDate()final Optional<String>title()The current title of the individual. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_classCode()Returns the raw JSON value of classCode. final JsonField<List<EmploymentUpdateResponse.CustomField>>_customFields()Returns the raw JSON value of customFields. final JsonField<EmploymentUpdateResponse.Department>_department()Returns the raw JSON value of department. final JsonField<EmploymentUpdateResponse.Employment>_employment()Returns the raw JSON value of employment. final JsonField<EmploymentUpdateResponse.EmploymentStatus>_employmentStatus()Returns the raw JSON value of employmentStatus. final JsonField<String>_endDate()Returns the raw JSON value of endDate. final JsonField<String>_firstName()Returns the raw JSON value of firstName. final JsonField<EmploymentUpdateResponse.FlsaStatus>_flsaStatus()Returns the raw JSON value of flsaStatus. final JsonField<Income>_income()Returns the raw JSON value of income. final JsonField<List<Income>>_incomeHistory()Returns the raw JSON value of incomeHistory. final JsonField<Boolean>_isActive()Returns the raw JSON value of isActive. final JsonField<String>_lastName()Returns the raw JSON value of lastName. final JsonField<String>_latestRehireDate()Returns the raw JSON value of latestRehireDate. final JsonField<Location>_location()Returns the raw JSON value of location. final JsonField<EmploymentUpdateResponse.Manager>_manager()Returns the raw JSON value of manager. final JsonField<String>_middleName()Returns the raw JSON value of middleName. final JsonField<String>_sourceId()Returns the raw JSON value of sourceId. final JsonField<String>_startDate()Returns the raw JSON value of startDate. final JsonField<String>_title()Returns the raw JSON value of title. final Map<String, JsonValue>_additionalProperties()final EmploymentUpdateResponse.BuildertoBuilder()final EmploymentUpdateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EmploymentUpdateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of EmploymentUpdateResponse. -
-
Method Detail
-
classCode
final Optional<String> classCode()
Worker's compensation classification code for this employee
-
customFields
final Optional<List<EmploymentUpdateResponse.CustomField>> customFields()
Custom fields for the individual. These are fields which are defined by the employer in the system. Custom fields are not currently supported for assisted connections.
-
department
final Optional<EmploymentUpdateResponse.Department> department()
The department object.
-
employment
final Optional<EmploymentUpdateResponse.Employment> employment()
The employment object.
-
employmentStatus
final Optional<EmploymentUpdateResponse.EmploymentStatus> employmentStatus()
The detailed employment status of the individual.
-
flsaStatus
final Optional<EmploymentUpdateResponse.FlsaStatus> flsaStatus()
The FLSA status of the individual. Available options:
exempt,non_exempt,unknown.
-
income
final Optional<Income> income()
The employee's income as reported by the provider. This may not always be annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc, depending on what information the provider returns.
-
incomeHistory
final Optional<List<Income>> incomeHistory()
The array of income history.
-
isActive
final Optional<Boolean> isActive()
trueif the individual an an active employee or contractor at the company.
-
latestRehireDate
final Optional<String> latestRehireDate()
-
manager
final Optional<EmploymentUpdateResponse.Manager> manager()
The manager object representing the manager of the individual within the org.
-
middleName
final Optional<String> middleName()
The legal middle name of the individual.
-
sourceId
final Optional<String> sourceId()
The source system's unique employment identifier for this individual
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_classCode
final JsonField<String> _classCode()
Returns the raw JSON value of classCode.
Unlike classCode, this method doesn't throw if the JSON field has an unexpected type.
-
_customFields
final JsonField<List<EmploymentUpdateResponse.CustomField>> _customFields()
Returns the raw JSON value of customFields.
Unlike customFields, this method doesn't throw if the JSON field has an unexpected type.
-
_department
final JsonField<EmploymentUpdateResponse.Department> _department()
Returns the raw JSON value of department.
Unlike department, this method doesn't throw if the JSON field has an unexpected type.
-
_employment
final JsonField<EmploymentUpdateResponse.Employment> _employment()
Returns the raw JSON value of employment.
Unlike employment, this method doesn't throw if the JSON field has an unexpected type.
-
_employmentStatus
final JsonField<EmploymentUpdateResponse.EmploymentStatus> _employmentStatus()
Returns the raw JSON value of employmentStatus.
Unlike employmentStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_endDate
final JsonField<String> _endDate()
Returns the raw JSON value of endDate.
Unlike endDate, this method doesn't throw if the JSON field has an unexpected type.
-
_firstName
final JsonField<String> _firstName()
Returns the raw JSON value of firstName.
Unlike firstName, this method doesn't throw if the JSON field has an unexpected type.
-
_flsaStatus
final JsonField<EmploymentUpdateResponse.FlsaStatus> _flsaStatus()
Returns the raw JSON value of flsaStatus.
Unlike flsaStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_income
final JsonField<Income> _income()
Returns the raw JSON value of income.
Unlike income, this method doesn't throw if the JSON field has an unexpected type.
-
_incomeHistory
final JsonField<List<Income>> _incomeHistory()
Returns the raw JSON value of incomeHistory.
Unlike incomeHistory, this method doesn't throw if the JSON field has an unexpected type.
-
_isActive
final JsonField<Boolean> _isActive()
Returns the raw JSON value of isActive.
Unlike isActive, this method doesn't throw if the JSON field has an unexpected type.
-
_lastName
final JsonField<String> _lastName()
Returns the raw JSON value of lastName.
Unlike lastName, this method doesn't throw if the JSON field has an unexpected type.
-
_latestRehireDate
final JsonField<String> _latestRehireDate()
Returns the raw JSON value of latestRehireDate.
Unlike latestRehireDate, this method doesn't throw if the JSON field has an unexpected type.
-
_location
final JsonField<Location> _location()
Returns the raw JSON value of location.
Unlike location, this method doesn't throw if the JSON field has an unexpected type.
-
_manager
final JsonField<EmploymentUpdateResponse.Manager> _manager()
Returns the raw JSON value of manager.
Unlike manager, this method doesn't throw if the JSON field has an unexpected type.
-
_middleName
final JsonField<String> _middleName()
Returns the raw JSON value of middleName.
Unlike middleName, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceId
final JsonField<String> _sourceId()
Returns the raw JSON value of sourceId.
Unlike sourceId, this method doesn't throw if the JSON field has an unexpected type.
-
_startDate
final JsonField<String> _startDate()
Returns the raw JSON value of startDate.
Unlike startDate, this method doesn't throw if the JSON field has an unexpected type.
-
_title
final JsonField<String> _title()
Returns the raw JSON value of title.
Unlike title, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EmploymentUpdateResponse.Builder toBuilder()
-
validate
final EmploymentUpdateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EmploymentUpdateResponse.Builder builder()
Returns a mutable builder for constructing an instance of EmploymentUpdateResponse.
-
-
-
-