Class EmploymentUpdateResponse.Builder
-
- All Implemented Interfaces:
public final class EmploymentUpdateResponse.BuilderA builder for EmploymentUpdateResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final EmploymentUpdateResponse.Builder id(String id)
A stable Finch
id(UUID v4) for an individual in the company.
-
id
final EmploymentUpdateResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
classCode
final EmploymentUpdateResponse.Builder classCode(String classCode)
Worker's compensation classification code for this employee
-
classCode
final EmploymentUpdateResponse.Builder classCode(Optional<String> classCode)
Alias for calling Builder.classCode with
classCode.orElse(null).
-
classCode
final EmploymentUpdateResponse.Builder classCode(JsonField<String> classCode)
Sets Builder.classCode to an arbitrary JSON value.
You should usually call Builder.classCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customFields
final EmploymentUpdateResponse.Builder customFields(List<EmploymentUpdateResponse.CustomField> customFields)
Custom fields for the individual. These are fields which are defined by the employer in the system. Custom fields are not currently supported for assisted connections.
-
customFields
final EmploymentUpdateResponse.Builder customFields(Optional<List<EmploymentUpdateResponse.CustomField>> customFields)
Alias for calling Builder.customFields with
customFields.orElse(null).
-
customFields
final EmploymentUpdateResponse.Builder customFields(JsonField<List<EmploymentUpdateResponse.CustomField>> customFields)
Sets Builder.customFields to an arbitrary JSON value.
You should usually call Builder.customFields with a well-typed
List<CustomField>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addCustomField
final EmploymentUpdateResponse.Builder addCustomField(EmploymentUpdateResponse.CustomField customField)
Adds a single CustomField to customFields.
-
department
final EmploymentUpdateResponse.Builder department(EmploymentUpdateResponse.Department department)
The department object.
-
department
final EmploymentUpdateResponse.Builder department(Optional<EmploymentUpdateResponse.Department> department)
Alias for calling Builder.department with
department.orElse(null).
-
department
final EmploymentUpdateResponse.Builder department(JsonField<EmploymentUpdateResponse.Department> department)
Sets Builder.department to an arbitrary JSON value.
You should usually call Builder.department with a well-typed Department value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
employment
final EmploymentUpdateResponse.Builder employment(EmploymentUpdateResponse.Employment employment)
The employment object.
-
employment
final EmploymentUpdateResponse.Builder employment(Optional<EmploymentUpdateResponse.Employment> employment)
Alias for calling Builder.employment with
employment.orElse(null).
-
employment
final EmploymentUpdateResponse.Builder employment(JsonField<EmploymentUpdateResponse.Employment> employment)
Sets Builder.employment to an arbitrary JSON value.
You should usually call Builder.employment with a well-typed Employment value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
employmentStatus
final EmploymentUpdateResponse.Builder employmentStatus(EmploymentUpdateResponse.EmploymentStatus employmentStatus)
The detailed employment status of the individual.
-
employmentStatus
final EmploymentUpdateResponse.Builder employmentStatus(Optional<EmploymentUpdateResponse.EmploymentStatus> employmentStatus)
Alias for calling Builder.employmentStatus with
employmentStatus.orElse(null).
-
employmentStatus
final EmploymentUpdateResponse.Builder employmentStatus(JsonField<EmploymentUpdateResponse.EmploymentStatus> employmentStatus)
Sets Builder.employmentStatus to an arbitrary JSON value.
You should usually call Builder.employmentStatus with a well-typed EmploymentStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
endDate
final EmploymentUpdateResponse.Builder endDate(String endDate)
-
endDate
final EmploymentUpdateResponse.Builder endDate(Optional<String> endDate)
Alias for calling Builder.endDate with
endDate.orElse(null).
-
endDate
final EmploymentUpdateResponse.Builder endDate(JsonField<String> endDate)
Sets Builder.endDate to an arbitrary JSON value.
You should usually call Builder.endDate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
firstName
final EmploymentUpdateResponse.Builder firstName(String firstName)
The legal first name of the individual.
-
firstName
final EmploymentUpdateResponse.Builder firstName(Optional<String> firstName)
Alias for calling Builder.firstName with
firstName.orElse(null).
-
firstName
final EmploymentUpdateResponse.Builder firstName(JsonField<String> firstName)
Sets Builder.firstName to an arbitrary JSON value.
You should usually call Builder.firstName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
flsaStatus
final EmploymentUpdateResponse.Builder flsaStatus(EmploymentUpdateResponse.FlsaStatus flsaStatus)
The FLSA status of the individual. Available options:
exempt,non_exempt,unknown.
-
flsaStatus
final EmploymentUpdateResponse.Builder flsaStatus(Optional<EmploymentUpdateResponse.FlsaStatus> flsaStatus)
Alias for calling Builder.flsaStatus with
flsaStatus.orElse(null).
-
flsaStatus
final EmploymentUpdateResponse.Builder flsaStatus(JsonField<EmploymentUpdateResponse.FlsaStatus> flsaStatus)
Sets Builder.flsaStatus to an arbitrary JSON value.
You should usually call Builder.flsaStatus with a well-typed FlsaStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
income
final EmploymentUpdateResponse.Builder income(Income income)
The employee's income as reported by the provider. This may not always be annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc, depending on what information the provider returns.
-
income
final EmploymentUpdateResponse.Builder income(Optional<Income> income)
Alias for calling Builder.income with
income.orElse(null).
-
income
final EmploymentUpdateResponse.Builder income(JsonField<Income> income)
Sets Builder.income to an arbitrary JSON value.
You should usually call Builder.income with a well-typed Income value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
incomeHistory
final EmploymentUpdateResponse.Builder incomeHistory(List<Income> incomeHistory)
The array of income history.
-
incomeHistory
final EmploymentUpdateResponse.Builder incomeHistory(Optional<List<Income>> incomeHistory)
Alias for calling Builder.incomeHistory with
incomeHistory.orElse(null).
-
incomeHistory
final EmploymentUpdateResponse.Builder incomeHistory(JsonField<List<Income>> incomeHistory)
Sets Builder.incomeHistory to an arbitrary JSON value.
You should usually call Builder.incomeHistory with a well-typed
List<Income?>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addIncomeHistory
final EmploymentUpdateResponse.Builder addIncomeHistory(Income incomeHistory)
Adds a single Income to Builder.incomeHistory.
-
isActive
final EmploymentUpdateResponse.Builder isActive(Boolean isActive)
trueif the individual an an active employee or contractor at the company.
-
isActive
final EmploymentUpdateResponse.Builder isActive(Boolean isActive)
Alias for Builder.isActive.
This unboxed primitive overload exists for backwards compatibility.
-
isActive
final EmploymentUpdateResponse.Builder isActive(Optional<Boolean> isActive)
Alias for calling Builder.isActive with
isActive.orElse(null).
-
isActive
final EmploymentUpdateResponse.Builder isActive(JsonField<Boolean> isActive)
Sets Builder.isActive to an arbitrary JSON value.
You should usually call Builder.isActive with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastName
final EmploymentUpdateResponse.Builder lastName(String lastName)
The legal last name of the individual.
-
lastName
final EmploymentUpdateResponse.Builder lastName(Optional<String> lastName)
Alias for calling Builder.lastName with
lastName.orElse(null).
-
lastName
final EmploymentUpdateResponse.Builder lastName(JsonField<String> lastName)
Sets Builder.lastName to an arbitrary JSON value.
You should usually call Builder.lastName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
latestRehireDate
final EmploymentUpdateResponse.Builder latestRehireDate(String latestRehireDate)
-
latestRehireDate
final EmploymentUpdateResponse.Builder latestRehireDate(Optional<String> latestRehireDate)
Alias for calling Builder.latestRehireDate with
latestRehireDate.orElse(null).
-
latestRehireDate
final EmploymentUpdateResponse.Builder latestRehireDate(JsonField<String> latestRehireDate)
Sets Builder.latestRehireDate to an arbitrary JSON value.
You should usually call Builder.latestRehireDate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
location
final EmploymentUpdateResponse.Builder location(Location location)
-
location
final EmploymentUpdateResponse.Builder location(Optional<Location> location)
Alias for calling Builder.location with
location.orElse(null).
-
location
final EmploymentUpdateResponse.Builder location(JsonField<Location> location)
Sets Builder.location to an arbitrary JSON value.
You should usually call Builder.location with a well-typed Location value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
manager
final EmploymentUpdateResponse.Builder manager(EmploymentUpdateResponse.Manager manager)
The manager object representing the manager of the individual within the org.
-
manager
final EmploymentUpdateResponse.Builder manager(Optional<EmploymentUpdateResponse.Manager> manager)
Alias for calling Builder.manager with
manager.orElse(null).
-
manager
final EmploymentUpdateResponse.Builder manager(JsonField<EmploymentUpdateResponse.Manager> manager)
Sets Builder.manager to an arbitrary JSON value.
You should usually call Builder.manager with a well-typed Manager value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
middleName
final EmploymentUpdateResponse.Builder middleName(String middleName)
The legal middle name of the individual.
-
middleName
final EmploymentUpdateResponse.Builder middleName(Optional<String> middleName)
Alias for calling Builder.middleName with
middleName.orElse(null).
-
middleName
final EmploymentUpdateResponse.Builder middleName(JsonField<String> middleName)
Sets Builder.middleName to an arbitrary JSON value.
You should usually call Builder.middleName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sourceId
final EmploymentUpdateResponse.Builder sourceId(String sourceId)
The source system's unique employment identifier for this individual
-
sourceId
final EmploymentUpdateResponse.Builder sourceId(Optional<String> sourceId)
Alias for calling Builder.sourceId with
sourceId.orElse(null).
-
sourceId
final EmploymentUpdateResponse.Builder sourceId(JsonField<String> sourceId)
Sets Builder.sourceId to an arbitrary JSON value.
You should usually call Builder.sourceId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
startDate
final EmploymentUpdateResponse.Builder startDate(String startDate)
-
startDate
final EmploymentUpdateResponse.Builder startDate(Optional<String> startDate)
Alias for calling Builder.startDate with
startDate.orElse(null).
-
startDate
final EmploymentUpdateResponse.Builder startDate(JsonField<String> startDate)
Sets Builder.startDate to an arbitrary JSON value.
You should usually call Builder.startDate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
title
final EmploymentUpdateResponse.Builder title(String title)
The current title of the individual.
-
title
final EmploymentUpdateResponse.Builder title(Optional<String> title)
Alias for calling Builder.title with
title.orElse(null).
-
title
final EmploymentUpdateResponse.Builder title(JsonField<String> title)
Sets Builder.title to an arbitrary JSON value.
You should usually call Builder.title with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EmploymentUpdateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EmploymentUpdateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EmploymentUpdateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EmploymentUpdateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EmploymentUpdateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EmploymentUpdateResponse build()
Returns an immutable instance of EmploymentUpdateResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-