Package com.tryfinch.api.models
Class EmploymentUpdateResponse.CustomField
-
- All Implemented Interfaces:
public final class EmploymentUpdateResponse.CustomField
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEmploymentUpdateResponse.CustomField.BuilderA builder for CustomField.
public final classEmploymentUpdateResponse.CustomField.Value
-
Method Summary
Modifier and Type Method Description final Optional<String>name()final Optional<EmploymentUpdateResponse.CustomField.Value>value()final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<EmploymentUpdateResponse.CustomField.Value>_value()Returns the raw JSON value of value. final Map<String, JsonValue>_additionalProperties()final EmploymentUpdateResponse.CustomField.BuildertoBuilder()final EmploymentUpdateResponse.CustomFieldvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EmploymentUpdateResponse.CustomField.Builderbuilder()Returns a mutable builder for constructing an instance of CustomField. -
-
Method Detail
-
value
final Optional<EmploymentUpdateResponse.CustomField.Value> value()
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_value
final JsonField<EmploymentUpdateResponse.CustomField.Value> _value()
Returns the raw JSON value of value.
Unlike value, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EmploymentUpdateResponse.CustomField.Builder toBuilder()
-
validate
final EmploymentUpdateResponse.CustomField validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EmploymentUpdateResponse.CustomField.Builder builder()
Returns a mutable builder for constructing an instance of CustomField.
-
-
-
-