Class EmploymentUpdateResponse.CustomField.Builder
-
- All Implemented Interfaces:
public final class EmploymentUpdateResponse.CustomField.BuilderA builder for CustomField.
-
-
Method Summary
-
-
Method Detail
-
name
final EmploymentUpdateResponse.CustomField.Builder name(String name)
-
name
final EmploymentUpdateResponse.CustomField.Builder name(Optional<String> name)
Alias for calling Builder.name with
name.orElse(null).
-
name
final EmploymentUpdateResponse.CustomField.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
value
final EmploymentUpdateResponse.CustomField.Builder value(EmploymentUpdateResponse.CustomField.Value value)
-
value
final EmploymentUpdateResponse.CustomField.Builder value(Optional<EmploymentUpdateResponse.CustomField.Value> value)
Alias for calling Builder.value with
value.orElse(null).
-
value
final EmploymentUpdateResponse.CustomField.Builder value(JsonField<EmploymentUpdateResponse.CustomField.Value> value)
Sets Builder.value to an arbitrary JSON value.
You should usually call Builder.value with a well-typed Value value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
value
final EmploymentUpdateResponse.CustomField.Builder value(String string)
Alias for calling value with
Value.ofString(string).
-
value
final EmploymentUpdateResponse.CustomField.Builder value(JsonValue json)
Alias for calling value with
Value.ofJson(json).
-
value
final EmploymentUpdateResponse.CustomField.Builder value(Double number)
Alias for calling value with
Value.ofNumber(number).
-
value
final EmploymentUpdateResponse.CustomField.Builder value(Boolean bool)
Alias for calling value with
Value.ofBool(bool).
-
valueOfJsonValues
final EmploymentUpdateResponse.CustomField.Builder valueOfJsonValues(List<JsonValue> jsonValues)
Alias for calling value with
Value.ofJsonValues(jsonValues).
-
additionalProperties
final EmploymentUpdateResponse.CustomField.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EmploymentUpdateResponse.CustomField.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EmploymentUpdateResponse.CustomField.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EmploymentUpdateResponse.CustomField.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EmploymentUpdateResponse.CustomField.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EmploymentUpdateResponse.CustomField build()
Returns an immutable instance of CustomField.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-