Package com.tryfinch.api.models
Interface EmploymentUpdateResponse.CustomField.Value.Visitor
-
- All Implemented Interfaces:
public interface EmploymentUpdateResponse.CustomField.Value.Visitor<T extends Object>
-
-
Method Summary
Modifier and Type Method Description abstract TvisitString(String string)abstract TvisitJsonValues(List<JsonValue> jsonValues)abstract TvisitJson(JsonValue json)abstract TvisitNumber(Double number)abstract TvisitBool(Boolean bool)Tunknown(JsonValue json)Maps an unknown variant of Value to a value of type T. -
-
Method Detail
-
visitString
abstract T visitString(String string)
-
visitJsonValues
abstract T visitJsonValues(List<JsonValue> jsonValues)
-
visitNumber
abstract T visitNumber(Double number)
-
unknown
T unknown(JsonValue json)
Maps an unknown variant of Value to a value of type T.
An instance of Value can contain an unknown variant if it was deserialized from data that doesn't match any known variant. For example, if the SDK is on an older version than the API, then the API may respond with new variants that the SDK is unaware of.
-
-
-
-