Package com.tryfinch.api.models
Class EmploymentUpdateResponse.Department
-
- All Implemented Interfaces:
public final class EmploymentUpdateResponse.DepartmentThe department object.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEmploymentUpdateResponse.Department.BuilderA builder for Department.
-
Method Summary
Modifier and Type Method Description final Optional<String>name()The name of the department associated with the individual. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final EmploymentUpdateResponse.Department.BuildertoBuilder()final EmploymentUpdateResponse.Departmentvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EmploymentUpdateResponse.Department.Builderbuilder()Returns a mutable builder for constructing an instance of Department. -
-
Method Detail
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EmploymentUpdateResponse.Department.Builder toBuilder()
-
validate
final EmploymentUpdateResponse.Department validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EmploymentUpdateResponse.Department.Builder builder()
Returns a mutable builder for constructing an instance of Department.
-
-
-
-