Package com.tryfinch.api.models
Class EnrolledIndividualBenefitResponse
-
- All Implemented Interfaces:
public final class EnrolledIndividualBenefitResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEnrolledIndividualBenefitResponse.BuilderA builder for EnrolledIndividualBenefitResponse.
-
Method Summary
Modifier and Type Method Description final StringjobId()final JsonField<String>_jobId()Returns the raw JSON value of jobId. final Map<String, JsonValue>_additionalProperties()final EnrolledIndividualBenefitResponse.BuildertoBuilder()final EnrolledIndividualBenefitResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EnrolledIndividualBenefitResponse.Builderbuilder()Returns a mutable builder for constructing an instance of EnrolledIndividualBenefitResponse. -
-
Method Detail
-
_jobId
final JsonField<String> _jobId()
Returns the raw JSON value of jobId.
Unlike jobId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EnrolledIndividualBenefitResponse.Builder toBuilder()
-
validate
final EnrolledIndividualBenefitResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EnrolledIndividualBenefitResponse.Builder builder()
Returns a mutable builder for constructing an instance of EnrolledIndividualBenefitResponse.
The following fields are required:
.jobId()
-
-
-
-