Class HrisBenefitCreateParams
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Params
public final class HrisBenefitCreateParams implements Params
Creates a new company-wide deduction or contribution. Please use the
/providersendpoint to view available types for each provider.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisBenefitCreateParams.BuilderA builder for HrisBenefitCreateParams.
public final classHrisBenefitCreateParams.Bodypublic final classHrisBenefitCreateParams.BenefitCompanyMatchContributionThe company match for this benefit.
-
Method Summary
Modifier and Type Method Description final Optional<List<String>>entityIds()The entity IDs to specify which entities' data to access. final Optional<HrisBenefitCreateParams.BenefitCompanyMatchContribution>companyContribution()The company match for this benefit. final Optional<String>description()Name of the benefit as it appears in the provider and pay statements. final Optional<BenefitFrequency>frequency()The frequency of the benefit deduction/contribution. final Optional<BenefitType>type()Type of benefit. final JsonField<HrisBenefitCreateParams.BenefitCompanyMatchContribution>_companyContribution()Returns the raw JSON value of companyContribution. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<BenefitFrequency>_frequency()Returns the raw JSON value of frequency. final JsonField<BenefitType>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final HrisBenefitCreateParams.BuildertoBuilder()final HrisBenefitCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static HrisBenefitCreateParamsnone()final static HrisBenefitCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of HrisBenefitCreateParams. -
-
Method Detail
-
entityIds
final Optional<List<String>> entityIds()
The entity IDs to specify which entities' data to access.
-
companyContribution
final Optional<HrisBenefitCreateParams.BenefitCompanyMatchContribution> companyContribution()
The company match for this benefit.
-
description
final Optional<String> description()
Name of the benefit as it appears in the provider and pay statements. Recommend limiting this to <30 characters due to limitations in specific providers (e.g. Justworks).
-
frequency
final Optional<BenefitFrequency> frequency()
The frequency of the benefit deduction/contribution.
-
type
final Optional<BenefitType> type()
Type of benefit.
-
_companyContribution
final JsonField<HrisBenefitCreateParams.BenefitCompanyMatchContribution> _companyContribution()
Returns the raw JSON value of companyContribution.
Unlike companyContribution, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_frequency
final JsonField<BenefitFrequency> _frequency()
Returns the raw JSON value of frequency.
Unlike frequency, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<BenefitType> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final HrisBenefitCreateParams.Builder toBuilder()
-
_body
final HrisBenefitCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static HrisBenefitCreateParams none()
-
builder
final static HrisBenefitCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of HrisBenefitCreateParams.
-
-
-
-