Class HrisBenefitCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class HrisBenefitCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
companyContribution
final HrisBenefitCreateParams.Body.Builder companyContribution(HrisBenefitCreateParams.BenefitCompanyMatchContribution companyContribution)
The company match for this benefit.
-
companyContribution
final HrisBenefitCreateParams.Body.Builder companyContribution(Optional<HrisBenefitCreateParams.BenefitCompanyMatchContribution> companyContribution)
Alias for calling Builder.companyContribution with
companyContribution.orElse(null).
-
companyContribution
final HrisBenefitCreateParams.Body.Builder companyContribution(JsonField<HrisBenefitCreateParams.BenefitCompanyMatchContribution> companyContribution)
Sets Builder.companyContribution to an arbitrary JSON value.
You should usually call Builder.companyContribution with a well-typed BenefitCompanyMatchContribution value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final HrisBenefitCreateParams.Body.Builder description(String description)
Name of the benefit as it appears in the provider and pay statements. Recommend limiting this to <30 characters due to limitations in specific providers (e.g. Justworks).
-
description
final HrisBenefitCreateParams.Body.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
frequency
final HrisBenefitCreateParams.Body.Builder frequency(BenefitFrequency frequency)
The frequency of the benefit deduction/contribution.
-
frequency
final HrisBenefitCreateParams.Body.Builder frequency(Optional<BenefitFrequency> frequency)
Alias for calling Builder.frequency with
frequency.orElse(null).
-
frequency
final HrisBenefitCreateParams.Body.Builder frequency(JsonField<BenefitFrequency> frequency)
Sets Builder.frequency to an arbitrary JSON value.
You should usually call Builder.frequency with a well-typed BenefitFrequency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final HrisBenefitCreateParams.Body.Builder type(BenefitType type)
Type of benefit.
-
type
final HrisBenefitCreateParams.Body.Builder type(Optional<BenefitType> type)
Alias for calling Builder.type with
type.orElse(null).
-
type
final HrisBenefitCreateParams.Body.Builder type(JsonField<BenefitType> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed BenefitType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final HrisBenefitCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final HrisBenefitCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final HrisBenefitCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final HrisBenefitCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final HrisBenefitCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final HrisBenefitCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-