Package com.tryfinch.api.models
Class HrisBenefitListPageAsync
-
- All Implemented Interfaces:
public final class HrisBenefitListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisBenefitListPageAsync.BuilderA builder for HrisBenefitListPageAsync.
public final classHrisBenefitListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final BooleanhasNextPage()final Optional<HrisBenefitListParams>getNextPageParams()final CompletableFuture<Optional<HrisBenefitListPageAsync>>getNextPage()final HrisBenefitListPageAsync.AutoPagerautoPager()final HrisBenefitListParamsparams()The parameters that were used to request this page. final List<CompanyBenefit>items()The response that this page was parsed from. final HrisBenefitListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static HrisBenefitListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of HrisBenefitListPageAsync. -
-
Method Detail
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<HrisBenefitListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<HrisBenefitListPageAsync>> getNextPage()
-
autoPager
final HrisBenefitListPageAsync.AutoPager autoPager()
-
params
final HrisBenefitListParams params()
The parameters that were used to request this page.
-
items
final List<CompanyBenefit> items()
The response that this page was parsed from.
-
toBuilder
final HrisBenefitListPageAsync.Builder toBuilder()
-
builder
final static HrisBenefitListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of HrisBenefitListPageAsync.
The following fields are required:
.service() .params() .items()
-
-
-
-