Package com.tryfinch.api.models
Class HrisBenefitUpdateParams.Body
-
- All Implemented Interfaces:
public final class HrisBenefitUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisBenefitUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>description()Updated name or description. final JsonField<String>_description()Returns the raw JSON value of description. final Map<String, JsonValue>_additionalProperties()final HrisBenefitUpdateParams.Body.BuildertoBuilder()final HrisBenefitUpdateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static HrisBenefitUpdateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
description
final Optional<String> description()
Updated name or description.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final HrisBenefitUpdateParams.Body.Builder toBuilder()
-
validate
final HrisBenefitUpdateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static HrisBenefitUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-