Class HrisCompanyPayStatementItemRuleCreateParams.CreateRuleRequest
-
- All Implemented Interfaces:
public final class HrisCompanyPayStatementItemRuleCreateParams.CreateRuleRequest
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisCompanyPayStatementItemRuleCreateParams.CreateRuleRequest.BuilderA builder for CreateRuleRequest.
-
Method Summary
-
-
Method Detail
-
attributes
final Optional<HrisCompanyPayStatementItemRuleCreateParams.Attributes> attributes()
Specifies the fields to be applied when the condition is met.
-
conditions
final Optional<List<HrisCompanyPayStatementItemRuleCreateParams.Condition>> conditions()
-
effectiveEndDate
final Optional<String> effectiveEndDate()
Specifies when the rules should stop applying rules based on the date.
-
effectiveStartDate
final Optional<String> effectiveStartDate()
Specifies when the rule should begin applying based on the date.
-
entityType
final Optional<HrisCompanyPayStatementItemRuleCreateParams.EntityType> entityType()
The entity type to which the rule is applied.
-
_attributes
final JsonField<HrisCompanyPayStatementItemRuleCreateParams.Attributes> _attributes()
Returns the raw JSON value of attributes.
Unlike attributes, this method doesn't throw if the JSON field has an unexpected type.
-
_conditions
final JsonField<List<HrisCompanyPayStatementItemRuleCreateParams.Condition>> _conditions()
Returns the raw JSON value of conditions.
Unlike conditions, this method doesn't throw if the JSON field has an unexpected type.
-
_effectiveEndDate
final JsonField<String> _effectiveEndDate()
Returns the raw JSON value of effectiveEndDate.
Unlike effectiveEndDate, this method doesn't throw if the JSON field has an unexpected type.
-
_effectiveStartDate
final JsonField<String> _effectiveStartDate()
Returns the raw JSON value of effectiveStartDate.
Unlike effectiveStartDate, this method doesn't throw if the JSON field has an unexpected type.
-
_entityType
final JsonField<HrisCompanyPayStatementItemRuleCreateParams.EntityType> _entityType()
Returns the raw JSON value of entityType.
Unlike entityType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final HrisCompanyPayStatementItemRuleCreateParams.CreateRuleRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static HrisCompanyPayStatementItemRuleCreateParams.CreateRuleRequest.Builder builder()
Returns a mutable builder for constructing an instance of CreateRuleRequest.
-
-
-
-