Class HrisDirectoryListIndividualsPageAsync
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.PageAsync
@Deprecated(message = "use `list` instead") public final class HrisDirectoryListIndividualsPageAsync implements PageAsync<IndividualInDirectory>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisDirectoryListIndividualsPageAsync.BuilderA builder for HrisDirectoryListIndividualsPageAsync.
-
Method Summary
-
-
Method Detail
-
individuals
final List<IndividualInDirectory> individuals()
Delegates to HrisDirectoryListIndividualsPageResponse, but gracefully handles missing data.
-
paging
final Optional<Paging> paging()
Delegates to HrisDirectoryListIndividualsPageResponse, but gracefully handles missing data.
-
items
List<IndividualInDirectory> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final HrisDirectoryListIndividualsParams nextPageParams()
-
nextPage
CompletableFuture<HrisDirectoryListIndividualsPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<IndividualInDirectory> autoPager()
-
params
final HrisDirectoryListIndividualsParams params()
The parameters that were used to request this page.
-
response
final HrisDirectoryListIndividualsPageResponse response()
The response that this page was parsed from.
-
toBuilder
final HrisDirectoryListIndividualsPageAsync.Builder toBuilder()
-
builder
final static HrisDirectoryListIndividualsPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of HrisDirectoryListIndividualsPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-