Class HrisDirectoryListPage
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Page
public final class HrisDirectoryListPage implements Page<IndividualInDirectory>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisDirectoryListPage.BuilderA builder for HrisDirectoryListPage.
-
Method Summary
Modifier and Type Method Description final List<IndividualInDirectory>individuals()Delegates to HrisDirectoryListPageResponse, but gracefully handles missing data. final Optional<Paging>paging()Delegates to HrisDirectoryListPageResponse, but gracefully handles missing data. List<IndividualInDirectory>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final HrisDirectoryListParamsnextPageParams()HrisDirectoryListPagenextPage()Returns the page after this one by making another request. final AutoPager<IndividualInDirectory>autoPager()final HrisDirectoryListParamsparams()The parameters that were used to request this page. final HrisDirectoryListPageResponseresponse()The response that this page was parsed from. final HrisDirectoryListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static HrisDirectoryListPage.Builderbuilder()Returns a mutable builder for constructing an instance of HrisDirectoryListPage. -
-
Method Detail
-
individuals
final List<IndividualInDirectory> individuals()
Delegates to HrisDirectoryListPageResponse, but gracefully handles missing data.
-
paging
final Optional<Paging> paging()
Delegates to HrisDirectoryListPageResponse, but gracefully handles missing data.
-
items
List<IndividualInDirectory> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final HrisDirectoryListParams nextPageParams()
-
nextPage
HrisDirectoryListPage nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPager<IndividualInDirectory> autoPager()
-
params
final HrisDirectoryListParams params()
The parameters that were used to request this page.
-
response
final HrisDirectoryListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final HrisDirectoryListPage.Builder toBuilder()
-
builder
final static HrisDirectoryListPage.Builder builder()
Returns a mutable builder for constructing an instance of HrisDirectoryListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-