Package com.tryfinch.api.models
Class HrisDirectoryListPage.Builder
-
- All Implemented Interfaces:
public final class HrisDirectoryListPage.BuilderA builder for HrisDirectoryListPage.
-
-
Method Summary
Modifier and Type Method Description final HrisDirectoryListPage.Builderservice(DirectoryService service)final HrisDirectoryListPage.Builderparams(HrisDirectoryListParams params)The parameters that were used to request this page. final HrisDirectoryListPage.Builderresponse(HrisDirectoryListPageResponse response)The response that this page was parsed from. final HrisDirectoryListPagebuild()Returns an immutable instance of HrisDirectoryListPage. -
-
Method Detail
-
service
final HrisDirectoryListPage.Builder service(DirectoryService service)
-
params
final HrisDirectoryListPage.Builder params(HrisDirectoryListParams params)
The parameters that were used to request this page.
-
response
final HrisDirectoryListPage.Builder response(HrisDirectoryListPageResponse response)
The response that this page was parsed from.
-
build
final HrisDirectoryListPage build()
Returns an immutable instance of HrisDirectoryListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-