Class HrisDirectoryListPageAsync
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.PageAsync
public final class HrisDirectoryListPageAsync implements PageAsync<IndividualInDirectory>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisDirectoryListPageAsync.BuilderA builder for HrisDirectoryListPageAsync.
-
Method Summary
Modifier and Type Method Description final List<IndividualInDirectory>individuals()Delegates to HrisDirectoryListPageResponse, but gracefully handles missing data. final Optional<Paging>paging()Delegates to HrisDirectoryListPageResponse, but gracefully handles missing data. List<IndividualInDirectory>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final HrisDirectoryListParamsnextPageParams()CompletableFuture<HrisDirectoryListPageAsync>nextPage()Returns the page after this one by making another request. final AutoPagerAsync<IndividualInDirectory>autoPager()final HrisDirectoryListParamsparams()The parameters that were used to request this page. final HrisDirectoryListPageResponseresponse()The response that this page was parsed from. final HrisDirectoryListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static HrisDirectoryListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of HrisDirectoryListPageAsync. -
-
Method Detail
-
individuals
final List<IndividualInDirectory> individuals()
Delegates to HrisDirectoryListPageResponse, but gracefully handles missing data.
-
paging
final Optional<Paging> paging()
Delegates to HrisDirectoryListPageResponse, but gracefully handles missing data.
-
items
List<IndividualInDirectory> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final HrisDirectoryListParams nextPageParams()
-
nextPage
CompletableFuture<HrisDirectoryListPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<IndividualInDirectory> autoPager()
-
params
final HrisDirectoryListParams params()
The parameters that were used to request this page.
-
response
final HrisDirectoryListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final HrisDirectoryListPageAsync.Builder toBuilder()
-
builder
final static HrisDirectoryListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of HrisDirectoryListPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-