Package com.tryfinch.api.models
Class HrisDirectoryListPageAsync.Builder
-
- All Implemented Interfaces:
public final class HrisDirectoryListPageAsync.BuilderA builder for HrisDirectoryListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final HrisDirectoryListPageAsync.Builderservice(DirectoryServiceAsync service)final HrisDirectoryListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final HrisDirectoryListPageAsync.Builderparams(HrisDirectoryListParams params)The parameters that were used to request this page. final HrisDirectoryListPageAsync.Builderresponse(HrisDirectoryListPageResponse response)The response that this page was parsed from. final HrisDirectoryListPageAsyncbuild()Returns an immutable instance of HrisDirectoryListPageAsync. -
-
Method Detail
-
service
final HrisDirectoryListPageAsync.Builder service(DirectoryServiceAsync service)
-
streamHandlerExecutor
final HrisDirectoryListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final HrisDirectoryListPageAsync.Builder params(HrisDirectoryListParams params)
The parameters that were used to request this page.
-
response
final HrisDirectoryListPageAsync.Builder response(HrisDirectoryListPageResponse response)
The response that this page was parsed from.
-
build
final HrisDirectoryListPageAsync build()
Returns an immutable instance of HrisDirectoryListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-