Package com.tryfinch.api.models
Class HrisDocumentListParams
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Params
public final class HrisDocumentListParams implements Params
Beta: This endpoint is in beta and may change. Retrieve a list of company-wide documents.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisDocumentListParams.BuilderA builder for HrisDocumentListParams.
public final classHrisDocumentListParams.Type
-
Method Summary
Modifier and Type Method Description final Optional<List<String>>entityIds()The entity IDs to specify which entities' data to access. final Optional<List<String>>individualIds()Comma-delimited list of stable Finch uuids for each individual. final Optional<Long>limit()Number of documents to return (defaults to all) final Optional<Long>offset()Index to start from (defaults to 0) final Optional<List<HrisDocumentListParams.Type>>types()Comma-delimited list of document types to filter on. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final HrisDocumentListParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static HrisDocumentListParamsnone()final static HrisDocumentListParams.Builderbuilder()Returns a mutable builder for constructing an instance of HrisDocumentListParams. -
-
Method Detail
-
entityIds
final Optional<List<String>> entityIds()
The entity IDs to specify which entities' data to access.
-
individualIds
final Optional<List<String>> individualIds()
Comma-delimited list of stable Finch uuids for each individual. If empty, defaults to all individuals
-
types
final Optional<List<HrisDocumentListParams.Type>> types()
Comma-delimited list of document types to filter on. If empty, defaults to all types
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final HrisDocumentListParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static HrisDocumentListParams none()
-
builder
final static HrisDocumentListParams.Builder builder()
Returns a mutable builder for constructing an instance of HrisDocumentListParams.
-
-
-
-