Package com.tryfinch.api.models
Class HrisEmploymentRetrieveManyPage
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Page
public final class HrisEmploymentRetrieveManyPage implements Page<EmploymentDataResponse>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisEmploymentRetrieveManyPage.BuilderA builder for HrisEmploymentRetrieveManyPage.
-
Method Summary
Modifier and Type Method Description final List<EmploymentDataResponse>responses()Delegates to HrisEmploymentRetrieveManyPageResponse, but gracefully handles missing data. List<EmploymentDataResponse>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final HrisEmploymentRetrieveManyParamsnextPageParams()HrisEmploymentRetrieveManyPagenextPage()Returns the page after this one by making another request. final AutoPager<EmploymentDataResponse>autoPager()final HrisEmploymentRetrieveManyParamsparams()The parameters that were used to request this page. final HrisEmploymentRetrieveManyPageResponseresponse()The response that this page was parsed from. final HrisEmploymentRetrieveManyPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static HrisEmploymentRetrieveManyPage.Builderbuilder()Returns a mutable builder for constructing an instance of HrisEmploymentRetrieveManyPage. -
-
Method Detail
-
responses
final List<EmploymentDataResponse> responses()
Delegates to HrisEmploymentRetrieveManyPageResponse, but gracefully handles missing data.
-
items
List<EmploymentDataResponse> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final HrisEmploymentRetrieveManyParams nextPageParams()
-
nextPage
HrisEmploymentRetrieveManyPage nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPager<EmploymentDataResponse> autoPager()
-
params
final HrisEmploymentRetrieveManyParams params()
The parameters that were used to request this page.
-
response
final HrisEmploymentRetrieveManyPageResponse response()
The response that this page was parsed from.
-
toBuilder
final HrisEmploymentRetrieveManyPage.Builder toBuilder()
-
builder
final static HrisEmploymentRetrieveManyPage.Builder builder()
Returns a mutable builder for constructing an instance of HrisEmploymentRetrieveManyPage.
The following fields are required:
.service() .params() .response()
-
-
-
-