Package com.tryfinch.api.models
Class HrisEmploymentRetrieveManyPageAsync
-
- All Implemented Interfaces:
public final class HrisEmploymentRetrieveManyPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisEmploymentRetrieveManyPageAsync.BuilderA builder for HrisEmploymentRetrieveManyPageAsync.
public final classHrisEmploymentRetrieveManyPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<EmploymentDataResponse>responses()Delegates to HrisEmploymentRetrieveManyPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<HrisEmploymentRetrieveManyParams>getNextPageParams()final CompletableFuture<Optional<HrisEmploymentRetrieveManyPageAsync>>getNextPage()final HrisEmploymentRetrieveManyPageAsync.AutoPagerautoPager()final HrisEmploymentRetrieveManyParamsparams()The parameters that were used to request this page. final HrisEmploymentRetrieveManyPageResponseresponse()The response that this page was parsed from. final HrisEmploymentRetrieveManyPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static HrisEmploymentRetrieveManyPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of HrisEmploymentRetrieveManyPageAsync. -
-
Method Detail
-
responses
final List<EmploymentDataResponse> responses()
Delegates to HrisEmploymentRetrieveManyPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<HrisEmploymentRetrieveManyParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<HrisEmploymentRetrieveManyPageAsync>> getNextPage()
-
autoPager
final HrisEmploymentRetrieveManyPageAsync.AutoPager autoPager()
-
params
final HrisEmploymentRetrieveManyParams params()
The parameters that were used to request this page.
-
response
final HrisEmploymentRetrieveManyPageResponse response()
The response that this page was parsed from.
-
toBuilder
final HrisEmploymentRetrieveManyPageAsync.Builder toBuilder()
-
builder
final static HrisEmploymentRetrieveManyPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of HrisEmploymentRetrieveManyPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-