Package com.tryfinch.api.models
Class HrisEmploymentRetrieveManyPageAsync.Builder
-
- All Implemented Interfaces:
public final class HrisEmploymentRetrieveManyPageAsync.BuilderA builder for HrisEmploymentRetrieveManyPageAsync.
-
-
Method Summary
Modifier and Type Method Description final HrisEmploymentRetrieveManyPageAsync.Builderservice(EmploymentServiceAsync service)final HrisEmploymentRetrieveManyPageAsync.Builderparams(HrisEmploymentRetrieveManyParams params)The parameters that were used to request this page. final HrisEmploymentRetrieveManyPageAsync.Builderresponse(HrisEmploymentRetrieveManyPageResponse response)The response that this page was parsed from. final HrisEmploymentRetrieveManyPageAsyncbuild()Returns an immutable instance of HrisEmploymentRetrieveManyPageAsync. -
-
Method Detail
-
service
final HrisEmploymentRetrieveManyPageAsync.Builder service(EmploymentServiceAsync service)
-
params
final HrisEmploymentRetrieveManyPageAsync.Builder params(HrisEmploymentRetrieveManyParams params)
The parameters that were used to request this page.
-
response
final HrisEmploymentRetrieveManyPageAsync.Builder response(HrisEmploymentRetrieveManyPageResponse response)
The response that this page was parsed from.
-
build
final HrisEmploymentRetrieveManyPageAsync build()
Returns an immutable instance of HrisEmploymentRetrieveManyPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-