Package com.tryfinch.api.models
Class HrisEmploymentRetrieveManyPageResponse
-
- All Implemented Interfaces:
public final class HrisEmploymentRetrieveManyPageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisEmploymentRetrieveManyPageResponse.BuilderA builder for HrisEmploymentRetrieveManyPageResponse.
-
Method Summary
Modifier and Type Method Description final List<EmploymentDataResponse>responses()final JsonField<List<EmploymentDataResponse>>_responses()Returns the raw JSON value of responses. final Map<String, JsonValue>_additionalProperties()final HrisEmploymentRetrieveManyPageResponse.BuildertoBuilder()final HrisEmploymentRetrieveManyPageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static HrisEmploymentRetrieveManyPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of HrisEmploymentRetrieveManyPageResponse. -
-
Method Detail
-
responses
final List<EmploymentDataResponse> responses()
-
_responses
final JsonField<List<EmploymentDataResponse>> _responses()
Returns the raw JSON value of responses.
Unlike responses, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final HrisEmploymentRetrieveManyPageResponse.Builder toBuilder()
-
validate
final HrisEmploymentRetrieveManyPageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static HrisEmploymentRetrieveManyPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of HrisEmploymentRetrieveManyPageResponse.
The following fields are required:
.responses()
-
-
-
-