Package com.tryfinch.api.models
Class HrisIndividualRetrieveManyPage
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Page
public final class HrisIndividualRetrieveManyPage implements Page<IndividualResponse>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisIndividualRetrieveManyPage.BuilderA builder for HrisIndividualRetrieveManyPage.
-
Method Summary
Modifier and Type Method Description final List<IndividualResponse>responses()Delegates to HrisIndividualRetrieveManyPageResponse, but gracefully handles missing data. List<IndividualResponse>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final HrisIndividualRetrieveManyParamsnextPageParams()HrisIndividualRetrieveManyPagenextPage()Returns the page after this one by making another request. final AutoPager<IndividualResponse>autoPager()final HrisIndividualRetrieveManyParamsparams()The parameters that were used to request this page. final HrisIndividualRetrieveManyPageResponseresponse()The response that this page was parsed from. final HrisIndividualRetrieveManyPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static HrisIndividualRetrieveManyPage.Builderbuilder()Returns a mutable builder for constructing an instance of HrisIndividualRetrieveManyPage. -
-
Method Detail
-
responses
final List<IndividualResponse> responses()
Delegates to HrisIndividualRetrieveManyPageResponse, but gracefully handles missing data.
-
items
List<IndividualResponse> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final HrisIndividualRetrieveManyParams nextPageParams()
-
nextPage
HrisIndividualRetrieveManyPage nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPager<IndividualResponse> autoPager()
-
params
final HrisIndividualRetrieveManyParams params()
The parameters that were used to request this page.
-
response
final HrisIndividualRetrieveManyPageResponse response()
The response that this page was parsed from.
-
toBuilder
final HrisIndividualRetrieveManyPage.Builder toBuilder()
-
builder
final static HrisIndividualRetrieveManyPage.Builder builder()
Returns a mutable builder for constructing an instance of HrisIndividualRetrieveManyPage.
The following fields are required:
.service() .params() .response()
-
-
-
-