Package com.tryfinch.api.models
Class HrisIndividualRetrieveManyPageAsync
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.PageAsync
public final class HrisIndividualRetrieveManyPageAsync implements PageAsync<IndividualResponse>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisIndividualRetrieveManyPageAsync.BuilderA builder for HrisIndividualRetrieveManyPageAsync.
-
Method Summary
-
-
Method Detail
-
responses
final List<IndividualResponse> responses()
Delegates to HrisIndividualRetrieveManyPageResponse, but gracefully handles missing data.
-
items
List<IndividualResponse> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final HrisIndividualRetrieveManyParams nextPageParams()
-
nextPage
CompletableFuture<HrisIndividualRetrieveManyPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<IndividualResponse> autoPager()
-
params
final HrisIndividualRetrieveManyParams params()
The parameters that were used to request this page.
-
response
final HrisIndividualRetrieveManyPageResponse response()
The response that this page was parsed from.
-
toBuilder
final HrisIndividualRetrieveManyPageAsync.Builder toBuilder()
-
builder
final static HrisIndividualRetrieveManyPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of HrisIndividualRetrieveManyPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-