Package com.tryfinch.api.models
Class HrisPayStatementItemListPageAsync
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.PageAsync
public final class HrisPayStatementItemListPageAsync implements PageAsync<PayStatementItemListResponse>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisPayStatementItemListPageAsync.BuilderA builder for HrisPayStatementItemListPageAsync.
-
Method Summary
-
-
Method Detail
-
responses
final List<PayStatementItemListResponse> responses()
Delegates to HrisPayStatementItemListPageResponse, but gracefully handles missing data.
-
items
List<PayStatementItemListResponse> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final HrisPayStatementItemListParams nextPageParams()
-
nextPage
CompletableFuture<HrisPayStatementItemListPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<PayStatementItemListResponse> autoPager()
-
params
final HrisPayStatementItemListParams params()
The parameters that were used to request this page.
-
response
final HrisPayStatementItemListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final HrisPayStatementItemListPageAsync.Builder toBuilder()
-
builder
final static HrisPayStatementItemListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of HrisPayStatementItemListPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-