Class HrisPayStatementItemRuleCreateParams
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Params
public final class HrisPayStatementItemRuleCreateParams implements Params
Custom rules can be created to associate specific attributes to pay statement items depending on the use case. For example, pay statement items that meet certain conditions can be labeled as a pre-tax 401k. This metadata can be retrieved where pay statement item information is available.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisPayStatementItemRuleCreateParams.BuilderA builder for HrisPayStatementItemRuleCreateParams.
public final classHrisPayStatementItemRuleCreateParams.CreateRuleRequestpublic final classHrisPayStatementItemRuleCreateParams.AttributesSpecifies the fields to be applied when the condition is met.
public final classHrisPayStatementItemRuleCreateParams.Conditionpublic final classHrisPayStatementItemRuleCreateParams.EntityTypeThe entity type to which the rule is applied.
-
Method Summary
Modifier and Type Method Description final Optional<List<String>>entityIds()The entity IDs to create the rule for. final Optional<HrisPayStatementItemRuleCreateParams.Attributes>attributes()Specifies the fields to be applied when the condition is met. final Optional<List<HrisPayStatementItemRuleCreateParams.Condition>>conditions()final Optional<String>effectiveEndDate()Specifies when the rules should stop applying rules based on the date. final Optional<String>effectiveStartDate()Specifies when the rule should begin applying based on the date. final Optional<HrisPayStatementItemRuleCreateParams.EntityType>entityType()The entity type to which the rule is applied. final JsonField<HrisPayStatementItemRuleCreateParams.Attributes>_attributes()Returns the raw JSON value of attributes. final JsonField<List<HrisPayStatementItemRuleCreateParams.Condition>>_conditions()Returns the raw JSON value of conditions. final JsonField<String>_effectiveEndDate()Returns the raw JSON value of effectiveEndDate. final JsonField<String>_effectiveStartDate()Returns the raw JSON value of effectiveStartDate. final JsonField<HrisPayStatementItemRuleCreateParams.EntityType>_entityType()Returns the raw JSON value of entityType. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final HrisPayStatementItemRuleCreateParams.BuildertoBuilder()final HrisPayStatementItemRuleCreateParams.CreateRuleRequest_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static HrisPayStatementItemRuleCreateParamsnone()final static HrisPayStatementItemRuleCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of HrisPayStatementItemRuleCreateParams. -
-
Method Detail
-
attributes
final Optional<HrisPayStatementItemRuleCreateParams.Attributes> attributes()
Specifies the fields to be applied when the condition is met.
-
conditions
final Optional<List<HrisPayStatementItemRuleCreateParams.Condition>> conditions()
-
effectiveEndDate
final Optional<String> effectiveEndDate()
Specifies when the rules should stop applying rules based on the date.
-
effectiveStartDate
final Optional<String> effectiveStartDate()
Specifies when the rule should begin applying based on the date.
-
entityType
final Optional<HrisPayStatementItemRuleCreateParams.EntityType> entityType()
The entity type to which the rule is applied.
-
_attributes
final JsonField<HrisPayStatementItemRuleCreateParams.Attributes> _attributes()
Returns the raw JSON value of attributes.
Unlike attributes, this method doesn't throw if the JSON field has an unexpected type.
-
_conditions
final JsonField<List<HrisPayStatementItemRuleCreateParams.Condition>> _conditions()
Returns the raw JSON value of conditions.
Unlike conditions, this method doesn't throw if the JSON field has an unexpected type.
-
_effectiveEndDate
final JsonField<String> _effectiveEndDate()
Returns the raw JSON value of effectiveEndDate.
Unlike effectiveEndDate, this method doesn't throw if the JSON field has an unexpected type.
-
_effectiveStartDate
final JsonField<String> _effectiveStartDate()
Returns the raw JSON value of effectiveStartDate.
Unlike effectiveStartDate, this method doesn't throw if the JSON field has an unexpected type.
-
_entityType
final JsonField<HrisPayStatementItemRuleCreateParams.EntityType> _entityType()
Returns the raw JSON value of entityType.
Unlike entityType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final HrisPayStatementItemRuleCreateParams.Builder toBuilder()
-
_body
final HrisPayStatementItemRuleCreateParams.CreateRuleRequest _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static HrisPayStatementItemRuleCreateParams none()
-
builder
final static HrisPayStatementItemRuleCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of HrisPayStatementItemRuleCreateParams.
-
-
-
-