Class HrisPayStatementItemRuleCreateParams.Attributes
-
- All Implemented Interfaces:
public final class HrisPayStatementItemRuleCreateParams.AttributesSpecifies the fields to be applied when the condition is met.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisPayStatementItemRuleCreateParams.Attributes.BuilderA builder for Attributes.
public final classHrisPayStatementItemRuleCreateParams.Attributes.MetadataThe metadata to be attached in the entity. It is a key-value pairs where the values can be of any type (string, number, boolean, object, array, etc.).
-
Method Summary
Modifier and Type Method Description final Optional<HrisPayStatementItemRuleCreateParams.Attributes.Metadata>metadata()The metadata to be attached in the entity. final JsonField<HrisPayStatementItemRuleCreateParams.Attributes.Metadata>_metadata()Returns the raw JSON value of metadata. final Map<String, JsonValue>_additionalProperties()final HrisPayStatementItemRuleCreateParams.Attributes.BuildertoBuilder()final HrisPayStatementItemRuleCreateParams.Attributesvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static HrisPayStatementItemRuleCreateParams.Attributes.Builderbuilder()Returns a mutable builder for constructing an instance of Attributes. -
-
Method Detail
-
metadata
final Optional<HrisPayStatementItemRuleCreateParams.Attributes.Metadata> metadata()
The metadata to be attached in the entity. It is a key-value pairs where the values can be of any type (string, number, boolean, object, array, etc.).
-
_metadata
final JsonField<HrisPayStatementItemRuleCreateParams.Attributes.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final HrisPayStatementItemRuleCreateParams.Attributes.Builder toBuilder()
-
validate
final HrisPayStatementItemRuleCreateParams.Attributes validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static HrisPayStatementItemRuleCreateParams.Attributes.Builder builder()
Returns a mutable builder for constructing an instance of Attributes.
-
-
-
-