Package com.tryfinch.api.models
Class HrisPayStatementItemRuleCreateParams.Attributes.Metadata
-
- All Implemented Interfaces:
public final class HrisPayStatementItemRuleCreateParams.Attributes.MetadataThe metadata to be attached in the entity. It is a key-value pairs where the values can be of any type (string, number, boolean, object, array, etc.).
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisPayStatementItemRuleCreateParams.Attributes.Metadata.BuilderA builder for Metadata.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final HrisPayStatementItemRuleCreateParams.Attributes.Metadata.BuildertoBuilder()final HrisPayStatementItemRuleCreateParams.Attributes.Metadatavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static HrisPayStatementItemRuleCreateParams.Attributes.Metadata.Builderbuilder()Returns a mutable builder for constructing an instance of Metadata. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final HrisPayStatementItemRuleCreateParams.Attributes.Metadata.Builder toBuilder()
-
validate
final HrisPayStatementItemRuleCreateParams.Attributes.Metadata validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static HrisPayStatementItemRuleCreateParams.Attributes.Metadata.Builder builder()
Returns a mutable builder for constructing an instance of Metadata.
-
-
-
-