Class HrisPayStatementItemRuleCreateParams.CreateRuleRequest.Builder
-
- All Implemented Interfaces:
public final class HrisPayStatementItemRuleCreateParams.CreateRuleRequest.BuilderA builder for CreateRuleRequest.
-
-
Method Summary
-
-
Method Detail
-
attributes
final HrisPayStatementItemRuleCreateParams.CreateRuleRequest.Builder attributes(HrisPayStatementItemRuleCreateParams.Attributes attributes)
Specifies the fields to be applied when the condition is met.
-
attributes
final HrisPayStatementItemRuleCreateParams.CreateRuleRequest.Builder attributes(JsonField<HrisPayStatementItemRuleCreateParams.Attributes> attributes)
Sets Builder.attributes to an arbitrary JSON value.
You should usually call Builder.attributes with a well-typed Attributes value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
conditions
final HrisPayStatementItemRuleCreateParams.CreateRuleRequest.Builder conditions(List<HrisPayStatementItemRuleCreateParams.Condition> conditions)
-
conditions
final HrisPayStatementItemRuleCreateParams.CreateRuleRequest.Builder conditions(JsonField<List<HrisPayStatementItemRuleCreateParams.Condition>> conditions)
Sets Builder.conditions to an arbitrary JSON value.
You should usually call Builder.conditions with a well-typed
List<Condition>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addCondition
final HrisPayStatementItemRuleCreateParams.CreateRuleRequest.Builder addCondition(HrisPayStatementItemRuleCreateParams.Condition condition)
Adds a single Condition to conditions.
-
effectiveEndDate
final HrisPayStatementItemRuleCreateParams.CreateRuleRequest.Builder effectiveEndDate(String effectiveEndDate)
Specifies when the rules should stop applying rules based on the date.
-
effectiveEndDate
final HrisPayStatementItemRuleCreateParams.CreateRuleRequest.Builder effectiveEndDate(Optional<String> effectiveEndDate)
Alias for calling Builder.effectiveEndDate with
effectiveEndDate.orElse(null).
-
effectiveEndDate
final HrisPayStatementItemRuleCreateParams.CreateRuleRequest.Builder effectiveEndDate(JsonField<String> effectiveEndDate)
Sets Builder.effectiveEndDate to an arbitrary JSON value.
You should usually call Builder.effectiveEndDate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
effectiveStartDate
final HrisPayStatementItemRuleCreateParams.CreateRuleRequest.Builder effectiveStartDate(String effectiveStartDate)
Specifies when the rule should begin applying based on the date.
-
effectiveStartDate
final HrisPayStatementItemRuleCreateParams.CreateRuleRequest.Builder effectiveStartDate(Optional<String> effectiveStartDate)
Alias for calling Builder.effectiveStartDate with
effectiveStartDate.orElse(null).
-
effectiveStartDate
final HrisPayStatementItemRuleCreateParams.CreateRuleRequest.Builder effectiveStartDate(JsonField<String> effectiveStartDate)
Sets Builder.effectiveStartDate to an arbitrary JSON value.
You should usually call Builder.effectiveStartDate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entityType
final HrisPayStatementItemRuleCreateParams.CreateRuleRequest.Builder entityType(HrisPayStatementItemRuleCreateParams.EntityType entityType)
The entity type to which the rule is applied.
-
entityType
final HrisPayStatementItemRuleCreateParams.CreateRuleRequest.Builder entityType(JsonField<HrisPayStatementItemRuleCreateParams.EntityType> entityType)
Sets Builder.entityType to an arbitrary JSON value.
You should usually call Builder.entityType with a well-typed EntityType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final HrisPayStatementItemRuleCreateParams.CreateRuleRequest.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final HrisPayStatementItemRuleCreateParams.CreateRuleRequest.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final HrisPayStatementItemRuleCreateParams.CreateRuleRequest.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final HrisPayStatementItemRuleCreateParams.CreateRuleRequest.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final HrisPayStatementItemRuleCreateParams.CreateRuleRequest.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final HrisPayStatementItemRuleCreateParams.CreateRuleRequest build()
Returns an immutable instance of CreateRuleRequest.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-