Package com.tryfinch.api.models
Class HrisPayStatementItemRuleUpdateParams
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Params
public final class HrisPayStatementItemRuleUpdateParams implements Params
Update a rule for a pay statement item.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisPayStatementItemRuleUpdateParams.BuilderA builder for HrisPayStatementItemRuleUpdateParams.
public final classHrisPayStatementItemRuleUpdateParams.UpdateRuleRequest
-
Method Summary
Modifier and Type Method Description final Optional<String>ruleId()final Optional<List<String>>entityIds()The entity IDs to update the rule for. final JsonValue_optionalProperty()This arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = hrisPayStatementItemRuleUpdateParams.optionalProperty().convert(MyClass.class);final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final HrisPayStatementItemRuleUpdateParams.BuildertoBuilder()final HrisPayStatementItemRuleUpdateParams.UpdateRuleRequest_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static HrisPayStatementItemRuleUpdateParamsnone()final static HrisPayStatementItemRuleUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of HrisPayStatementItemRuleUpdateParams. -
-
Method Detail
-
_optionalProperty
final JsonValue _optionalProperty()
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = hrisPayStatementItemRuleUpdateParams.optionalProperty().convert(MyClass.class);
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final HrisPayStatementItemRuleUpdateParams.Builder toBuilder()
-
_body
final HrisPayStatementItemRuleUpdateParams.UpdateRuleRequest _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static HrisPayStatementItemRuleUpdateParams none()
-
builder
final static HrisPayStatementItemRuleUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of HrisPayStatementItemRuleUpdateParams.
-
-
-
-