Package com.tryfinch.api.models
Class HrisPayStatementItemRuleUpdateParams.UpdateRuleRequest
-
- All Implemented Interfaces:
public final class HrisPayStatementItemRuleUpdateParams.UpdateRuleRequest
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisPayStatementItemRuleUpdateParams.UpdateRuleRequest.BuilderA builder for UpdateRuleRequest.
-
Method Summary
Modifier and Type Method Description final JsonValue_optionalProperty()This arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = updateRuleRequest.optionalProperty().convert(MyClass.class);final Map<String, JsonValue>_additionalProperties()final HrisPayStatementItemRuleUpdateParams.UpdateRuleRequest.BuildertoBuilder()final HrisPayStatementItemRuleUpdateParams.UpdateRuleRequestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static HrisPayStatementItemRuleUpdateParams.UpdateRuleRequest.Builderbuilder()Returns a mutable builder for constructing an instance of UpdateRuleRequest. -
-
Method Detail
-
_optionalProperty
final JsonValue _optionalProperty()
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = updateRuleRequest.optionalProperty().convert(MyClass.class);
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final HrisPayStatementItemRuleUpdateParams.UpdateRuleRequest.Builder toBuilder()
-
validate
final HrisPayStatementItemRuleUpdateParams.UpdateRuleRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static HrisPayStatementItemRuleUpdateParams.UpdateRuleRequest.Builder builder()
Returns a mutable builder for constructing an instance of UpdateRuleRequest.
-
-
-
-