Package com.tryfinch.api.models
Class HrisPayStatementRetrieveManyPage
-
- All Implemented Interfaces:
public final class HrisPayStatementRetrieveManyPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisPayStatementRetrieveManyPage.BuilderA builder for HrisPayStatementRetrieveManyPage.
public final classHrisPayStatementRetrieveManyPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<PayStatementResponse>responses()Delegates to HrisPayStatementRetrieveManyPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<HrisPayStatementRetrieveManyParams>getNextPageParams()final Optional<HrisPayStatementRetrieveManyPage>getNextPage()final HrisPayStatementRetrieveManyPage.AutoPagerautoPager()final HrisPayStatementRetrieveManyParamsparams()The parameters that were used to request this page. final HrisPayStatementRetrieveManyPageResponseresponse()The response that this page was parsed from. final HrisPayStatementRetrieveManyPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static HrisPayStatementRetrieveManyPage.Builderbuilder()Returns a mutable builder for constructing an instance of HrisPayStatementRetrieveManyPage. -
-
Method Detail
-
responses
final List<PayStatementResponse> responses()
Delegates to HrisPayStatementRetrieveManyPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<HrisPayStatementRetrieveManyParams> getNextPageParams()
-
getNextPage
final Optional<HrisPayStatementRetrieveManyPage> getNextPage()
-
autoPager
final HrisPayStatementRetrieveManyPage.AutoPager autoPager()
-
params
final HrisPayStatementRetrieveManyParams params()
The parameters that were used to request this page.
-
response
final HrisPayStatementRetrieveManyPageResponse response()
The response that this page was parsed from.
-
toBuilder
final HrisPayStatementRetrieveManyPage.Builder toBuilder()
-
builder
final static HrisPayStatementRetrieveManyPage.Builder builder()
Returns a mutable builder for constructing an instance of HrisPayStatementRetrieveManyPage.
The following fields are required:
.service() .params() .response()
-
-
-
-