Package com.tryfinch.api.models
Class HrisPayStatementRetrieveManyPage.Builder
-
- All Implemented Interfaces:
public final class HrisPayStatementRetrieveManyPage.BuilderA builder for HrisPayStatementRetrieveManyPage.
-
-
Method Summary
Modifier and Type Method Description final HrisPayStatementRetrieveManyPage.Builderservice(PayStatementService service)final HrisPayStatementRetrieveManyPage.Builderparams(HrisPayStatementRetrieveManyParams params)The parameters that were used to request this page. final HrisPayStatementRetrieveManyPage.Builderresponse(HrisPayStatementRetrieveManyPageResponse response)The response that this page was parsed from. final HrisPayStatementRetrieveManyPagebuild()Returns an immutable instance of HrisPayStatementRetrieveManyPage. -
-
Method Detail
-
service
final HrisPayStatementRetrieveManyPage.Builder service(PayStatementService service)
-
params
final HrisPayStatementRetrieveManyPage.Builder params(HrisPayStatementRetrieveManyParams params)
The parameters that were used to request this page.
-
response
final HrisPayStatementRetrieveManyPage.Builder response(HrisPayStatementRetrieveManyPageResponse response)
The response that this page was parsed from.
-
build
final HrisPayStatementRetrieveManyPage build()
Returns an immutable instance of HrisPayStatementRetrieveManyPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-