Package com.tryfinch.api.models
Class HrisPayStatementRetrieveManyPageAsync
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.PageAsync
public final class HrisPayStatementRetrieveManyPageAsync implements PageAsync<PayStatementResponse>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisPayStatementRetrieveManyPageAsync.BuilderA builder for HrisPayStatementRetrieveManyPageAsync.
-
Method Summary
-
-
Method Detail
-
responses
final List<PayStatementResponse> responses()
Delegates to HrisPayStatementRetrieveManyPageResponse, but gracefully handles missing data.
-
items
List<PayStatementResponse> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final HrisPayStatementRetrieveManyParams nextPageParams()
-
nextPage
CompletableFuture<HrisPayStatementRetrieveManyPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<PayStatementResponse> autoPager()
-
params
final HrisPayStatementRetrieveManyParams params()
The parameters that were used to request this page.
-
response
final HrisPayStatementRetrieveManyPageResponse response()
The response that this page was parsed from.
-
toBuilder
final HrisPayStatementRetrieveManyPageAsync.Builder toBuilder()
-
builder
final static HrisPayStatementRetrieveManyPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of HrisPayStatementRetrieveManyPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-