Package com.tryfinch.api.models
Class HrisPayStatementRetrieveManyPageAsync.Builder
-
- All Implemented Interfaces:
public final class HrisPayStatementRetrieveManyPageAsync.BuilderA builder for HrisPayStatementRetrieveManyPageAsync.
-
-
Method Summary
Modifier and Type Method Description final HrisPayStatementRetrieveManyPageAsync.Builderservice(PayStatementServiceAsync service)final HrisPayStatementRetrieveManyPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final HrisPayStatementRetrieveManyPageAsync.Builderparams(HrisPayStatementRetrieveManyParams params)The parameters that were used to request this page. final HrisPayStatementRetrieveManyPageAsync.Builderresponse(HrisPayStatementRetrieveManyPageResponse response)The response that this page was parsed from. final HrisPayStatementRetrieveManyPageAsyncbuild()Returns an immutable instance of HrisPayStatementRetrieveManyPageAsync. -
-
Method Detail
-
service
final HrisPayStatementRetrieveManyPageAsync.Builder service(PayStatementServiceAsync service)
-
streamHandlerExecutor
final HrisPayStatementRetrieveManyPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final HrisPayStatementRetrieveManyPageAsync.Builder params(HrisPayStatementRetrieveManyParams params)
The parameters that were used to request this page.
-
response
final HrisPayStatementRetrieveManyPageAsync.Builder response(HrisPayStatementRetrieveManyPageResponse response)
The response that this page was parsed from.
-
build
final HrisPayStatementRetrieveManyPageAsync build()
Returns an immutable instance of HrisPayStatementRetrieveManyPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-