Package com.tryfinch.api.models
Class HrisPayStatementRetrieveManyPageResponse
-
- All Implemented Interfaces:
public final class HrisPayStatementRetrieveManyPageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisPayStatementRetrieveManyPageResponse.BuilderA builder for HrisPayStatementRetrieveManyPageResponse.
-
Method Summary
Modifier and Type Method Description final List<PayStatementResponse>responses()final JsonField<List<PayStatementResponse>>_responses()Returns the raw JSON value of responses. final Map<String, JsonValue>_additionalProperties()final HrisPayStatementRetrieveManyPageResponse.BuildertoBuilder()final HrisPayStatementRetrieveManyPageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static HrisPayStatementRetrieveManyPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of HrisPayStatementRetrieveManyPageResponse. -
-
Method Detail
-
responses
final List<PayStatementResponse> responses()
-
_responses
final JsonField<List<PayStatementResponse>> _responses()
Returns the raw JSON value of responses.
Unlike responses, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final HrisPayStatementRetrieveManyPageResponse.Builder toBuilder()
-
validate
final HrisPayStatementRetrieveManyPageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static HrisPayStatementRetrieveManyPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of HrisPayStatementRetrieveManyPageResponse.
The following fields are required:
.responses()
-
-
-
-