Package com.tryfinch.api.models
Class HrisPaymentListPageAsync
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.PageAsync
public final class HrisPaymentListPageAsync implements PageAsync<Payment>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisPaymentListPageAsync.BuilderA builder for HrisPaymentListPageAsync.
-
Method Summary
Modifier and Type Method Description BooleanhasNextPage()Returns whether there's another page after this one. final HrisPaymentListParamsnextPageParams()CompletableFuture<HrisPaymentListPageAsync>nextPage()Returns the page after this one by making another request. final AutoPagerAsync<Payment>autoPager()final HrisPaymentListParamsparams()The parameters that were used to request this page. List<Payment>items()The response that this page was parsed from. final HrisPaymentListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static HrisPaymentListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of HrisPaymentListPageAsync. -
-
Method Detail
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final HrisPaymentListParams nextPageParams()
-
nextPage
CompletableFuture<HrisPaymentListPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<Payment> autoPager()
-
params
final HrisPaymentListParams params()
The parameters that were used to request this page.
-
toBuilder
final HrisPaymentListPageAsync.Builder toBuilder()
-
builder
final static HrisPaymentListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of HrisPaymentListPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .items()
-
-
-
-