Class Individual.Ethnicity
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Enum
public final class Individual.Ethnicity implements EnumThe EEOC-defined ethnicity of the individual.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumIndividual.Ethnicity.KnownAn enum containing Ethnicity's known values.
public enumIndividual.Ethnicity.ValueAn enum containing Ethnicity's known values, as well as an _UNKNOWN member.
An instance of Ethnicity can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static Individual.EthnicityASIANpublic final static Individual.EthnicityWHITEpublic final static Individual.EthnicityBLACK_OR_AFRICAN_AMERICANpublic final static Individual.EthnicityNATIVE_HAWAIIAN_OR_PACIFIC_ISLANDERpublic final static Individual.EthnicityAMERICAN_INDIAN_OR_ALASKA_NATIVEpublic final static Individual.EthnicityHISPANIC_OR_LATINOpublic final static Individual.EthnicityTWO_OR_MORE_RACESpublic final static Individual.EthnicityDECLINE_TO_SPECIFY
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final Individual.Ethnicity.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final Individual.Ethnicity.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. final Individual.Ethnicityvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Individual.Ethnicityof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final Individual.Ethnicity.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final Individual.Ethnicity.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
validate
final Individual.Ethnicity validate()
-
of
final static Individual.Ethnicity of(String value)
-
-
-
-