Class Individual.IndividualResponseBody
-
- All Implemented Interfaces:
public final class Individual.IndividualResponseBody
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIndividual.IndividualResponseBody.BuilderA builder for IndividualResponseBody.
public final classIndividual.IndividualResponseBody.EthnicityThe EEOC-defined ethnicity of the individual.
public final classIndividual.IndividualResponseBody.GenderThe gender of the individual.
public final classIndividual.IndividualResponseBody.PhoneNumberpublic final classIndividual.IndividualResponseBody.Email
-
Method Summary
Modifier and Type Method Description final Stringid()A stable Finch id(UUID v4) for an individual in the company.final Optional<String>dob()final Optional<Individual.IndividualResponseBody.Ethnicity>ethnicity()The EEOC-defined ethnicity of the individual. final Optional<String>firstName()The legal first name of the individual. final Optional<Individual.IndividualResponseBody.Gender>gender()The gender of the individual. final Optional<String>lastName()The legal last name of the individual. final Optional<String>middleName()The legal middle name of the individual. final Optional<List<Individual.IndividualResponseBody.PhoneNumber>>phoneNumbers()final Optional<String>preferredName()The preferred name of the individual. final Optional<Location>residence()final Optional<List<Individual.IndividualResponseBody.Email>>emails()final Optional<String>encryptedSsn()Social Security Number of the individual in encrypted format. final Optional<String>ssn()Social Security Number of the individual. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_dob()Returns the raw JSON value of dob. final JsonField<Individual.IndividualResponseBody.Ethnicity>_ethnicity()Returns the raw JSON value of ethnicity. final JsonField<String>_firstName()Returns the raw JSON value of firstName. final JsonField<Individual.IndividualResponseBody.Gender>_gender()Returns the raw JSON value of gender. final JsonField<String>_lastName()Returns the raw JSON value of lastName. final JsonField<String>_middleName()Returns the raw JSON value of middleName. final JsonField<List<Individual.IndividualResponseBody.PhoneNumber>>_phoneNumbers()Returns the raw JSON value of phoneNumbers. final JsonField<String>_preferredName()Returns the raw JSON value of preferredName. final JsonField<Location>_residence()Returns the raw JSON value of residence. final JsonField<List<Individual.IndividualResponseBody.Email>>_emails()Returns the raw JSON value of emails. final JsonField<String>_encryptedSsn()Returns the raw JSON value of encryptedSsn. final JsonField<String>_ssn()Returns the raw JSON value of ssn. final Map<String, JsonValue>_additionalProperties()final Individual.IndividualResponseBody.BuildertoBuilder()final Individual.IndividualResponseBodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Individual.IndividualResponseBody.Builderbuilder()Returns a mutable builder for constructing an instance of IndividualResponseBody. -
-
Method Detail
-
ethnicity
final Optional<Individual.IndividualResponseBody.Ethnicity> ethnicity()
The EEOC-defined ethnicity of the individual.
-
gender
final Optional<Individual.IndividualResponseBody.Gender> gender()
The gender of the individual.
-
middleName
final Optional<String> middleName()
The legal middle name of the individual.
-
phoneNumbers
final Optional<List<Individual.IndividualResponseBody.PhoneNumber>> phoneNumbers()
-
preferredName
final Optional<String> preferredName()
The preferred name of the individual.
-
emails
final Optional<List<Individual.IndividualResponseBody.Email>> emails()
-
encryptedSsn
final Optional<String> encryptedSsn()
Social Security Number of the individual in encrypted format. This field is only available with the
ssnscope enabled and theoptions: { include: ['ssn'] }param set in the body.
-
ssn
final Optional<String> ssn()
Social Security Number of the individual. This field is only available with the
ssnscope enabled and theoptions: { include: ['ssn'] }param set in the body. /developer-resources/Enable-SSN-Field.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_dob
final JsonField<String> _dob()
Returns the raw JSON value of dob.
Unlike dob, this method doesn't throw if the JSON field has an unexpected type.
-
_ethnicity
final JsonField<Individual.IndividualResponseBody.Ethnicity> _ethnicity()
Returns the raw JSON value of ethnicity.
Unlike ethnicity, this method doesn't throw if the JSON field has an unexpected type.
-
_firstName
final JsonField<String> _firstName()
Returns the raw JSON value of firstName.
Unlike firstName, this method doesn't throw if the JSON field has an unexpected type.
-
_gender
final JsonField<Individual.IndividualResponseBody.Gender> _gender()
Returns the raw JSON value of gender.
Unlike gender, this method doesn't throw if the JSON field has an unexpected type.
-
_lastName
final JsonField<String> _lastName()
Returns the raw JSON value of lastName.
Unlike lastName, this method doesn't throw if the JSON field has an unexpected type.
-
_middleName
final JsonField<String> _middleName()
Returns the raw JSON value of middleName.
Unlike middleName, this method doesn't throw if the JSON field has an unexpected type.
-
_phoneNumbers
final JsonField<List<Individual.IndividualResponseBody.PhoneNumber>> _phoneNumbers()
Returns the raw JSON value of phoneNumbers.
Unlike phoneNumbers, this method doesn't throw if the JSON field has an unexpected type.
-
_preferredName
final JsonField<String> _preferredName()
Returns the raw JSON value of preferredName.
Unlike preferredName, this method doesn't throw if the JSON field has an unexpected type.
-
_residence
final JsonField<Location> _residence()
Returns the raw JSON value of residence.
Unlike residence, this method doesn't throw if the JSON field has an unexpected type.
-
_emails
final JsonField<List<Individual.IndividualResponseBody.Email>> _emails()
Returns the raw JSON value of emails.
Unlike emails, this method doesn't throw if the JSON field has an unexpected type.
-
_encryptedSsn
final JsonField<String> _encryptedSsn()
Returns the raw JSON value of encryptedSsn.
Unlike encryptedSsn, this method doesn't throw if the JSON field has an unexpected type.
-
_ssn
final JsonField<String> _ssn()
Returns the raw JSON value of ssn.
Unlike ssn, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Individual.IndividualResponseBody.Builder toBuilder()
-
validate
final Individual.IndividualResponseBody validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Individual.IndividualResponseBody.Builder builder()
Returns a mutable builder for constructing an instance of IndividualResponseBody.
The following fields are required:
.id() .dob() .ethnicity() .firstName() .gender() .lastName() .middleName() .phoneNumbers() .preferredName() .residence()
-
-
-
-