Class Individual.IndividualResponseBody.Builder
-
- All Implemented Interfaces:
public final class Individual.IndividualResponseBody.BuilderA builder for IndividualResponseBody.
-
-
Method Summary
-
-
Method Detail
-
id
final Individual.IndividualResponseBody.Builder id(String id)
A stable Finch
id(UUID v4) for an individual in the company.
-
id
final Individual.IndividualResponseBody.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
dob
final Individual.IndividualResponseBody.Builder dob(String dob)
-
dob
final Individual.IndividualResponseBody.Builder dob(Optional<String> dob)
Alias for calling Builder.dob with
dob.orElse(null).
-
dob
final Individual.IndividualResponseBody.Builder dob(JsonField<String> dob)
Sets Builder.dob to an arbitrary JSON value.
You should usually call Builder.dob with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ethnicity
final Individual.IndividualResponseBody.Builder ethnicity(Individual.IndividualResponseBody.Ethnicity ethnicity)
The EEOC-defined ethnicity of the individual.
-
ethnicity
final Individual.IndividualResponseBody.Builder ethnicity(Optional<Individual.IndividualResponseBody.Ethnicity> ethnicity)
Alias for calling Builder.ethnicity with
ethnicity.orElse(null).
-
ethnicity
final Individual.IndividualResponseBody.Builder ethnicity(JsonField<Individual.IndividualResponseBody.Ethnicity> ethnicity)
Sets Builder.ethnicity to an arbitrary JSON value.
You should usually call Builder.ethnicity with a well-typed Ethnicity value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
firstName
final Individual.IndividualResponseBody.Builder firstName(String firstName)
The legal first name of the individual.
-
firstName
final Individual.IndividualResponseBody.Builder firstName(Optional<String> firstName)
Alias for calling Builder.firstName with
firstName.orElse(null).
-
firstName
final Individual.IndividualResponseBody.Builder firstName(JsonField<String> firstName)
Sets Builder.firstName to an arbitrary JSON value.
You should usually call Builder.firstName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
gender
final Individual.IndividualResponseBody.Builder gender(Individual.IndividualResponseBody.Gender gender)
The gender of the individual.
-
gender
final Individual.IndividualResponseBody.Builder gender(Optional<Individual.IndividualResponseBody.Gender> gender)
Alias for calling Builder.gender with
gender.orElse(null).
-
gender
final Individual.IndividualResponseBody.Builder gender(JsonField<Individual.IndividualResponseBody.Gender> gender)
Sets Builder.gender to an arbitrary JSON value.
You should usually call Builder.gender with a well-typed Gender value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastName
final Individual.IndividualResponseBody.Builder lastName(String lastName)
The legal last name of the individual.
-
lastName
final Individual.IndividualResponseBody.Builder lastName(Optional<String> lastName)
Alias for calling Builder.lastName with
lastName.orElse(null).
-
lastName
final Individual.IndividualResponseBody.Builder lastName(JsonField<String> lastName)
Sets Builder.lastName to an arbitrary JSON value.
You should usually call Builder.lastName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
middleName
final Individual.IndividualResponseBody.Builder middleName(String middleName)
The legal middle name of the individual.
-
middleName
final Individual.IndividualResponseBody.Builder middleName(Optional<String> middleName)
Alias for calling Builder.middleName with
middleName.orElse(null).
-
middleName
final Individual.IndividualResponseBody.Builder middleName(JsonField<String> middleName)
Sets Builder.middleName to an arbitrary JSON value.
You should usually call Builder.middleName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
phoneNumbers
final Individual.IndividualResponseBody.Builder phoneNumbers(List<Individual.IndividualResponseBody.PhoneNumber> phoneNumbers)
-
phoneNumbers
final Individual.IndividualResponseBody.Builder phoneNumbers(Optional<List<Individual.IndividualResponseBody.PhoneNumber>> phoneNumbers)
Alias for calling Builder.phoneNumbers with
phoneNumbers.orElse(null).
-
phoneNumbers
final Individual.IndividualResponseBody.Builder phoneNumbers(JsonField<List<Individual.IndividualResponseBody.PhoneNumber>> phoneNumbers)
Sets Builder.phoneNumbers to an arbitrary JSON value.
You should usually call Builder.phoneNumbers with a well-typed
List<PhoneNumber?>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addPhoneNumber
final Individual.IndividualResponseBody.Builder addPhoneNumber(Individual.IndividualResponseBody.PhoneNumber phoneNumber)
Adds a single PhoneNumber to phoneNumbers.
-
preferredName
final Individual.IndividualResponseBody.Builder preferredName(String preferredName)
The preferred name of the individual.
-
preferredName
final Individual.IndividualResponseBody.Builder preferredName(Optional<String> preferredName)
Alias for calling Builder.preferredName with
preferredName.orElse(null).
-
preferredName
final Individual.IndividualResponseBody.Builder preferredName(JsonField<String> preferredName)
Sets Builder.preferredName to an arbitrary JSON value.
You should usually call Builder.preferredName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
residence
final Individual.IndividualResponseBody.Builder residence(Location residence)
-
residence
final Individual.IndividualResponseBody.Builder residence(Optional<Location> residence)
Alias for calling Builder.residence with
residence.orElse(null).
-
residence
final Individual.IndividualResponseBody.Builder residence(JsonField<Location> residence)
Sets Builder.residence to an arbitrary JSON value.
You should usually call Builder.residence with a well-typed Location value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
emails
final Individual.IndividualResponseBody.Builder emails(List<Individual.IndividualResponseBody.Email> emails)
-
emails
final Individual.IndividualResponseBody.Builder emails(Optional<List<Individual.IndividualResponseBody.Email>> emails)
Alias for calling Builder.emails with
emails.orElse(null).
-
emails
final Individual.IndividualResponseBody.Builder emails(JsonField<List<Individual.IndividualResponseBody.Email>> emails)
Sets Builder.emails to an arbitrary JSON value.
You should usually call Builder.emails with a well-typed
List<Email>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEmail
final Individual.IndividualResponseBody.Builder addEmail(Individual.IndividualResponseBody.Email email)
-
encryptedSsn
final Individual.IndividualResponseBody.Builder encryptedSsn(String encryptedSsn)
Social Security Number of the individual in encrypted format. This field is only available with the
ssnscope enabled and theoptions: { include: ['ssn'] }param set in the body.
-
encryptedSsn
final Individual.IndividualResponseBody.Builder encryptedSsn(Optional<String> encryptedSsn)
Alias for calling Builder.encryptedSsn with
encryptedSsn.orElse(null).
-
encryptedSsn
final Individual.IndividualResponseBody.Builder encryptedSsn(JsonField<String> encryptedSsn)
Sets Builder.encryptedSsn to an arbitrary JSON value.
You should usually call Builder.encryptedSsn with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ssn
final Individual.IndividualResponseBody.Builder ssn(String ssn)
Social Security Number of the individual. This field is only available with the
ssnscope enabled and theoptions: { include: ['ssn'] }param set in the body. /developer-resources/Enable-SSN-Field.
-
ssn
final Individual.IndividualResponseBody.Builder ssn(Optional<String> ssn)
Alias for calling Builder.ssn with
ssn.orElse(null).
-
ssn
final Individual.IndividualResponseBody.Builder ssn(JsonField<String> ssn)
Sets Builder.ssn to an arbitrary JSON value.
You should usually call Builder.ssn with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Individual.IndividualResponseBody.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Individual.IndividualResponseBody.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Individual.IndividualResponseBody.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Individual.IndividualResponseBody.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Individual.IndividualResponseBody.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Individual.IndividualResponseBody build()
Returns an immutable instance of IndividualResponseBody.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .dob() .ethnicity() .firstName() .gender() .lastName() .middleName() .phoneNumbers() .preferredName() .residence()
-
-
-
-