Package com.tryfinch.api.models
Class Individual.IndividualResponseBody.Email
-
- All Implemented Interfaces:
public final class Individual.IndividualResponseBody.Email
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIndividual.IndividualResponseBody.Email.BuilderA builder for Email.
public final classIndividual.IndividualResponseBody.Email.Type
-
Method Summary
Modifier and Type Method Description final Stringdata()final Optional<Individual.IndividualResponseBody.Email.Type>type()final JsonField<String>_data()Returns the raw JSON value of data. final JsonField<Individual.IndividualResponseBody.Email.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final Individual.IndividualResponseBody.Email.BuildertoBuilder()final Individual.IndividualResponseBody.Emailvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Individual.IndividualResponseBody.Email.Builderbuilder()Returns a mutable builder for constructing an instance of Email. -
-
Method Detail
-
type
final Optional<Individual.IndividualResponseBody.Email.Type> type()
-
_data
final JsonField<String> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<Individual.IndividualResponseBody.Email.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Individual.IndividualResponseBody.Email.Builder toBuilder()
-
validate
final Individual.IndividualResponseBody.Email validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Individual.IndividualResponseBody.Email.Builder builder()
Returns a mutable builder for constructing an instance of Email.
The following fields are required:
.data() .type()
-
-
-
-