Package com.tryfinch.api.models
Class Individual.IndividualResponseBody.PhoneNumber
-
- All Implemented Interfaces:
public final class Individual.IndividualResponseBody.PhoneNumber
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIndividual.IndividualResponseBody.PhoneNumber.BuilderA builder for PhoneNumber.
public final classIndividual.IndividualResponseBody.PhoneNumber.Type
-
Method Summary
Modifier and Type Method Description final Optional<String>data()final Optional<Individual.IndividualResponseBody.PhoneNumber.Type>type()final JsonField<String>_data()Returns the raw JSON value of data. final JsonField<Individual.IndividualResponseBody.PhoneNumber.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final Individual.IndividualResponseBody.PhoneNumber.BuildertoBuilder()final Individual.IndividualResponseBody.PhoneNumbervalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Individual.IndividualResponseBody.PhoneNumber.Builderbuilder()Returns a mutable builder for constructing an instance of PhoneNumber. -
-
Method Detail
-
type
final Optional<Individual.IndividualResponseBody.PhoneNumber.Type> type()
-
_data
final JsonField<String> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<Individual.IndividualResponseBody.PhoneNumber.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Individual.IndividualResponseBody.PhoneNumber.Builder toBuilder()
-
validate
final Individual.IndividualResponseBody.PhoneNumber validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Individual.IndividualResponseBody.PhoneNumber.Builder builder()
Returns a mutable builder for constructing an instance of PhoneNumber.
The following fields are required:
.data() .type()
-
-
-
-