Package com.tryfinch.api.models
Interface Individual.Visitor
-
- All Implemented Interfaces:
public interface Individual.Visitor<T extends Object>An interface that defines how to map each variant of Individual to a value of type T.
-
-
Method Summary
Modifier and Type Method Description abstract TvisitResponseBody(Individual.IndividualResponseBody responseBody)abstract TvisitBatchError(Individual.BatchError batchError)Tunknown(JsonValue json)Maps an unknown variant of Individual to a value of type T. -
-
Method Detail
-
visitResponseBody
abstract T visitResponseBody(Individual.IndividualResponseBody responseBody)
-
visitBatchError
abstract T visitBatchError(Individual.BatchError batchError)
-
unknown
T unknown(JsonValue json)
Maps an unknown variant of Individual to a value of type T.
An instance of Individual can contain an unknown variant if it was deserialized from data that doesn't match any known variant. For example, if the SDK is on an older version than the API, then the API may respond with new variants that the SDK is unaware of.
-
-
-
-