Class IndividualBenefit.Body
-
- All Implemented Interfaces:
public final class IndividualBenefit.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIndividualBenefit.Body.BuilderA builder for Body.
public final classIndividualBenefit.Body.HsaContributionLimitType for HSA contribution limit if the benefit is a HSA.
-
Method Summary
-
-
Method Detail
-
annualMaximum
final Optional<Long> annualMaximum()
If the benefit supports annual maximum, the amount in cents for this individual.
-
catchUp
final Optional<Boolean> catchUp()
If the benefit supports catch up (401k, 403b, etc.), whether catch up is enabled for this individual.
-
companyContribution
final Optional<BenefitContribution> companyContribution()
-
employeeDeduction
final Optional<BenefitContribution> employeeDeduction()
-
hsaContributionLimit
final Optional<IndividualBenefit.Body.HsaContributionLimit> hsaContributionLimit()
Type for HSA contribution limit if the benefit is a HSA.
-
_annualMaximum
final JsonField<Long> _annualMaximum()
Returns the raw JSON value of annualMaximum.
Unlike annualMaximum, this method doesn't throw if the JSON field has an unexpected type.
-
_catchUp
final JsonField<Boolean> _catchUp()
Returns the raw JSON value of catchUp.
Unlike catchUp, this method doesn't throw if the JSON field has an unexpected type.
-
_companyContribution
final JsonField<BenefitContribution> _companyContribution()
Returns the raw JSON value of companyContribution.
Unlike companyContribution, this method doesn't throw if the JSON field has an unexpected type.
-
_employeeDeduction
final JsonField<BenefitContribution> _employeeDeduction()
Returns the raw JSON value of employeeDeduction.
Unlike employeeDeduction, this method doesn't throw if the JSON field has an unexpected type.
-
_hsaContributionLimit
final JsonField<IndividualBenefit.Body.HsaContributionLimit> _hsaContributionLimit()
Returns the raw JSON value of hsaContributionLimit.
Unlike hsaContributionLimit, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final IndividualBenefit.Body.Builder toBuilder()
-
validate
final IndividualBenefit.Body validate()
-
builder
final static IndividualBenefit.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-