Class IndividualBenefit.Body.BatchError
-
- All Implemented Interfaces:
public final class IndividualBenefit.Body.BatchError
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIndividualBenefit.Body.BatchError.BuilderA builder for BatchError.
-
Method Summary
Modifier and Type Method Description final Doublecode()final Stringmessage()final Stringname()final Optional<String>finchCode()final JsonField<Double>_code()Returns the raw JSON value of code. final JsonField<String>_message()Returns the raw JSON value of message. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_finchCode()Returns the raw JSON value of finchCode. final Map<String, JsonValue>_additionalProperties()final IndividualBenefit.Body.BatchError.BuildertoBuilder()final IndividualBenefit.Body.BatchErrorvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static IndividualBenefit.Body.BatchError.Builderbuilder()Returns a mutable builder for constructing an instance of BatchError. -
-
Method Detail
-
_code
final JsonField<Double> _code()
Returns the raw JSON value of code.
Unlike code, this method doesn't throw if the JSON field has an unexpected type.
-
_message
final JsonField<String> _message()
Returns the raw JSON value of message.
Unlike message, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_finchCode
final JsonField<String> _finchCode()
Returns the raw JSON value of finchCode.
Unlike finchCode, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final IndividualBenefit.Body.BatchError.Builder toBuilder()
-
validate
final IndividualBenefit.Body.BatchError validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static IndividualBenefit.Body.BatchError.Builder builder()
Returns a mutable builder for constructing an instance of BatchError.
The following fields are required:
.code() .message() .name()
-
-
-
-