Package com.tryfinch.api.models
Interface IndividualBenefit.Body.Visitor
-
- All Implemented Interfaces:
public interface IndividualBenefit.Body.Visitor<T extends Object>
-
-
Method Summary
Modifier and Type Method Description abstract TvisitIndividualBenefit(IndividualBenefit.Body.InnerIndividualBenefit individualBenefit)abstract TvisitBatchError(IndividualBenefit.Body.BatchError batchError)Tunknown(JsonValue json)Maps an unknown variant of Body to a value of type T. -
-
Method Detail
-
visitIndividualBenefit
abstract T visitIndividualBenefit(IndividualBenefit.Body.InnerIndividualBenefit individualBenefit)
-
visitBatchError
abstract T visitBatchError(IndividualBenefit.Body.BatchError batchError)
-
unknown
T unknown(JsonValue json)
Maps an unknown variant of Body to a value of type T.
An instance of Body can contain an unknown variant if it was deserialized from data that doesn't match any known variant. For example, if the SDK is on an older version than the API, then the API may respond with new variants that the SDK is unaware of.
-
-
-
-