Package com.tryfinch.api.models
Class IndividualEvent.Data
-
- All Implemented Interfaces:
public final class IndividualEvent.Data
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIndividualEvent.Data.BuilderA builder for Data.
-
Method Summary
Modifier and Type Method Description final Optional<String>individualId()The ID of the individual related to the event. final JsonField<String>_individualId()Returns the raw JSON value of individualId. final Map<String, JsonValue>_additionalProperties()final IndividualEvent.Data.BuildertoBuilder()final IndividualEvent.Datavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static IndividualEvent.Data.Builderbuilder()Returns a mutable builder for constructing an instance of Data. -
-
Method Detail
-
individualId
final Optional<String> individualId()
The ID of the individual related to the event.
-
_individualId
final JsonField<String> _individualId()
Returns the raw JSON value of individualId.
Unlike individualId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final IndividualEvent.Data.Builder toBuilder()
-
validate
final IndividualEvent.Data validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static IndividualEvent.Data.Builder builder()
Returns a mutable builder for constructing an instance of Data.
-
-
-
-