Class IndividualInDirectory
-
- All Implemented Interfaces:
public final class IndividualInDirectory
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIndividualInDirectory.BuilderA builder for IndividualInDirectory.
public final classIndividualInDirectory.DepartmentThe department object.
public final classIndividualInDirectory.ManagerThe manager object.
-
Method Summary
Modifier and Type Method Description final Stringid()A stable Finch id(UUID v4) for an individual in the company.final Optional<IndividualInDirectory.Department>department()The department object. final Optional<String>firstName()The legal first name of the individual. final Optional<Boolean>isActive()trueif the individual is an active employee or contractor at the company.final Optional<String>lastName()The legal last name of the individual. final Optional<IndividualInDirectory.Manager>manager()The manager object. final Optional<String>middleName()The legal middle name of the individual. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<IndividualInDirectory.Department>_department()Returns the raw JSON value of department. final JsonField<String>_firstName()Returns the raw JSON value of firstName. final JsonField<Boolean>_isActive()Returns the raw JSON value of isActive. final JsonField<String>_lastName()Returns the raw JSON value of lastName. final JsonField<IndividualInDirectory.Manager>_manager()Returns the raw JSON value of manager. final JsonField<String>_middleName()Returns the raw JSON value of middleName. final Map<String, JsonValue>_additionalProperties()final IndividualInDirectory.BuildertoBuilder()final IndividualInDirectoryvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static IndividualInDirectory.Builderbuilder()Returns a mutable builder for constructing an instance of IndividualInDirectory. -
-
Method Detail
-
department
final Optional<IndividualInDirectory.Department> department()
The department object.
-
isActive
final Optional<Boolean> isActive()
trueif the individual is an active employee or contractor at the company.
-
manager
final Optional<IndividualInDirectory.Manager> manager()
The manager object.
-
middleName
final Optional<String> middleName()
The legal middle name of the individual.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_department
final JsonField<IndividualInDirectory.Department> _department()
Returns the raw JSON value of department.
Unlike department, this method doesn't throw if the JSON field has an unexpected type.
-
_firstName
final JsonField<String> _firstName()
Returns the raw JSON value of firstName.
Unlike firstName, this method doesn't throw if the JSON field has an unexpected type.
-
_isActive
final JsonField<Boolean> _isActive()
Returns the raw JSON value of isActive.
Unlike isActive, this method doesn't throw if the JSON field has an unexpected type.
-
_lastName
final JsonField<String> _lastName()
Returns the raw JSON value of lastName.
Unlike lastName, this method doesn't throw if the JSON field has an unexpected type.
-
_manager
final JsonField<IndividualInDirectory.Manager> _manager()
Returns the raw JSON value of manager.
Unlike manager, this method doesn't throw if the JSON field has an unexpected type.
-
_middleName
final JsonField<String> _middleName()
Returns the raw JSON value of middleName.
Unlike middleName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final IndividualInDirectory.Builder toBuilder()
-
validate
final IndividualInDirectory validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static IndividualInDirectory.Builder builder()
Returns a mutable builder for constructing an instance of IndividualInDirectory.
The following fields are required:
.id() .department() .firstName() .isActive() .lastName() .manager() .middleName()
-
-
-
-