Package com.tryfinch.api.models
Class IndividualInDirectory.Department
-
- All Implemented Interfaces:
public final class IndividualInDirectory.DepartmentThe department object.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIndividualInDirectory.Department.BuilderA builder for Department.
-
Method Summary
Modifier and Type Method Description final Optional<String>name()The name of the department. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final IndividualInDirectory.Department.BuildertoBuilder()final IndividualInDirectory.Departmentvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static IndividualInDirectory.Department.Builderbuilder()Returns a mutable builder for constructing an instance of Department. -
-
Method Detail
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final IndividualInDirectory.Department.Builder toBuilder()
-
validate
final IndividualInDirectory.Department validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static IndividualInDirectory.Department.Builder builder()
Returns a mutable builder for constructing an instance of Department.
-
-
-
-