Package com.tryfinch.api.models
Class IndividualInDirectory.Manager
-
- All Implemented Interfaces:
public final class IndividualInDirectory.ManagerThe manager object.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIndividualInDirectory.Manager.BuilderA builder for Manager.
-
Method Summary
Modifier and Type Method Description final Stringid()A stable Finch id(UUID v4) for an individual in the company.final JsonField<String>_id()Returns the raw JSON value of id. final Map<String, JsonValue>_additionalProperties()final IndividualInDirectory.Manager.BuildertoBuilder()final IndividualInDirectory.Managervalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static IndividualInDirectory.Manager.Builderbuilder()Returns a mutable builder for constructing an instance of Manager. -
-
Method Detail
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final IndividualInDirectory.Manager.Builder toBuilder()
-
validate
final IndividualInDirectory.Manager validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static IndividualInDirectory.Manager.Builder builder()
Returns a mutable builder for constructing an instance of Manager.
The following fields are required:
.id()
-
-
-
-