Class IndividualResponse.Builder
-
- All Implemented Interfaces:
public final class IndividualResponse.BuilderA builder for IndividualResponse.
-
-
Method Summary
-
-
Method Detail
-
body
final IndividualResponse.Builder body(Individual body)
-
body
final IndividualResponse.Builder body(JsonField<Individual> body)
Sets Builder.body to an arbitrary JSON value.
You should usually call Builder.body with a well-typed Individual value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
body
final IndividualResponse.Builder body(Individual.IndividualResponseBody responseBody)
Alias for calling body with
Individual.ofResponseBody(responseBody).
-
body
final IndividualResponse.Builder body(Individual.BatchError batchError)
Alias for calling body with
Individual.ofBatchError(batchError).
-
code
final IndividualResponse.Builder code(Long code)
-
code
final IndividualResponse.Builder code(JsonField<Long> code)
Sets Builder.code to an arbitrary JSON value.
You should usually call Builder.code with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
individualId
final IndividualResponse.Builder individualId(String individualId)
-
individualId
final IndividualResponse.Builder individualId(JsonField<String> individualId)
Sets Builder.individualId to an arbitrary JSON value.
You should usually call Builder.individualId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final IndividualResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final IndividualResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final IndividualResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final IndividualResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final IndividualResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final IndividualResponse build()
Returns an immutable instance of IndividualResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.body() .code() .individualId()
-
-
-
-