Class IndividualUpdateResponse.Builder
-
- All Implemented Interfaces:
public final class IndividualUpdateResponse.BuilderA builder for IndividualUpdateResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final IndividualUpdateResponse.Builder id(String id)
A stable Finch
id(UUID v4) for an individual in the company.
-
id
final IndividualUpdateResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
dob
final IndividualUpdateResponse.Builder dob(String dob)
-
dob
final IndividualUpdateResponse.Builder dob(Optional<String> dob)
Alias for calling Builder.dob with
dob.orElse(null).
-
dob
final IndividualUpdateResponse.Builder dob(JsonField<String> dob)
Sets Builder.dob to an arbitrary JSON value.
You should usually call Builder.dob with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
emails
final IndividualUpdateResponse.Builder emails(List<IndividualUpdateResponse.Email> emails)
-
emails
final IndividualUpdateResponse.Builder emails(Optional<List<IndividualUpdateResponse.Email>> emails)
Alias for calling Builder.emails with
emails.orElse(null).
-
emails
final IndividualUpdateResponse.Builder emails(JsonField<List<IndividualUpdateResponse.Email>> emails)
Sets Builder.emails to an arbitrary JSON value.
You should usually call Builder.emails with a well-typed
List<Email>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEmail
final IndividualUpdateResponse.Builder addEmail(IndividualUpdateResponse.Email email)
-
encryptedSsn
final IndividualUpdateResponse.Builder encryptedSsn(String encryptedSsn)
Social Security Number of the individual in encrypted format. This field is only available with the
ssnscope enabled and theoptions: { include: ['ssn'] }param set in the body.
-
encryptedSsn
final IndividualUpdateResponse.Builder encryptedSsn(Optional<String> encryptedSsn)
Alias for calling Builder.encryptedSsn with
encryptedSsn.orElse(null).
-
encryptedSsn
final IndividualUpdateResponse.Builder encryptedSsn(JsonField<String> encryptedSsn)
Sets Builder.encryptedSsn to an arbitrary JSON value.
You should usually call Builder.encryptedSsn with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ethnicity
final IndividualUpdateResponse.Builder ethnicity(IndividualUpdateResponse.Ethnicity ethnicity)
The EEOC-defined ethnicity of the individual.
-
ethnicity
final IndividualUpdateResponse.Builder ethnicity(Optional<IndividualUpdateResponse.Ethnicity> ethnicity)
Alias for calling Builder.ethnicity with
ethnicity.orElse(null).
-
ethnicity
final IndividualUpdateResponse.Builder ethnicity(JsonField<IndividualUpdateResponse.Ethnicity> ethnicity)
Sets Builder.ethnicity to an arbitrary JSON value.
You should usually call Builder.ethnicity with a well-typed Ethnicity value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
firstName
final IndividualUpdateResponse.Builder firstName(String firstName)
The legal first name of the individual.
-
firstName
final IndividualUpdateResponse.Builder firstName(Optional<String> firstName)
Alias for calling Builder.firstName with
firstName.orElse(null).
-
firstName
final IndividualUpdateResponse.Builder firstName(JsonField<String> firstName)
Sets Builder.firstName to an arbitrary JSON value.
You should usually call Builder.firstName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
gender
final IndividualUpdateResponse.Builder gender(IndividualUpdateResponse.Gender gender)
The gender of the individual.
-
gender
final IndividualUpdateResponse.Builder gender(Optional<IndividualUpdateResponse.Gender> gender)
Alias for calling Builder.gender with
gender.orElse(null).
-
gender
final IndividualUpdateResponse.Builder gender(JsonField<IndividualUpdateResponse.Gender> gender)
Sets Builder.gender to an arbitrary JSON value.
You should usually call Builder.gender with a well-typed Gender value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastName
final IndividualUpdateResponse.Builder lastName(String lastName)
The legal last name of the individual.
-
lastName
final IndividualUpdateResponse.Builder lastName(Optional<String> lastName)
Alias for calling Builder.lastName with
lastName.orElse(null).
-
lastName
final IndividualUpdateResponse.Builder lastName(JsonField<String> lastName)
Sets Builder.lastName to an arbitrary JSON value.
You should usually call Builder.lastName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
middleName
final IndividualUpdateResponse.Builder middleName(String middleName)
The legal middle name of the individual.
-
middleName
final IndividualUpdateResponse.Builder middleName(Optional<String> middleName)
Alias for calling Builder.middleName with
middleName.orElse(null).
-
middleName
final IndividualUpdateResponse.Builder middleName(JsonField<String> middleName)
Sets Builder.middleName to an arbitrary JSON value.
You should usually call Builder.middleName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
phoneNumbers
final IndividualUpdateResponse.Builder phoneNumbers(List<IndividualUpdateResponse.PhoneNumber> phoneNumbers)
-
phoneNumbers
final IndividualUpdateResponse.Builder phoneNumbers(Optional<List<IndividualUpdateResponse.PhoneNumber>> phoneNumbers)
Alias for calling Builder.phoneNumbers with
phoneNumbers.orElse(null).
-
phoneNumbers
final IndividualUpdateResponse.Builder phoneNumbers(JsonField<List<IndividualUpdateResponse.PhoneNumber>> phoneNumbers)
Sets Builder.phoneNumbers to an arbitrary JSON value.
You should usually call Builder.phoneNumbers with a well-typed
List<PhoneNumber?>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addPhoneNumber
final IndividualUpdateResponse.Builder addPhoneNumber(IndividualUpdateResponse.PhoneNumber phoneNumber)
Adds a single PhoneNumber to phoneNumbers.
-
preferredName
final IndividualUpdateResponse.Builder preferredName(String preferredName)
The preferred name of the individual.
-
preferredName
final IndividualUpdateResponse.Builder preferredName(Optional<String> preferredName)
Alias for calling Builder.preferredName with
preferredName.orElse(null).
-
preferredName
final IndividualUpdateResponse.Builder preferredName(JsonField<String> preferredName)
Sets Builder.preferredName to an arbitrary JSON value.
You should usually call Builder.preferredName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
residence
final IndividualUpdateResponse.Builder residence(Location residence)
-
residence
final IndividualUpdateResponse.Builder residence(Optional<Location> residence)
Alias for calling Builder.residence with
residence.orElse(null).
-
residence
final IndividualUpdateResponse.Builder residence(JsonField<Location> residence)
Sets Builder.residence to an arbitrary JSON value.
You should usually call Builder.residence with a well-typed Location value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ssn
final IndividualUpdateResponse.Builder ssn(String ssn)
Social Security Number of the individual. This field is only available with the
ssnscope enabled and theoptions: { include: ['ssn'] }param set in the body. /developer-resources/Enable-SSN-Field.
-
ssn
final IndividualUpdateResponse.Builder ssn(Optional<String> ssn)
Alias for calling Builder.ssn with
ssn.orElse(null).
-
ssn
final IndividualUpdateResponse.Builder ssn(JsonField<String> ssn)
Sets Builder.ssn to an arbitrary JSON value.
You should usually call Builder.ssn with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final IndividualUpdateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final IndividualUpdateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final IndividualUpdateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final IndividualUpdateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final IndividualUpdateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final IndividualUpdateResponse build()
Returns an immutable instance of IndividualUpdateResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-