Package com.tryfinch.api.models
Enum IndividualUpdateResponse.Gender.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum IndividualUpdateResponse.Gender.Known extends Enum<IndividualUpdateResponse.Gender.Known>
An enum containing Gender's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<IndividualUpdateResponse.Gender.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description FEMALEMALEOTHERDECLINE_TO_SPECIFY
-
Method Summary
Modifier and Type Method Description final IndividualUpdateResponse.Gender.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<IndividualUpdateResponse.Gender.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<IndividualUpdateResponse.Gender.Known>getEntries()An enum containing Gender's known values. -
-
Method Detail
-
valueOf
final IndividualUpdateResponse.Gender.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<IndividualUpdateResponse.Gender.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<IndividualUpdateResponse.Gender.Known> getEntries()
An enum containing Gender's known values.
-
-
-
-