Package com.tryfinch.api.models
Class IndividualUpdateResponse.PhoneNumber
-
- All Implemented Interfaces:
public final class IndividualUpdateResponse.PhoneNumber
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIndividualUpdateResponse.PhoneNumber.BuilderA builder for PhoneNumber.
public final classIndividualUpdateResponse.PhoneNumber.Type
-
Method Summary
Modifier and Type Method Description final Optional<String>data()final Optional<IndividualUpdateResponse.PhoneNumber.Type>type()final JsonField<String>_data()Returns the raw JSON value of data. final JsonField<IndividualUpdateResponse.PhoneNumber.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final IndividualUpdateResponse.PhoneNumber.BuildertoBuilder()final IndividualUpdateResponse.PhoneNumbervalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static IndividualUpdateResponse.PhoneNumber.Builderbuilder()Returns a mutable builder for constructing an instance of PhoneNumber. -
-
Method Detail
-
type
final Optional<IndividualUpdateResponse.PhoneNumber.Type> type()
-
_data
final JsonField<String> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<IndividualUpdateResponse.PhoneNumber.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final IndividualUpdateResponse.PhoneNumber.Builder toBuilder()
-
validate
final IndividualUpdateResponse.PhoneNumber validate()
-
builder
final static IndividualUpdateResponse.PhoneNumber.Builder builder()
Returns a mutable builder for constructing an instance of PhoneNumber.
-
-
-
-