Class Introspection
-
- All Implemented Interfaces:
public final class Introspection
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIntrospection.BuilderA builder for Introspection.
public final classIntrospection.ClientTypeThe type of application associated with a token.
public final classIntrospection.ConnectionStatusDetailpublic final classIntrospection.ConnectionTypeThe type of the connection associated with the token.
provider- connection to an external providerfinch- finch-generated data.
public final classIntrospection.AuthenticationMethodDetailpublic final classIntrospection.MultiAccountEntity
-
Method Summary
Modifier and Type Method Description final Stringid()The Finch UUID of the token being introspected final StringclientId()The client ID of the application associated with the access_tokenfinal Introspection.ClientTypeclientType()The type of application associated with a token. final StringconnectionId()The Finch UUID of the connection associated with the access_tokenfinal Introspection.ConnectionStatusDetailconnectionStatus()final Introspection.ConnectionTypeconnectionType()The type of the connection associated with the token. final List<String>products()An array of the authorized products associated with the access_token.final StringproviderId()The ID of the provider associated with the access_token.final Optional<String>accountId()DEPRECATED Use connection_idto associate tokens with a Finch connection instead of this account IDfinal Optional<List<Introspection.AuthenticationMethodDetail>>authenticationMethods()final Optional<String>companyId()DEPRECATED Use connection_idto associate tokens with a Finch connection instead of this company IDfinal Optional<String>customerEmail()The email of your customer you provided to Finch when a connect session was created for this connection final Optional<String>customerId()The ID of your customer you provided to Finch when a connect session was created for this connection final Optional<String>customerName()The name of your customer you provided to Finch when a connect session was created for this connection final Optional<List<Introspection.MultiAccountEntity>>entities()Array of detailed entity information for each connected account in multi-account mode final Optional<Boolean>manual()Whether the connection associated with the access_tokenuses the Assisted Connect Flow.final Optional<String>payrollProviderId()DEPRECATED Use provider_idto identify the provider instead of this payroll provider ID.final Optional<String>username()The account username used for login associated with the access_token.final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_clientId()Returns the raw JSON value of clientId. final JsonField<Introspection.ClientType>_clientType()Returns the raw JSON value of clientType. final JsonField<String>_connectionId()Returns the raw JSON value of connectionId. final JsonField<Introspection.ConnectionStatusDetail>_connectionStatus()Returns the raw JSON value of connectionStatus. final JsonField<Introspection.ConnectionType>_connectionType()Returns the raw JSON value of connectionType. final JsonField<List<String>>_products()Returns the raw JSON value of products. final JsonField<String>_providerId()Returns the raw JSON value of providerId. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<List<Introspection.AuthenticationMethodDetail>>_authenticationMethods()Returns the raw JSON value of authenticationMethods. final JsonField<String>_companyId()Returns the raw JSON value of companyId. final JsonField<String>_customerEmail()Returns the raw JSON value of customerEmail. final JsonField<String>_customerId()Returns the raw JSON value of customerId. final JsonField<String>_customerName()Returns the raw JSON value of customerName. final JsonField<List<Introspection.MultiAccountEntity>>_entities()Returns the raw JSON value of entities. final JsonField<Boolean>_manual()Returns the raw JSON value of manual. final JsonField<String>_payrollProviderId()Returns the raw JSON value of payrollProviderId. final JsonField<String>_username()Returns the raw JSON value of username. final Map<String, JsonValue>_additionalProperties()final Introspection.BuildertoBuilder()final Introspectionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Introspection.Builderbuilder()Returns a mutable builder for constructing an instance of Introspection. -
-
Method Detail
-
clientType
final Introspection.ClientType clientType()
The type of application associated with a token.
-
connectionId
final String connectionId()
The Finch UUID of the connection associated with the
access_token
-
connectionStatus
final Introspection.ConnectionStatusDetail connectionStatus()
-
connectionType
final Introspection.ConnectionType connectionType()
The type of the connection associated with the token.
provider- connection to an external providerfinch- finch-generated data.
-
products
final List<String> products()
An array of the authorized products associated with the
access_token.
-
providerId
final String providerId()
The ID of the provider associated with the
access_token.
-
accountId
@Deprecated(message = "deprecated") final Optional<String> accountId()
DEPRECATED Use
connection_idto associate tokens with a Finch connection instead of this account ID
-
authenticationMethods
final Optional<List<Introspection.AuthenticationMethodDetail>> authenticationMethods()
-
companyId
@Deprecated(message = "deprecated") final Optional<String> companyId()
DEPRECATED Use
connection_idto associate tokens with a Finch connection instead of this company ID
-
customerEmail
final Optional<String> customerEmail()
The email of your customer you provided to Finch when a connect session was created for this connection
-
customerId
final Optional<String> customerId()
The ID of your customer you provided to Finch when a connect session was created for this connection
-
customerName
final Optional<String> customerName()
The name of your customer you provided to Finch when a connect session was created for this connection
-
entities
final Optional<List<Introspection.MultiAccountEntity>> entities()
Array of detailed entity information for each connected account in multi-account mode
-
manual
final Optional<Boolean> manual()
Whether the connection associated with the
access_tokenuses the Assisted Connect Flow. (trueif using Assisted Connect,falseif connection is automated)
-
payrollProviderId
@Deprecated(message = "deprecated") final Optional<String> payrollProviderId()
DEPRECATED Use
provider_idto identify the provider instead of this payroll provider ID.
-
username
final Optional<String> username()
The account username used for login associated with the
access_token.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_clientId
final JsonField<String> _clientId()
Returns the raw JSON value of clientId.
Unlike clientId, this method doesn't throw if the JSON field has an unexpected type.
-
_clientType
final JsonField<Introspection.ClientType> _clientType()
Returns the raw JSON value of clientType.
Unlike clientType, this method doesn't throw if the JSON field has an unexpected type.
-
_connectionId
final JsonField<String> _connectionId()
Returns the raw JSON value of connectionId.
Unlike connectionId, this method doesn't throw if the JSON field has an unexpected type.
-
_connectionStatus
final JsonField<Introspection.ConnectionStatusDetail> _connectionStatus()
Returns the raw JSON value of connectionStatus.
Unlike connectionStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_connectionType
final JsonField<Introspection.ConnectionType> _connectionType()
Returns the raw JSON value of connectionType.
Unlike connectionType, this method doesn't throw if the JSON field has an unexpected type.
-
_products
final JsonField<List<String>> _products()
Returns the raw JSON value of products.
Unlike products, this method doesn't throw if the JSON field has an unexpected type.
-
_providerId
final JsonField<String> _providerId()
Returns the raw JSON value of providerId.
Unlike providerId, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
@Deprecated(message = "deprecated") final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_authenticationMethods
final JsonField<List<Introspection.AuthenticationMethodDetail>> _authenticationMethods()
Returns the raw JSON value of authenticationMethods.
Unlike authenticationMethods, this method doesn't throw if the JSON field has an unexpected type.
-
_companyId
@Deprecated(message = "deprecated") final JsonField<String> _companyId()
Returns the raw JSON value of companyId.
Unlike companyId, this method doesn't throw if the JSON field has an unexpected type.
-
_customerEmail
final JsonField<String> _customerEmail()
Returns the raw JSON value of customerEmail.
Unlike customerEmail, this method doesn't throw if the JSON field has an unexpected type.
-
_customerId
final JsonField<String> _customerId()
Returns the raw JSON value of customerId.
Unlike customerId, this method doesn't throw if the JSON field has an unexpected type.
-
_customerName
final JsonField<String> _customerName()
Returns the raw JSON value of customerName.
Unlike customerName, this method doesn't throw if the JSON field has an unexpected type.
-
_entities
final JsonField<List<Introspection.MultiAccountEntity>> _entities()
Returns the raw JSON value of entities.
Unlike entities, this method doesn't throw if the JSON field has an unexpected type.
-
_manual
final JsonField<Boolean> _manual()
Returns the raw JSON value of manual.
Unlike manual, this method doesn't throw if the JSON field has an unexpected type.
-
_payrollProviderId
@Deprecated(message = "deprecated") final JsonField<String> _payrollProviderId()
Returns the raw JSON value of payrollProviderId.
Unlike payrollProviderId, this method doesn't throw if the JSON field has an unexpected type.
-
_username
final JsonField<String> _username()
Returns the raw JSON value of username.
Unlike username, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Introspection.Builder toBuilder()
-
validate
final Introspection validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Introspection.Builder builder()
Returns a mutable builder for constructing an instance of Introspection.
The following fields are required:
.id() .clientId() .clientType() .connectionId() .connectionStatus() .connectionType() .products() .providerId()
-
-
-
-