Package com.tryfinch.api.models
Class Introspection.AuthenticationMethod
-
- All Implemented Interfaces:
public final class Introspection.AuthenticationMethod
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIntrospection.AuthenticationMethod.BuilderA builder for AuthenticationMethod.
public final classIntrospection.AuthenticationMethod.ConnectionStatuspublic final classIntrospection.AuthenticationMethod.TypeThe type of authentication method.
-
Method Summary
-
-
Method Detail
-
connectionStatus
final Optional<Introspection.AuthenticationMethod.ConnectionStatus> connectionStatus()
-
products
final Optional<List<String>> products()
An array of the authorized products associated with the
access_token.
-
type
final Optional<Introspection.AuthenticationMethod.Type> type()
The type of authentication method.
-
_connectionStatus
final JsonField<Introspection.AuthenticationMethod.ConnectionStatus> _connectionStatus()
Returns the raw JSON value of connectionStatus.
Unlike connectionStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_products
final JsonField<List<String>> _products()
Returns the raw JSON value of products.
Unlike products, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<Introspection.AuthenticationMethod.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Introspection.AuthenticationMethod.Builder toBuilder()
-
validate
final Introspection.AuthenticationMethod validate()
-
builder
final static Introspection.AuthenticationMethod.Builder builder()
Returns a mutable builder for constructing an instance of AuthenticationMethod.
-
-
-
-