Class Introspection.AuthenticationMethod.Builder
-
- All Implemented Interfaces:
public final class Introspection.AuthenticationMethod.BuilderA builder for AuthenticationMethod.
-
-
Method Summary
-
-
Method Detail
-
connectionStatus
final Introspection.AuthenticationMethod.Builder connectionStatus(Introspection.AuthenticationMethod.ConnectionStatus connectionStatus)
-
connectionStatus
final Introspection.AuthenticationMethod.Builder connectionStatus(JsonField<Introspection.AuthenticationMethod.ConnectionStatus> connectionStatus)
Sets Builder.connectionStatus to an arbitrary JSON value.
You should usually call Builder.connectionStatus with a well-typed ConnectionStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
products
final Introspection.AuthenticationMethod.Builder products(List<String> products)
An array of the authorized products associated with the
access_token.
-
products
final Introspection.AuthenticationMethod.Builder products(JsonField<List<String>> products)
Sets Builder.products to an arbitrary JSON value.
You should usually call Builder.products with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addProduct
final Introspection.AuthenticationMethod.Builder addProduct(String product)
-
type
final Introspection.AuthenticationMethod.Builder type(Introspection.AuthenticationMethod.Type type)
The type of authentication method.
-
type
final Introspection.AuthenticationMethod.Builder type(JsonField<Introspection.AuthenticationMethod.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Introspection.AuthenticationMethod.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Introspection.AuthenticationMethod.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Introspection.AuthenticationMethod.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Introspection.AuthenticationMethod.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Introspection.AuthenticationMethod.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Introspection.AuthenticationMethod build()
Returns an immutable instance of AuthenticationMethod.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-