Class Introspection.AuthenticationMethodDetail.Builder
-
- All Implemented Interfaces:
public final class Introspection.AuthenticationMethodDetail.BuilderA builder for AuthenticationMethodDetail.
-
-
Method Summary
-
-
Method Detail
-
type
final Introspection.AuthenticationMethodDetail.Builder type(Introspection.AuthenticationMethodDetail.Type type)
The type of authentication method
-
type
final Introspection.AuthenticationMethodDetail.Builder type(JsonField<Introspection.AuthenticationMethodDetail.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
connectionStatus
final Introspection.AuthenticationMethodDetail.Builder connectionStatus(Introspection.AuthenticationMethodDetail.ConnectionStatusDetail connectionStatus)
-
connectionStatus
final Introspection.AuthenticationMethodDetail.Builder connectionStatus(JsonField<Introspection.AuthenticationMethodDetail.ConnectionStatusDetail> connectionStatus)
Sets Builder.connectionStatus to an arbitrary JSON value.
You should usually call Builder.connectionStatus with a well-typed ConnectionStatusDetail value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
products
final Introspection.AuthenticationMethodDetail.Builder products(List<String> products)
An array of the authorized products associated with the
access_token
-
products
final Introspection.AuthenticationMethodDetail.Builder products(JsonField<List<String>> products)
Sets Builder.products to an arbitrary JSON value.
You should usually call Builder.products with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addProduct
final Introspection.AuthenticationMethodDetail.Builder addProduct(String product)
-
additionalProperties
final Introspection.AuthenticationMethodDetail.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Introspection.AuthenticationMethodDetail.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Introspection.AuthenticationMethodDetail.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Introspection.AuthenticationMethodDetail.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Introspection.AuthenticationMethodDetail.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Introspection.AuthenticationMethodDetail build()
Returns an immutable instance of AuthenticationMethodDetail.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.type()
-
-
-
-