Class Introspection.AuthenticationMethodDetail.ConnectionStatusDetail
-
- All Implemented Interfaces:
public final class Introspection.AuthenticationMethodDetail.ConnectionStatusDetail
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIntrospection.AuthenticationMethodDetail.ConnectionStatusDetail.BuilderA builder for ConnectionStatusDetail.
public final classIntrospection.AuthenticationMethodDetail.ConnectionStatusDetail.LastSuccessfulSyncThe datetime when the connection was last successfully synced
-
Method Summary
-
-
Method Detail
-
status
final ConnectionStatusType status()
-
lastSuccessfulSync
final Optional<Introspection.AuthenticationMethodDetail.ConnectionStatusDetail.LastSuccessfulSync> lastSuccessfulSync()
The datetime when the connection was last successfully synced
-
_status
final JsonField<ConnectionStatusType> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_lastSuccessfulSync
final JsonField<Introspection.AuthenticationMethodDetail.ConnectionStatusDetail.LastSuccessfulSync> _lastSuccessfulSync()
Returns the raw JSON value of lastSuccessfulSync.
Unlike lastSuccessfulSync, this method doesn't throw if the JSON field has an unexpected type.
-
_message
final JsonField<String> _message()
Returns the raw JSON value of message.
Unlike message, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Introspection.AuthenticationMethodDetail.ConnectionStatusDetail validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Introspection.AuthenticationMethodDetail.ConnectionStatusDetail.Builder builder()
Returns a mutable builder for constructing an instance of ConnectionStatusDetail.
The following fields are required:
.status()
-
-
-
-