Package com.tryfinch.api.models
Class Introspection.AuthenticationMethodDetail.ConnectionStatusDetail.LastSuccessfulSync
-
- All Implemented Interfaces:
public final class Introspection.AuthenticationMethodDetail.ConnectionStatusDetail.LastSuccessfulSyncThe datetime when the connection was last successfully synced
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceIntrospection.AuthenticationMethodDetail.ConnectionStatusDetail.LastSuccessfulSync.VisitorAn interface that defines how to map each variant of LastSuccessfulSync to a value of type T.
-
Method Summary
-
-
Method Detail
-
offsetDateTime
final Optional<OffsetDateTime> offsetDateTime()
-
isOffsetDateTime
final Boolean isOffsetDateTime()
-
asOffsetDateTime
final OffsetDateTime asOffsetDateTime()
-
accept
final <T extends Any> T accept(Introspection.AuthenticationMethodDetail.ConnectionStatusDetail.LastSuccessfulSync.Visitor<T> visitor)
Maps this instance's current variant to a value of type T using the given visitor.
Note that this method is not forwards compatible with new variants from the API, unless visitor overrides Visitor.unknown. To handle variants not known to this version of the SDK gracefully, consider overriding Visitor.unknown:
import com.tryfinch.api.core.JsonValue; import java.util.Optional; Optional<String> result = lastSuccessfulSync.accept(new LastSuccessfulSync.Visitor<Optional<String>>() { @Override public Optional<String> visitOffsetDateTime(OffsetDateTime offsetDateTime) { return Optional.of(offsetDateTime.toString()); } // ... @Override public Optional<String> unknown(JsonValue json) { // Or inspect the `json`. return Optional.empty(); } });
-
validate
final Introspection.AuthenticationMethodDetail.ConnectionStatusDetail.LastSuccessfulSync validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
ofOffsetDateTime
final static Introspection.AuthenticationMethodDetail.ConnectionStatusDetail.LastSuccessfulSync ofOffsetDateTime(OffsetDateTime offsetDateTime)
-
ofString
final static Introspection.AuthenticationMethodDetail.ConnectionStatusDetail.LastSuccessfulSync ofString(String string)
-
-
-
-