Package com.tryfinch.api.models
Interface Introspection.AuthenticationMethodDetail.ConnectionStatusDetail.LastSuccessfulSync.Visitor
-
- All Implemented Interfaces:
public interface Introspection.AuthenticationMethodDetail.ConnectionStatusDetail.LastSuccessfulSync.Visitor<T extends Object>An interface that defines how to map each variant of LastSuccessfulSync to a value of type T.
-
-
Method Summary
Modifier and Type Method Description abstract TvisitOffsetDateTime(OffsetDateTime offsetDateTime)abstract TvisitString(String string)Tunknown(JsonValue json)Maps an unknown variant of LastSuccessfulSync to a value of type T. -
-
Method Detail
-
visitOffsetDateTime
abstract T visitOffsetDateTime(OffsetDateTime offsetDateTime)
-
visitString
abstract T visitString(String string)
-
unknown
T unknown(JsonValue json)
Maps an unknown variant of LastSuccessfulSync to a value of type T.
An instance of LastSuccessfulSync can contain an unknown variant if it was deserialized from data that doesn't match any known variant. For example, if the SDK is on an older version than the API, then the API may respond with new variants that the SDK is unaware of.
-
-
-
-