Class Introspection.Builder
-
- All Implemented Interfaces:
public final class Introspection.BuilderA builder for Introspection.
-
-
Method Summary
Modifier and Type Method Description final Introspection.Builderid(String id)The Finch UUID of the token being introspected final Introspection.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final Introspection.BuilderclientId(String clientId)The client ID of the application associated with the access_tokenfinal Introspection.BuilderclientId(JsonField<String> clientId)Sets Builder.clientId to an arbitrary JSON value. final Introspection.BuilderclientType(Introspection.ClientType clientType)The type of application associated with a token. final Introspection.BuilderclientType(JsonField<Introspection.ClientType> clientType)Sets Builder.clientType to an arbitrary JSON value. final Introspection.BuilderconnectionId(String connectionId)The Finch UUID of the connection associated with the access_tokenfinal Introspection.BuilderconnectionId(JsonField<String> connectionId)Sets Builder.connectionId to an arbitrary JSON value. final Introspection.BuilderconnectionStatus(Introspection.ConnectionStatusDetail connectionStatus)final Introspection.BuilderconnectionStatus(JsonField<Introspection.ConnectionStatusDetail> connectionStatus)Sets Builder.connectionStatus to an arbitrary JSON value. final Introspection.BuilderconnectionType(Introspection.ConnectionType connectionType)The type of the connection associated with the token. final Introspection.BuilderconnectionType(JsonField<Introspection.ConnectionType> connectionType)Sets Builder.connectionType to an arbitrary JSON value. final Introspection.Builderproducts(List<String> products)An array of the authorized products associated with the access_token.final Introspection.Builderproducts(JsonField<List<String>> products)Sets Builder.products to an arbitrary JSON value. final Introspection.BuilderaddProduct(String product)Adds a single String to products. final Introspection.BuilderproviderId(String providerId)The ID of the provider associated with the access_token.final Introspection.BuilderproviderId(JsonField<String> providerId)Sets Builder.providerId to an arbitrary JSON value. final Introspection.BuilderaccountId(String accountId)DEPRECATED Use connection_idto associate tokens with a Finch connection instead of this account IDfinal Introspection.BuilderaccountId(JsonField<String> accountId)Sets Builder.accountId to an arbitrary JSON value. final Introspection.BuilderauthenticationMethods(List<Introspection.AuthenticationMethodDetail> authenticationMethods)final Introspection.BuilderauthenticationMethods(JsonField<List<Introspection.AuthenticationMethodDetail>> authenticationMethods)Sets Builder.authenticationMethods to an arbitrary JSON value. final Introspection.BuilderaddAuthenticationMethod(Introspection.AuthenticationMethodDetail authenticationMethod)Adds a single AuthenticationMethodDetail to authenticationMethods. final Introspection.BuildercompanyId(String companyId)DEPRECATED Use connection_idto associate tokens with a Finch connection instead of this company IDfinal Introspection.BuildercompanyId(JsonField<String> companyId)Sets Builder.companyId to an arbitrary JSON value. final Introspection.BuildercustomerEmail(String customerEmail)The email of your customer you provided to Finch when a connect session was created for this connection final Introspection.BuildercustomerEmail(Optional<String> customerEmail)Alias for calling Builder.customerEmail with customerEmail.orElse(null).final Introspection.BuildercustomerEmail(JsonField<String> customerEmail)Sets Builder.customerEmail to an arbitrary JSON value. final Introspection.BuildercustomerId(String customerId)The ID of your customer you provided to Finch when a connect session was created for this connection final Introspection.BuildercustomerId(Optional<String> customerId)Alias for calling Builder.customerId with customerId.orElse(null).final Introspection.BuildercustomerId(JsonField<String> customerId)Sets Builder.customerId to an arbitrary JSON value. final Introspection.BuildercustomerName(String customerName)The name of your customer you provided to Finch when a connect session was created for this connection final Introspection.BuildercustomerName(Optional<String> customerName)Alias for calling Builder.customerName with customerName.orElse(null).final Introspection.BuildercustomerName(JsonField<String> customerName)Sets Builder.customerName to an arbitrary JSON value. final Introspection.Builderentities(List<Introspection.MultiAccountEntity> entities)Array of detailed entity information for each connected account in multi-account mode final Introspection.Builderentities(JsonField<List<Introspection.MultiAccountEntity>> entities)Sets Builder.entities to an arbitrary JSON value. final Introspection.BuilderaddEntity(Introspection.MultiAccountEntity entity)Adds a single MultiAccountEntity to entities. final Introspection.Buildermanual(Boolean manual)Whether the connection associated with the access_tokenuses the Assisted Connect Flow.final Introspection.Buildermanual(JsonField<Boolean> manual)Sets Builder.manual to an arbitrary JSON value. final Introspection.BuilderpayrollProviderId(String payrollProviderId)DEPRECATED Use provider_idto identify the provider instead of this payroll provider ID.final Introspection.BuilderpayrollProviderId(JsonField<String> payrollProviderId)Sets Builder.payrollProviderId to an arbitrary JSON value. final Introspection.Builderusername(String username)The account username used for login associated with the access_token.final Introspection.Builderusername(Optional<String> username)Alias for calling Builder.username with username.orElse(null).final Introspection.Builderusername(JsonField<String> username)Sets Builder.username to an arbitrary JSON value. final Introspection.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Introspection.BuilderputAdditionalProperty(String key, JsonValue value)final Introspection.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Introspection.BuilderremoveAdditionalProperty(String key)final Introspection.BuilderremoveAllAdditionalProperties(Set<String> keys)final Introspectionbuild()Returns an immutable instance of Introspection. -
-
Method Detail
-
id
final Introspection.Builder id(String id)
The Finch UUID of the token being introspected
-
id
final Introspection.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
clientId
final Introspection.Builder clientId(String clientId)
The client ID of the application associated with the
access_token
-
clientId
final Introspection.Builder clientId(JsonField<String> clientId)
Sets Builder.clientId to an arbitrary JSON value.
You should usually call Builder.clientId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
clientType
final Introspection.Builder clientType(Introspection.ClientType clientType)
The type of application associated with a token.
-
clientType
final Introspection.Builder clientType(JsonField<Introspection.ClientType> clientType)
Sets Builder.clientType to an arbitrary JSON value.
You should usually call Builder.clientType with a well-typed ClientType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
connectionId
final Introspection.Builder connectionId(String connectionId)
The Finch UUID of the connection associated with the
access_token
-
connectionId
final Introspection.Builder connectionId(JsonField<String> connectionId)
Sets Builder.connectionId to an arbitrary JSON value.
You should usually call Builder.connectionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
connectionStatus
final Introspection.Builder connectionStatus(Introspection.ConnectionStatusDetail connectionStatus)
-
connectionStatus
final Introspection.Builder connectionStatus(JsonField<Introspection.ConnectionStatusDetail> connectionStatus)
Sets Builder.connectionStatus to an arbitrary JSON value.
You should usually call Builder.connectionStatus with a well-typed ConnectionStatusDetail value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
connectionType
final Introspection.Builder connectionType(Introspection.ConnectionType connectionType)
The type of the connection associated with the token.
provider- connection to an external providerfinch- finch-generated data.
-
connectionType
final Introspection.Builder connectionType(JsonField<Introspection.ConnectionType> connectionType)
Sets Builder.connectionType to an arbitrary JSON value.
You should usually call Builder.connectionType with a well-typed ConnectionType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
products
final Introspection.Builder products(List<String> products)
An array of the authorized products associated with the
access_token.
-
products
final Introspection.Builder products(JsonField<List<String>> products)
Sets Builder.products to an arbitrary JSON value.
You should usually call Builder.products with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addProduct
final Introspection.Builder addProduct(String product)
-
providerId
final Introspection.Builder providerId(String providerId)
The ID of the provider associated with the
access_token.
-
providerId
final Introspection.Builder providerId(JsonField<String> providerId)
Sets Builder.providerId to an arbitrary JSON value.
You should usually call Builder.providerId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountId
@Deprecated(message = "deprecated") final Introspection.Builder accountId(String accountId)
DEPRECATED Use
connection_idto associate tokens with a Finch connection instead of this account ID
-
accountId
@Deprecated(message = "deprecated") final Introspection.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
authenticationMethods
final Introspection.Builder authenticationMethods(List<Introspection.AuthenticationMethodDetail> authenticationMethods)
-
authenticationMethods
final Introspection.Builder authenticationMethods(JsonField<List<Introspection.AuthenticationMethodDetail>> authenticationMethods)
Sets Builder.authenticationMethods to an arbitrary JSON value.
You should usually call Builder.authenticationMethods with a well-typed
List<AuthenticationMethodDetail>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addAuthenticationMethod
final Introspection.Builder addAuthenticationMethod(Introspection.AuthenticationMethodDetail authenticationMethod)
Adds a single AuthenticationMethodDetail to authenticationMethods.
-
companyId
@Deprecated(message = "deprecated") final Introspection.Builder companyId(String companyId)
DEPRECATED Use
connection_idto associate tokens with a Finch connection instead of this company ID
-
companyId
@Deprecated(message = "deprecated") final Introspection.Builder companyId(JsonField<String> companyId)
Sets Builder.companyId to an arbitrary JSON value.
You should usually call Builder.companyId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customerEmail
final Introspection.Builder customerEmail(String customerEmail)
The email of your customer you provided to Finch when a connect session was created for this connection
-
customerEmail
final Introspection.Builder customerEmail(Optional<String> customerEmail)
Alias for calling Builder.customerEmail with
customerEmail.orElse(null).
-
customerEmail
final Introspection.Builder customerEmail(JsonField<String> customerEmail)
Sets Builder.customerEmail to an arbitrary JSON value.
You should usually call Builder.customerEmail with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customerId
final Introspection.Builder customerId(String customerId)
The ID of your customer you provided to Finch when a connect session was created for this connection
-
customerId
final Introspection.Builder customerId(Optional<String> customerId)
Alias for calling Builder.customerId with
customerId.orElse(null).
-
customerId
final Introspection.Builder customerId(JsonField<String> customerId)
Sets Builder.customerId to an arbitrary JSON value.
You should usually call Builder.customerId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customerName
final Introspection.Builder customerName(String customerName)
The name of your customer you provided to Finch when a connect session was created for this connection
-
customerName
final Introspection.Builder customerName(Optional<String> customerName)
Alias for calling Builder.customerName with
customerName.orElse(null).
-
customerName
final Introspection.Builder customerName(JsonField<String> customerName)
Sets Builder.customerName to an arbitrary JSON value.
You should usually call Builder.customerName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entities
final Introspection.Builder entities(List<Introspection.MultiAccountEntity> entities)
Array of detailed entity information for each connected account in multi-account mode
-
entities
final Introspection.Builder entities(JsonField<List<Introspection.MultiAccountEntity>> entities)
Sets Builder.entities to an arbitrary JSON value.
You should usually call Builder.entities with a well-typed
List<MultiAccountEntity>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEntity
final Introspection.Builder addEntity(Introspection.MultiAccountEntity entity)
Adds a single MultiAccountEntity to entities.
-
manual
final Introspection.Builder manual(Boolean manual)
Whether the connection associated with the
access_tokenuses the Assisted Connect Flow. (trueif using Assisted Connect,falseif connection is automated)
-
manual
final Introspection.Builder manual(JsonField<Boolean> manual)
Sets Builder.manual to an arbitrary JSON value.
You should usually call Builder.manual with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
payrollProviderId
@Deprecated(message = "deprecated") final Introspection.Builder payrollProviderId(String payrollProviderId)
DEPRECATED Use
provider_idto identify the provider instead of this payroll provider ID.
-
payrollProviderId
@Deprecated(message = "deprecated") final Introspection.Builder payrollProviderId(JsonField<String> payrollProviderId)
Sets Builder.payrollProviderId to an arbitrary JSON value.
You should usually call Builder.payrollProviderId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
username
final Introspection.Builder username(String username)
The account username used for login associated with the
access_token.
-
username
final Introspection.Builder username(Optional<String> username)
Alias for calling Builder.username with
username.orElse(null).
-
username
final Introspection.Builder username(JsonField<String> username)
Sets Builder.username to an arbitrary JSON value.
You should usually call Builder.username with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Introspection.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Introspection.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Introspection.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Introspection.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Introspection.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Introspection build()
Returns an immutable instance of Introspection.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .clientId() .clientType() .connectionId() .connectionStatus() .connectionType() .products() .providerId()
-
-
-
-