Class Introspection.MultiAccountEntity
-
- All Implemented Interfaces:
public final class Introspection.MultiAccountEntity
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIntrospection.MultiAccountEntity.BuilderA builder for MultiAccountEntity.
public final classIntrospection.MultiAccountEntity.EntityConnectionStatusThe status of the entity connection
-
Method Summary
Modifier and Type Method Description final Stringid()The connection account ID for this entity final Optional<String>name()The name of the entity (payroll provider company name) final Optional<String>sourceId()The source ID of the entity final Introspection.MultiAccountEntity.EntityConnectionStatusstatus()The status of the entity connection final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_sourceId()Returns the raw JSON value of sourceId. final JsonField<Introspection.MultiAccountEntity.EntityConnectionStatus>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final Introspection.MultiAccountEntity.BuildertoBuilder()final Introspection.MultiAccountEntityvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Introspection.MultiAccountEntity.Builderbuilder()Returns a mutable builder for constructing an instance of MultiAccountEntity. -
-
Method Detail
-
status
final Introspection.MultiAccountEntity.EntityConnectionStatus status()
The status of the entity connection
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceId
final JsonField<String> _sourceId()
Returns the raw JSON value of sourceId.
Unlike sourceId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<Introspection.MultiAccountEntity.EntityConnectionStatus> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Introspection.MultiAccountEntity.Builder toBuilder()
-
validate
final Introspection.MultiAccountEntity validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Introspection.MultiAccountEntity.Builder builder()
Returns a mutable builder for constructing an instance of MultiAccountEntity.
The following fields are required:
.id() .name() .sourceId() .status()
-
-
-
-