Class Introspection.MultiAccountEntity.Builder
-
- All Implemented Interfaces:
public final class Introspection.MultiAccountEntity.BuilderA builder for MultiAccountEntity.
-
-
Method Summary
-
-
Method Detail
-
id
final Introspection.MultiAccountEntity.Builder id(String id)
The connection account ID for this entity
-
id
final Introspection.MultiAccountEntity.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final Introspection.MultiAccountEntity.Builder name(String name)
The name of the entity (payroll provider company name)
-
name
final Introspection.MultiAccountEntity.Builder name(Optional<String> name)
Alias for calling Builder.name with
name.orElse(null).
-
name
final Introspection.MultiAccountEntity.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sourceId
final Introspection.MultiAccountEntity.Builder sourceId(String sourceId)
The source ID of the entity
-
sourceId
final Introspection.MultiAccountEntity.Builder sourceId(Optional<String> sourceId)
Alias for calling Builder.sourceId with
sourceId.orElse(null).
-
sourceId
final Introspection.MultiAccountEntity.Builder sourceId(JsonField<String> sourceId)
Sets Builder.sourceId to an arbitrary JSON value.
You should usually call Builder.sourceId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final Introspection.MultiAccountEntity.Builder status(Introspection.MultiAccountEntity.EntityConnectionStatus status)
The status of the entity connection
-
status
final Introspection.MultiAccountEntity.Builder status(JsonField<Introspection.MultiAccountEntity.EntityConnectionStatus> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed EntityConnectionStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Introspection.MultiAccountEntity.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Introspection.MultiAccountEntity.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Introspection.MultiAccountEntity.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Introspection.MultiAccountEntity.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Introspection.MultiAccountEntity.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Introspection.MultiAccountEntity build()
Returns an immutable instance of MultiAccountEntity.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .name() .sourceId() .status()
-
-
-
-