Package com.tryfinch.api.models
Class JobAutomatedCreateParams.Body
-
- All Implemented Interfaces:
public final class JobAutomatedCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceJobAutomatedCreateParams.Body.VisitorAn interface that defines how to map each variant of Body to a value of type T.
public final classJobAutomatedCreateParams.Body.W4FormEmployeeSync
-
Method Summary
Modifier and Type Method Description final Optional<JsonValue>dataSyncAll()final Optional<JobAutomatedCreateParams.Body.W4FormEmployeeSync>w4FormEmployeeSync()final BooleanisDataSyncAll()final BooleanisW4FormEmployeeSync()final JsonValueasDataSyncAll()final JobAutomatedCreateParams.Body.W4FormEmployeeSyncasW4FormEmployeeSync()final Optional<JsonValue>_json()final <T extends Any> Taccept(JobAutomatedCreateParams.Body.Visitor<T> visitor)Maps this instance's current variant to a value of type T using the given visitor. final JobAutomatedCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static JobAutomatedCreateParams.BodyofDataSyncAll()final static JobAutomatedCreateParams.BodyofW4FormEmployeeSync(JobAutomatedCreateParams.Body.W4FormEmployeeSync w4FormEmployeeSync)-
-
Method Detail
-
dataSyncAll
final Optional<JsonValue> dataSyncAll()
-
w4FormEmployeeSync
final Optional<JobAutomatedCreateParams.Body.W4FormEmployeeSync> w4FormEmployeeSync()
-
isDataSyncAll
final Boolean isDataSyncAll()
-
isW4FormEmployeeSync
final Boolean isW4FormEmployeeSync()
-
asDataSyncAll
final JsonValue asDataSyncAll()
-
asW4FormEmployeeSync
final JobAutomatedCreateParams.Body.W4FormEmployeeSync asW4FormEmployeeSync()
-
accept
final <T extends Any> T accept(JobAutomatedCreateParams.Body.Visitor<T> visitor)
Maps this instance's current variant to a value of type T using the given visitor.
Note that this method is not forwards compatible with new variants from the API, unless visitor overrides Visitor.unknown. To handle variants not known to this version of the SDK gracefully, consider overriding Visitor.unknown:
import com.tryfinch.api.core.JsonValue; import java.util.Optional; Optional<String> result = body.accept(new Body.Visitor<Optional<String>>() { @Override public Optional<String> visitDataSyncAll(JsonValue dataSyncAll) { return Optional.of(dataSyncAll.toString()); } // ... @Override public Optional<String> unknown(JsonValue json) { // Or inspect the `json`. return Optional.empty(); } });
-
validate
final JobAutomatedCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
ofDataSyncAll
final static JobAutomatedCreateParams.Body ofDataSyncAll()
-
ofW4FormEmployeeSync
final static JobAutomatedCreateParams.Body ofW4FormEmployeeSync(JobAutomatedCreateParams.Body.W4FormEmployeeSync w4FormEmployeeSync)
-
-
-
-