Package com.tryfinch.api.models
Class JobAutomatedCreateParams.Body.DataSyncAll.Builder
-
- All Implemented Interfaces:
public final class JobAutomatedCreateParams.Body.DataSyncAll.BuilderA builder for DataSyncAll.
-
-
Method Summary
-
-
Method Detail
-
type
final JobAutomatedCreateParams.Body.DataSyncAll.Builder type(JobAutomatedCreateParams.Body.DataSyncAll.Type type)
The type of job to start.
-
type
final JobAutomatedCreateParams.Body.DataSyncAll.Builder type(JsonField<JobAutomatedCreateParams.Body.DataSyncAll.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final JobAutomatedCreateParams.Body.DataSyncAll.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final JobAutomatedCreateParams.Body.DataSyncAll.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final JobAutomatedCreateParams.Body.DataSyncAll.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final JobAutomatedCreateParams.Body.DataSyncAll.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final JobAutomatedCreateParams.Body.DataSyncAll.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final JobAutomatedCreateParams.Body.DataSyncAll build()
Returns an immutable instance of DataSyncAll.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.type()
-
-
-
-