Package com.tryfinch.api.models
Interface JobAutomatedCreateParams.Body.Visitor
-
- All Implemented Interfaces:
public interface JobAutomatedCreateParams.Body.Visitor<T extends Object>
-
-
Method Summary
Modifier and Type Method Description abstract TvisitDataSyncAll(JsonValue dataSyncAll)abstract TvisitW4FormEmployeeSync(JobAutomatedCreateParams.Body.W4FormEmployeeSync w4FormEmployeeSync)Tunknown(JsonValue json)Maps an unknown variant of Body to a value of type T. -
-
Method Detail
-
visitDataSyncAll
abstract T visitDataSyncAll(JsonValue dataSyncAll)
-
visitW4FormEmployeeSync
abstract T visitW4FormEmployeeSync(JobAutomatedCreateParams.Body.W4FormEmployeeSync w4FormEmployeeSync)
-
unknown
T unknown(JsonValue json)
Maps an unknown variant of Body to a value of type T.
An instance of Body can contain an unknown variant if it was deserialized from data that doesn't match any known variant. For example, if the SDK is on an older version than the API, then the API may respond with new variants that the SDK is unaware of.
-
-
-
-