Package com.tryfinch.api.models
Class JobAutomatedCreateParams.Body.W4FormEmployeeSync
-
- All Implemented Interfaces:
public final class JobAutomatedCreateParams.Body.W4FormEmployeeSync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classJobAutomatedCreateParams.Body.W4FormEmployeeSync.BuilderA builder for W4FormEmployeeSync.
public final classJobAutomatedCreateParams.Body.W4FormEmployeeSync.Params
-
Method Summary
Modifier and Type Method Description final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Paramsparams()final JsonValue_type()The type of job to start. final JsonField<JobAutomatedCreateParams.Body.W4FormEmployeeSync.Params>_params()Returns the raw JSON value of params. final Map<String, JsonValue>_additionalProperties()final JobAutomatedCreateParams.Body.W4FormEmployeeSync.BuildertoBuilder()final JobAutomatedCreateParams.Body.W4FormEmployeeSyncvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static JobAutomatedCreateParams.Body.W4FormEmployeeSync.Builderbuilder()Returns a mutable builder for constructing an instance of W4FormEmployeeSync. -
-
Method Detail
-
params
final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Params params()
-
_type
final JsonValue _type()
The type of job to start.
Expected to always return the following:
JsonValue.from("w4_form_employee_sync")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_params
final JsonField<JobAutomatedCreateParams.Body.W4FormEmployeeSync.Params> _params()
Returns the raw JSON value of params.
Unlike params, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Builder toBuilder()
-
validate
final JobAutomatedCreateParams.Body.W4FormEmployeeSync validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static JobAutomatedCreateParams.Body.W4FormEmployeeSync.Builder builder()
Returns a mutable builder for constructing an instance of W4FormEmployeeSync.
The following fields are required:
.params()
-
-
-
-