Package com.tryfinch.api.models
Class JobAutomatedCreateParams.Body.W4FormEmployeeSync.Builder
-
- All Implemented Interfaces:
public final class JobAutomatedCreateParams.Body.W4FormEmployeeSync.BuilderA builder for W4FormEmployeeSync.
-
-
Method Summary
-
-
Method Detail
-
params
final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Builder params(JobAutomatedCreateParams.Body.W4FormEmployeeSync.Params params)
-
params
final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Builder params(JsonField<JobAutomatedCreateParams.Body.W4FormEmployeeSync.Params> params)
Sets Builder.params to an arbitrary JSON value.
You should usually call Builder.params with a well-typed Params value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Builder type(JsonValue type)
Sets the field to an arbitrary JSON value.
It is usually unnecessary to call this method because the field defaults to the following:
JsonValue.from("w4_form_employee_sync")This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final JobAutomatedCreateParams.Body.W4FormEmployeeSync build()
Returns an immutable instance of W4FormEmployeeSync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.params()
-
-
-
-