Package com.tryfinch.api.models
Class JobAutomatedCreateParams.Body.W4FormEmployeeSync.Params
-
- All Implemented Interfaces:
public final class JobAutomatedCreateParams.Body.W4FormEmployeeSync.Params
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classJobAutomatedCreateParams.Body.W4FormEmployeeSync.Params.BuilderA builder for Params.
-
Method Summary
Modifier and Type Method Description final StringindividualId()The unique ID of the individual for W-4 data sync. final JsonField<String>_individualId()Returns the raw JSON value of individualId. final Map<String, JsonValue>_additionalProperties()final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Params.BuildertoBuilder()final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Paramsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static JobAutomatedCreateParams.Body.W4FormEmployeeSync.Params.Builderbuilder()Returns a mutable builder for constructing an instance of Params. -
-
Method Detail
-
individualId
final String individualId()
The unique ID of the individual for W-4 data sync.
-
_individualId
final JsonField<String> _individualId()
Returns the raw JSON value of individualId.
Unlike individualId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Params.Builder toBuilder()
-
validate
final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Params validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static JobAutomatedCreateParams.Body.W4FormEmployeeSync.Params.Builder builder()
Returns a mutable builder for constructing an instance of Params.
The following fields are required:
.individualId()
-
-
-
-