Class JobAutomatedListParams

  • All Implemented Interfaces:
    com.tryfinch.api.core.Params

    
    public final class JobAutomatedListParams
     implements Params
                        

    Get all automated jobs. Automated jobs are completed by a machine. By default, jobs are sorted in descending order by submission time. For scheduled jobs such as data syncs, only the next scheduled job is shown.