Package com.tryfinch.api.models
Class JobCompletionEvent.Data
-
- All Implemented Interfaces:
public final class JobCompletionEvent.Data
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classJobCompletionEvent.Data.BuilderA builder for Data.
-
Method Summary
Modifier and Type Method Description final StringjobId()The id of the job which has completed. final StringjobUrl()The url to query the result of the job. final JsonField<String>_jobId()Returns the raw JSON value of jobId. final JsonField<String>_jobUrl()Returns the raw JSON value of jobUrl. final Map<String, JsonValue>_additionalProperties()final JobCompletionEvent.Data.BuildertoBuilder()final JobCompletionEvent.Datavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static JobCompletionEvent.Data.Builderbuilder()Returns a mutable builder for constructing an instance of Data. -
-
Method Detail
-
_jobId
final JsonField<String> _jobId()
Returns the raw JSON value of jobId.
Unlike jobId, this method doesn't throw if the JSON field has an unexpected type.
-
_jobUrl
final JsonField<String> _jobUrl()
Returns the raw JSON value of jobUrl.
Unlike jobUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final JobCompletionEvent.Data.Builder toBuilder()
-
validate
final JobCompletionEvent.Data validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static JobCompletionEvent.Data.Builder builder()
Returns a mutable builder for constructing an instance of Data.
The following fields are required:
.jobId() .jobUrl()
-
-
-
-