Package com.tryfinch.api.models
Class JobCompletionEvent.Data.Builder
-
- All Implemented Interfaces:
public final class JobCompletionEvent.Data.BuilderA builder for Data.
-
-
Method Summary
-
-
Method Detail
-
jobId
final JobCompletionEvent.Data.Builder jobId(String jobId)
The id of the job which has completed.
-
jobId
final JobCompletionEvent.Data.Builder jobId(JsonField<String> jobId)
Sets Builder.jobId to an arbitrary JSON value.
You should usually call Builder.jobId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
jobUrl
final JobCompletionEvent.Data.Builder jobUrl(String jobUrl)
The url to query the result of the job.
-
jobUrl
final JobCompletionEvent.Data.Builder jobUrl(JsonField<String> jobUrl)
Sets Builder.jobUrl to an arbitrary JSON value.
You should usually call Builder.jobUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final JobCompletionEvent.Data.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final JobCompletionEvent.Data.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final JobCompletionEvent.Data.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final JobCompletionEvent.Data.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final JobCompletionEvent.Data.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final JobCompletionEvent.Data build()
Returns an immutable instance of Data.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.jobId() .jobUrl()
-
-
-
-