Class JobCreateResponse
-
- All Implemented Interfaces:
public final class JobCreateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classJobCreateResponse.BuilderA builder for JobCreateResponse.
-
Method Summary
Modifier and Type Method Description final LongallowedRefreshes()The number of allowed refreshes per hour (per hour, fixed window) final StringjobId()The id of the job that has been created. final StringjobUrl()The url that can be used to retrieve the job status final LongremainingRefreshes()The number of remaining refreshes available (per hour, fixed window) final JsonField<Long>_allowedRefreshes()Returns the raw JSON value of allowedRefreshes. final JsonField<String>_jobId()Returns the raw JSON value of jobId. final JsonField<String>_jobUrl()Returns the raw JSON value of jobUrl. final JsonField<Long>_remainingRefreshes()Returns the raw JSON value of remainingRefreshes. final Map<String, JsonValue>_additionalProperties()final JobCreateResponse.BuildertoBuilder()final JobCreateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static JobCreateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of JobCreateResponse. -
-
Method Detail
-
allowedRefreshes
final Long allowedRefreshes()
The number of allowed refreshes per hour (per hour, fixed window)
-
remainingRefreshes
final Long remainingRefreshes()
The number of remaining refreshes available (per hour, fixed window)
-
_allowedRefreshes
final JsonField<Long> _allowedRefreshes()
Returns the raw JSON value of allowedRefreshes.
Unlike allowedRefreshes, this method doesn't throw if the JSON field has an unexpected type.
-
_jobId
final JsonField<String> _jobId()
Returns the raw JSON value of jobId.
Unlike jobId, this method doesn't throw if the JSON field has an unexpected type.
-
_jobUrl
final JsonField<String> _jobUrl()
Returns the raw JSON value of jobUrl.
Unlike jobUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_remainingRefreshes
final JsonField<Long> _remainingRefreshes()
Returns the raw JSON value of remainingRefreshes.
Unlike remainingRefreshes, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final JobCreateResponse.Builder toBuilder()
-
validate
final JobCreateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static JobCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of JobCreateResponse.
The following fields are required:
.allowedRefreshes() .jobId() .jobUrl() .remainingRefreshes()
-
-
-
-