Class JobCreateResponse.Builder
-
- All Implemented Interfaces:
public final class JobCreateResponse.BuilderA builder for JobCreateResponse.
-
-
Method Summary
-
-
Method Detail
-
allowedRefreshes
final JobCreateResponse.Builder allowedRefreshes(Long allowedRefreshes)
The number of allowed refreshes per hour (per hour, fixed window)
-
allowedRefreshes
final JobCreateResponse.Builder allowedRefreshes(JsonField<Long> allowedRefreshes)
Sets Builder.allowedRefreshes to an arbitrary JSON value.
You should usually call Builder.allowedRefreshes with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
jobId
final JobCreateResponse.Builder jobId(String jobId)
The id of the job that has been created.
-
jobId
final JobCreateResponse.Builder jobId(JsonField<String> jobId)
Sets Builder.jobId to an arbitrary JSON value.
You should usually call Builder.jobId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
jobUrl
final JobCreateResponse.Builder jobUrl(String jobUrl)
The url that can be used to retrieve the job status
-
jobUrl
final JobCreateResponse.Builder jobUrl(JsonField<String> jobUrl)
Sets Builder.jobUrl to an arbitrary JSON value.
You should usually call Builder.jobUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
remainingRefreshes
final JobCreateResponse.Builder remainingRefreshes(Long remainingRefreshes)
The number of remaining refreshes available (per hour, fixed window)
-
remainingRefreshes
final JobCreateResponse.Builder remainingRefreshes(JsonField<Long> remainingRefreshes)
Sets Builder.remainingRefreshes to an arbitrary JSON value.
You should usually call Builder.remainingRefreshes with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final JobCreateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final JobCreateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final JobCreateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final JobCreateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final JobCreateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final JobCreateResponse build()
Returns an immutable instance of JobCreateResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.allowedRefreshes() .jobId() .jobUrl() .remainingRefreshes()
-
-
-
-