Class JobManualRetrieveParams

  • All Implemented Interfaces:
    com.tryfinch.api.core.Params

    
    public final class JobManualRetrieveParams
     implements Params
                        

    Check the status and outcome of a job by job_id. This includes all deductions jobs including those for both automated and assisted integrations.