Class ManualAsyncJob.Builder
-
- All Implemented Interfaces:
public final class ManualAsyncJob.BuilderA builder for ManualAsyncJob.
-
-
Method Summary
-
-
Method Detail
-
body
final ManualAsyncJob.Builder body(List<JsonValue> body)
Specific information about the job, such as individual statuses for batch jobs.
-
body
final ManualAsyncJob.Builder body(Optional<List<JsonValue>> body)
Alias for calling Builder.body with
body.orElse(null).
-
body
final ManualAsyncJob.Builder body(JsonField<List<JsonValue>> body)
Sets Builder.body to an arbitrary JSON value.
You should usually call Builder.body with a well-typed
List<JsonValue?>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addBody
final ManualAsyncJob.Builder addBody(JsonValue body)
Adds a single JsonValue to Builder.body.
-
jobId
final ManualAsyncJob.Builder jobId(String jobId)
-
jobId
final ManualAsyncJob.Builder jobId(JsonField<String> jobId)
Sets Builder.jobId to an arbitrary JSON value.
You should usually call Builder.jobId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final ManualAsyncJob.Builder status(ManualAsyncJob.Status status)
-
status
final ManualAsyncJob.Builder status(JsonField<ManualAsyncJob.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ManualAsyncJob.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ManualAsyncJob.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ManualAsyncJob.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ManualAsyncJob.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ManualAsyncJob.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ManualAsyncJob build()
Returns an immutable instance of ManualAsyncJob.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.body() .jobId() .status()
-
-
-
-