Package com.tryfinch.api.models
Class Money
-
- All Implemented Interfaces:
public final class Money
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMoney.BuilderA builder for Money.
-
Method Summary
Modifier and Type Method Description final Optional<Long>amount()Amount for money object (in cents) final Stringcurrency()final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_currency()Returns the raw JSON value of currency. final Map<String, JsonValue>_additionalProperties()final Money.BuildertoBuilder()final Moneyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Money.Builderbuilder()Returns a mutable builder for constructing an instance of Money. -
-
Method Detail
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Money.Builder toBuilder()
-
validate
final Money validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Money.Builder builder()
Returns a mutable builder for constructing an instance of Money.
The following fields are required:
.amount() .currency()
-
-
-
-