Class OperationSupport
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Enum
public final class OperationSupport implements Enumsupported: This operation is supported by both the provider and Finchnot_supported_by_finch: This operation is not supported by Finch but supported by the providernot_supported_by_provider: This operation is not supported by the provider, so Finch cannot supportclient_access_only: This behavior is supported by the provider, but only available to the client and not to Finch
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumOperationSupport.KnownAn enum containing OperationSupport's known values.
public enumOperationSupport.ValueAn enum containing OperationSupport's known values, as well as an _UNKNOWN member.
An instance of OperationSupport can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static OperationSupportSUPPORTEDpublic final static OperationSupportNOT_SUPPORTED_BY_FINCHpublic final static OperationSupportNOT_SUPPORTED_BY_PROVIDERpublic final static OperationSupportCLIENT_ACCESS_ONLY
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final OperationSupport.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final OperationSupport.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. final OperationSupportvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static OperationSupportof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final OperationSupport.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final OperationSupport.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
validate
final OperationSupport validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
of
final static OperationSupport of(String value)
-
-
-
-