Enum OperationSupport.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum OperationSupport.Value extends Enum<OperationSupport.Value>
An enum containing OperationSupport's known values, as well as an _UNKNOWN member.
An instance of OperationSupport can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<OperationSupport.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description SUPPORTEDNOT_SUPPORTED_BY_FINCHNOT_SUPPORTED_BY_PROVIDERCLIENT_ACCESS_ONLY_UNKNOWNAn enum member indicating that OperationSupport was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final OperationSupport.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<OperationSupport.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<OperationSupport.Value>getEntries()An enum containing OperationSupport's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final OperationSupport.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<OperationSupport.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<OperationSupport.Value> getEntries()
An enum containing OperationSupport's known values, as well as an _UNKNOWN member.
An instance of OperationSupport can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-