Class OperationSupportMatrix.Builder
-
- All Implemented Interfaces:
public final class OperationSupportMatrix.BuilderA builder for OperationSupportMatrix.
-
-
Method Summary
Modifier and Type Method Description final OperationSupportMatrix.Buildercreate(OperationSupport create)supported: This operation is supported by both the provider and Finchnot_supported_by_finch: This operation is not supported by Finch but supported by the providernot_supported_by_provider: This operation is not supported by the provider, so Finch cannot supportclient_access_only: This behavior is supported by the provider, but only available to the client and not to Finch
final OperationSupportMatrix.Buildercreate(JsonField<OperationSupport> create)Sets Builder.create to an arbitrary JSON value. final OperationSupportMatrix.Builderdelete(OperationSupport delete)supported: This operation is supported by both the provider and Finchnot_supported_by_finch: This operation is not supported by Finch but supported by the providernot_supported_by_provider: This operation is not supported by the provider, so Finch cannot supportclient_access_only: This behavior is supported by the provider, but only available to the client and not to Finch
final OperationSupportMatrix.Builderdelete(JsonField<OperationSupport> delete)Sets Builder.delete to an arbitrary JSON value. final OperationSupportMatrix.Builderread(OperationSupport read)supported: This operation is supported by both the provider and Finchnot_supported_by_finch: This operation is not supported by Finch but supported by the providernot_supported_by_provider: This operation is not supported by the provider, so Finch cannot supportclient_access_only: This behavior is supported by the provider, but only available to the client and not to Finch
final OperationSupportMatrix.Builderread(JsonField<OperationSupport> read)Sets Builder.read to an arbitrary JSON value. final OperationSupportMatrix.Builderupdate(OperationSupport update)supported: This operation is supported by both the provider and Finchnot_supported_by_finch: This operation is not supported by Finch but supported by the providernot_supported_by_provider: This operation is not supported by the provider, so Finch cannot supportclient_access_only: This behavior is supported by the provider, but only available to the client and not to Finch
final OperationSupportMatrix.Builderupdate(JsonField<OperationSupport> update)Sets Builder.update to an arbitrary JSON value. final OperationSupportMatrix.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final OperationSupportMatrix.BuilderputAdditionalProperty(String key, JsonValue value)final OperationSupportMatrix.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final OperationSupportMatrix.BuilderremoveAdditionalProperty(String key)final OperationSupportMatrix.BuilderremoveAllAdditionalProperties(Set<String> keys)final OperationSupportMatrixbuild()Returns an immutable instance of OperationSupportMatrix. -
-
Method Detail
-
create
final OperationSupportMatrix.Builder create(OperationSupport create)
supported: This operation is supported by both the provider and Finchnot_supported_by_finch: This operation is not supported by Finch but supported by the providernot_supported_by_provider: This operation is not supported by the provider, so Finch cannot supportclient_access_only: This behavior is supported by the provider, but only available to the client and not to Finch
-
create
final OperationSupportMatrix.Builder create(JsonField<OperationSupport> create)
Sets Builder.create to an arbitrary JSON value.
You should usually call Builder.create with a well-typed OperationSupport value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
delete
final OperationSupportMatrix.Builder delete(OperationSupport delete)
supported: This operation is supported by both the provider and Finchnot_supported_by_finch: This operation is not supported by Finch but supported by the providernot_supported_by_provider: This operation is not supported by the provider, so Finch cannot supportclient_access_only: This behavior is supported by the provider, but only available to the client and not to Finch
-
delete
final OperationSupportMatrix.Builder delete(JsonField<OperationSupport> delete)
Sets Builder.delete to an arbitrary JSON value.
You should usually call Builder.delete with a well-typed OperationSupport value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
read
final OperationSupportMatrix.Builder read(OperationSupport read)
supported: This operation is supported by both the provider and Finchnot_supported_by_finch: This operation is not supported by Finch but supported by the providernot_supported_by_provider: This operation is not supported by the provider, so Finch cannot supportclient_access_only: This behavior is supported by the provider, but only available to the client and not to Finch
-
read
final OperationSupportMatrix.Builder read(JsonField<OperationSupport> read)
Sets Builder.read to an arbitrary JSON value.
You should usually call Builder.read with a well-typed OperationSupport value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
update
final OperationSupportMatrix.Builder update(OperationSupport update)
supported: This operation is supported by both the provider and Finchnot_supported_by_finch: This operation is not supported by Finch but supported by the providernot_supported_by_provider: This operation is not supported by the provider, so Finch cannot supportclient_access_only: This behavior is supported by the provider, but only available to the client and not to Finch
-
update
final OperationSupportMatrix.Builder update(JsonField<OperationSupport> update)
Sets Builder.update to an arbitrary JSON value.
You should usually call Builder.update with a well-typed OperationSupport value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final OperationSupportMatrix.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final OperationSupportMatrix.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final OperationSupportMatrix.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final OperationSupportMatrix.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final OperationSupportMatrix.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final OperationSupportMatrix build()
Returns an immutable instance of OperationSupportMatrix.
Further updates to this Builder will not mutate the returned instance.
-
-
-