Package com.tryfinch.api.models
Class Paging.Builder
-
- All Implemented Interfaces:
public final class Paging.BuilderA builder for Paging.
-
-
Method Summary
Modifier and Type Method Description final Paging.Builderoffset(Long offset)The current start index of the returned list of elements final Paging.Builderoffset(JsonField<Long> offset)Sets Builder.offset to an arbitrary JSON value. final Paging.Buildercount(Long count)The total number of elements for the entire query (not just the given page) final Paging.Buildercount(JsonField<Long> count)Sets Builder.count to an arbitrary JSON value. final Paging.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Paging.BuilderputAdditionalProperty(String key, JsonValue value)final Paging.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Paging.BuilderremoveAdditionalProperty(String key)final Paging.BuilderremoveAllAdditionalProperties(Set<String> keys)final Pagingbuild()Returns an immutable instance of Paging. -
-
Method Detail
-
offset
final Paging.Builder offset(Long offset)
The current start index of the returned list of elements
-
offset
final Paging.Builder offset(JsonField<Long> offset)
Sets Builder.offset to an arbitrary JSON value.
You should usually call Builder.offset with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
count
final Paging.Builder count(Long count)
The total number of elements for the entire query (not just the given page)
-
count
final Paging.Builder count(JsonField<Long> count)
Sets Builder.count to an arbitrary JSON value.
You should usually call Builder.count with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Paging.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Paging.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Paging.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Paging.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Paging.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-