Class PayGroupRetrieveResponse.Builder
-
- All Implemented Interfaces:
public final class PayGroupRetrieveResponse.BuilderA builder for PayGroupRetrieveResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final PayGroupRetrieveResponse.Builder id(String id)
Finch id (uuidv4) for the pay group
-
id
final PayGroupRetrieveResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
individualIds
final PayGroupRetrieveResponse.Builder individualIds(List<String> individualIds)
-
individualIds
final PayGroupRetrieveResponse.Builder individualIds(JsonField<List<String>> individualIds)
Sets Builder.individualIds to an arbitrary JSON value.
You should usually call Builder.individualIds with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addIndividualId
final PayGroupRetrieveResponse.Builder addIndividualId(String individualId)
Adds a single String to individualIds.
-
name
final PayGroupRetrieveResponse.Builder name(String name)
Name of the pay group
-
name
final PayGroupRetrieveResponse.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
payFrequencies
final PayGroupRetrieveResponse.Builder payFrequencies(List<PayGroupRetrieveResponse.PayFrequency> payFrequencies)
List of pay frequencies associated with this pay group
-
payFrequencies
final PayGroupRetrieveResponse.Builder payFrequencies(JsonField<List<PayGroupRetrieveResponse.PayFrequency>> payFrequencies)
Sets Builder.payFrequencies to an arbitrary JSON value.
You should usually call Builder.payFrequencies with a well-typed
List<PayFrequency>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addPayFrequency
final PayGroupRetrieveResponse.Builder addPayFrequency(PayGroupRetrieveResponse.PayFrequency payFrequency)
Adds a single PayFrequency to payFrequencies.
-
additionalProperties
final PayGroupRetrieveResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PayGroupRetrieveResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PayGroupRetrieveResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PayGroupRetrieveResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PayGroupRetrieveResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PayGroupRetrieveResponse build()
Returns an immutable instance of PayGroupRetrieveResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .individualIds() .name() .payFrequencies()
-
-
-
-