Class PayStatement
-
- All Implemented Interfaces:
public final class PayStatement
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayStatement.BuilderA builder for PayStatement.
public final classPayStatement.Earningpublic final classPayStatement.EmployeeDeductionpublic final classPayStatement.EmployerContributionpublic final classPayStatement.PaymentMethodThe payment method.
public final classPayStatement.Taxpublic final classPayStatement.TypeThe type of the payment associated with the pay statement.
-
Method Summary
Modifier and Type Method Description final Optional<List<PayStatement.Earning>>earnings()The array of earnings objects associated with this pay statement final Optional<List<PayStatement.EmployeeDeduction>>employeeDeductions()The array of deductions objects associated with this pay statement. final Optional<List<PayStatement.EmployerContribution>>employerContributions()final Optional<Money>grossPay()final StringindividualId()A stable Finch id(UUID v4) for an individual in the companyfinal Optional<Money>netPay()final Optional<PayStatement.PaymentMethod>paymentMethod()The payment method. final Optional<List<PayStatement.Tax>>taxes()The array of taxes objects associated with this pay statement. final Optional<Double>totalHours()The number of hours worked for this pay period final Optional<PayStatement.Type>type()The type of the payment associated with the pay statement. final JsonField<List<PayStatement.Earning>>_earnings()Returns the raw JSON value of earnings. final JsonField<List<PayStatement.EmployeeDeduction>>_employeeDeductions()Returns the raw JSON value of employeeDeductions. final JsonField<List<PayStatement.EmployerContribution>>_employerContributions()Returns the raw JSON value of employerContributions. final JsonField<Money>_grossPay()Returns the raw JSON value of grossPay. final JsonField<String>_individualId()Returns the raw JSON value of individualId. final JsonField<Money>_netPay()Returns the raw JSON value of netPay. final JsonField<PayStatement.PaymentMethod>_paymentMethod()Returns the raw JSON value of paymentMethod. final JsonField<List<PayStatement.Tax>>_taxes()Returns the raw JSON value of taxes. final JsonField<Double>_totalHours()Returns the raw JSON value of totalHours. final JsonField<PayStatement.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final PayStatement.BuildertoBuilder()final PayStatementvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PayStatement.Builderbuilder()Returns a mutable builder for constructing an instance of PayStatement. -
-
Method Detail
-
earnings
final Optional<List<PayStatement.Earning>> earnings()
The array of earnings objects associated with this pay statement
-
employeeDeductions
final Optional<List<PayStatement.EmployeeDeduction>> employeeDeductions()
The array of deductions objects associated with this pay statement.
-
employerContributions
final Optional<List<PayStatement.EmployerContribution>> employerContributions()
-
individualId
final String individualId()
A stable Finch
id(UUID v4) for an individual in the company
-
paymentMethod
final Optional<PayStatement.PaymentMethod> paymentMethod()
The payment method.
-
taxes
final Optional<List<PayStatement.Tax>> taxes()
The array of taxes objects associated with this pay statement.
-
totalHours
final Optional<Double> totalHours()
The number of hours worked for this pay period
-
type
final Optional<PayStatement.Type> type()
The type of the payment associated with the pay statement.
-
_earnings
final JsonField<List<PayStatement.Earning>> _earnings()
Returns the raw JSON value of earnings.
Unlike earnings, this method doesn't throw if the JSON field has an unexpected type.
-
_employeeDeductions
final JsonField<List<PayStatement.EmployeeDeduction>> _employeeDeductions()
Returns the raw JSON value of employeeDeductions.
Unlike employeeDeductions, this method doesn't throw if the JSON field has an unexpected type.
-
_employerContributions
final JsonField<List<PayStatement.EmployerContribution>> _employerContributions()
Returns the raw JSON value of employerContributions.
Unlike employerContributions, this method doesn't throw if the JSON field has an unexpected type.
-
_grossPay
final JsonField<Money> _grossPay()
Returns the raw JSON value of grossPay.
Unlike grossPay, this method doesn't throw if the JSON field has an unexpected type.
-
_individualId
final JsonField<String> _individualId()
Returns the raw JSON value of individualId.
Unlike individualId, this method doesn't throw if the JSON field has an unexpected type.
-
_netPay
final JsonField<Money> _netPay()
Returns the raw JSON value of netPay.
Unlike netPay, this method doesn't throw if the JSON field has an unexpected type.
-
_paymentMethod
final JsonField<PayStatement.PaymentMethod> _paymentMethod()
Returns the raw JSON value of paymentMethod.
Unlike paymentMethod, this method doesn't throw if the JSON field has an unexpected type.
-
_taxes
final JsonField<List<PayStatement.Tax>> _taxes()
Returns the raw JSON value of taxes.
Unlike taxes, this method doesn't throw if the JSON field has an unexpected type.
-
_totalHours
final JsonField<Double> _totalHours()
Returns the raw JSON value of totalHours.
Unlike totalHours, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<PayStatement.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PayStatement.Builder toBuilder()
-
validate
final PayStatement validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PayStatement.Builder builder()
Returns a mutable builder for constructing an instance of PayStatement.
The following fields are required:
.earnings() .employeeDeductions() .employerContributions() .grossPay() .individualId() .netPay() .paymentMethod() .taxes() .totalHours() .type()
-
-
-
-