Class PayStatement.Builder
-
- All Implemented Interfaces:
public final class PayStatement.BuilderA builder for PayStatement.
-
-
Method Summary
-
-
Method Detail
-
earnings
final PayStatement.Builder earnings(List<PayStatement.Earning> earnings)
The array of earnings objects associated with this pay statement
-
earnings
final PayStatement.Builder earnings(Optional<List<PayStatement.Earning>> earnings)
Alias for calling Builder.earnings with
earnings.orElse(null).
-
earnings
final PayStatement.Builder earnings(JsonField<List<PayStatement.Earning>> earnings)
Sets Builder.earnings to an arbitrary JSON value.
You should usually call Builder.earnings with a well-typed
List<Earning?>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEarning
final PayStatement.Builder addEarning(PayStatement.Earning earning)
-
employeeDeductions
final PayStatement.Builder employeeDeductions(List<PayStatement.EmployeeDeduction> employeeDeductions)
The array of deductions objects associated with this pay statement.
-
employeeDeductions
final PayStatement.Builder employeeDeductions(Optional<List<PayStatement.EmployeeDeduction>> employeeDeductions)
Alias for calling Builder.employeeDeductions with
employeeDeductions.orElse(null).
-
employeeDeductions
final PayStatement.Builder employeeDeductions(JsonField<List<PayStatement.EmployeeDeduction>> employeeDeductions)
Sets Builder.employeeDeductions to an arbitrary JSON value.
You should usually call Builder.employeeDeductions with a well-typed
List<EmployeeDeduction>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEmployeeDeduction
final PayStatement.Builder addEmployeeDeduction(PayStatement.EmployeeDeduction employeeDeduction)
Adds a single EmployeeDeduction to employeeDeductions.
-
employerContributions
final PayStatement.Builder employerContributions(List<PayStatement.EmployerContribution> employerContributions)
-
employerContributions
final PayStatement.Builder employerContributions(Optional<List<PayStatement.EmployerContribution>> employerContributions)
Alias for calling Builder.employerContributions with
employerContributions.orElse(null).
-
employerContributions
final PayStatement.Builder employerContributions(JsonField<List<PayStatement.EmployerContribution>> employerContributions)
Sets Builder.employerContributions to an arbitrary JSON value.
You should usually call Builder.employerContributions with a well-typed
List<EmployerContribution>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEmployerContribution
final PayStatement.Builder addEmployerContribution(PayStatement.EmployerContribution employerContribution)
Adds a single EmployerContribution to employerContributions.
-
grossPay
final PayStatement.Builder grossPay(Money grossPay)
-
grossPay
final PayStatement.Builder grossPay(Optional<Money> grossPay)
Alias for calling Builder.grossPay with
grossPay.orElse(null).
-
grossPay
final PayStatement.Builder grossPay(JsonField<Money> grossPay)
Sets Builder.grossPay to an arbitrary JSON value.
You should usually call Builder.grossPay with a well-typed Money value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
individualId
final PayStatement.Builder individualId(String individualId)
A stable Finch
id(UUID v4) for an individual in the company
-
individualId
final PayStatement.Builder individualId(JsonField<String> individualId)
Sets Builder.individualId to an arbitrary JSON value.
You should usually call Builder.individualId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
netPay
final PayStatement.Builder netPay(Money netPay)
-
netPay
final PayStatement.Builder netPay(Optional<Money> netPay)
Alias for calling Builder.netPay with
netPay.orElse(null).
-
netPay
final PayStatement.Builder netPay(JsonField<Money> netPay)
Sets Builder.netPay to an arbitrary JSON value.
You should usually call Builder.netPay with a well-typed Money value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
paymentMethod
final PayStatement.Builder paymentMethod(PayStatement.PaymentMethod paymentMethod)
The payment method.
-
paymentMethod
final PayStatement.Builder paymentMethod(Optional<PayStatement.PaymentMethod> paymentMethod)
Alias for calling Builder.paymentMethod with
paymentMethod.orElse(null).
-
paymentMethod
final PayStatement.Builder paymentMethod(JsonField<PayStatement.PaymentMethod> paymentMethod)
Sets Builder.paymentMethod to an arbitrary JSON value.
You should usually call Builder.paymentMethod with a well-typed PaymentMethod value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
taxes
final PayStatement.Builder taxes(List<PayStatement.Tax> taxes)
The array of taxes objects associated with this pay statement.
-
taxes
final PayStatement.Builder taxes(Optional<List<PayStatement.Tax>> taxes)
Alias for calling Builder.taxes with
taxes.orElse(null).
-
taxes
final PayStatement.Builder taxes(JsonField<List<PayStatement.Tax>> taxes)
Sets Builder.taxes to an arbitrary JSON value.
You should usually call Builder.taxes with a well-typed
List<Tax>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTax
final PayStatement.Builder addTax(PayStatement.Tax tax)
-
totalHours
final PayStatement.Builder totalHours(Double totalHours)
The number of hours worked for this pay period
-
totalHours
final PayStatement.Builder totalHours(Double totalHours)
Alias for Builder.totalHours.
This unboxed primitive overload exists for backwards compatibility.
-
totalHours
final PayStatement.Builder totalHours(Optional<Double> totalHours)
Alias for calling Builder.totalHours with
totalHours.orElse(null).
-
totalHours
final PayStatement.Builder totalHours(JsonField<Double> totalHours)
Sets Builder.totalHours to an arbitrary JSON value.
You should usually call Builder.totalHours with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final PayStatement.Builder type(PayStatement.Type type)
The type of the payment associated with the pay statement.
-
type
final PayStatement.Builder type(Optional<PayStatement.Type> type)
Alias for calling Builder.type with
type.orElse(null).
-
type
final PayStatement.Builder type(JsonField<PayStatement.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PayStatement.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PayStatement.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PayStatement.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PayStatement.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PayStatement.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PayStatement build()
Returns an immutable instance of PayStatement.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.earnings() .employeeDeductions() .employerContributions() .grossPay() .individualId() .netPay() .paymentMethod() .taxes() .totalHours() .type()
-
-
-
-