Class PayStatement.Earning.Attributes
-
- All Implemented Interfaces:
public final class PayStatement.Earning.Attributes
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayStatement.Earning.Attributes.BuilderA builder for Attributes.
public final classPayStatement.Earning.Attributes.MetadataThe metadata to be attached to the entity by existing rules. It is a key-value pairs where the values can be of any type (string, number, boolean, object, array, etc.).
-
Method Summary
Modifier and Type Method Description final PayStatement.Earning.Attributes.Metadatametadata()The metadata to be attached to the entity by existing rules. final JsonField<PayStatement.Earning.Attributes.Metadata>_metadata()Returns the raw JSON value of metadata. final Map<String, JsonValue>_additionalProperties()final PayStatement.Earning.Attributes.BuildertoBuilder()final PayStatement.Earning.Attributesvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PayStatement.Earning.Attributes.Builderbuilder()Returns a mutable builder for constructing an instance of Attributes. -
-
Method Detail
-
metadata
final PayStatement.Earning.Attributes.Metadata metadata()
The metadata to be attached to the entity by existing rules. It is a key-value pairs where the values can be of any type (string, number, boolean, object, array, etc.).
-
_metadata
final JsonField<PayStatement.Earning.Attributes.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PayStatement.Earning.Attributes.Builder toBuilder()
-
validate
final PayStatement.Earning.Attributes validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PayStatement.Earning.Attributes.Builder builder()
Returns a mutable builder for constructing an instance of Attributes.
The following fields are required:
.metadata()
-
-
-
-