Package com.tryfinch.api.models
Class PayStatement.Earning.Attributes.Metadata
-
- All Implemented Interfaces:
public final class PayStatement.Earning.Attributes.MetadataThe metadata to be attached to the entity by existing rules. It is a key-value pairs where the values can be of any type (string, number, boolean, object, array, etc.).
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayStatement.Earning.Attributes.Metadata.BuilderA builder for Metadata.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final PayStatement.Earning.Attributes.Metadata.BuildertoBuilder()final PayStatement.Earning.Attributes.Metadatavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PayStatement.Earning.Attributes.Metadata.Builderbuilder()Returns a mutable builder for constructing an instance of Metadata. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PayStatement.Earning.Attributes.Metadata.Builder toBuilder()
-
validate
final PayStatement.Earning.Attributes.Metadata validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PayStatement.Earning.Attributes.Metadata.Builder builder()
Returns a mutable builder for constructing an instance of Metadata.
-
-
-
-