Class PayStatement.Earning.Builder
-
- All Implemented Interfaces:
public final class PayStatement.Earning.BuilderA builder for Earning.
-
-
Method Summary
-
-
Method Detail
-
amount
final PayStatement.Earning.Builder amount(Long amount)
The earnings amount in cents.
-
amount
final PayStatement.Earning.Builder amount(Long amount)
Alias for Builder.amount.
This unboxed primitive overload exists for backwards compatibility.
-
amount
final PayStatement.Earning.Builder amount(Optional<Long> amount)
Alias for calling Builder.amount with
amount.orElse(null).
-
amount
final PayStatement.Earning.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final PayStatement.Earning.Builder currency(String currency)
The earnings currency code.
-
currency
final PayStatement.Earning.Builder currency(Optional<String> currency)
Alias for calling Builder.currency with
currency.orElse(null).
-
currency
final PayStatement.Earning.Builder currency(JsonField<String> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
hours
final PayStatement.Earning.Builder hours(Double hours)
The number of hours associated with this earning. (For salaried employees, this could be hours per pay period,
0ornull, depending on the provider).
-
hours
final PayStatement.Earning.Builder hours(Double hours)
Alias for Builder.hours.
This unboxed primitive overload exists for backwards compatibility.
-
hours
final PayStatement.Earning.Builder hours(Optional<Double> hours)
Alias for calling Builder.hours with
hours.orElse(null).
-
hours
final PayStatement.Earning.Builder hours(JsonField<Double> hours)
Sets Builder.hours to an arbitrary JSON value.
You should usually call Builder.hours with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final PayStatement.Earning.Builder name(String name)
The exact name of the deduction from the pay statement.
-
name
final PayStatement.Earning.Builder name(Optional<String> name)
Alias for calling Builder.name with
name.orElse(null).
-
name
final PayStatement.Earning.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final PayStatement.Earning.Builder type(PayStatement.Earning.Type type)
The type of earning.
-
type
final PayStatement.Earning.Builder type(Optional<PayStatement.Earning.Type> type)
Alias for calling Builder.type with
type.orElse(null).
-
type
final PayStatement.Earning.Builder type(JsonField<PayStatement.Earning.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
attributes
final PayStatement.Earning.Builder attributes(PayStatement.Earning.Attributes attributes)
-
attributes
final PayStatement.Earning.Builder attributes(Optional<PayStatement.Earning.Attributes> attributes)
Alias for calling Builder.attributes with
attributes.orElse(null).
-
attributes
final PayStatement.Earning.Builder attributes(JsonField<PayStatement.Earning.Attributes> attributes)
Sets Builder.attributes to an arbitrary JSON value.
You should usually call Builder.attributes with a well-typed Attributes value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PayStatement.Earning.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PayStatement.Earning.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PayStatement.Earning.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PayStatement.Earning.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PayStatement.Earning.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PayStatement.Earning build()
Returns an immutable instance of Earning.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.amount() .currency() .hours() .name() .type()
-
-
-
-