Class PayStatement.EmployerContribution
-
- All Implemented Interfaces:
public final class PayStatement.EmployerContribution
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayStatement.EmployerContribution.BuilderA builder for EmployerContribution.
public final classPayStatement.EmployerContribution.Attributes
-
Method Summary
Modifier and Type Method Description final Optional<String>currency()The contribution currency. final Optional<String>name()The contribution name from the pay statement. final Optional<BenefitType>type()Type of benefit. final Optional<Long>amount()The contribution amount in cents. final Optional<PayStatement.EmployerContribution.Attributes>attributes()final JsonField<String>_currency()Returns the raw JSON value of currency. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<BenefitType>_type()Returns the raw JSON value of type. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<PayStatement.EmployerContribution.Attributes>_attributes()Returns the raw JSON value of attributes. final Map<String, JsonValue>_additionalProperties()final PayStatement.EmployerContribution.BuildertoBuilder()final PayStatement.EmployerContributionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PayStatement.EmployerContribution.Builderbuilder()Returns a mutable builder for constructing an instance of EmployerContribution. -
-
Method Detail
-
type
final Optional<BenefitType> type()
Type of benefit.
-
attributes
final Optional<PayStatement.EmployerContribution.Attributes> attributes()
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<BenefitType> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_attributes
final JsonField<PayStatement.EmployerContribution.Attributes> _attributes()
Returns the raw JSON value of attributes.
Unlike attributes, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PayStatement.EmployerContribution.Builder toBuilder()
-
validate
final PayStatement.EmployerContribution validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PayStatement.EmployerContribution.Builder builder()
Returns a mutable builder for constructing an instance of EmployerContribution.
The following fields are required:
.currency() .name() .type()
-
-
-
-