Package com.tryfinch.api.models
Class PayStatement.EmployerContribution.Attributes
-
- All Implemented Interfaces:
public final class PayStatement.EmployerContribution.Attributes
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayStatement.EmployerContribution.Attributes.BuilderA builder for Attributes.
public final classPayStatement.EmployerContribution.Attributes.MetadataThe metadata to be attached to the entity by existing rules. It is a key-value pairs where the values can be of any type (string, number, boolean, object, array, etc.).
-
Method Summary
Modifier and Type Method Description final PayStatement.EmployerContribution.Attributes.Metadatametadata()The metadata to be attached to the entity by existing rules. final JsonField<PayStatement.EmployerContribution.Attributes.Metadata>_metadata()Returns the raw JSON value of metadata. final Map<String, JsonValue>_additionalProperties()final PayStatement.EmployerContribution.Attributes.BuildertoBuilder()final PayStatement.EmployerContribution.Attributesvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PayStatement.EmployerContribution.Attributes.Builderbuilder()Returns a mutable builder for constructing an instance of Attributes. -
-
Method Detail
-
metadata
final PayStatement.EmployerContribution.Attributes.Metadata metadata()
The metadata to be attached to the entity by existing rules. It is a key-value pairs where the values can be of any type (string, number, boolean, object, array, etc.).
-
_metadata
final JsonField<PayStatement.EmployerContribution.Attributes.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PayStatement.EmployerContribution.Attributes.Builder toBuilder()
-
validate
final PayStatement.EmployerContribution.Attributes validate()
-
builder
final static PayStatement.EmployerContribution.Attributes.Builder builder()
Returns a mutable builder for constructing an instance of Attributes.
The following fields are required:
.metadata()
-
-
-
-