Package com.tryfinch.api.models
Class PayStatement.EmployerContribution.Attributes.Builder
-
- All Implemented Interfaces:
public final class PayStatement.EmployerContribution.Attributes.BuilderA builder for Attributes.
-
-
Method Summary
-
-
Method Detail
-
metadata
final PayStatement.EmployerContribution.Attributes.Builder metadata(PayStatement.EmployerContribution.Attributes.Metadata metadata)
The metadata to be attached to the entity by existing rules. It is a key-value pairs where the values can be of any type (string, number, boolean, object, array, etc.).
-
metadata
final PayStatement.EmployerContribution.Attributes.Builder metadata(JsonField<PayStatement.EmployerContribution.Attributes.Metadata> metadata)
Sets Builder.metadata to an arbitrary JSON value.
You should usually call Builder.metadata with a well-typed Metadata value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PayStatement.EmployerContribution.Attributes.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PayStatement.EmployerContribution.Attributes.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PayStatement.EmployerContribution.Attributes.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PayStatement.EmployerContribution.Attributes.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PayStatement.EmployerContribution.Attributes.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PayStatement.EmployerContribution.Attributes build()
Returns an immutable instance of Attributes.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.metadata()
-
-
-
-