Package com.tryfinch.api.models
Class PayStatement.EmployerContribution.Attributes.Metadata
-
- All Implemented Interfaces:
public final class PayStatement.EmployerContribution.Attributes.Metadata
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayStatement.EmployerContribution.Attributes.Metadata.BuilderA builder for Metadata.
public final classPayStatement.EmployerContribution.Attributes.Metadata.InnerMetadataThe metadata to be attached to the entity by existing rules. It is a key-value pairs where the values can be of any type (string, number, boolean, object, array, etc.).
-
Method Summary
Modifier and Type Method Description final PayStatement.EmployerContribution.Attributes.Metadata.InnerMetadatametadata()The metadata to be attached to the entity by existing rules. final JsonField<PayStatement.EmployerContribution.Attributes.Metadata.InnerMetadata>_metadata()Returns the raw JSON value of metadata. final Map<String, JsonValue>_additionalProperties()final PayStatement.EmployerContribution.Attributes.Metadata.BuildertoBuilder()final PayStatement.EmployerContribution.Attributes.Metadatavalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PayStatement.EmployerContribution.Attributes.Metadata.Builderbuilder()Returns a mutable builder for constructing an instance of Metadata. -
-
Method Detail
-
metadata
final PayStatement.EmployerContribution.Attributes.Metadata.InnerMetadata metadata()
The metadata to be attached to the entity by existing rules. It is a key-value pairs where the values can be of any type (string, number, boolean, object, array, etc.).
-
_metadata
final JsonField<PayStatement.EmployerContribution.Attributes.Metadata.InnerMetadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PayStatement.EmployerContribution.Attributes.Metadata.Builder toBuilder()
-
validate
final PayStatement.EmployerContribution.Attributes.Metadata validate()
-
builder
final static PayStatement.EmployerContribution.Attributes.Metadata.Builder builder()
Returns a mutable builder for constructing an instance of Metadata.
The following fields are required:
.metadata()
-
-
-
-