Package com.tryfinch.api.models
Class PayStatement.EmployerContribution.Attributes.Metadata.InnerMetadata
-
- All Implemented Interfaces:
public final class PayStatement.EmployerContribution.Attributes.Metadata.InnerMetadataThe metadata to be attached to the entity by existing rules. It is a key-value pairs where the values can be of any type (string, number, boolean, object, array, etc.).
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayStatement.EmployerContribution.Attributes.Metadata.InnerMetadata.BuilderA builder for InnerMetadata.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final PayStatement.EmployerContribution.Attributes.Metadata.InnerMetadata.BuildertoBuilder()final PayStatement.EmployerContribution.Attributes.Metadata.InnerMetadatavalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PayStatement.EmployerContribution.Attributes.Metadata.InnerMetadata.Builderbuilder()Returns a mutable builder for constructing an instance of InnerMetadata. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PayStatement.EmployerContribution.Attributes.Metadata.InnerMetadata.Builder toBuilder()
-
builder
final static PayStatement.EmployerContribution.Attributes.Metadata.InnerMetadata.Builder builder()
Returns a mutable builder for constructing an instance of InnerMetadata.
-
-
-
-