Class PayStatement.EmployerContribution.Builder
-
- All Implemented Interfaces:
public final class PayStatement.EmployerContribution.BuilderA builder for EmployerContribution.
-
-
Method Summary
-
-
Method Detail
-
currency
final PayStatement.EmployerContribution.Builder currency(String currency)
The contribution currency.
-
currency
final PayStatement.EmployerContribution.Builder currency(Optional<String> currency)
Alias for calling Builder.currency with
currency.orElse(null).
-
currency
final PayStatement.EmployerContribution.Builder currency(JsonField<String> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final PayStatement.EmployerContribution.Builder name(String name)
The contribution name from the pay statement.
-
name
final PayStatement.EmployerContribution.Builder name(Optional<String> name)
Alias for calling Builder.name with
name.orElse(null).
-
name
final PayStatement.EmployerContribution.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final PayStatement.EmployerContribution.Builder type(BenefitType type)
Type of benefit.
-
type
final PayStatement.EmployerContribution.Builder type(Optional<BenefitType> type)
Alias for calling Builder.type with
type.orElse(null).
-
type
final PayStatement.EmployerContribution.Builder type(JsonField<BenefitType> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed BenefitType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final PayStatement.EmployerContribution.Builder amount(Long amount)
The contribution amount in cents.
-
amount
final PayStatement.EmployerContribution.Builder amount(Long amount)
Alias for Builder.amount.
This unboxed primitive overload exists for backwards compatibility.
-
amount
final PayStatement.EmployerContribution.Builder amount(Optional<Long> amount)
Alias for calling Builder.amount with
amount.orElse(null).
-
amount
final PayStatement.EmployerContribution.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
attributes
final PayStatement.EmployerContribution.Builder attributes(PayStatement.EmployerContribution.Attributes attributes)
-
attributes
final PayStatement.EmployerContribution.Builder attributes(Optional<PayStatement.EmployerContribution.Attributes> attributes)
Alias for calling Builder.attributes with
attributes.orElse(null).
-
attributes
final PayStatement.EmployerContribution.Builder attributes(JsonField<PayStatement.EmployerContribution.Attributes> attributes)
Sets Builder.attributes to an arbitrary JSON value.
You should usually call Builder.attributes with a well-typed Attributes value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PayStatement.EmployerContribution.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PayStatement.EmployerContribution.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PayStatement.EmployerContribution.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PayStatement.EmployerContribution.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PayStatement.EmployerContribution.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PayStatement.EmployerContribution build()
Returns an immutable instance of EmployerContribution.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.currency() .name() .type()
-
-
-
-