Class PayStatement.Tax
-
- All Implemented Interfaces:
public final class PayStatement.Tax
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayStatement.Tax.BuilderA builder for Tax.
public final classPayStatement.Tax.TypeThe type of taxes.
public final classPayStatement.Tax.Attributes
-
Method Summary
Modifier and Type Method Description final Optional<String>currency()The currency code. final Optional<Boolean>employer()trueif the amount is paid by the employers.final Optional<String>name()The exact name of tax from the pay statement. final Optional<PayStatement.Tax.Type>type()The type of taxes. final Optional<Long>amount()The tax amount in cents. final Optional<PayStatement.Tax.Attributes>attributes()final JsonField<String>_currency()Returns the raw JSON value of currency. final JsonField<Boolean>_employer()Returns the raw JSON value of employer. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<PayStatement.Tax.Type>_type()Returns the raw JSON value of type. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<PayStatement.Tax.Attributes>_attributes()Returns the raw JSON value of attributes. final Map<String, JsonValue>_additionalProperties()final PayStatement.Tax.BuildertoBuilder()final PayStatement.Taxvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PayStatement.Tax.Builderbuilder()Returns a mutable builder for constructing an instance of Tax. -
-
Method Detail
-
type
final Optional<PayStatement.Tax.Type> type()
The type of taxes.
-
attributes
final Optional<PayStatement.Tax.Attributes> attributes()
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_employer
final JsonField<Boolean> _employer()
Returns the raw JSON value of employer.
Unlike employer, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<PayStatement.Tax.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_attributes
final JsonField<PayStatement.Tax.Attributes> _attributes()
Returns the raw JSON value of attributes.
Unlike attributes, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PayStatement.Tax.Builder toBuilder()
-
validate
final PayStatement.Tax validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PayStatement.Tax.Builder builder()
Returns a mutable builder for constructing an instance of Tax.
The following fields are required:
.currency() .employer() .name() .type()
-
-
-
-