Class PayStatement.Tax.Attributes.Metadata.InnerMetadata

  • All Implemented Interfaces:

    
    public final class PayStatement.Tax.Attributes.Metadata.InnerMetadata
    
                        

    The metadata to be attached to the entity by existing rules. It is a key-value pairs where the values can be of any type (string, number, boolean, object, array, etc.).