Class PayStatement.Tax.Builder
-
- All Implemented Interfaces:
public final class PayStatement.Tax.BuilderA builder for Tax.
-
-
Method Summary
-
-
Method Detail
-
amount
final PayStatement.Tax.Builder amount(Long amount)
The tax amount in cents.
-
amount
final PayStatement.Tax.Builder amount(Long amount)
Alias for Builder.amount.
This unboxed primitive overload exists for backwards compatibility.
-
amount
final PayStatement.Tax.Builder amount(Optional<Long> amount)
Alias for calling Builder.amount with
amount.orElse(null).
-
amount
final PayStatement.Tax.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
attributes
final PayStatement.Tax.Builder attributes(PayStatement.Tax.Attributes attributes)
-
attributes
final PayStatement.Tax.Builder attributes(Optional<PayStatement.Tax.Attributes> attributes)
Alias for calling Builder.attributes with
attributes.orElse(null).
-
attributes
final PayStatement.Tax.Builder attributes(JsonField<PayStatement.Tax.Attributes> attributes)
Sets Builder.attributes to an arbitrary JSON value.
You should usually call Builder.attributes with a well-typed Attributes value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final PayStatement.Tax.Builder currency(String currency)
The currency code.
-
currency
final PayStatement.Tax.Builder currency(Optional<String> currency)
Alias for calling Builder.currency with
currency.orElse(null).
-
currency
final PayStatement.Tax.Builder currency(JsonField<String> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
employer
final PayStatement.Tax.Builder employer(Boolean employer)
trueif the amount is paid by the employers.
-
employer
final PayStatement.Tax.Builder employer(Boolean employer)
Alias for Builder.employer.
This unboxed primitive overload exists for backwards compatibility.
-
employer
final PayStatement.Tax.Builder employer(Optional<Boolean> employer)
Alias for calling Builder.employer with
employer.orElse(null).
-
employer
final PayStatement.Tax.Builder employer(JsonField<Boolean> employer)
Sets Builder.employer to an arbitrary JSON value.
You should usually call Builder.employer with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final PayStatement.Tax.Builder name(String name)
The exact name of tax from the pay statement.
-
name
final PayStatement.Tax.Builder name(Optional<String> name)
Alias for calling Builder.name with
name.orElse(null).
-
name
final PayStatement.Tax.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final PayStatement.Tax.Builder type(PayStatement.Tax.Type type)
The type of taxes.
-
type
final PayStatement.Tax.Builder type(Optional<PayStatement.Tax.Type> type)
Alias for calling Builder.type with
type.orElse(null).
-
type
final PayStatement.Tax.Builder type(JsonField<PayStatement.Tax.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PayStatement.Tax.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PayStatement.Tax.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PayStatement.Tax.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PayStatement.Tax.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PayStatement.Tax.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PayStatement.Tax build()
Returns an immutable instance of Tax.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-