Package com.tryfinch.api.models
Class PayStatementData
-
- All Implemented Interfaces:
public final class PayStatementData
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayStatementData.BuilderA builder for PayStatementData.
public final classPayStatementData.Paging
-
Method Summary
Modifier and Type Method Description final PayStatementData.Pagingpaging()final List<PayStatement>payStatements()final JsonField<PayStatementData.Paging>_paging()Returns the raw JSON value of paging. final JsonField<List<PayStatement>>_payStatements()Returns the raw JSON value of payStatements. final Map<String, JsonValue>_additionalProperties()final PayStatementData.BuildertoBuilder()final PayStatementDatavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PayStatementData.Builderbuilder()Returns a mutable builder for constructing an instance of PayStatementData. -
-
Method Detail
-
paging
final PayStatementData.Paging paging()
-
payStatements
final List<PayStatement> payStatements()
-
_paging
final JsonField<PayStatementData.Paging> _paging()
Returns the raw JSON value of paging.
Unlike paging, this method doesn't throw if the JSON field has an unexpected type.
-
_payStatements
final JsonField<List<PayStatement>> _payStatements()
Returns the raw JSON value of payStatements.
Unlike payStatements, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PayStatementData.Builder toBuilder()
-
validate
final PayStatementData validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PayStatementData.Builder builder()
Returns a mutable builder for constructing an instance of PayStatementData.
The following fields are required:
.paging() .payStatements()
-
-
-
-