Package com.tryfinch.api.models
Class PayStatementData.Paging.Builder
-
- All Implemented Interfaces:
public final class PayStatementData.Paging.BuilderA builder for Paging.
-
-
Method Summary
-
-
Method Detail
-
offset
final PayStatementData.Paging.Builder offset(Long offset)
The current start index of the returned list of elements
-
offset
final PayStatementData.Paging.Builder offset(JsonField<Long> offset)
Sets Builder.offset to an arbitrary JSON value.
You should usually call Builder.offset with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
count
final PayStatementData.Paging.Builder count(Long count)
The total number of elements for the entire query (not just the given page)
-
count
final PayStatementData.Paging.Builder count(JsonField<Long> count)
Sets Builder.count to an arbitrary JSON value.
You should usually call Builder.count with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PayStatementData.Paging.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PayStatementData.Paging.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PayStatementData.Paging.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PayStatementData.Paging.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PayStatementData.Paging.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PayStatementData.Paging build()
Returns an immutable instance of Paging.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.offset()
-
-
-
-