Class PayStatementDataSyncInProgress.Builder
-
- All Implemented Interfaces:
public final class PayStatementDataSyncInProgress.BuilderA builder for PayStatementDataSyncInProgress.
-
-
Method Summary
-
-
Method Detail
-
code
final PayStatementDataSyncInProgress.Builder code(JsonField<PayStatementDataSyncInProgress.Code> code)
Sets Builder.code to an arbitrary JSON value.
You should usually call Builder.code with a well-typed Code value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
finchCode
final PayStatementDataSyncInProgress.Builder finchCode(PayStatementDataSyncInProgress.FinchCode finchCode)
-
finchCode
final PayStatementDataSyncInProgress.Builder finchCode(JsonField<PayStatementDataSyncInProgress.FinchCode> finchCode)
Sets Builder.finchCode to an arbitrary JSON value.
You should usually call Builder.finchCode with a well-typed FinchCode value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
message
final PayStatementDataSyncInProgress.Builder message(PayStatementDataSyncInProgress.Message message)
-
message
final PayStatementDataSyncInProgress.Builder message(JsonField<PayStatementDataSyncInProgress.Message> message)
Sets Builder.message to an arbitrary JSON value.
You should usually call Builder.message with a well-typed Message value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final PayStatementDataSyncInProgress.Builder name(JsonField<PayStatementDataSyncInProgress.Name> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed Name value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PayStatementDataSyncInProgress.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PayStatementDataSyncInProgress.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PayStatementDataSyncInProgress.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PayStatementDataSyncInProgress.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PayStatementDataSyncInProgress.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PayStatementDataSyncInProgress build()
Returns an immutable instance of PayStatementDataSyncInProgress.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.code() .finchCode() .message() .name()
-
-
-
-