Package com.tryfinch.api.models
Class PayStatementEvent.Data
-
- All Implemented Interfaces:
public final class PayStatementEvent.Data
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayStatementEvent.Data.BuilderA builder for Data.
-
Method Summary
Modifier and Type Method Description final Optional<String>individualId()The ID of the individual associated with the pay statement. final Optional<String>paymentId()The ID of the payment associated with the pay statement. final JsonField<String>_individualId()Returns the raw JSON value of individualId. final JsonField<String>_paymentId()Returns the raw JSON value of paymentId. final Map<String, JsonValue>_additionalProperties()final PayStatementEvent.Data.BuildertoBuilder()final PayStatementEvent.Datavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PayStatementEvent.Data.Builderbuilder()Returns a mutable builder for constructing an instance of Data. -
-
Method Detail
-
individualId
final Optional<String> individualId()
The ID of the individual associated with the pay statement.
-
paymentId
final Optional<String> paymentId()
The ID of the payment associated with the pay statement.
-
_individualId
final JsonField<String> _individualId()
Returns the raw JSON value of individualId.
Unlike individualId, this method doesn't throw if the JSON field has an unexpected type.
-
_paymentId
final JsonField<String> _paymentId()
Returns the raw JSON value of paymentId.
Unlike paymentId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PayStatementEvent.Data.Builder toBuilder()
-
validate
final PayStatementEvent.Data validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PayStatementEvent.Data.Builder builder()
Returns a mutable builder for constructing an instance of Data.
-
-
-
-