Package com.tryfinch.api.models
Class PayStatementEvent.Data.Builder
-
- All Implemented Interfaces:
public final class PayStatementEvent.Data.BuilderA builder for Data.
-
-
Method Summary
-
-
Method Detail
-
individualId
final PayStatementEvent.Data.Builder individualId(String individualId)
The ID of the individual associated with the pay statement.
-
individualId
final PayStatementEvent.Data.Builder individualId(JsonField<String> individualId)
Sets Builder.individualId to an arbitrary JSON value.
You should usually call Builder.individualId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
paymentId
final PayStatementEvent.Data.Builder paymentId(String paymentId)
The ID of the payment associated with the pay statement.
-
paymentId
final PayStatementEvent.Data.Builder paymentId(JsonField<String> paymentId)
Sets Builder.paymentId to an arbitrary JSON value.
You should usually call Builder.paymentId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PayStatementEvent.Data.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PayStatementEvent.Data.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PayStatementEvent.Data.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PayStatementEvent.Data.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PayStatementEvent.Data.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PayStatementEvent.Data build()
Returns an immutable instance of Data.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-