Class PayStatementItemListResponse
-
- All Implemented Interfaces:
public final class PayStatementItemListResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayStatementItemListResponse.BuilderA builder for PayStatementItemListResponse.
public final classPayStatementItemListResponse.AttributesThe attributes of the pay statement item.
public final classPayStatementItemListResponse.CategoryThe category of the pay statement item.
-
Method Summary
Modifier and Type Method Description final PayStatementItemListResponse.Attributesattributes()The attributes of the pay statement item. final PayStatementItemListResponse.Categorycategory()The category of the pay statement item. final Stringname()The name of the pay statement item. final JsonField<PayStatementItemListResponse.Attributes>_attributes()Returns the raw JSON value of attributes. final JsonField<PayStatementItemListResponse.Category>_category()Returns the raw JSON value of category. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final PayStatementItemListResponse.BuildertoBuilder()final PayStatementItemListResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PayStatementItemListResponse.Builderbuilder()Returns a mutable builder for constructing an instance of PayStatementItemListResponse. -
-
Method Detail
-
attributes
final PayStatementItemListResponse.Attributes attributes()
The attributes of the pay statement item.
-
category
final PayStatementItemListResponse.Category category()
The category of the pay statement item.
-
_attributes
final JsonField<PayStatementItemListResponse.Attributes> _attributes()
Returns the raw JSON value of attributes.
Unlike attributes, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<PayStatementItemListResponse.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PayStatementItemListResponse.Builder toBuilder()
-
validate
final PayStatementItemListResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PayStatementItemListResponse.Builder builder()
Returns a mutable builder for constructing an instance of PayStatementItemListResponse.
The following fields are required:
.attributes() .category() .name()
-
-
-
-