Class PayStatementItemListResponse.Attributes.Builder
-
- All Implemented Interfaces:
public final class PayStatementItemListResponse.Attributes.BuilderA builder for Attributes.
-
-
Method Summary
-
-
Method Detail
-
employer
final PayStatementItemListResponse.Attributes.Builder employer(Boolean employer)
trueif the amount is paid by the employers. This field is only available for taxes.
-
employer
final PayStatementItemListResponse.Attributes.Builder employer(Boolean employer)
Alias for Builder.employer.
This unboxed primitive overload exists for backwards compatibility.
-
employer
final PayStatementItemListResponse.Attributes.Builder employer(Optional<Boolean> employer)
Alias for calling Builder.employer with
employer.orElse(null).
-
employer
final PayStatementItemListResponse.Attributes.Builder employer(JsonField<Boolean> employer)
Sets Builder.employer to an arbitrary JSON value.
You should usually call Builder.employer with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
metadata
final PayStatementItemListResponse.Attributes.Builder metadata(JsonValue metadata)
The metadata of the pay statement item derived by the rules engine if available. Each attribute will be a key-value pair defined by a rule.
-
preTax
final PayStatementItemListResponse.Attributes.Builder preTax(Boolean preTax)
trueif the pay statement item is pre-tax. This field is only available for employee deductions.
-
preTax
final PayStatementItemListResponse.Attributes.Builder preTax(Boolean preTax)
Alias for Builder.preTax.
This unboxed primitive overload exists for backwards compatibility.
-
preTax
final PayStatementItemListResponse.Attributes.Builder preTax(Optional<Boolean> preTax)
Alias for calling Builder.preTax with
preTax.orElse(null).
-
preTax
final PayStatementItemListResponse.Attributes.Builder preTax(JsonField<Boolean> preTax)
Sets Builder.preTax to an arbitrary JSON value.
You should usually call Builder.preTax with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final PayStatementItemListResponse.Attributes.Builder type(String type)
The type of the pay statement item.
-
type
final PayStatementItemListResponse.Attributes.Builder type(Optional<String> type)
Alias for calling Builder.type with
type.orElse(null).
-
type
final PayStatementItemListResponse.Attributes.Builder type(JsonField<String> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PayStatementItemListResponse.Attributes.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PayStatementItemListResponse.Attributes.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PayStatementItemListResponse.Attributes.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PayStatementItemListResponse.Attributes.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PayStatementItemListResponse.Attributes.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PayStatementItemListResponse.Attributes build()
Returns an immutable instance of Attributes.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-