Package com.tryfinch.api.models
Class PayStatementItemListResponse.Attributes.Metadata
-
- All Implemented Interfaces:
public final class PayStatementItemListResponse.Attributes.MetadataThe metadata of the pay statement item derived by the rules engine if available. Each attribute will be a key-value pair defined by a rule.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayStatementItemListResponse.Attributes.Metadata.BuilderA builder for Metadata.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final PayStatementItemListResponse.Attributes.Metadata.BuildertoBuilder()final PayStatementItemListResponse.Attributes.Metadatavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PayStatementItemListResponse.Attributes.Metadata.Builderbuilder()Returns a mutable builder for constructing an instance of Metadata. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PayStatementItemListResponse.Attributes.Metadata.Builder toBuilder()
-
validate
final PayStatementItemListResponse.Attributes.Metadata validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PayStatementItemListResponse.Attributes.Metadata.Builder builder()
Returns a mutable builder for constructing an instance of Metadata.
-
-
-
-