Package com.tryfinch.api.models
Interface PayStatementResponse.Body.Visitor
-
- All Implemented Interfaces:
public interface PayStatementResponse.Body.Visitor<T extends Object>
-
-
Method Summary
Modifier and Type Method Description abstract TvisitPayStatementResponse(PayStatementResponseBody payStatementResponse)abstract TvisitBatchError(PayStatementResponse.Body.BatchError batchError)abstract TvisitPayStatementDataSyncInProgress(PayStatementDataSyncInProgress payStatementDataSyncInProgress)Tunknown(JsonValue json)Maps an unknown variant of Body to a value of type T. -
-
Method Detail
-
visitPayStatementResponse
abstract T visitPayStatementResponse(PayStatementResponseBody payStatementResponse)
-
visitBatchError
abstract T visitBatchError(PayStatementResponse.Body.BatchError batchError)
-
visitPayStatementDataSyncInProgress
abstract T visitPayStatementDataSyncInProgress(PayStatementDataSyncInProgress payStatementDataSyncInProgress)
-
unknown
T unknown(JsonValue json)
Maps an unknown variant of Body to a value of type T.
An instance of Body can contain an unknown variant if it was deserialized from data that doesn't match any known variant. For example, if the SDK is on an older version than the API, then the API may respond with new variants that the SDK is unaware of.
-
-
-
-