Class PayStatementResponse.Builder
-
- All Implemented Interfaces:
public final class PayStatementResponse.BuilderA builder for PayStatementResponse.
-
-
Method Summary
-
-
Method Detail
-
body
final PayStatementResponse.Builder body(PayStatementResponse.Body body)
-
body
final PayStatementResponse.Builder body(JsonField<PayStatementResponse.Body> body)
Sets Builder.body to an arbitrary JSON value.
You should usually call Builder.body with a well-typed Body value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
body
final PayStatementResponse.Builder body(PayStatementResponseBody payStatementResponse)
Alias for calling body with
Body.ofPayStatementResponse(payStatementResponse).
-
body
final PayStatementResponse.Builder body(PayStatementResponse.Body.BatchError batchError)
Alias for calling body with
Body.ofBatchError(batchError).
-
body
final PayStatementResponse.Builder body(PayStatementDataSyncInProgress payStatementDataSyncInProgress)
Alias for calling body with
Body.ofPayStatementDataSyncInProgress(payStatementDataSyncInProgress).
-
code
final PayStatementResponse.Builder code(Long code)
-
code
final PayStatementResponse.Builder code(JsonField<Long> code)
Sets Builder.code to an arbitrary JSON value.
You should usually call Builder.code with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
paymentId
final PayStatementResponse.Builder paymentId(String paymentId)
-
paymentId
final PayStatementResponse.Builder paymentId(JsonField<String> paymentId)
Sets Builder.paymentId to an arbitrary JSON value.
You should usually call Builder.paymentId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PayStatementResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PayStatementResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PayStatementResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PayStatementResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PayStatementResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PayStatementResponse build()
Returns an immutable instance of PayStatementResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.body() .code() .paymentId()
-
-
-
-