Package com.tryfinch.api.models
Class PayStatementResponseBody
-
- All Implemented Interfaces:
public final class PayStatementResponseBody
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayStatementResponseBody.BuilderA builder for PayStatementResponseBody.
public final classPayStatementResponseBody.Paging
-
Method Summary
Modifier and Type Method Description final PayStatementResponseBody.Pagingpaging()final List<PayStatement>payStatements()final JsonField<PayStatementResponseBody.Paging>_paging()Returns the raw JSON value of paging. final JsonField<List<PayStatement>>_payStatements()Returns the raw JSON value of payStatements. final Map<String, JsonValue>_additionalProperties()final PayStatementResponseBody.BuildertoBuilder()final PayStatementResponseBodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PayStatementResponseBody.Builderbuilder()Returns a mutable builder for constructing an instance of PayStatementResponseBody. -
-
Method Detail
-
paging
final PayStatementResponseBody.Paging paging()
-
payStatements
final List<PayStatement> payStatements()
-
_paging
final JsonField<PayStatementResponseBody.Paging> _paging()
Returns the raw JSON value of paging.
Unlike paging, this method doesn't throw if the JSON field has an unexpected type.
-
_payStatements
final JsonField<List<PayStatement>> _payStatements()
Returns the raw JSON value of payStatements.
Unlike payStatements, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PayStatementResponseBody.Builder toBuilder()
-
validate
final PayStatementResponseBody validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PayStatementResponseBody.Builder builder()
Returns a mutable builder for constructing an instance of PayStatementResponseBody.
The following fields are required:
.paging() .payStatements()
-
-
-
-