Class Payment.Builder
-
- All Implemented Interfaces:
public final class Payment.BuilderA builder for Payment.
-
-
Method Summary
Modifier and Type Method Description final Payment.Builderid(String id)The unique id for the payment. final Payment.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final Payment.BuildercompanyDebit(Money companyDebit)final Payment.BuildercompanyDebit(Optional<Money> companyDebit)Alias for calling Builder.companyDebit with companyDebit.orElse(null).final Payment.BuildercompanyDebit(JsonField<Money> companyDebit)Sets Builder.companyDebit to an arbitrary JSON value. final Payment.BuilderdebitDate(String debitDate)final Payment.BuilderdebitDate(Optional<String> debitDate)Alias for calling Builder.debitDate with debitDate.orElse(null).final Payment.BuilderdebitDate(JsonField<String> debitDate)Sets Builder.debitDate to an arbitrary JSON value. final Payment.BuilderemployeeTaxes(Money employeeTaxes)final Payment.BuilderemployeeTaxes(Optional<Money> employeeTaxes)Alias for calling Builder.employeeTaxes with employeeTaxes.orElse(null).final Payment.BuilderemployeeTaxes(JsonField<Money> employeeTaxes)Sets Builder.employeeTaxes to an arbitrary JSON value. final Payment.BuilderemployerTaxes(Money employerTaxes)final Payment.BuilderemployerTaxes(Optional<Money> employerTaxes)Alias for calling Builder.employerTaxes with employerTaxes.orElse(null).final Payment.BuilderemployerTaxes(JsonField<Money> employerTaxes)Sets Builder.employerTaxes to an arbitrary JSON value. final Payment.BuildergrossPay(Money grossPay)final Payment.BuildergrossPay(Optional<Money> grossPay)Alias for calling Builder.grossPay with grossPay.orElse(null).final Payment.BuildergrossPay(JsonField<Money> grossPay)Sets Builder.grossPay to an arbitrary JSON value. final Payment.BuilderindividualIds(List<String> individualIds)Array of every individual on this payment. final Payment.BuilderindividualIds(Optional<List<String>> individualIds)Alias for calling Builder.individualIds with individualIds.orElse(null).final Payment.BuilderindividualIds(JsonField<List<String>> individualIds)Sets Builder.individualIds to an arbitrary JSON value. final Payment.BuilderaddIndividualId(String individualId)Adds a single String to individualIds. final Payment.BuildernetPay(Money netPay)final Payment.BuildernetPay(Optional<Money> netPay)Alias for calling Builder.netPay with netPay.orElse(null).final Payment.BuildernetPay(JsonField<Money> netPay)Sets Builder.netPay to an arbitrary JSON value. final Payment.BuilderpayDate(String payDate)final Payment.BuilderpayDate(Optional<String> payDate)Alias for calling Builder.payDate with payDate.orElse(null).final Payment.BuilderpayDate(JsonField<String> payDate)Sets Builder.payDate to an arbitrary JSON value. final Payment.BuilderpayFrequencies(List<Payment.PayFrequency> payFrequencies)List of pay frequencies associated with this payment. final Payment.BuilderpayFrequencies(Optional<List<Payment.PayFrequency>> payFrequencies)Alias for calling Builder.payFrequencies with payFrequencies.orElse(null).final Payment.BuilderpayFrequencies(JsonField<List<Payment.PayFrequency>> payFrequencies)Sets Builder.payFrequencies to an arbitrary JSON value. final Payment.BuilderaddPayFrequency(Payment.PayFrequency payFrequency)Adds a single PayFrequency to payFrequencies. final Payment.BuilderpayGroupIds(List<String> payGroupIds)Array of the Finch id (uuidv4) of every pay group associated with this payment. final Payment.BuilderpayGroupIds(Optional<List<String>> payGroupIds)Alias for calling Builder.payGroupIds with payGroupIds.orElse(null).final Payment.BuilderpayGroupIds(JsonField<List<String>> payGroupIds)Sets Builder.payGroupIds to an arbitrary JSON value. final Payment.BuilderaddPayGroupId(String payGroupId)Adds a single String to payGroupIds. final Payment.BuilderpayPeriod(Payment.PayPeriod payPeriod)The pay period object. final Payment.BuilderpayPeriod(Optional<Payment.PayPeriod> payPeriod)Alias for calling Builder.payPeriod with payPeriod.orElse(null).final Payment.BuilderpayPeriod(JsonField<Payment.PayPeriod> payPeriod)Sets Builder.payPeriod to an arbitrary JSON value. final Payment.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Payment.BuilderputAdditionalProperty(String key, JsonValue value)final Payment.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Payment.BuilderremoveAdditionalProperty(String key)final Payment.BuilderremoveAllAdditionalProperties(Set<String> keys)final Paymentbuild()Returns an immutable instance of Payment. -
-
Method Detail
-
id
final Payment.Builder id(String id)
The unique id for the payment.
-
id
final Payment.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
companyDebit
final Payment.Builder companyDebit(Money companyDebit)
-
companyDebit
final Payment.Builder companyDebit(Optional<Money> companyDebit)
Alias for calling Builder.companyDebit with
companyDebit.orElse(null).
-
companyDebit
final Payment.Builder companyDebit(JsonField<Money> companyDebit)
Sets Builder.companyDebit to an arbitrary JSON value.
You should usually call Builder.companyDebit with a well-typed Money value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debitDate
final Payment.Builder debitDate(String debitDate)
-
debitDate
final Payment.Builder debitDate(Optional<String> debitDate)
Alias for calling Builder.debitDate with
debitDate.orElse(null).
-
debitDate
final Payment.Builder debitDate(JsonField<String> debitDate)
Sets Builder.debitDate to an arbitrary JSON value.
You should usually call Builder.debitDate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
employeeTaxes
final Payment.Builder employeeTaxes(Money employeeTaxes)
-
employeeTaxes
final Payment.Builder employeeTaxes(Optional<Money> employeeTaxes)
Alias for calling Builder.employeeTaxes with
employeeTaxes.orElse(null).
-
employeeTaxes
final Payment.Builder employeeTaxes(JsonField<Money> employeeTaxes)
Sets Builder.employeeTaxes to an arbitrary JSON value.
You should usually call Builder.employeeTaxes with a well-typed Money value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
employerTaxes
final Payment.Builder employerTaxes(Money employerTaxes)
-
employerTaxes
final Payment.Builder employerTaxes(Optional<Money> employerTaxes)
Alias for calling Builder.employerTaxes with
employerTaxes.orElse(null).
-
employerTaxes
final Payment.Builder employerTaxes(JsonField<Money> employerTaxes)
Sets Builder.employerTaxes to an arbitrary JSON value.
You should usually call Builder.employerTaxes with a well-typed Money value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
grossPay
final Payment.Builder grossPay(Money grossPay)
-
grossPay
final Payment.Builder grossPay(Optional<Money> grossPay)
Alias for calling Builder.grossPay with
grossPay.orElse(null).
-
grossPay
final Payment.Builder grossPay(JsonField<Money> grossPay)
Sets Builder.grossPay to an arbitrary JSON value.
You should usually call Builder.grossPay with a well-typed Money value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
individualIds
final Payment.Builder individualIds(List<String> individualIds)
Array of every individual on this payment.
-
individualIds
final Payment.Builder individualIds(Optional<List<String>> individualIds)
Alias for calling Builder.individualIds with
individualIds.orElse(null).
-
individualIds
final Payment.Builder individualIds(JsonField<List<String>> individualIds)
Sets Builder.individualIds to an arbitrary JSON value.
You should usually call Builder.individualIds with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addIndividualId
final Payment.Builder addIndividualId(String individualId)
Adds a single String to individualIds.
-
netPay
final Payment.Builder netPay(Money netPay)
-
netPay
final Payment.Builder netPay(Optional<Money> netPay)
Alias for calling Builder.netPay with
netPay.orElse(null).
-
netPay
final Payment.Builder netPay(JsonField<Money> netPay)
Sets Builder.netPay to an arbitrary JSON value.
You should usually call Builder.netPay with a well-typed Money value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
payDate
final Payment.Builder payDate(String payDate)
-
payDate
final Payment.Builder payDate(Optional<String> payDate)
Alias for calling Builder.payDate with
payDate.orElse(null).
-
payDate
final Payment.Builder payDate(JsonField<String> payDate)
Sets Builder.payDate to an arbitrary JSON value.
You should usually call Builder.payDate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
payFrequencies
final Payment.Builder payFrequencies(List<Payment.PayFrequency> payFrequencies)
List of pay frequencies associated with this payment.
-
payFrequencies
final Payment.Builder payFrequencies(Optional<List<Payment.PayFrequency>> payFrequencies)
Alias for calling Builder.payFrequencies with
payFrequencies.orElse(null).
-
payFrequencies
final Payment.Builder payFrequencies(JsonField<List<Payment.PayFrequency>> payFrequencies)
Sets Builder.payFrequencies to an arbitrary JSON value.
You should usually call Builder.payFrequencies with a well-typed
List<PayFrequency>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addPayFrequency
final Payment.Builder addPayFrequency(Payment.PayFrequency payFrequency)
Adds a single PayFrequency to payFrequencies.
-
payGroupIds
final Payment.Builder payGroupIds(List<String> payGroupIds)
Array of the Finch id (uuidv4) of every pay group associated with this payment.
-
payGroupIds
final Payment.Builder payGroupIds(Optional<List<String>> payGroupIds)
Alias for calling Builder.payGroupIds with
payGroupIds.orElse(null).
-
payGroupIds
final Payment.Builder payGroupIds(JsonField<List<String>> payGroupIds)
Sets Builder.payGroupIds to an arbitrary JSON value.
You should usually call Builder.payGroupIds with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addPayGroupId
final Payment.Builder addPayGroupId(String payGroupId)
Adds a single String to payGroupIds.
-
payPeriod
final Payment.Builder payPeriod(Payment.PayPeriod payPeriod)
The pay period object.
-
payPeriod
final Payment.Builder payPeriod(Optional<Payment.PayPeriod> payPeriod)
Alias for calling Builder.payPeriod with
payPeriod.orElse(null).
-
payPeriod
final Payment.Builder payPeriod(JsonField<Payment.PayPeriod> payPeriod)
Sets Builder.payPeriod to an arbitrary JSON value.
You should usually call Builder.payPeriod with a well-typed PayPeriod value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Payment.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Payment.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Payment.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Payment.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Payment.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Payment build()
Returns an immutable instance of Payment.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .companyDebit() .debitDate() .employeeTaxes() .employerTaxes() .grossPay() .individualIds() .netPay() .payDate() .payFrequencies() .payGroupIds() .payPeriod()
-
-
-
-