Package com.tryfinch.api.models
Class PaymentCreateResponse
-
- All Implemented Interfaces:
public final class PaymentCreateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPaymentCreateResponse.BuilderA builder for PaymentCreateResponse.
-
Method Summary
Modifier and Type Method Description final StringpayDate()The date of the payment. final StringpaymentId()The ID of the payment. final JsonField<String>_payDate()Returns the raw JSON value of payDate. final JsonField<String>_paymentId()Returns the raw JSON value of paymentId. final Map<String, JsonValue>_additionalProperties()final PaymentCreateResponse.BuildertoBuilder()final PaymentCreateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PaymentCreateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of PaymentCreateResponse. -
-
Method Detail
-
_payDate
final JsonField<String> _payDate()
Returns the raw JSON value of payDate.
Unlike payDate, this method doesn't throw if the JSON field has an unexpected type.
-
_paymentId
final JsonField<String> _paymentId()
Returns the raw JSON value of paymentId.
Unlike paymentId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PaymentCreateResponse.Builder toBuilder()
-
validate
final PaymentCreateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PaymentCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of PaymentCreateResponse.
The following fields are required:
.payDate() .paymentId()
-
-
-
-