Package com.tryfinch.api.models
Class PaymentCreateResponse.Builder
-
- All Implemented Interfaces:
public final class PaymentCreateResponse.BuilderA builder for PaymentCreateResponse.
-
-
Method Summary
-
-
Method Detail
-
payDate
final PaymentCreateResponse.Builder payDate(String payDate)
The date of the payment.
-
payDate
final PaymentCreateResponse.Builder payDate(JsonField<String> payDate)
Sets Builder.payDate to an arbitrary JSON value.
You should usually call Builder.payDate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
paymentId
final PaymentCreateResponse.Builder paymentId(String paymentId)
The ID of the payment.
-
paymentId
final PaymentCreateResponse.Builder paymentId(JsonField<String> paymentId)
Sets Builder.paymentId to an arbitrary JSON value.
You should usually call Builder.paymentId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PaymentCreateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PaymentCreateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PaymentCreateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PaymentCreateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PaymentCreateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PaymentCreateResponse build()
Returns an immutable instance of PaymentCreateResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.payDate() .paymentId()
-
-
-
-