Package com.tryfinch.api.models
Class PaymentEvent.PaymentIdentifiers
-
- All Implemented Interfaces:
public final class PaymentEvent.PaymentIdentifiers
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPaymentEvent.PaymentIdentifiers.BuilderA builder for PaymentIdentifiers.
-
Method Summary
Modifier and Type Method Description final StringpayDate()The date of the payment. final StringpaymentId()The ID of the payment. final JsonField<String>_payDate()Returns the raw JSON value of payDate. final JsonField<String>_paymentId()Returns the raw JSON value of paymentId. final Map<String, JsonValue>_additionalProperties()final PaymentEvent.PaymentIdentifiers.BuildertoBuilder()final PaymentEvent.PaymentIdentifiersvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PaymentEvent.PaymentIdentifiers.Builderbuilder()Returns a mutable builder for constructing an instance of PaymentIdentifiers. -
-
Method Detail
-
_payDate
final JsonField<String> _payDate()
Returns the raw JSON value of payDate.
Unlike payDate, this method doesn't throw if the JSON field has an unexpected type.
-
_paymentId
final JsonField<String> _paymentId()
Returns the raw JSON value of paymentId.
Unlike paymentId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PaymentEvent.PaymentIdentifiers.Builder toBuilder()
-
validate
final PaymentEvent.PaymentIdentifiers validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PaymentEvent.PaymentIdentifiers.Builder builder()
Returns a mutable builder for constructing an instance of PaymentIdentifiers.
The following fields are required:
.payDate() .paymentId()
-
-
-
-