Package com.tryfinch.api.models
Class PayrollPayGroupListPage
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Page
public final class PayrollPayGroupListPage implements Page<PayGroupListResponse>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayrollPayGroupListPage.BuilderA builder for PayrollPayGroupListPage.
-
Method Summary
Modifier and Type Method Description BooleanhasNextPage()Returns whether there's another page after this one. final PayrollPayGroupListParamsnextPageParams()PayrollPayGroupListPagenextPage()Returns the page after this one by making another request. final AutoPager<PayGroupListResponse>autoPager()final PayrollPayGroupListParamsparams()The parameters that were used to request this page. List<PayGroupListResponse>items()The response that this page was parsed from. final PayrollPayGroupListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PayrollPayGroupListPage.Builderbuilder()Returns a mutable builder for constructing an instance of PayrollPayGroupListPage. -
-
Method Detail
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final PayrollPayGroupListParams nextPageParams()
-
nextPage
PayrollPayGroupListPage nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPager<PayGroupListResponse> autoPager()
-
params
final PayrollPayGroupListParams params()
The parameters that were used to request this page.
-
items
List<PayGroupListResponse> items()
The response that this page was parsed from.
-
toBuilder
final PayrollPayGroupListPage.Builder toBuilder()
-
builder
final static PayrollPayGroupListPage.Builder builder()
Returns a mutable builder for constructing an instance of PayrollPayGroupListPage.
The following fields are required:
.service() .params() .items()
-
-
-
-