Package com.tryfinch.api.models
Class PayrollPayGroupListPageAsync
-
- All Implemented Interfaces:
public final class PayrollPayGroupListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayrollPayGroupListPageAsync.BuilderA builder for PayrollPayGroupListPageAsync.
public final classPayrollPayGroupListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final BooleanhasNextPage()final Optional<PayrollPayGroupListParams>getNextPageParams()final CompletableFuture<Optional<PayrollPayGroupListPageAsync>>getNextPage()final PayrollPayGroupListPageAsync.AutoPagerautoPager()final PayrollPayGroupListParamsparams()The parameters that were used to request this page. final List<PayGroupListResponse>items()The response that this page was parsed from. final PayrollPayGroupListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PayrollPayGroupListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of PayrollPayGroupListPageAsync. -
-
Method Detail
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<PayrollPayGroupListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<PayrollPayGroupListPageAsync>> getNextPage()
-
autoPager
final PayrollPayGroupListPageAsync.AutoPager autoPager()
-
params
final PayrollPayGroupListParams params()
The parameters that were used to request this page.
-
items
final List<PayGroupListResponse> items()
The response that this page was parsed from.
-
toBuilder
final PayrollPayGroupListPageAsync.Builder toBuilder()
-
builder
final static PayrollPayGroupListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of PayrollPayGroupListPageAsync.
The following fields are required:
.service() .params() .items()
-
-
-
-