Package com.tryfinch.api.models
Class PayrollPayGroupRetrieveParams
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Params
public final class PayrollPayGroupRetrieveParams implements Params
Read information from a single pay group
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayrollPayGroupRetrieveParams.BuilderA builder for PayrollPayGroupRetrieveParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>payGroupId()final Optional<List<String>>entityIds()The entity IDs to specify which entities' data to access. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final PayrollPayGroupRetrieveParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static PayrollPayGroupRetrieveParamsnone()final static PayrollPayGroupRetrieveParams.Builderbuilder()Returns a mutable builder for constructing an instance of PayrollPayGroupRetrieveParams. -
-
Method Detail
-
payGroupId
final Optional<String> payGroupId()
-
entityIds
final Optional<List<String>> entityIds()
The entity IDs to specify which entities' data to access.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final PayrollPayGroupRetrieveParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static PayrollPayGroupRetrieveParams none()
-
builder
final static PayrollPayGroupRetrieveParams.Builder builder()
Returns a mutable builder for constructing an instance of PayrollPayGroupRetrieveParams.
-
-
-
-