Class Provider.AuthenticationMethod
-
- All Implemented Interfaces:
public final class Provider.AuthenticationMethod
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProvider.AuthenticationMethod.BuilderA builder for AuthenticationMethod.
public final classProvider.AuthenticationMethod.TypeThe type of authentication method
public final classProvider.AuthenticationMethod.BenefitsSupportThe supported benefit types and their configurations
public final classProvider.AuthenticationMethod.SupportedFieldsThe supported fields for each Finch product
-
Method Summary
-
-
Method Detail
-
type
final Provider.AuthenticationMethod.Type type()
The type of authentication method
-
benefitsSupport
final Optional<Provider.AuthenticationMethod.BenefitsSupport> benefitsSupport()
The supported benefit types and their configurations
-
supportedFields
final Optional<Provider.AuthenticationMethod.SupportedFields> supportedFields()
The supported fields for each Finch product
-
_type
final JsonField<Provider.AuthenticationMethod.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_benefitsSupport
final JsonField<Provider.AuthenticationMethod.BenefitsSupport> _benefitsSupport()
Returns the raw JSON value of benefitsSupport.
Unlike benefitsSupport, this method doesn't throw if the JSON field has an unexpected type.
-
_supportedFields
final JsonField<Provider.AuthenticationMethod.SupportedFields> _supportedFields()
Returns the raw JSON value of supportedFields.
Unlike supportedFields, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Provider.AuthenticationMethod.Builder toBuilder()
-
validate
final Provider.AuthenticationMethod validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Provider.AuthenticationMethod.Builder builder()
Returns a mutable builder for constructing an instance of AuthenticationMethod.
The following fields are required:
.type()
-
-
-
-