Class Provider.AuthenticationMethod.Builder
-
- All Implemented Interfaces:
public final class Provider.AuthenticationMethod.BuilderA builder for AuthenticationMethod.
-
-
Method Summary
-
-
Method Detail
-
type
final Provider.AuthenticationMethod.Builder type(Provider.AuthenticationMethod.Type type)
The type of authentication method
-
type
final Provider.AuthenticationMethod.Builder type(JsonField<Provider.AuthenticationMethod.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
benefitsSupport
final Provider.AuthenticationMethod.Builder benefitsSupport(Provider.AuthenticationMethod.BenefitsSupport benefitsSupport)
The supported benefit types and their configurations
-
benefitsSupport
final Provider.AuthenticationMethod.Builder benefitsSupport(JsonField<Provider.AuthenticationMethod.BenefitsSupport> benefitsSupport)
Sets Builder.benefitsSupport to an arbitrary JSON value.
You should usually call Builder.benefitsSupport with a well-typed BenefitsSupport value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
supportedFields
final Provider.AuthenticationMethod.Builder supportedFields(Provider.AuthenticationMethod.SupportedFields supportedFields)
The supported fields for each Finch product
-
supportedFields
final Provider.AuthenticationMethod.Builder supportedFields(JsonField<Provider.AuthenticationMethod.SupportedFields> supportedFields)
Sets Builder.supportedFields to an arbitrary JSON value.
You should usually call Builder.supportedFields with a well-typed SupportedFields value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Provider.AuthenticationMethod.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Provider.AuthenticationMethod.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Provider.AuthenticationMethod.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Provider.AuthenticationMethod.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Provider.AuthenticationMethod.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Provider.AuthenticationMethod build()
Returns an immutable instance of AuthenticationMethod.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.type()
-
-
-
-