Class Provider.AuthenticationMethod.SupportedFields
-
- All Implemented Interfaces:
public final class Provider.AuthenticationMethod.SupportedFieldsThe supported data fields returned by our HR and payroll endpoints
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProvider.AuthenticationMethod.SupportedFields.BuilderA builder for SupportedFields.
public final classProvider.AuthenticationMethod.SupportedFields.SupportedCompanyFieldspublic final classProvider.AuthenticationMethod.SupportedFields.SupportedDirectoryFieldspublic final classProvider.AuthenticationMethod.SupportedFields.SupportedEmploymentFieldspublic final classProvider.AuthenticationMethod.SupportedFields.SupportedIndividualFieldspublic final classProvider.AuthenticationMethod.SupportedFields.SupportedPayGroupFieldspublic final classProvider.AuthenticationMethod.SupportedFields.SupportedPayStatementFieldspublic final classProvider.AuthenticationMethod.SupportedFields.SupportedPaymentFields
-
Method Summary
-
-
Method Detail
-
company
final Optional<Provider.AuthenticationMethod.SupportedFields.SupportedCompanyFields> company()
-
directory
final Optional<Provider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields> directory()
-
employment
final Optional<Provider.AuthenticationMethod.SupportedFields.SupportedEmploymentFields> employment()
-
individual
final Optional<Provider.AuthenticationMethod.SupportedFields.SupportedIndividualFields> individual()
-
payGroup
final Optional<Provider.AuthenticationMethod.SupportedFields.SupportedPayGroupFields> payGroup()
-
payStatement
final Optional<Provider.AuthenticationMethod.SupportedFields.SupportedPayStatementFields> payStatement()
-
payment
final Optional<Provider.AuthenticationMethod.SupportedFields.SupportedPaymentFields> payment()
-
_company
final JsonField<Provider.AuthenticationMethod.SupportedFields.SupportedCompanyFields> _company()
Returns the raw JSON value of company.
Unlike company, this method doesn't throw if the JSON field has an unexpected type.
-
_directory
final JsonField<Provider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields> _directory()
Returns the raw JSON value of directory.
Unlike directory, this method doesn't throw if the JSON field has an unexpected type.
-
_employment
final JsonField<Provider.AuthenticationMethod.SupportedFields.SupportedEmploymentFields> _employment()
Returns the raw JSON value of employment.
Unlike employment, this method doesn't throw if the JSON field has an unexpected type.
-
_individual
final JsonField<Provider.AuthenticationMethod.SupportedFields.SupportedIndividualFields> _individual()
Returns the raw JSON value of individual.
Unlike individual, this method doesn't throw if the JSON field has an unexpected type.
-
_payGroup
final JsonField<Provider.AuthenticationMethod.SupportedFields.SupportedPayGroupFields> _payGroup()
Returns the raw JSON value of payGroup.
Unlike payGroup, this method doesn't throw if the JSON field has an unexpected type.
-
_payStatement
final JsonField<Provider.AuthenticationMethod.SupportedFields.SupportedPayStatementFields> _payStatement()
Returns the raw JSON value of payStatement.
Unlike payStatement, this method doesn't throw if the JSON field has an unexpected type.
-
_payment
final JsonField<Provider.AuthenticationMethod.SupportedFields.SupportedPaymentFields> _payment()
Returns the raw JSON value of payment.
Unlike payment, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Provider.AuthenticationMethod.SupportedFields.Builder toBuilder()
-
validate
final Provider.AuthenticationMethod.SupportedFields validate()
-
builder
final static Provider.AuthenticationMethod.SupportedFields.Builder builder()
Returns a mutable builder for constructing an instance of SupportedFields.
-
-
-
-