Package com.tryfinch.api.models
Class Provider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields
-
- All Implemented Interfaces:
public final class Provider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProvider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.BuilderA builder for SupportedDirectoryFields.
public final classProvider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individualspublic final classProvider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Paging
-
Method Summary
-
-
Method Detail
-
individuals
final Optional<Provider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals> individuals()
-
paging
final Optional<Provider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Paging> paging()
-
_individuals
final JsonField<Provider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals> _individuals()
Returns the raw JSON value of individuals.
Unlike individuals, this method doesn't throw if the JSON field has an unexpected type.
-
_paging
final JsonField<Provider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Paging> _paging()
Returns the raw JSON value of paging.
Unlike paging, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Provider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Builder toBuilder()
-
builder
final static Provider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Builder builder()
Returns a mutable builder for constructing an instance of SupportedDirectoryFields.
-
-
-
-