Package com.tryfinch.api.models
Class Provider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Builder
-
- All Implemented Interfaces:
public final class Provider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.BuilderA builder for SupportedDirectoryFields.
-
-
Method Summary
-
-
Method Detail
-
individuals
final Provider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Builder individuals(Provider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals individuals)
-
individuals
final Provider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Builder individuals(JsonField<Provider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Individuals> individuals)
Sets Builder.individuals to an arbitrary JSON value.
You should usually call Builder.individuals with a well-typed Individuals value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
paging
final Provider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Builder paging(Provider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Paging paging)
-
paging
final Provider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Builder paging(JsonField<Provider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Paging> paging)
Sets Builder.paging to an arbitrary JSON value.
You should usually call Builder.paging with a well-typed Paging value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Provider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Provider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Provider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Provider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Provider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Provider.AuthenticationMethod.SupportedFields.SupportedDirectoryFields build()
Returns an immutable instance of SupportedDirectoryFields.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-