Package com.tryfinch.api.models
Class Provider.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Department
-
- All Implemented Interfaces:
public final class Provider.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Department
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProvider.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Department.BuilderA builder for Department.
-
Method Summary
Modifier and Type Method Description final Optional<Boolean>name()final JsonField<Boolean>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final Provider.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Department.BuildertoBuilder()final Provider.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Departmentvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Provider.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Department.Builderbuilder()Returns a mutable builder for constructing an instance of Department. -
-
Method Detail
-
_name
final JsonField<Boolean> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Provider.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Department.Builder toBuilder()
-
validate
final Provider.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Department validate()
-
builder
final static Provider.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Department.Builder builder()
Returns a mutable builder for constructing an instance of Department.
-
-
-
-