Class Provider.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Location
-
- All Implemented Interfaces:
public final class Provider.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Location
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProvider.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Location.BuilderA builder for Location.
-
Method Summary
-
-
Method Detail
-
postalCode
final Optional<Boolean> postalCode()
-
_city
final JsonField<Boolean> _city()
Returns the raw JSON value of city.
Unlike city, this method doesn't throw if the JSON field has an unexpected type.
-
_country
final JsonField<Boolean> _country()
Returns the raw JSON value of country.
Unlike country, this method doesn't throw if the JSON field has an unexpected type.
-
_line1
final JsonField<Boolean> _line1()
Returns the raw JSON value of line1.
Unlike line1, this method doesn't throw if the JSON field has an unexpected type.
-
_line2
final JsonField<Boolean> _line2()
Returns the raw JSON value of line2.
Unlike line2, this method doesn't throw if the JSON field has an unexpected type.
-
_postalCode
final JsonField<Boolean> _postalCode()
Returns the raw JSON value of postalCode.
Unlike postalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<Boolean> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Provider.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Location.Builder toBuilder()
-
validate
final Provider.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Location validate()
-
builder
final static Provider.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Location.Builder builder()
Returns a mutable builder for constructing an instance of Location.
-
-
-
-