Package com.tryfinch.api.models
Class Provider.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Manager
-
- All Implemented Interfaces:
public final class Provider.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Manager
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProvider.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Manager.BuilderA builder for Manager.
-
Method Summary
Modifier and Type Method Description final Optional<Boolean>id()final JsonField<Boolean>_id()Returns the raw JSON value of id. final Map<String, JsonValue>_additionalProperties()final Provider.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Manager.BuildertoBuilder()final Provider.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Managervalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Provider.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Manager.Builderbuilder()Returns a mutable builder for constructing an instance of Manager. -
-
Method Detail
-
_id
final JsonField<Boolean> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Provider.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Manager.Builder toBuilder()
-
validate
final Provider.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Manager validate()
-
builder
final static Provider.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Manager.Builder builder()
Returns a mutable builder for constructing an instance of Manager.
-
-
-
-