Package com.tryfinch.api.models
Class Provider.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers
-
- All Implemented Interfaces:
public final class Provider.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProvider.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers.BuilderA builder for PhoneNumbers.
-
Method Summary
Modifier and Type Method Description final Optional<Boolean>data()final Optional<Boolean>type()final JsonField<Boolean>_data()Returns the raw JSON value of data. final JsonField<Boolean>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final Provider.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers.BuildertoBuilder()final Provider.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbersvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Provider.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers.Builderbuilder()Returns a mutable builder for constructing an instance of PhoneNumbers. -
-
Method Detail
-
_data
final JsonField<Boolean> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<Boolean> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Provider.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers.Builder toBuilder()
-
validate
final Provider.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers validate()
-
builder
final static Provider.AuthenticationMethod.SupportedFields.SupportedIndividualFields.PhoneNumbers.Builder builder()
Returns a mutable builder for constructing an instance of PhoneNumbers.
-
-
-
-