Package com.tryfinch.api.models
Class Provider.AuthenticationMethod.SupportedFields.SupportedPayGroupFields
-
- All Implemented Interfaces:
public final class Provider.AuthenticationMethod.SupportedFields.SupportedPayGroupFields
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProvider.AuthenticationMethod.SupportedFields.SupportedPayGroupFields.BuilderA builder for SupportedPayGroupFields.
-
Method Summary
Modifier and Type Method Description final Optional<Boolean>id()final Optional<Boolean>individualIds()final Optional<Boolean>name()final Optional<Boolean>payFrequencies()final JsonField<Boolean>_id()Returns the raw JSON value of id. final JsonField<Boolean>_individualIds()Returns the raw JSON value of individualIds. final JsonField<Boolean>_name()Returns the raw JSON value of name. final JsonField<Boolean>_payFrequencies()Returns the raw JSON value of payFrequencies. final Map<String, JsonValue>_additionalProperties()final Provider.AuthenticationMethod.SupportedFields.SupportedPayGroupFields.BuildertoBuilder()final Provider.AuthenticationMethod.SupportedFields.SupportedPayGroupFieldsvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Provider.AuthenticationMethod.SupportedFields.SupportedPayGroupFields.Builderbuilder()Returns a mutable builder for constructing an instance of SupportedPayGroupFields. -
-
Method Detail
-
individualIds
final Optional<Boolean> individualIds()
-
payFrequencies
final Optional<Boolean> payFrequencies()
-
_id
final JsonField<Boolean> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_individualIds
final JsonField<Boolean> _individualIds()
Returns the raw JSON value of individualIds.
Unlike individualIds, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<Boolean> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_payFrequencies
final JsonField<Boolean> _payFrequencies()
Returns the raw JSON value of payFrequencies.
Unlike payFrequencies, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Provider.AuthenticationMethod.SupportedFields.SupportedPayGroupFields.Builder toBuilder()
-
builder
final static Provider.AuthenticationMethod.SupportedFields.SupportedPayGroupFields.Builder builder()
Returns a mutable builder for constructing an instance of SupportedPayGroupFields.
-
-
-
-