Class Provider.Builder
-
- All Implemented Interfaces:
public final class Provider.BuilderA builder for Provider.
-
-
Method Summary
Modifier and Type Method Description final Provider.Builderid(String id)The id of the payroll provider used in Connect. final Provider.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final Provider.BuilderdisplayName(String displayName)The display name of the payroll provider. final Provider.BuilderdisplayName(JsonField<String> displayName)Sets Builder.displayName to an arbitrary JSON value. final Provider.Builderproducts(List<String> products)The list of Finch products supported on this payroll provider. final Provider.Builderproducts(JsonField<List<String>> products)Sets Builder.products to an arbitrary JSON value. final Provider.BuilderaddProduct(String product)Adds a single String to products. final Provider.BuilderauthenticationMethods(List<Provider.AuthenticationMethod> authenticationMethods)The authentication methods supported by the provider. final Provider.BuilderauthenticationMethods(JsonField<List<Provider.AuthenticationMethod>> authenticationMethods)Sets Builder.authenticationMethods to an arbitrary JSON value. final Provider.BuilderaddAuthenticationMethod(Provider.AuthenticationMethod authenticationMethod)Adds a single AuthenticationMethod to authenticationMethods. final Provider.Builderbeta(Boolean beta)trueif the integration is in a beta state,falseotherwisefinal Provider.Builderbeta(JsonField<Boolean> beta)Sets Builder.beta to an arbitrary JSON value. final Provider.Buildericon(String icon)The url to the official icon of the payroll provider. final Provider.Buildericon(JsonField<String> icon)Sets Builder.icon to an arbitrary JSON value. final Provider.Builderlogo(String logo)The url to the official logo of the payroll provider. final Provider.Builderlogo(JsonField<String> logo)Sets Builder.logo to an arbitrary JSON value. final Provider.Buildermanual(Boolean manual)DEPRECATED Whether the Finch integration with this provider uses the Assisted Connect Flow by default. final Provider.Buildermanual(JsonField<Boolean> manual)Sets Builder.manual to an arbitrary JSON value. final Provider.BuildermfaRequired(Boolean mfaRequired)whether MFA is required for the provider. final Provider.BuildermfaRequired(JsonField<Boolean> mfaRequired)Sets Builder.mfaRequired to an arbitrary JSON value. final Provider.BuilderprimaryColor(String primaryColor)The hex code for the primary color of the payroll provider. final Provider.BuilderprimaryColor(JsonField<String> primaryColor)Sets Builder.primaryColor to an arbitrary JSON value. final Provider.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Provider.BuilderputAdditionalProperty(String key, JsonValue value)final Provider.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Provider.BuilderremoveAdditionalProperty(String key)final Provider.BuilderremoveAllAdditionalProperties(Set<String> keys)final Providerbuild()Returns an immutable instance of Provider. -
-
Method Detail
-
id
final Provider.Builder id(String id)
The id of the payroll provider used in Connect.
-
id
final Provider.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
displayName
final Provider.Builder displayName(String displayName)
The display name of the payroll provider.
-
displayName
final Provider.Builder displayName(JsonField<String> displayName)
Sets Builder.displayName to an arbitrary JSON value.
You should usually call Builder.displayName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
products
final Provider.Builder products(List<String> products)
The list of Finch products supported on this payroll provider.
-
products
final Provider.Builder products(JsonField<List<String>> products)
Sets Builder.products to an arbitrary JSON value.
You should usually call Builder.products with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addProduct
final Provider.Builder addProduct(String product)
-
authenticationMethods
final Provider.Builder authenticationMethods(List<Provider.AuthenticationMethod> authenticationMethods)
The authentication methods supported by the provider.
-
authenticationMethods
final Provider.Builder authenticationMethods(JsonField<List<Provider.AuthenticationMethod>> authenticationMethods)
Sets Builder.authenticationMethods to an arbitrary JSON value.
You should usually call Builder.authenticationMethods with a well-typed
List<AuthenticationMethod>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addAuthenticationMethod
final Provider.Builder addAuthenticationMethod(Provider.AuthenticationMethod authenticationMethod)
Adds a single AuthenticationMethod to authenticationMethods.
-
beta
final Provider.Builder beta(Boolean beta)
trueif the integration is in a beta state,falseotherwise
-
beta
final Provider.Builder beta(JsonField<Boolean> beta)
Sets Builder.beta to an arbitrary JSON value.
You should usually call Builder.beta with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
icon
final Provider.Builder icon(String icon)
The url to the official icon of the payroll provider.
-
icon
final Provider.Builder icon(JsonField<String> icon)
Sets Builder.icon to an arbitrary JSON value.
You should usually call Builder.icon with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
logo
final Provider.Builder logo(String logo)
The url to the official logo of the payroll provider.
-
logo
final Provider.Builder logo(JsonField<String> logo)
Sets Builder.logo to an arbitrary JSON value.
You should usually call Builder.logo with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
manual
@Deprecated(message = "deprecated") final Provider.Builder manual(Boolean manual)
DEPRECATED Whether the Finch integration with this provider uses the Assisted Connect Flow by default. This field is now deprecated. Please check for a
typeofassistedin theauthentication_methodsfield instead.
-
manual
@Deprecated(message = "deprecated") final Provider.Builder manual(JsonField<Boolean> manual)
Sets Builder.manual to an arbitrary JSON value.
You should usually call Builder.manual with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
mfaRequired
final Provider.Builder mfaRequired(Boolean mfaRequired)
whether MFA is required for the provider.
-
mfaRequired
final Provider.Builder mfaRequired(JsonField<Boolean> mfaRequired)
Sets Builder.mfaRequired to an arbitrary JSON value.
You should usually call Builder.mfaRequired with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
primaryColor
final Provider.Builder primaryColor(String primaryColor)
The hex code for the primary color of the payroll provider.
-
primaryColor
final Provider.Builder primaryColor(JsonField<String> primaryColor)
Sets Builder.primaryColor to an arbitrary JSON value.
You should usually call Builder.primaryColor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Provider.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Provider.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Provider.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Provider.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Provider.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-