Package com.tryfinch.api.models
Class ProviderListPage
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Page
public final class ProviderListPage implements Page<ProviderListResponse>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProviderListPage.BuilderA builder for ProviderListPage.
-
Method Summary
Modifier and Type Method Description BooleanhasNextPage()Returns whether there's another page after this one. final ProviderListParamsnextPageParams()ProviderListPagenextPage()Returns the page after this one by making another request. final AutoPager<ProviderListResponse>autoPager()final ProviderListParamsparams()The parameters that were used to request this page. List<ProviderListResponse>items()The response that this page was parsed from. final ProviderListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProviderListPage.Builderbuilder()Returns a mutable builder for constructing an instance of ProviderListPage. -
-
Method Detail
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final ProviderListParams nextPageParams()
-
nextPage
ProviderListPage nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPager<ProviderListResponse> autoPager()
-
params
final ProviderListParams params()
The parameters that were used to request this page.
-
items
List<ProviderListResponse> items()
The response that this page was parsed from.
-
toBuilder
final ProviderListPage.Builder toBuilder()
-
builder
final static ProviderListPage.Builder builder()
Returns a mutable builder for constructing an instance of ProviderListPage.
The following fields are required:
.service() .params() .items()
-
-
-
-