Package com.tryfinch.api.models
Class ProviderListPageAsync
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.PageAsync
public final class ProviderListPageAsync implements PageAsync<ProviderListResponse>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProviderListPageAsync.BuilderA builder for ProviderListPageAsync.
-
Method Summary
Modifier and Type Method Description BooleanhasNextPage()Returns whether there's another page after this one. final ProviderListParamsnextPageParams()CompletableFuture<ProviderListPageAsync>nextPage()Returns the page after this one by making another request. final AutoPagerAsync<ProviderListResponse>autoPager()final ProviderListParamsparams()The parameters that were used to request this page. List<ProviderListResponse>items()The response that this page was parsed from. final ProviderListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProviderListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of ProviderListPageAsync. -
-
Method Detail
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final ProviderListParams nextPageParams()
-
nextPage
CompletableFuture<ProviderListPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<ProviderListResponse> autoPager()
-
params
final ProviderListParams params()
The parameters that were used to request this page.
-
items
List<ProviderListResponse> items()
The response that this page was parsed from.
-
toBuilder
final ProviderListPageAsync.Builder toBuilder()
-
builder
final static ProviderListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of ProviderListPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .items()
-
-
-
-