Package com.tryfinch.api.models
Class ProviderListPageAsync.Builder
-
- All Implemented Interfaces:
public final class ProviderListPageAsync.BuilderA builder for ProviderListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final ProviderListPageAsync.Builderservice(ProviderServiceAsync service)final ProviderListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final ProviderListPageAsync.Builderparams(ProviderListParams params)The parameters that were used to request this page. final ProviderListPageAsync.Builderitems(List<ProviderListResponse> items)The response that this page was parsed from. final ProviderListPageAsyncbuild()Returns an immutable instance of ProviderListPageAsync. -
-
Method Detail
-
service
final ProviderListPageAsync.Builder service(ProviderServiceAsync service)
-
streamHandlerExecutor
final ProviderListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final ProviderListPageAsync.Builder params(ProviderListParams params)
The parameters that were used to request this page.
-
items
final ProviderListPageAsync.Builder items(List<ProviderListResponse> items)
The response that this page was parsed from.
-
build
final ProviderListPageAsync build()
Returns an immutable instance of ProviderListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .items()
-
-
-
-