Class ProviderListResponse
-
- All Implemented Interfaces:
public final class ProviderListResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProviderListResponse.BuilderA builder for ProviderListResponse.
public final classProviderListResponse.AuthenticationMethod
-
Method Summary
Modifier and Type Method Description final Stringid()The id of the payroll provider used in Connect. final StringdisplayName()The display name of the payroll provider. final List<String>products()The list of Finch products supported on this payroll provider. final Optional<List<ProviderListResponse.AuthenticationMethod>>authenticationMethods()The authentication methods supported by the provider. final Optional<Boolean>beta()trueif the integration is in a beta state,falseotherwisefinal Optional<String>icon()The url to the official icon of the payroll provider. final Optional<String>logo()The url to the official logo of the payroll provider. final Optional<Boolean>manual()DEPRECATED Whether the Finch integration with this provider uses the Assisted Connect Flow by default. final Optional<Boolean>mfaRequired()whether MFA is required for the provider. final Optional<String>primaryColor()The hex code for the primary color of the payroll provider. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_displayName()Returns the raw JSON value of displayName. final JsonField<List<String>>_products()Returns the raw JSON value of products. final JsonField<List<ProviderListResponse.AuthenticationMethod>>_authenticationMethods()Returns the raw JSON value of authenticationMethods. final JsonField<Boolean>_beta()Returns the raw JSON value of beta. final JsonField<String>_icon()Returns the raw JSON value of icon. final JsonField<String>_logo()Returns the raw JSON value of logo. final JsonField<Boolean>_manual()Returns the raw JSON value of manual. final JsonField<Boolean>_mfaRequired()Returns the raw JSON value of mfaRequired. final JsonField<String>_primaryColor()Returns the raw JSON value of primaryColor. final Map<String, JsonValue>_additionalProperties()final ProviderListResponse.BuildertoBuilder()final ProviderListResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProviderListResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ProviderListResponse. -
-
Method Detail
-
displayName
final String displayName()
The display name of the payroll provider.
-
products
final List<String> products()
The list of Finch products supported on this payroll provider.
-
authenticationMethods
final Optional<List<ProviderListResponse.AuthenticationMethod>> authenticationMethods()
The authentication methods supported by the provider.
-
manual
@Deprecated(message = "deprecated") final Optional<Boolean> manual()
DEPRECATED Whether the Finch integration with this provider uses the Assisted Connect Flow by default. This field is now deprecated. Please check for a
typeofassistedin theauthentication_methodsfield instead.
-
mfaRequired
final Optional<Boolean> mfaRequired()
whether MFA is required for the provider.
-
primaryColor
final Optional<String> primaryColor()
The hex code for the primary color of the payroll provider.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_displayName
final JsonField<String> _displayName()
Returns the raw JSON value of displayName.
Unlike displayName, this method doesn't throw if the JSON field has an unexpected type.
-
_products
final JsonField<List<String>> _products()
Returns the raw JSON value of products.
Unlike products, this method doesn't throw if the JSON field has an unexpected type.
-
_authenticationMethods
final JsonField<List<ProviderListResponse.AuthenticationMethod>> _authenticationMethods()
Returns the raw JSON value of authenticationMethods.
Unlike authenticationMethods, this method doesn't throw if the JSON field has an unexpected type.
-
_beta
final JsonField<Boolean> _beta()
Returns the raw JSON value of beta.
Unlike beta, this method doesn't throw if the JSON field has an unexpected type.
-
_icon
final JsonField<String> _icon()
Returns the raw JSON value of icon.
Unlike icon, this method doesn't throw if the JSON field has an unexpected type.
-
_logo
final JsonField<String> _logo()
Returns the raw JSON value of logo.
Unlike logo, this method doesn't throw if the JSON field has an unexpected type.
-
_manual
@Deprecated(message = "deprecated") final JsonField<Boolean> _manual()
Returns the raw JSON value of manual.
Unlike manual, this method doesn't throw if the JSON field has an unexpected type.
-
_mfaRequired
final JsonField<Boolean> _mfaRequired()
Returns the raw JSON value of mfaRequired.
Unlike mfaRequired, this method doesn't throw if the JSON field has an unexpected type.
-
_primaryColor
final JsonField<String> _primaryColor()
Returns the raw JSON value of primaryColor.
Unlike primaryColor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProviderListResponse.Builder toBuilder()
-
validate
final ProviderListResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ProviderListResponse.Builder builder()
Returns a mutable builder for constructing an instance of ProviderListResponse.
The following fields are required:
.id() .displayName() .products()
-
-
-
-