Class ProviderListResponse.AuthenticationMethod.Builder
-
- All Implemented Interfaces:
public final class ProviderListResponse.AuthenticationMethod.BuilderA builder for AuthenticationMethod.
-
-
Method Summary
-
-
Method Detail
-
type
final ProviderListResponse.AuthenticationMethod.Builder type(ProviderListResponse.AuthenticationMethod.Type type)
The type of authentication method
-
type
final ProviderListResponse.AuthenticationMethod.Builder type(JsonField<ProviderListResponse.AuthenticationMethod.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
benefitsSupport
final ProviderListResponse.AuthenticationMethod.Builder benefitsSupport(ProviderListResponse.AuthenticationMethod.BenefitsSupport benefitsSupport)
The supported benefit types and their configurations
-
benefitsSupport
final ProviderListResponse.AuthenticationMethod.Builder benefitsSupport(JsonField<ProviderListResponse.AuthenticationMethod.BenefitsSupport> benefitsSupport)
Sets Builder.benefitsSupport to an arbitrary JSON value.
You should usually call Builder.benefitsSupport with a well-typed BenefitsSupport value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
supportedFields
final ProviderListResponse.AuthenticationMethod.Builder supportedFields(ProviderListResponse.AuthenticationMethod.SupportedFields supportedFields)
The supported fields for each Finch product
-
supportedFields
final ProviderListResponse.AuthenticationMethod.Builder supportedFields(JsonField<ProviderListResponse.AuthenticationMethod.SupportedFields> supportedFields)
Sets Builder.supportedFields to an arbitrary JSON value.
You should usually call Builder.supportedFields with a well-typed SupportedFields value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ProviderListResponse.AuthenticationMethod.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ProviderListResponse.AuthenticationMethod.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ProviderListResponse.AuthenticationMethod.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ProviderListResponse.AuthenticationMethod.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ProviderListResponse.AuthenticationMethod.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ProviderListResponse.AuthenticationMethod build()
Returns an immutable instance of AuthenticationMethod.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.type()
-
-
-
-