Package com.tryfinch.api.models
Class ProviderListResponse.AuthenticationMethod.SupportedFields
-
- All Implemented Interfaces:
public final class ProviderListResponse.AuthenticationMethod.SupportedFieldsThe supported fields for each Finch product
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProviderListResponse.AuthenticationMethod.SupportedFields.BuilderA builder for SupportedFields.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final ProviderListResponse.AuthenticationMethod.SupportedFields.BuildertoBuilder()final ProviderListResponse.AuthenticationMethod.SupportedFieldsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProviderListResponse.AuthenticationMethod.SupportedFields.Builderbuilder()Returns a mutable builder for constructing an instance of SupportedFields. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProviderListResponse.AuthenticationMethod.SupportedFields.Builder toBuilder()
-
validate
final ProviderListResponse.AuthenticationMethod.SupportedFields validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ProviderListResponse.AuthenticationMethod.SupportedFields.Builder builder()
Returns a mutable builder for constructing an instance of SupportedFields.
-
-
-
-