Class ProviderListResponse.Builder
-
- All Implemented Interfaces:
public final class ProviderListResponse.BuilderA builder for ProviderListResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final ProviderListResponse.Builder id(String id)
The id of the payroll provider used in Connect.
-
id
final ProviderListResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
displayName
final ProviderListResponse.Builder displayName(String displayName)
The display name of the payroll provider.
-
displayName
final ProviderListResponse.Builder displayName(JsonField<String> displayName)
Sets Builder.displayName to an arbitrary JSON value.
You should usually call Builder.displayName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
products
final ProviderListResponse.Builder products(List<String> products)
The list of Finch products supported on this payroll provider.
-
products
final ProviderListResponse.Builder products(JsonField<List<String>> products)
Sets Builder.products to an arbitrary JSON value.
You should usually call Builder.products with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addProduct
final ProviderListResponse.Builder addProduct(String product)
-
authenticationMethods
final ProviderListResponse.Builder authenticationMethods(List<ProviderListResponse.AuthenticationMethod> authenticationMethods)
The authentication methods supported by the provider.
-
authenticationMethods
final ProviderListResponse.Builder authenticationMethods(JsonField<List<ProviderListResponse.AuthenticationMethod>> authenticationMethods)
Sets Builder.authenticationMethods to an arbitrary JSON value.
You should usually call Builder.authenticationMethods with a well-typed
List<AuthenticationMethod>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addAuthenticationMethod
final ProviderListResponse.Builder addAuthenticationMethod(ProviderListResponse.AuthenticationMethod authenticationMethod)
Adds a single AuthenticationMethod to authenticationMethods.
-
beta
final ProviderListResponse.Builder beta(Boolean beta)
trueif the integration is in a beta state,falseotherwise
-
beta
final ProviderListResponse.Builder beta(JsonField<Boolean> beta)
Sets Builder.beta to an arbitrary JSON value.
You should usually call Builder.beta with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
icon
final ProviderListResponse.Builder icon(String icon)
The url to the official icon of the payroll provider.
-
icon
final ProviderListResponse.Builder icon(JsonField<String> icon)
Sets Builder.icon to an arbitrary JSON value.
You should usually call Builder.icon with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
logo
final ProviderListResponse.Builder logo(String logo)
The url to the official logo of the payroll provider.
-
logo
final ProviderListResponse.Builder logo(JsonField<String> logo)
Sets Builder.logo to an arbitrary JSON value.
You should usually call Builder.logo with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
manual
@Deprecated(message = "deprecated") final ProviderListResponse.Builder manual(Boolean manual)
DEPRECATED Whether the Finch integration with this provider uses the Assisted Connect Flow by default. This field is now deprecated. Please check for a
typeofassistedin theauthentication_methodsfield instead.
-
manual
@Deprecated(message = "deprecated") final ProviderListResponse.Builder manual(JsonField<Boolean> manual)
Sets Builder.manual to an arbitrary JSON value.
You should usually call Builder.manual with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
mfaRequired
final ProviderListResponse.Builder mfaRequired(Boolean mfaRequired)
whether MFA is required for the provider.
-
mfaRequired
final ProviderListResponse.Builder mfaRequired(JsonField<Boolean> mfaRequired)
Sets Builder.mfaRequired to an arbitrary JSON value.
You should usually call Builder.mfaRequired with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
primaryColor
final ProviderListResponse.Builder primaryColor(String primaryColor)
The hex code for the primary color of the payroll provider.
-
primaryColor
final ProviderListResponse.Builder primaryColor(JsonField<String> primaryColor)
Sets Builder.primaryColor to an arbitrary JSON value.
You should usually call Builder.primaryColor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ProviderListResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ProviderListResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ProviderListResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ProviderListResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ProviderListResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ProviderListResponse build()
Returns an immutable instance of ProviderListResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .displayName() .products()
-
-
-
-