Package com.tryfinch.api.models
Class RegisterCompanyBenefitResponse
-
- All Implemented Interfaces:
public final class RegisterCompanyBenefitResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRegisterCompanyBenefitResponse.BuilderA builder for RegisterCompanyBenefitResponse.
-
Method Summary
Modifier and Type Method Description final StringbenefitId()The id of the benefit. final StringjobId()final JsonField<String>_benefitId()Returns the raw JSON value of benefitId. final JsonField<String>_jobId()Returns the raw JSON value of jobId. final Map<String, JsonValue>_additionalProperties()final RegisterCompanyBenefitResponse.BuildertoBuilder()final RegisterCompanyBenefitResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RegisterCompanyBenefitResponse.Builderbuilder()Returns a mutable builder for constructing an instance of RegisterCompanyBenefitResponse. -
-
Method Detail
-
_benefitId
final JsonField<String> _benefitId()
Returns the raw JSON value of benefitId.
Unlike benefitId, this method doesn't throw if the JSON field has an unexpected type.
-
_jobId
final JsonField<String> _jobId()
Returns the raw JSON value of jobId.
Unlike jobId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RegisterCompanyBenefitResponse.Builder toBuilder()
-
validate
final RegisterCompanyBenefitResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RegisterCompanyBenefitResponse.Builder builder()
Returns a mutable builder for constructing an instance of RegisterCompanyBenefitResponse.
The following fields are required:
.benefitId() .jobId()
-
-
-
-