Class RequestForwardingForwardParams
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Params
public final class RequestForwardingForwardParams implements Params
The Forward API allows you to make direct requests to an employment system. If Finch's unified API doesn't have a data model that cleanly fits your needs, then Forward allows you to push or pull data models directly against an integration's API.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRequestForwardingForwardParams.BuilderA builder for RequestForwardingForwardParams.
public final classRequestForwardingForwardParams.ForwardRequestpublic final classRequestForwardingForwardParams.ParamsThe query parameters for the forwarded request. This value must be specified as a valid JSON object rather than a query string.
public final classRequestForwardingForwardParams.RequestHeadersThe HTTP headers to include on the forwarded request. This value must be specified as an object of key-value pairs. Example:
{"Content-Type": "application/xml", "X-API-Version": "v1" }
-
Method Summary
Modifier and Type Method Description final Stringmethod()The HTTP method for the forwarded request. final Stringroute()The URL route path for the forwarded request. final Optional<String>data()The body for the forwarded request. final Optional<RequestForwardingForwardParams.Params>params()The query parameters for the forwarded request. final Optional<RequestForwardingForwardParams.RequestHeaders>requestHeaders()The HTTP headers to include on the forwarded request. final JsonField<String>_method()Returns the raw JSON value of method. final JsonField<String>_route()Returns the raw JSON value of route. final JsonField<String>_data()Returns the raw JSON value of data. final JsonField<RequestForwardingForwardParams.Params>_params()Returns the raw JSON value of params. final JsonField<RequestForwardingForwardParams.RequestHeaders>_requestHeaders()Returns the raw JSON value of requestHeaders. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final RequestForwardingForwardParams.BuildertoBuilder()final RequestForwardingForwardParams.ForwardRequest_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static RequestForwardingForwardParams.Builderbuilder()Returns a mutable builder for constructing an instance of RequestForwardingForwardParams. -
-
Method Detail
-
method
final String method()
The HTTP method for the forwarded request. Valid values include:
GET,POST,PUT,DELETE, andPATCH.
-
route
final String route()
The URL route path for the forwarded request. This value must begin with a forward-slash ( / ) and may only contain alphanumeric characters, hyphens, and underscores.
-
data
final Optional<String> data()
The body for the forwarded request. This value must be specified as either a string or a valid JSON object.
-
params
final Optional<RequestForwardingForwardParams.Params> params()
The query parameters for the forwarded request. This value must be specified as a valid JSON object rather than a query string.
-
requestHeaders
final Optional<RequestForwardingForwardParams.RequestHeaders> requestHeaders()
The HTTP headers to include on the forwarded request. This value must be specified as an object of key-value pairs. Example:
{"Content-Type": "application/xml", "X-API-Version": "v1" }
-
_method
final JsonField<String> _method()
Returns the raw JSON value of method.
Unlike method, this method doesn't throw if the JSON field has an unexpected type.
-
_route
final JsonField<String> _route()
Returns the raw JSON value of route.
Unlike route, this method doesn't throw if the JSON field has an unexpected type.
-
_data
final JsonField<String> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_params
final JsonField<RequestForwardingForwardParams.Params> _params()
Returns the raw JSON value of params.
Unlike params, this method doesn't throw if the JSON field has an unexpected type.
-
_requestHeaders
final JsonField<RequestForwardingForwardParams.RequestHeaders> _requestHeaders()
Returns the raw JSON value of requestHeaders.
Unlike requestHeaders, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final RequestForwardingForwardParams.Builder toBuilder()
-
_body
final RequestForwardingForwardParams.ForwardRequest _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static RequestForwardingForwardParams.Builder builder()
Returns a mutable builder for constructing an instance of RequestForwardingForwardParams.
The following fields are required:
.method() .route()
-
-
-
-