Class RequestForwardingForwardParams.Body
-
- All Implemented Interfaces:
public final class RequestForwardingForwardParams.BodyForward Request Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRequestForwardingForwardParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringmethod()The HTTP method for the forwarded request. final Stringroute()The URL route path for the forwarded request. final Optional<String>data()The body for the forwarded request. final JsonValue_headers_()The HTTP headers to include on the forwarded request. final JsonValue_params()The query parameters for the forwarded request. final JsonField<String>_method()Returns the raw JSON value of method. final JsonField<String>_route()Returns the raw JSON value of route. final JsonField<String>_data()Returns the raw JSON value of data. final Map<String, JsonValue>_additionalProperties()final RequestForwardingForwardParams.Body.BuildertoBuilder()final RequestForwardingForwardParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RequestForwardingForwardParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
method
final String method()
The HTTP method for the forwarded request. Valid values include:
GET,POST,PUT,DELETE, andPATCH.
-
route
final String route()
The URL route path for the forwarded request. This value must begin with a forward-slash ( / ) and may only contain alphanumeric characters, hyphens, and underscores.
-
data
final Optional<String> data()
The body for the forwarded request. This value must be specified as either a string or a valid JSON object.
-
_headers_
final JsonValue _headers_()
The HTTP headers to include on the forwarded request. This value must be specified as an object of key-value pairs. Example:
{"Content-Type": "application/xml", "X-API-Version": "v1" }
-
_params
final JsonValue _params()
The query parameters for the forwarded request. This value must be specified as a valid JSON object rather than a query string.
-
_method
final JsonField<String> _method()
Returns the raw JSON value of method.
Unlike method, this method doesn't throw if the JSON field has an unexpected type.
-
_route
final JsonField<String> _route()
Returns the raw JSON value of route.
Unlike route, this method doesn't throw if the JSON field has an unexpected type.
-
_data
final JsonField<String> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RequestForwardingForwardParams.Body.Builder toBuilder()
-
validate
final RequestForwardingForwardParams.Body validate()
-
builder
final static RequestForwardingForwardParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.method() .route()
-
-
-
-