Class RequestForwardingForwardParams.Body.Builder
-
- All Implemented Interfaces:
public final class RequestForwardingForwardParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
method
final RequestForwardingForwardParams.Body.Builder method(String method)
The HTTP method for the forwarded request. Valid values include:
GET,POST,PUT,DELETE, andPATCH.
-
method
final RequestForwardingForwardParams.Body.Builder method(JsonField<String> method)
Sets Builder.method to an arbitrary JSON value.
You should usually call Builder.method with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
route
final RequestForwardingForwardParams.Body.Builder route(String route)
The URL route path for the forwarded request. This value must begin with a forward-slash ( / ) and may only contain alphanumeric characters, hyphens, and underscores.
-
route
final RequestForwardingForwardParams.Body.Builder route(JsonField<String> route)
Sets Builder.route to an arbitrary JSON value.
You should usually call Builder.route with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
data
final RequestForwardingForwardParams.Body.Builder data(String data)
The body for the forwarded request. This value must be specified as either a string or a valid JSON object.
-
data
final RequestForwardingForwardParams.Body.Builder data(Optional<String> data)
Alias for calling Builder.data with
data.orElse(null).
-
data
final RequestForwardingForwardParams.Body.Builder data(JsonField<String> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
headers
final RequestForwardingForwardParams.Body.Builder headers(JsonValue headers)
The HTTP headers to include on the forwarded request. This value must be specified as an object of key-value pairs. Example:
{"Content-Type": "application/xml", "X-API-Version": "v1" }
-
params
final RequestForwardingForwardParams.Body.Builder params(JsonValue params)
The query parameters for the forwarded request. This value must be specified as a valid JSON object rather than a query string.
-
additionalProperties
final RequestForwardingForwardParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RequestForwardingForwardParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RequestForwardingForwardParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RequestForwardingForwardParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RequestForwardingForwardParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RequestForwardingForwardParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.method() .route()
-
-
-
-