Class RequestForwardingForwardParams.ForwardRequest
-
- All Implemented Interfaces:
public final class RequestForwardingForwardParams.ForwardRequest
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRequestForwardingForwardParams.ForwardRequest.BuilderA builder for ForwardRequest.
-
Method Summary
Modifier and Type Method Description final Stringmethod()The HTTP method for the forwarded request. final Stringroute()The URL route path for the forwarded request. final Optional<String>data()The body for the forwarded request. final Optional<RequestForwardingForwardParams.Params>params()The query parameters for the forwarded request. final Optional<RequestForwardingForwardParams.RequestHeaders>requestHeaders()The HTTP headers to include on the forwarded request. final JsonField<String>_method()Returns the raw JSON value of method. final JsonField<String>_route()Returns the raw JSON value of route. final JsonField<String>_data()Returns the raw JSON value of data. final JsonField<RequestForwardingForwardParams.Params>_params()Returns the raw JSON value of params. final JsonField<RequestForwardingForwardParams.RequestHeaders>_requestHeaders()Returns the raw JSON value of requestHeaders. final Map<String, JsonValue>_additionalProperties()final RequestForwardingForwardParams.ForwardRequest.BuildertoBuilder()final RequestForwardingForwardParams.ForwardRequestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RequestForwardingForwardParams.ForwardRequest.Builderbuilder()Returns a mutable builder for constructing an instance of ForwardRequest. -
-
Method Detail
-
method
final String method()
The HTTP method for the forwarded request. Valid values include:
GET,POST,PUT,DELETE, andPATCH.
-
route
final String route()
The URL route path for the forwarded request. This value must begin with a forward-slash ( / ) and may only contain alphanumeric characters, hyphens, and underscores.
-
data
final Optional<String> data()
The body for the forwarded request. This value must be specified as either a string or a valid JSON object.
-
params
final Optional<RequestForwardingForwardParams.Params> params()
The query parameters for the forwarded request. This value must be specified as a valid JSON object rather than a query string.
-
requestHeaders
final Optional<RequestForwardingForwardParams.RequestHeaders> requestHeaders()
The HTTP headers to include on the forwarded request. This value must be specified as an object of key-value pairs. Example:
{"Content-Type": "application/xml", "X-API-Version": "v1" }
-
_method
final JsonField<String> _method()
Returns the raw JSON value of method.
Unlike method, this method doesn't throw if the JSON field has an unexpected type.
-
_route
final JsonField<String> _route()
Returns the raw JSON value of route.
Unlike route, this method doesn't throw if the JSON field has an unexpected type.
-
_data
final JsonField<String> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_params
final JsonField<RequestForwardingForwardParams.Params> _params()
Returns the raw JSON value of params.
Unlike params, this method doesn't throw if the JSON field has an unexpected type.
-
_requestHeaders
final JsonField<RequestForwardingForwardParams.RequestHeaders> _requestHeaders()
Returns the raw JSON value of requestHeaders.
Unlike requestHeaders, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RequestForwardingForwardParams.ForwardRequest.Builder toBuilder()
-
validate
final RequestForwardingForwardParams.ForwardRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RequestForwardingForwardParams.ForwardRequest.Builder builder()
Returns a mutable builder for constructing an instance of ForwardRequest.
The following fields are required:
.method() .route()
-
-
-
-