Class RequestForwardingForwardResponse
-
- All Implemented Interfaces:
public final class RequestForwardingForwardResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRequestForwardingForwardResponse.BuilderA builder for RequestForwardingForwardResponse.
public final classRequestForwardingForwardResponse.RequestAn object containing details of your original forwarded request, for your ease of reference.
public final classRequestForwardingForwardResponse.HeadersThe HTTP headers of the forwarded request's response, exactly as received from the underlying integration's API.
-
Method Summary
Modifier and Type Method Description final RequestForwardingForwardResponse.Requestrequest()An object containing details of your original forwarded request, for your ease of reference. final LongstatusCode()The HTTP status code of the forwarded request's response, exactly received from the underlying integration's API. final Optional<String>data()A string representation of the HTTP response body of the forwarded request's response received from the underlying integration's API. final Optional<RequestForwardingForwardResponse.Headers>headers()The HTTP headers of the forwarded request's response, exactly as received from the underlying integration's API. final JsonField<RequestForwardingForwardResponse.Request>_request()Returns the raw JSON value of request. final JsonField<Long>_statusCode()Returns the raw JSON value of statusCode. final JsonField<String>_data()Returns the raw JSON value of data. final JsonField<RequestForwardingForwardResponse.Headers>_headers()Returns the raw JSON value of headers. final Map<String, JsonValue>_additionalProperties()final RequestForwardingForwardResponse.BuildertoBuilder()final RequestForwardingForwardResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RequestForwardingForwardResponse.Builderbuilder()Returns a mutable builder for constructing an instance of RequestForwardingForwardResponse. -
-
Method Detail
-
request
final RequestForwardingForwardResponse.Request request()
An object containing details of your original forwarded request, for your ease of reference.
-
statusCode
final Long statusCode()
The HTTP status code of the forwarded request's response, exactly received from the underlying integration's API. This value will be returned as an integer.
-
data
final Optional<String> data()
A string representation of the HTTP response body of the forwarded request's response received from the underlying integration's API. This field may be null in the case where the upstream system's response is empty.
-
headers
final Optional<RequestForwardingForwardResponse.Headers> headers()
The HTTP headers of the forwarded request's response, exactly as received from the underlying integration's API.
-
_request
final JsonField<RequestForwardingForwardResponse.Request> _request()
Returns the raw JSON value of request.
Unlike request, this method doesn't throw if the JSON field has an unexpected type.
-
_statusCode
final JsonField<Long> _statusCode()
Returns the raw JSON value of statusCode.
Unlike statusCode, this method doesn't throw if the JSON field has an unexpected type.
-
_data
final JsonField<String> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_headers
final JsonField<RequestForwardingForwardResponse.Headers> _headers()
Returns the raw JSON value of headers.
Unlike headers, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RequestForwardingForwardResponse.Builder toBuilder()
-
validate
final RequestForwardingForwardResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RequestForwardingForwardResponse.Builder builder()
Returns a mutable builder for constructing an instance of RequestForwardingForwardResponse.
The following fields are required:
.request() .statusCode()
-
-
-
-