Class RequestForwardingForwardResponse.Builder
-
- All Implemented Interfaces:
public final class RequestForwardingForwardResponse.BuilderA builder for RequestForwardingForwardResponse.
-
-
Method Summary
-
-
Method Detail
-
request
final RequestForwardingForwardResponse.Builder request(RequestForwardingForwardResponse.Request request)
An object containing details of your original forwarded request, for your ease of reference.
-
request
final RequestForwardingForwardResponse.Builder request(JsonField<RequestForwardingForwardResponse.Request> request)
Sets Builder.request to an arbitrary JSON value.
You should usually call Builder.request with a well-typed Request value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
statusCode
final RequestForwardingForwardResponse.Builder statusCode(Long statusCode)
The HTTP status code of the forwarded request's response, exactly received from the underlying integration's API. This value will be returned as an integer.
-
statusCode
final RequestForwardingForwardResponse.Builder statusCode(JsonField<Long> statusCode)
Sets Builder.statusCode to an arbitrary JSON value.
You should usually call Builder.statusCode with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
data
final RequestForwardingForwardResponse.Builder data(String data)
A string representation of the HTTP response body of the forwarded request's response received from the underlying integration's API. This field may be null in the case where the upstream system's response is empty.
-
data
final RequestForwardingForwardResponse.Builder data(Optional<String> data)
Alias for calling Builder.data with
data.orElse(null).
-
data
final RequestForwardingForwardResponse.Builder data(JsonField<String> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
headers
final RequestForwardingForwardResponse.Builder headers(RequestForwardingForwardResponse.Headers headers)
The HTTP headers of the forwarded request's response, exactly as received from the underlying integration's API.
-
headers
final RequestForwardingForwardResponse.Builder headers(Optional<RequestForwardingForwardResponse.Headers> headers)
Alias for calling Builder.headers with
headers.orElse(null).
-
headers
final RequestForwardingForwardResponse.Builder headers(JsonField<RequestForwardingForwardResponse.Headers> headers)
Sets Builder.headers to an arbitrary JSON value.
You should usually call Builder.headers with a well-typed Headers value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RequestForwardingForwardResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RequestForwardingForwardResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RequestForwardingForwardResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RequestForwardingForwardResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RequestForwardingForwardResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RequestForwardingForwardResponse build()
Returns an immutable instance of RequestForwardingForwardResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.request() .statusCode()
-
-
-
-