Package com.tryfinch.api.models
Class RequestForwardingForwardResponse.Headers
-
- All Implemented Interfaces:
public final class RequestForwardingForwardResponse.HeadersThe HTTP headers of the forwarded request's response, exactly as received from the underlying integration's API.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRequestForwardingForwardResponse.Headers.BuilderA builder for Headers.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final RequestForwardingForwardResponse.Headers.BuildertoBuilder()final RequestForwardingForwardResponse.Headersvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RequestForwardingForwardResponse.Headers.Builderbuilder()Returns a mutable builder for constructing an instance of Headers. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RequestForwardingForwardResponse.Headers.Builder toBuilder()
-
validate
final RequestForwardingForwardResponse.Headers validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RequestForwardingForwardResponse.Headers.Builder builder()
Returns a mutable builder for constructing an instance of Headers.
-
-
-
-