Class RequestForwardingForwardResponse.Request
-
- All Implemented Interfaces:
public final class RequestForwardingForwardResponse.RequestAn object containing details of your original forwarded request, for your ease of reference.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRequestForwardingForwardResponse.Request.BuilderA builder for Request.
public final classRequestForwardingForwardResponse.Request.DataThe body that was specified for the forwarded request.
public final classRequestForwardingForwardResponse.Request.HeadersThe HTTP headers that were specified for the forwarded request.
public final classRequestForwardingForwardResponse.Request.ParamsThe query parameters that were specified for the forwarded request.
-
Method Summary
Modifier and Type Method Description final Stringmethod()The HTTP method that was specified for the forwarded request. final Stringroute()The URL route path that was specified for the forwarded request. final Optional<RequestForwardingForwardResponse.Request.Data>data()The body that was specified for the forwarded request. final Optional<RequestForwardingForwardResponse.Request.Headers>headers()The HTTP headers that were specified for the forwarded request. final Optional<RequestForwardingForwardResponse.Request.Params>params()The query parameters that were specified for the forwarded request. final JsonField<String>_method()Returns the raw JSON value of method. final JsonField<String>_route()Returns the raw JSON value of route. final JsonField<RequestForwardingForwardResponse.Request.Data>_data()Returns the raw JSON value of data. final JsonField<RequestForwardingForwardResponse.Request.Headers>_headers()Returns the raw JSON value of headers. final JsonField<RequestForwardingForwardResponse.Request.Params>_params()Returns the raw JSON value of params. final Map<String, JsonValue>_additionalProperties()final RequestForwardingForwardResponse.Request.BuildertoBuilder()final RequestForwardingForwardResponse.Requestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RequestForwardingForwardResponse.Request.Builderbuilder()Returns a mutable builder for constructing an instance of Request. -
-
Method Detail
-
method
final String method()
The HTTP method that was specified for the forwarded request. Valid values include:
GET,POST,PUT,DELETE, andPATCH.
-
data
final Optional<RequestForwardingForwardResponse.Request.Data> data()
The body that was specified for the forwarded request.
-
headers
final Optional<RequestForwardingForwardResponse.Request.Headers> headers()
The HTTP headers that were specified for the forwarded request.
-
params
final Optional<RequestForwardingForwardResponse.Request.Params> params()
The query parameters that were specified for the forwarded request.
-
_method
final JsonField<String> _method()
Returns the raw JSON value of method.
Unlike method, this method doesn't throw if the JSON field has an unexpected type.
-
_route
final JsonField<String> _route()
Returns the raw JSON value of route.
Unlike route, this method doesn't throw if the JSON field has an unexpected type.
-
_data
final JsonField<RequestForwardingForwardResponse.Request.Data> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_headers
final JsonField<RequestForwardingForwardResponse.Request.Headers> _headers()
Returns the raw JSON value of headers.
Unlike headers, this method doesn't throw if the JSON field has an unexpected type.
-
_params
final JsonField<RequestForwardingForwardResponse.Request.Params> _params()
Returns the raw JSON value of params.
Unlike params, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RequestForwardingForwardResponse.Request.Builder toBuilder()
-
validate
final RequestForwardingForwardResponse.Request validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RequestForwardingForwardResponse.Request.Builder builder()
Returns a mutable builder for constructing an instance of Request.
The following fields are required:
.method() .route()
-
-
-
-