Class RequestForwardingForwardResponse.Request.Builder
-
- All Implemented Interfaces:
public final class RequestForwardingForwardResponse.Request.BuilderA builder for Request.
-
-
Method Summary
-
-
Method Detail
-
method
final RequestForwardingForwardResponse.Request.Builder method(String method)
The HTTP method that was specified for the forwarded request. Valid values include:
GET,POST,PUT,DELETE, andPATCH.
-
method
final RequestForwardingForwardResponse.Request.Builder method(JsonField<String> method)
Sets Builder.method to an arbitrary JSON value.
You should usually call Builder.method with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
route
final RequestForwardingForwardResponse.Request.Builder route(String route)
The URL route path that was specified for the forwarded request.
-
route
final RequestForwardingForwardResponse.Request.Builder route(JsonField<String> route)
Sets Builder.route to an arbitrary JSON value.
You should usually call Builder.route with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
data
final RequestForwardingForwardResponse.Request.Builder data(RequestForwardingForwardResponse.Request.Data data)
The body that was specified for the forwarded request.
-
data
final RequestForwardingForwardResponse.Request.Builder data(Optional<RequestForwardingForwardResponse.Request.Data> data)
Alias for calling Builder.data with
data.orElse(null).
-
data
final RequestForwardingForwardResponse.Request.Builder data(JsonField<RequestForwardingForwardResponse.Request.Data> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed Data value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
data
final RequestForwardingForwardResponse.Request.Builder data(String string)
Alias for calling data with
Data.ofString(string).
-
data
final RequestForwardingForwardResponse.Request.Builder data(RequestForwardingForwardResponse.Request.Data.UnionMember1 unionMember1)
Alias for calling data with
Data.ofUnionMember1(unionMember1).
-
headers
final RequestForwardingForwardResponse.Request.Builder headers(RequestForwardingForwardResponse.Request.Headers headers)
The HTTP headers that were specified for the forwarded request.
-
headers
final RequestForwardingForwardResponse.Request.Builder headers(Optional<RequestForwardingForwardResponse.Request.Headers> headers)
Alias for calling Builder.headers with
headers.orElse(null).
-
headers
final RequestForwardingForwardResponse.Request.Builder headers(JsonField<RequestForwardingForwardResponse.Request.Headers> headers)
Sets Builder.headers to an arbitrary JSON value.
You should usually call Builder.headers with a well-typed Headers value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
params
final RequestForwardingForwardResponse.Request.Builder params(RequestForwardingForwardResponse.Request.Params params)
The query parameters that were specified for the forwarded request.
-
params
final RequestForwardingForwardResponse.Request.Builder params(Optional<RequestForwardingForwardResponse.Request.Params> params)
Alias for calling Builder.params with
params.orElse(null).
-
params
final RequestForwardingForwardResponse.Request.Builder params(JsonField<RequestForwardingForwardResponse.Request.Params> params)
Sets Builder.params to an arbitrary JSON value.
You should usually call Builder.params with a well-typed Params value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RequestForwardingForwardResponse.Request.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RequestForwardingForwardResponse.Request.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RequestForwardingForwardResponse.Request.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RequestForwardingForwardResponse.Request.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RequestForwardingForwardResponse.Request.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RequestForwardingForwardResponse.Request build()
Returns an immutable instance of Request.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.method() .route()
-
-
-
-