Package com.tryfinch.api.models
Interface RequestForwardingForwardResponse.Request.Data.Visitor
-
- All Implemented Interfaces:
public interface RequestForwardingForwardResponse.Request.Data.Visitor<T extends Object>
-
-
Method Summary
Modifier and Type Method Description abstract TvisitString(String string)abstract TvisitUnionMember1(RequestForwardingForwardResponse.Request.Data.UnionMember1 unionMember1)Tunknown(JsonValue json)Maps an unknown variant of Data to a value of type T. -
-
Method Detail
-
visitString
abstract T visitString(String string)
-
visitUnionMember1
abstract T visitUnionMember1(RequestForwardingForwardResponse.Request.Data.UnionMember1 unionMember1)
-
unknown
T unknown(JsonValue json)
Maps an unknown variant of Data to a value of type T.
An instance of Data can contain an unknown variant if it was deserialized from data that doesn't match any known variant. For example, if the SDK is on an older version than the API, then the API may respond with new variants that the SDK is unaware of.
-
-
-
-