Package com.tryfinch.api.models
Class RequestForwardingForwardResponse.Request.Params
-
- All Implemented Interfaces:
public final class RequestForwardingForwardResponse.Request.ParamsThe query parameters that were specified for the forwarded request.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRequestForwardingForwardResponse.Request.Params.BuilderA builder for Params.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final RequestForwardingForwardResponse.Request.Params.BuildertoBuilder()final RequestForwardingForwardResponse.Request.Paramsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RequestForwardingForwardResponse.Request.Params.Builderbuilder()Returns a mutable builder for constructing an instance of Params. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RequestForwardingForwardResponse.Request.Params.Builder toBuilder()
-
validate
final RequestForwardingForwardResponse.Request.Params validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RequestForwardingForwardResponse.Request.Params.Builder builder()
Returns a mutable builder for constructing an instance of Params.
-
-
-
-