Class RuleCreateResponse
-
- All Implemented Interfaces:
public final class RuleCreateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRuleCreateResponse.BuilderA builder for RuleCreateResponse.
public final classRuleCreateResponse.AttributesSpecifies the fields to be applied when the condition is met.
public final classRuleCreateResponse.Conditionpublic final classRuleCreateResponse.EntityTypeThe entity type to which the rule is applied.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Finch id (uuidv4) for the rule. final Optional<RuleCreateResponse.Attributes>attributes()Specifies the fields to be applied when the condition is met. final Optional<List<RuleCreateResponse.Condition>>conditions()final Optional<OffsetDateTime>createdAt()The datetime when the rule was created. final Optional<String>effectiveEndDate()Specifies when the rules should stop applying rules based on the date. final Optional<String>effectiveStartDate()Specifies when the rule should begin applying based on the date. final Optional<RuleCreateResponse.EntityType>entityType()The entity type to which the rule is applied. final Optional<Long>priority()The priority of the rule. final Optional<OffsetDateTime>updatedAt()The datetime when the rule was last updated. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<RuleCreateResponse.Attributes>_attributes()Returns the raw JSON value of attributes. final JsonField<List<RuleCreateResponse.Condition>>_conditions()Returns the raw JSON value of conditions. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_effectiveEndDate()Returns the raw JSON value of effectiveEndDate. final JsonField<String>_effectiveStartDate()Returns the raw JSON value of effectiveStartDate. final JsonField<RuleCreateResponse.EntityType>_entityType()Returns the raw JSON value of entityType. final JsonField<Long>_priority()Returns the raw JSON value of priority. final JsonField<OffsetDateTime>_updatedAt()Returns the raw JSON value of updatedAt. final Map<String, JsonValue>_additionalProperties()final RuleCreateResponse.BuildertoBuilder()final RuleCreateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RuleCreateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of RuleCreateResponse. -
-
Method Detail
-
attributes
final Optional<RuleCreateResponse.Attributes> attributes()
Specifies the fields to be applied when the condition is met.
-
conditions
final Optional<List<RuleCreateResponse.Condition>> conditions()
-
createdAt
final Optional<OffsetDateTime> createdAt()
The datetime when the rule was created.
-
effectiveEndDate
final Optional<String> effectiveEndDate()
Specifies when the rules should stop applying rules based on the date.
-
effectiveStartDate
final Optional<String> effectiveStartDate()
Specifies when the rule should begin applying based on the date.
-
entityType
final Optional<RuleCreateResponse.EntityType> entityType()
The entity type to which the rule is applied.
-
updatedAt
final Optional<OffsetDateTime> updatedAt()
The datetime when the rule was last updated.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_attributes
final JsonField<RuleCreateResponse.Attributes> _attributes()
Returns the raw JSON value of attributes.
Unlike attributes, this method doesn't throw if the JSON field has an unexpected type.
-
_conditions
final JsonField<List<RuleCreateResponse.Condition>> _conditions()
Returns the raw JSON value of conditions.
Unlike conditions, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_effectiveEndDate
final JsonField<String> _effectiveEndDate()
Returns the raw JSON value of effectiveEndDate.
Unlike effectiveEndDate, this method doesn't throw if the JSON field has an unexpected type.
-
_effectiveStartDate
final JsonField<String> _effectiveStartDate()
Returns the raw JSON value of effectiveStartDate.
Unlike effectiveStartDate, this method doesn't throw if the JSON field has an unexpected type.
-
_entityType
final JsonField<RuleCreateResponse.EntityType> _entityType()
Returns the raw JSON value of entityType.
Unlike entityType, this method doesn't throw if the JSON field has an unexpected type.
-
_priority
final JsonField<Long> _priority()
Returns the raw JSON value of priority.
Unlike priority, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
Returns the raw JSON value of updatedAt.
Unlike updatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RuleCreateResponse.Builder toBuilder()
-
validate
final RuleCreateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RuleCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of RuleCreateResponse.
-
-
-
-