Class RuleCreateResponse.Attributes
-
- All Implemented Interfaces:
public final class RuleCreateResponse.AttributesSpecifies the fields to be applied when the condition is met.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRuleCreateResponse.Attributes.BuilderA builder for Attributes.
public final classRuleCreateResponse.Attributes.MetadataThe metadata to be attached in the entity. It is a key-value pairs where the values can be of any type (string, number, boolean, object, array, etc.).
-
Method Summary
Modifier and Type Method Description final Optional<RuleCreateResponse.Attributes.Metadata>metadata()The metadata to be attached in the entity. final JsonField<RuleCreateResponse.Attributes.Metadata>_metadata()Returns the raw JSON value of metadata. final Map<String, JsonValue>_additionalProperties()final RuleCreateResponse.Attributes.BuildertoBuilder()final RuleCreateResponse.Attributesvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RuleCreateResponse.Attributes.Builderbuilder()Returns a mutable builder for constructing an instance of Attributes. -
-
Method Detail
-
metadata
final Optional<RuleCreateResponse.Attributes.Metadata> metadata()
The metadata to be attached in the entity. It is a key-value pairs where the values can be of any type (string, number, boolean, object, array, etc.).
-
_metadata
final JsonField<RuleCreateResponse.Attributes.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RuleCreateResponse.Attributes.Builder toBuilder()
-
validate
final RuleCreateResponse.Attributes validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RuleCreateResponse.Attributes.Builder builder()
Returns a mutable builder for constructing an instance of Attributes.
-
-
-
-