Package com.tryfinch.api.models
Class RuleCreateResponse.Condition
-
- All Implemented Interfaces:
public final class RuleCreateResponse.Condition
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRuleCreateResponse.Condition.BuilderA builder for Condition.
public final classRuleCreateResponse.Condition.OperatorThe operator to be used in the rule.
-
Method Summary
Modifier and Type Method Description final Optional<String>field()The field to be checked in the rule. final Optional<RuleCreateResponse.Condition.Operator>operator()The operator to be used in the rule. final Optional<String>value()The value of the field to be checked in the rule. final JsonField<String>_field()Returns the raw JSON value of field. final JsonField<RuleCreateResponse.Condition.Operator>_operator()Returns the raw JSON value of operator. final JsonField<String>_value()Returns the raw JSON value of value. final Map<String, JsonValue>_additionalProperties()final RuleCreateResponse.Condition.BuildertoBuilder()final RuleCreateResponse.Conditionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RuleCreateResponse.Condition.Builderbuilder()Returns a mutable builder for constructing an instance of Condition. -
-
Method Detail
-
operator
final Optional<RuleCreateResponse.Condition.Operator> operator()
The operator to be used in the rule.
-
_field
final JsonField<String> _field()
Returns the raw JSON value of field.
Unlike field, this method doesn't throw if the JSON field has an unexpected type.
-
_operator
final JsonField<RuleCreateResponse.Condition.Operator> _operator()
Returns the raw JSON value of operator.
Unlike operator, this method doesn't throw if the JSON field has an unexpected type.
-
_value
final JsonField<String> _value()
Returns the raw JSON value of value.
Unlike value, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RuleCreateResponse.Condition.Builder toBuilder()
-
validate
final RuleCreateResponse.Condition validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RuleCreateResponse.Condition.Builder builder()
Returns a mutable builder for constructing an instance of Condition.
-
-
-
-