Class RuleCreateResponse.Condition.Builder
-
- All Implemented Interfaces:
public final class RuleCreateResponse.Condition.BuilderA builder for Condition.
-
-
Method Summary
-
-
Method Detail
-
field
final RuleCreateResponse.Condition.Builder field(String field)
The field to be checked in the rule.
-
field
final RuleCreateResponse.Condition.Builder field(JsonField<String> field)
Sets Builder.field to an arbitrary JSON value.
You should usually call Builder.field with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
operator
final RuleCreateResponse.Condition.Builder operator(RuleCreateResponse.Condition.Operator operator)
The operator to be used in the rule.
-
operator
final RuleCreateResponse.Condition.Builder operator(JsonField<RuleCreateResponse.Condition.Operator> operator)
Sets Builder.operator to an arbitrary JSON value.
You should usually call Builder.operator with a well-typed Operator value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
value
final RuleCreateResponse.Condition.Builder value(String value)
The value of the field to be checked in the rule.
-
value
final RuleCreateResponse.Condition.Builder value(JsonField<String> value)
Sets Builder.value to an arbitrary JSON value.
You should usually call Builder.value with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RuleCreateResponse.Condition.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RuleCreateResponse.Condition.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RuleCreateResponse.Condition.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RuleCreateResponse.Condition.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RuleCreateResponse.Condition.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RuleCreateResponse.Condition build()
Returns an immutable instance of Condition.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-