Package com.tryfinch.api.models
Class RuleDeleteResponse.Attributes.Builder
-
- All Implemented Interfaces:
public final class RuleDeleteResponse.Attributes.BuilderA builder for Attributes.
-
-
Method Summary
Modifier and Type Method Description final RuleDeleteResponse.Attributes.Buildermetadata(RuleDeleteResponse.Attributes.Metadata metadata)The metadata to be attached in the entity. final RuleDeleteResponse.Attributes.Buildermetadata(JsonField<RuleDeleteResponse.Attributes.Metadata> metadata)Sets Builder.metadata to an arbitrary JSON value. final RuleDeleteResponse.Attributes.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final RuleDeleteResponse.Attributes.BuilderputAdditionalProperty(String key, JsonValue value)final RuleDeleteResponse.Attributes.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final RuleDeleteResponse.Attributes.BuilderremoveAdditionalProperty(String key)final RuleDeleteResponse.Attributes.BuilderremoveAllAdditionalProperties(Set<String> keys)final RuleDeleteResponse.Attributesbuild()Returns an immutable instance of Attributes. -
-
Method Detail
-
metadata
final RuleDeleteResponse.Attributes.Builder metadata(RuleDeleteResponse.Attributes.Metadata metadata)
The metadata to be attached in the entity. It is a key-value pairs where the values can be of any type (string, number, boolean, object, array, etc.).
-
metadata
final RuleDeleteResponse.Attributes.Builder metadata(JsonField<RuleDeleteResponse.Attributes.Metadata> metadata)
Sets Builder.metadata to an arbitrary JSON value.
You should usually call Builder.metadata with a well-typed Metadata value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RuleDeleteResponse.Attributes.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RuleDeleteResponse.Attributes.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RuleDeleteResponse.Attributes.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RuleDeleteResponse.Attributes.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RuleDeleteResponse.Attributes.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RuleDeleteResponse.Attributes build()
Returns an immutable instance of Attributes.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-