Package com.tryfinch.api.models
Class RuleDeleteResponse.Attributes.Metadata
-
- All Implemented Interfaces:
public final class RuleDeleteResponse.Attributes.MetadataThe metadata to be attached in the entity. It is a key-value pairs where the values can be of any type (string, number, boolean, object, array, etc.).
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRuleDeleteResponse.Attributes.Metadata.BuilderA builder for Metadata.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final RuleDeleteResponse.Attributes.Metadata.BuildertoBuilder()final RuleDeleteResponse.Attributes.Metadatavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RuleDeleteResponse.Attributes.Metadata.Builderbuilder()Returns a mutable builder for constructing an instance of Metadata. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RuleDeleteResponse.Attributes.Metadata.Builder toBuilder()
-
validate
final RuleDeleteResponse.Attributes.Metadata validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RuleDeleteResponse.Attributes.Metadata.Builder builder()
Returns a mutable builder for constructing an instance of Metadata.
-
-
-
-