Class RuleListResponse.Attributes
-
- All Implemented Interfaces:
public final class RuleListResponse.AttributesSpecifies the fields to be applied when the condition is met.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRuleListResponse.Attributes.BuilderA builder for Attributes.
public final classRuleListResponse.Attributes.MetadataThe metadata to be attached in the entity. It is a key-value pairs where the values can be of any type (string, number, boolean, object, array, etc.).
-
Method Summary
Modifier and Type Method Description final Optional<RuleListResponse.Attributes.Metadata>metadata()The metadata to be attached in the entity. final JsonField<RuleListResponse.Attributes.Metadata>_metadata()Returns the raw JSON value of metadata. final Map<String, JsonValue>_additionalProperties()final RuleListResponse.Attributes.BuildertoBuilder()final RuleListResponse.Attributesvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RuleListResponse.Attributes.Builderbuilder()Returns a mutable builder for constructing an instance of Attributes. -
-
Method Detail
-
metadata
final Optional<RuleListResponse.Attributes.Metadata> metadata()
The metadata to be attached in the entity. It is a key-value pairs where the values can be of any type (string, number, boolean, object, array, etc.).
-
_metadata
final JsonField<RuleListResponse.Attributes.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RuleListResponse.Attributes.Builder toBuilder()
-
validate
final RuleListResponse.Attributes validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RuleListResponse.Attributes.Builder builder()
Returns a mutable builder for constructing an instance of Attributes.
-
-
-
-