Package com.tryfinch.api.models
Class RuleListResponse.Attributes.Builder
-
- All Implemented Interfaces:
public final class RuleListResponse.Attributes.BuilderA builder for Attributes.
-
-
Method Summary
Modifier and Type Method Description final RuleListResponse.Attributes.Buildermetadata(RuleListResponse.Attributes.Metadata metadata)The metadata to be attached in the entity. final RuleListResponse.Attributes.Buildermetadata(JsonField<RuleListResponse.Attributes.Metadata> metadata)Sets Builder.metadata to an arbitrary JSON value. final RuleListResponse.Attributes.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final RuleListResponse.Attributes.BuilderputAdditionalProperty(String key, JsonValue value)final RuleListResponse.Attributes.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final RuleListResponse.Attributes.BuilderremoveAdditionalProperty(String key)final RuleListResponse.Attributes.BuilderremoveAllAdditionalProperties(Set<String> keys)final RuleListResponse.Attributesbuild()Returns an immutable instance of Attributes. -
-
Method Detail
-
metadata
final RuleListResponse.Attributes.Builder metadata(RuleListResponse.Attributes.Metadata metadata)
The metadata to be attached in the entity. It is a key-value pairs where the values can be of any type (string, number, boolean, object, array, etc.).
-
metadata
final RuleListResponse.Attributes.Builder metadata(JsonField<RuleListResponse.Attributes.Metadata> metadata)
Sets Builder.metadata to an arbitrary JSON value.
You should usually call Builder.metadata with a well-typed Metadata value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RuleListResponse.Attributes.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RuleListResponse.Attributes.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RuleListResponse.Attributes.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RuleListResponse.Attributes.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RuleListResponse.Attributes.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RuleListResponse.Attributes build()
Returns an immutable instance of Attributes.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-