Class RuleListResponse.Builder
-
- All Implemented Interfaces:
public final class RuleListResponse.BuilderA builder for RuleListResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final RuleListResponse.Builder id(String id)
Finch id (uuidv4) for the rule.
-
id
final RuleListResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
attributes
final RuleListResponse.Builder attributes(RuleListResponse.Attributes attributes)
Specifies the fields to be applied when the condition is met.
-
attributes
final RuleListResponse.Builder attributes(JsonField<RuleListResponse.Attributes> attributes)
Sets Builder.attributes to an arbitrary JSON value.
You should usually call Builder.attributes with a well-typed Attributes value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
conditions
final RuleListResponse.Builder conditions(List<RuleListResponse.Condition> conditions)
-
conditions
final RuleListResponse.Builder conditions(JsonField<List<RuleListResponse.Condition>> conditions)
Sets Builder.conditions to an arbitrary JSON value.
You should usually call Builder.conditions with a well-typed
List<Condition>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addCondition
final RuleListResponse.Builder addCondition(RuleListResponse.Condition condition)
Adds a single Condition to conditions.
-
createdAt
final RuleListResponse.Builder createdAt(OffsetDateTime createdAt)
The datetime when the rule was created.
-
createdAt
final RuleListResponse.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
effectiveEndDate
final RuleListResponse.Builder effectiveEndDate(String effectiveEndDate)
Specifies when the rules should stop applying rules based on the date.
-
effectiveEndDate
final RuleListResponse.Builder effectiveEndDate(Optional<String> effectiveEndDate)
Alias for calling Builder.effectiveEndDate with
effectiveEndDate.orElse(null).
-
effectiveEndDate
final RuleListResponse.Builder effectiveEndDate(JsonField<String> effectiveEndDate)
Sets Builder.effectiveEndDate to an arbitrary JSON value.
You should usually call Builder.effectiveEndDate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
effectiveStartDate
final RuleListResponse.Builder effectiveStartDate(String effectiveStartDate)
Specifies when the rule should begin applying based on the date.
-
effectiveStartDate
final RuleListResponse.Builder effectiveStartDate(Optional<String> effectiveStartDate)
Alias for calling Builder.effectiveStartDate with
effectiveStartDate.orElse(null).
-
effectiveStartDate
final RuleListResponse.Builder effectiveStartDate(JsonField<String> effectiveStartDate)
Sets Builder.effectiveStartDate to an arbitrary JSON value.
You should usually call Builder.effectiveStartDate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entityType
final RuleListResponse.Builder entityType(RuleListResponse.EntityType entityType)
The entity type to which the rule is applied.
-
entityType
final RuleListResponse.Builder entityType(JsonField<RuleListResponse.EntityType> entityType)
Sets Builder.entityType to an arbitrary JSON value.
You should usually call Builder.entityType with a well-typed EntityType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
priority
final RuleListResponse.Builder priority(Long priority)
The priority of the rule.
-
priority
final RuleListResponse.Builder priority(JsonField<Long> priority)
Sets Builder.priority to an arbitrary JSON value.
You should usually call Builder.priority with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updatedAt
final RuleListResponse.Builder updatedAt(OffsetDateTime updatedAt)
The datetime when the rule was last updated.
-
updatedAt
final RuleListResponse.Builder updatedAt(JsonField<OffsetDateTime> updatedAt)
Sets Builder.updatedAt to an arbitrary JSON value.
You should usually call Builder.updatedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RuleListResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RuleListResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RuleListResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RuleListResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RuleListResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RuleListResponse build()
Returns an immutable instance of RuleListResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-