Class RuleUpdateResponse.Builder
-
- All Implemented Interfaces:
public final class RuleUpdateResponse.BuilderA builder for RuleUpdateResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final RuleUpdateResponse.Builder id(String id)
Finch id (uuidv4) for the rule.
-
id
final RuleUpdateResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
attributes
final RuleUpdateResponse.Builder attributes(RuleUpdateResponse.Attributes attributes)
Specifies the fields to be applied when the condition is met.
-
attributes
final RuleUpdateResponse.Builder attributes(JsonField<RuleUpdateResponse.Attributes> attributes)
Sets Builder.attributes to an arbitrary JSON value.
You should usually call Builder.attributes with a well-typed Attributes value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
conditions
final RuleUpdateResponse.Builder conditions(List<RuleUpdateResponse.Condition> conditions)
-
conditions
final RuleUpdateResponse.Builder conditions(JsonField<List<RuleUpdateResponse.Condition>> conditions)
Sets Builder.conditions to an arbitrary JSON value.
You should usually call Builder.conditions with a well-typed
List<Condition>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addCondition
final RuleUpdateResponse.Builder addCondition(RuleUpdateResponse.Condition condition)
Adds a single Condition to conditions.
-
createdAt
final RuleUpdateResponse.Builder createdAt(OffsetDateTime createdAt)
The datetime when the rule was created.
-
createdAt
final RuleUpdateResponse.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
effectiveEndDate
final RuleUpdateResponse.Builder effectiveEndDate(String effectiveEndDate)
Specifies when the rules should stop applying rules based on the date.
-
effectiveEndDate
final RuleUpdateResponse.Builder effectiveEndDate(Optional<String> effectiveEndDate)
Alias for calling Builder.effectiveEndDate with
effectiveEndDate.orElse(null).
-
effectiveEndDate
final RuleUpdateResponse.Builder effectiveEndDate(JsonField<String> effectiveEndDate)
Sets Builder.effectiveEndDate to an arbitrary JSON value.
You should usually call Builder.effectiveEndDate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
effectiveStartDate
final RuleUpdateResponse.Builder effectiveStartDate(String effectiveStartDate)
Specifies when the rule should begin applying based on the date.
-
effectiveStartDate
final RuleUpdateResponse.Builder effectiveStartDate(Optional<String> effectiveStartDate)
Alias for calling Builder.effectiveStartDate with
effectiveStartDate.orElse(null).
-
effectiveStartDate
final RuleUpdateResponse.Builder effectiveStartDate(JsonField<String> effectiveStartDate)
Sets Builder.effectiveStartDate to an arbitrary JSON value.
You should usually call Builder.effectiveStartDate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entityType
final RuleUpdateResponse.Builder entityType(RuleUpdateResponse.EntityType entityType)
The entity type to which the rule is applied.
-
entityType
final RuleUpdateResponse.Builder entityType(JsonField<RuleUpdateResponse.EntityType> entityType)
Sets Builder.entityType to an arbitrary JSON value.
You should usually call Builder.entityType with a well-typed EntityType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
priority
final RuleUpdateResponse.Builder priority(Long priority)
The priority of the rule.
-
priority
final RuleUpdateResponse.Builder priority(JsonField<Long> priority)
Sets Builder.priority to an arbitrary JSON value.
You should usually call Builder.priority with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updatedAt
final RuleUpdateResponse.Builder updatedAt(OffsetDateTime updatedAt)
The datetime when the rule was last updated.
-
updatedAt
final RuleUpdateResponse.Builder updatedAt(JsonField<OffsetDateTime> updatedAt)
Sets Builder.updatedAt to an arbitrary JSON value.
You should usually call Builder.updatedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RuleUpdateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RuleUpdateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RuleUpdateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RuleUpdateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RuleUpdateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RuleUpdateResponse build()
Returns an immutable instance of RuleUpdateResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-