Package com.tryfinch.api.models
Class RuleUpdateResponse.Condition
-
- All Implemented Interfaces:
public final class RuleUpdateResponse.Condition
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRuleUpdateResponse.Condition.BuilderA builder for Condition.
public final classRuleUpdateResponse.Condition.OperatorThe operator to be used in the rule.
-
Method Summary
Modifier and Type Method Description final Optional<String>field()The field to be checked in the rule. final Optional<RuleUpdateResponse.Condition.Operator>operator()The operator to be used in the rule. final Optional<String>value()The value of the field to be checked in the rule. final JsonField<String>_field()Returns the raw JSON value of field. final JsonField<RuleUpdateResponse.Condition.Operator>_operator()Returns the raw JSON value of operator. final JsonField<String>_value()Returns the raw JSON value of value. final Map<String, JsonValue>_additionalProperties()final RuleUpdateResponse.Condition.BuildertoBuilder()final RuleUpdateResponse.Conditionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RuleUpdateResponse.Condition.Builderbuilder()Returns a mutable builder for constructing an instance of Condition. -
-
Method Detail
-
operator
final Optional<RuleUpdateResponse.Condition.Operator> operator()
The operator to be used in the rule.
-
_field
final JsonField<String> _field()
Returns the raw JSON value of field.
Unlike field, this method doesn't throw if the JSON field has an unexpected type.
-
_operator
final JsonField<RuleUpdateResponse.Condition.Operator> _operator()
Returns the raw JSON value of operator.
Unlike operator, this method doesn't throw if the JSON field has an unexpected type.
-
_value
final JsonField<String> _value()
Returns the raw JSON value of value.
Unlike value, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RuleUpdateResponse.Condition.Builder toBuilder()
-
validate
final RuleUpdateResponse.Condition validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RuleUpdateResponse.Condition.Builder builder()
Returns a mutable builder for constructing an instance of Condition.
-
-
-
-