Class SandboxCompanyUpdateParams
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Params
public final class SandboxCompanyUpdateParams implements Params
Update a sandbox company's data
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSandboxCompanyUpdateParams.BuilderA builder for SandboxCompanyUpdateParams.
public final classSandboxCompanyUpdateParams.CompanyWithoutIdpublic final classSandboxCompanyUpdateParams.Accountpublic final classSandboxCompanyUpdateParams.Departmentpublic final classSandboxCompanyUpdateParams.EntityThe entity type object.
-
Method Summary
Modifier and Type Method Description final Optional<List<SandboxCompanyUpdateParams.Account>>accounts()An array of bank account objects associated with the payroll/HRIS system. final Optional<List<SandboxCompanyUpdateParams.Department>>departments()The array of company departments. final Optional<String>ein()The employer identification number. final Optional<SandboxCompanyUpdateParams.Entity>entity()The entity type object. final Optional<String>legalName()The legal name of the company. final Optional<List<Location>>locations()final Optional<String>primaryEmail()The email of the main administrator on the account. final Optional<String>primaryPhoneNumber()The phone number of the main administrator on the account. final JsonField<List<SandboxCompanyUpdateParams.Account>>_accounts()Returns the raw JSON value of accounts. final JsonField<List<SandboxCompanyUpdateParams.Department>>_departments()Returns the raw JSON value of departments. final JsonField<String>_ein()Returns the raw JSON value of ein. final JsonField<SandboxCompanyUpdateParams.Entity>_entity()Returns the raw JSON value of entity. final JsonField<String>_legalName()Returns the raw JSON value of legalName. final JsonField<List<Location>>_locations()Returns the raw JSON value of locations. final JsonField<String>_primaryEmail()Returns the raw JSON value of primaryEmail. final JsonField<String>_primaryPhoneNumber()Returns the raw JSON value of primaryPhoneNumber. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final SandboxCompanyUpdateParams.BuildertoBuilder()final SandboxCompanyUpdateParams.CompanyWithoutId_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static SandboxCompanyUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of SandboxCompanyUpdateParams. -
-
Method Detail
-
accounts
final Optional<List<SandboxCompanyUpdateParams.Account>> accounts()
An array of bank account objects associated with the payroll/HRIS system.
-
departments
final Optional<List<SandboxCompanyUpdateParams.Department>> departments()
The array of company departments.
-
entity
final Optional<SandboxCompanyUpdateParams.Entity> entity()
The entity type object.
-
primaryEmail
final Optional<String> primaryEmail()
The email of the main administrator on the account.
-
primaryPhoneNumber
final Optional<String> primaryPhoneNumber()
The phone number of the main administrator on the account. Format: E.164, with extension where applicable, e.g.
+NNNNNNNNNNN xExtension
-
_accounts
final JsonField<List<SandboxCompanyUpdateParams.Account>> _accounts()
Returns the raw JSON value of accounts.
Unlike accounts, this method doesn't throw if the JSON field has an unexpected type.
-
_departments
final JsonField<List<SandboxCompanyUpdateParams.Department>> _departments()
Returns the raw JSON value of departments.
Unlike departments, this method doesn't throw if the JSON field has an unexpected type.
-
_ein
final JsonField<String> _ein()
Returns the raw JSON value of ein.
Unlike ein, this method doesn't throw if the JSON field has an unexpected type.
-
_entity
final JsonField<SandboxCompanyUpdateParams.Entity> _entity()
Returns the raw JSON value of entity.
Unlike entity, this method doesn't throw if the JSON field has an unexpected type.
-
_legalName
final JsonField<String> _legalName()
Returns the raw JSON value of legalName.
Unlike legalName, this method doesn't throw if the JSON field has an unexpected type.
-
_locations
final JsonField<List<Location>> _locations()
Returns the raw JSON value of locations.
Unlike locations, this method doesn't throw if the JSON field has an unexpected type.
-
_primaryEmail
final JsonField<String> _primaryEmail()
Returns the raw JSON value of primaryEmail.
Unlike primaryEmail, this method doesn't throw if the JSON field has an unexpected type.
-
_primaryPhoneNumber
final JsonField<String> _primaryPhoneNumber()
Returns the raw JSON value of primaryPhoneNumber.
Unlike primaryPhoneNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final SandboxCompanyUpdateParams.Builder toBuilder()
-
_body
final SandboxCompanyUpdateParams.CompanyWithoutId _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static SandboxCompanyUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of SandboxCompanyUpdateParams.
The following fields are required:
.accounts() .departments() .ein() .entity() .legalName() .locations() .primaryEmail() .primaryPhoneNumber()
-
-
-
-