Package com.tryfinch.api.models
Class SandboxCompanyUpdateParams.Entity
-
- All Implemented Interfaces:
public final class SandboxCompanyUpdateParams.EntityThe entity type object.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSandboxCompanyUpdateParams.Entity.BuilderA builder for Entity.
public final classSandboxCompanyUpdateParams.Entity.SubtypeThe tax payer subtype of the company.
public final classSandboxCompanyUpdateParams.Entity.TypeThe tax payer type of the company.
-
Method Summary
Modifier and Type Method Description final Optional<SandboxCompanyUpdateParams.Entity.Subtype>subtype()The tax payer subtype of the company. final Optional<SandboxCompanyUpdateParams.Entity.Type>type()The tax payer type of the company. final JsonField<SandboxCompanyUpdateParams.Entity.Subtype>_subtype()Returns the raw JSON value of subtype. final JsonField<SandboxCompanyUpdateParams.Entity.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final SandboxCompanyUpdateParams.Entity.BuildertoBuilder()final SandboxCompanyUpdateParams.Entityvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SandboxCompanyUpdateParams.Entity.Builderbuilder()Returns a mutable builder for constructing an instance of Entity. -
-
Method Detail
-
subtype
final Optional<SandboxCompanyUpdateParams.Entity.Subtype> subtype()
The tax payer subtype of the company.
-
type
final Optional<SandboxCompanyUpdateParams.Entity.Type> type()
The tax payer type of the company.
-
_subtype
final JsonField<SandboxCompanyUpdateParams.Entity.Subtype> _subtype()
Returns the raw JSON value of subtype.
Unlike subtype, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<SandboxCompanyUpdateParams.Entity.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SandboxCompanyUpdateParams.Entity.Builder toBuilder()
-
validate
final SandboxCompanyUpdateParams.Entity validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SandboxCompanyUpdateParams.Entity.Builder builder()
Returns a mutable builder for constructing an instance of Entity.
-
-
-
-