Class SandboxConnectionAccountCreateParams
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Params
public final class SandboxConnectionAccountCreateParams implements Params
Create a new account for an existing connection (company/provider pair)
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSandboxConnectionAccountCreateParams.BuilderA builder for SandboxConnectionAccountCreateParams.
public final classSandboxConnectionAccountCreateParams.Bodypublic final classSandboxConnectionAccountCreateParams.AuthenticationType
-
Method Summary
Modifier and Type Method Description final StringcompanyId()final StringproviderId()The provider associated with the access_tokenfinal Optional<SandboxConnectionAccountCreateParams.AuthenticationType>authenticationType()final Optional<List<String>>products()Optional, defaults to Organization products ( company,directory,employment,individual)final JsonField<String>_companyId()Returns the raw JSON value of companyId. final JsonField<String>_providerId()Returns the raw JSON value of providerId. final JsonField<SandboxConnectionAccountCreateParams.AuthenticationType>_authenticationType()Returns the raw JSON value of authenticationType. final JsonField<List<String>>_products()Returns the raw JSON value of products. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final SandboxConnectionAccountCreateParams.BuildertoBuilder()final SandboxConnectionAccountCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static SandboxConnectionAccountCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of SandboxConnectionAccountCreateParams. -
-
Method Detail
-
providerId
final String providerId()
The provider associated with the
access_token
-
authenticationType
final Optional<SandboxConnectionAccountCreateParams.AuthenticationType> authenticationType()
-
products
final Optional<List<String>> products()
Optional, defaults to Organization products (
company,directory,employment,individual)
-
_companyId
final JsonField<String> _companyId()
Returns the raw JSON value of companyId.
Unlike companyId, this method doesn't throw if the JSON field has an unexpected type.
-
_providerId
final JsonField<String> _providerId()
Returns the raw JSON value of providerId.
Unlike providerId, this method doesn't throw if the JSON field has an unexpected type.
-
_authenticationType
final JsonField<SandboxConnectionAccountCreateParams.AuthenticationType> _authenticationType()
Returns the raw JSON value of authenticationType.
Unlike authenticationType, this method doesn't throw if the JSON field has an unexpected type.
-
_products
final JsonField<List<String>> _products()
Returns the raw JSON value of products.
Unlike products, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final SandboxConnectionAccountCreateParams.Builder toBuilder()
-
_body
final SandboxConnectionAccountCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static SandboxConnectionAccountCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of SandboxConnectionAccountCreateParams.
The following fields are required:
.companyId() .providerId()
-
-
-
-