Class SandboxConnectionAccountCreateParams.Body
-
- All Implemented Interfaces:
public final class SandboxConnectionAccountCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSandboxConnectionAccountCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringcompanyId()final StringproviderId()The provider associated with the access_tokenfinal Optional<SandboxConnectionAccountCreateParams.AuthenticationType>authenticationType()final Optional<List<String>>products()Optional, defaults to Organization products ( company,directory,employment,individual)final JsonField<String>_companyId()Returns the raw JSON value of companyId. final JsonField<String>_providerId()Returns the raw JSON value of providerId. final JsonField<SandboxConnectionAccountCreateParams.AuthenticationType>_authenticationType()Returns the raw JSON value of authenticationType. final JsonField<List<String>>_products()Returns the raw JSON value of products. final Map<String, JsonValue>_additionalProperties()final SandboxConnectionAccountCreateParams.Body.BuildertoBuilder()final SandboxConnectionAccountCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SandboxConnectionAccountCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
providerId
final String providerId()
The provider associated with the
access_token
-
authenticationType
final Optional<SandboxConnectionAccountCreateParams.AuthenticationType> authenticationType()
-
products
final Optional<List<String>> products()
Optional, defaults to Organization products (
company,directory,employment,individual)
-
_companyId
final JsonField<String> _companyId()
Returns the raw JSON value of companyId.
Unlike companyId, this method doesn't throw if the JSON field has an unexpected type.
-
_providerId
final JsonField<String> _providerId()
Returns the raw JSON value of providerId.
Unlike providerId, this method doesn't throw if the JSON field has an unexpected type.
-
_authenticationType
final JsonField<SandboxConnectionAccountCreateParams.AuthenticationType> _authenticationType()
Returns the raw JSON value of authenticationType.
Unlike authenticationType, this method doesn't throw if the JSON field has an unexpected type.
-
_products
final JsonField<List<String>> _products()
Returns the raw JSON value of products.
Unlike products, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SandboxConnectionAccountCreateParams.Body.Builder toBuilder()
-
validate
final SandboxConnectionAccountCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SandboxConnectionAccountCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.companyId() .providerId()
-
-
-
-