Class SandboxConnectionAccountCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class SandboxConnectionAccountCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
companyId
final SandboxConnectionAccountCreateParams.Body.Builder companyId(String companyId)
-
companyId
final SandboxConnectionAccountCreateParams.Body.Builder companyId(JsonField<String> companyId)
Sets Builder.companyId to an arbitrary JSON value.
You should usually call Builder.companyId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
providerId
final SandboxConnectionAccountCreateParams.Body.Builder providerId(String providerId)
The provider associated with the
access_token
-
providerId
final SandboxConnectionAccountCreateParams.Body.Builder providerId(JsonField<String> providerId)
Sets Builder.providerId to an arbitrary JSON value.
You should usually call Builder.providerId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
authenticationType
final SandboxConnectionAccountCreateParams.Body.Builder authenticationType(SandboxConnectionAccountCreateParams.AuthenticationType authenticationType)
-
authenticationType
final SandboxConnectionAccountCreateParams.Body.Builder authenticationType(JsonField<SandboxConnectionAccountCreateParams.AuthenticationType> authenticationType)
Sets Builder.authenticationType to an arbitrary JSON value.
You should usually call Builder.authenticationType with a well-typed AuthenticationType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
products
final SandboxConnectionAccountCreateParams.Body.Builder products(List<String> products)
Optional, defaults to Organization products (
company,directory,employment,individual)
-
products
final SandboxConnectionAccountCreateParams.Body.Builder products(JsonField<List<String>> products)
Sets Builder.products to an arbitrary JSON value.
You should usually call Builder.products with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addProduct
final SandboxConnectionAccountCreateParams.Body.Builder addProduct(String product)
-
additionalProperties
final SandboxConnectionAccountCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SandboxConnectionAccountCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SandboxConnectionAccountCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SandboxConnectionAccountCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SandboxConnectionAccountCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SandboxConnectionAccountCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.companyId() .providerId()
-
-
-
-