Package com.tryfinch.api.models
Class SandboxConnectionAccountUpdateParams
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Params
public final class SandboxConnectionAccountUpdateParams implements Params
Update an existing sandbox account. Change the connection status to understand how the Finch API responds.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSandboxConnectionAccountUpdateParams.BuilderA builder for SandboxConnectionAccountUpdateParams.
public final classSandboxConnectionAccountUpdateParams.Body
-
Method Summary
Modifier and Type Method Description final Optional<ConnectionStatusType>connectionStatus()final JsonField<ConnectionStatusType>_connectionStatus()Returns the raw JSON value of connectionStatus. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final SandboxConnectionAccountUpdateParams.BuildertoBuilder()final SandboxConnectionAccountUpdateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static SandboxConnectionAccountUpdateParamsnone()final static SandboxConnectionAccountUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of SandboxConnectionAccountUpdateParams. -
-
Method Detail
-
connectionStatus
final Optional<ConnectionStatusType> connectionStatus()
-
_connectionStatus
final JsonField<ConnectionStatusType> _connectionStatus()
Returns the raw JSON value of connectionStatus.
Unlike connectionStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final SandboxConnectionAccountUpdateParams.Builder toBuilder()
-
_body
final SandboxConnectionAccountUpdateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static SandboxConnectionAccountUpdateParams none()
-
builder
final static SandboxConnectionAccountUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of SandboxConnectionAccountUpdateParams.
-
-
-
-