Package com.tryfinch.api.models
Class SandboxConnectionAccountUpdateParams.Body
-
- All Implemented Interfaces:
public final class SandboxConnectionAccountUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSandboxConnectionAccountUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<ConnectionStatusType>connectionStatus()final JsonField<ConnectionStatusType>_connectionStatus()Returns the raw JSON value of connectionStatus. final Map<String, JsonValue>_additionalProperties()final SandboxConnectionAccountUpdateParams.Body.BuildertoBuilder()final SandboxConnectionAccountUpdateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SandboxConnectionAccountUpdateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
connectionStatus
final Optional<ConnectionStatusType> connectionStatus()
-
_connectionStatus
final JsonField<ConnectionStatusType> _connectionStatus()
Returns the raw JSON value of connectionStatus.
Unlike connectionStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SandboxConnectionAccountUpdateParams.Body.Builder toBuilder()
-
validate
final SandboxConnectionAccountUpdateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SandboxConnectionAccountUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-