Class SandboxConnectionCreateParams
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Params
public final class SandboxConnectionCreateParams implements Params
Create a new connection (new company/provider pair) with a new account
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSandboxConnectionCreateParams.BuilderA builder for SandboxConnectionCreateParams.
public final classSandboxConnectionCreateParams.Bodypublic final classSandboxConnectionCreateParams.AuthenticationType
-
Method Summary
Modifier and Type Method Description final StringproviderId()The provider associated with the connection final Optional<SandboxConnectionCreateParams.AuthenticationType>authenticationType()final Optional<Long>employeeSize()Optional: the size of the employer to be created with this connection. final Optional<List<String>>products()final JsonField<String>_providerId()Returns the raw JSON value of providerId. final JsonField<SandboxConnectionCreateParams.AuthenticationType>_authenticationType()Returns the raw JSON value of authenticationType. final JsonField<Long>_employeeSize()Returns the raw JSON value of employeeSize. final JsonField<List<String>>_products()Returns the raw JSON value of products. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final SandboxConnectionCreateParams.BuildertoBuilder()final SandboxConnectionCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static SandboxConnectionCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of SandboxConnectionCreateParams. -
-
Method Detail
-
providerId
final String providerId()
The provider associated with the connection
-
authenticationType
final Optional<SandboxConnectionCreateParams.AuthenticationType> authenticationType()
-
employeeSize
final Optional<Long> employeeSize()
Optional: the size of the employer to be created with this connection. Defaults to 20. Note that if this is higher than 100, historical payroll data will not be generated, and instead only one pay period will be created.
-
_providerId
final JsonField<String> _providerId()
Returns the raw JSON value of providerId.
Unlike providerId, this method doesn't throw if the JSON field has an unexpected type.
-
_authenticationType
final JsonField<SandboxConnectionCreateParams.AuthenticationType> _authenticationType()
Returns the raw JSON value of authenticationType.
Unlike authenticationType, this method doesn't throw if the JSON field has an unexpected type.
-
_employeeSize
final JsonField<Long> _employeeSize()
Returns the raw JSON value of employeeSize.
Unlike employeeSize, this method doesn't throw if the JSON field has an unexpected type.
-
_products
final JsonField<List<String>> _products()
Returns the raw JSON value of products.
Unlike products, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final SandboxConnectionCreateParams.Builder toBuilder()
-
_body
final SandboxConnectionCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static SandboxConnectionCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of SandboxConnectionCreateParams.
The following fields are required:
.providerId()
-
-
-
-