Class SandboxConnectionCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class SandboxConnectionCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
providerId
final SandboxConnectionCreateParams.Body.Builder providerId(String providerId)
The provider associated with the connection
-
providerId
final SandboxConnectionCreateParams.Body.Builder providerId(JsonField<String> providerId)
Sets Builder.providerId to an arbitrary JSON value.
You should usually call Builder.providerId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
authenticationType
final SandboxConnectionCreateParams.Body.Builder authenticationType(SandboxConnectionCreateParams.AuthenticationType authenticationType)
-
authenticationType
final SandboxConnectionCreateParams.Body.Builder authenticationType(JsonField<SandboxConnectionCreateParams.AuthenticationType> authenticationType)
Sets Builder.authenticationType to an arbitrary JSON value.
You should usually call Builder.authenticationType with a well-typed AuthenticationType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
employeeSize
final SandboxConnectionCreateParams.Body.Builder employeeSize(Long employeeSize)
Optional: the size of the employer to be created with this connection. Defaults to 20. Note that if this is higher than 100, historical payroll data will not be generated, and instead only one pay period will be created.
-
employeeSize
final SandboxConnectionCreateParams.Body.Builder employeeSize(JsonField<Long> employeeSize)
Sets Builder.employeeSize to an arbitrary JSON value.
You should usually call Builder.employeeSize with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
products
final SandboxConnectionCreateParams.Body.Builder products(List<String> products)
-
products
final SandboxConnectionCreateParams.Body.Builder products(JsonField<List<String>> products)
Sets Builder.products to an arbitrary JSON value.
You should usually call Builder.products with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addProduct
final SandboxConnectionCreateParams.Body.Builder addProduct(String product)
-
additionalProperties
final SandboxConnectionCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SandboxConnectionCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SandboxConnectionCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SandboxConnectionCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SandboxConnectionCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SandboxConnectionCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.providerId()
-
-
-
-