Class SandboxDirectoryCreateParams.IndividualOrEmployment
-
- All Implemented Interfaces:
public final class SandboxDirectoryCreateParams.IndividualOrEmployment
-
-
Nested Class Summary
-
Method Summary
-
-
Method Detail
-
classCode
final Optional<String> classCode()
Worker's compensation classification code for this employee
-
customFields
final Optional<List<SandboxDirectoryCreateParams.IndividualOrEmployment.CustomField>> customFields()
Custom fields for the individual. These are fields which are defined by the employer in the system. Custom fields are not currently supported for assisted connections.
-
department
final Optional<SandboxDirectoryCreateParams.IndividualOrEmployment.Department> department()
The department object.
-
emails
final Optional<List<SandboxDirectoryCreateParams.IndividualOrEmployment.Email>> emails()
-
employment
final Optional<SandboxDirectoryCreateParams.IndividualOrEmployment.Employment> employment()
The employment object.
-
employmentStatus
final Optional<SandboxDirectoryCreateParams.IndividualOrEmployment.EmploymentStatus> employmentStatus()
The detailed employment status of the individual.
-
encryptedSsn
final Optional<String> encryptedSsn()
Social Security Number of the individual in encrypted format. This field is only available with the
ssnscope enabled and theoptions: { include: ['ssn'] }param set in the body.
-
ethnicity
final Optional<SandboxDirectoryCreateParams.IndividualOrEmployment.Ethnicity> ethnicity()
The EEOC-defined ethnicity of the individual.
-
flsaStatus
final Optional<SandboxDirectoryCreateParams.IndividualOrEmployment.FlsaStatus> flsaStatus()
The FLSA status of the individual. Available options:
exempt,non_exempt,unknown.
-
gender
final Optional<SandboxDirectoryCreateParams.IndividualOrEmployment.Gender> gender()
The gender of the individual.
-
income
final Optional<Income> income()
The employee's income as reported by the provider. This may not always be annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc, depending on what information the provider returns.
-
incomeHistory
final Optional<List<Income>> incomeHistory()
The array of income history.
-
isActive
final Optional<Boolean> isActive()
trueif the individual an an active employee or contractor at the company.
-
latestRehireDate
final Optional<String> latestRehireDate()
-
manager
final Optional<SandboxDirectoryCreateParams.IndividualOrEmployment.Manager> manager()
The manager object representing the manager of the individual within the org.
-
middleName
final Optional<String> middleName()
The legal middle name of the individual.
-
phoneNumbers
final Optional<List<SandboxDirectoryCreateParams.IndividualOrEmployment.PhoneNumber>> phoneNumbers()
-
preferredName
final Optional<String> preferredName()
The preferred name of the individual.
-
sourceId
final Optional<String> sourceId()
The source system's unique employment identifier for this individual
-
ssn
final Optional<String> ssn()
Social Security Number of the individual. This field is only available with the
ssnscope enabled and theoptions: { include: ['ssn'] }param set in the body. /developer-resources/Enable-SSN-Field.
-
_classCode
final JsonField<String> _classCode()
Returns the raw JSON value of classCode.
Unlike classCode, this method doesn't throw if the JSON field has an unexpected type.
-
_customFields
final JsonField<List<SandboxDirectoryCreateParams.IndividualOrEmployment.CustomField>> _customFields()
Returns the raw JSON value of customFields.
Unlike customFields, this method doesn't throw if the JSON field has an unexpected type.
-
_department
final JsonField<SandboxDirectoryCreateParams.IndividualOrEmployment.Department> _department()
Returns the raw JSON value of department.
Unlike department, this method doesn't throw if the JSON field has an unexpected type.
-
_dob
final JsonField<String> _dob()
Returns the raw JSON value of dob.
Unlike dob, this method doesn't throw if the JSON field has an unexpected type.
-
_emails
final JsonField<List<SandboxDirectoryCreateParams.IndividualOrEmployment.Email>> _emails()
Returns the raw JSON value of emails.
Unlike emails, this method doesn't throw if the JSON field has an unexpected type.
-
_employment
final JsonField<SandboxDirectoryCreateParams.IndividualOrEmployment.Employment> _employment()
Returns the raw JSON value of employment.
Unlike employment, this method doesn't throw if the JSON field has an unexpected type.
-
_employmentStatus
final JsonField<SandboxDirectoryCreateParams.IndividualOrEmployment.EmploymentStatus> _employmentStatus()
Returns the raw JSON value of employmentStatus.
Unlike employmentStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_encryptedSsn
final JsonField<String> _encryptedSsn()
Returns the raw JSON value of encryptedSsn.
Unlike encryptedSsn, this method doesn't throw if the JSON field has an unexpected type.
-
_endDate
final JsonField<String> _endDate()
Returns the raw JSON value of endDate.
Unlike endDate, this method doesn't throw if the JSON field has an unexpected type.
-
_ethnicity
final JsonField<SandboxDirectoryCreateParams.IndividualOrEmployment.Ethnicity> _ethnicity()
Returns the raw JSON value of ethnicity.
Unlike ethnicity, this method doesn't throw if the JSON field has an unexpected type.
-
_firstName
final JsonField<String> _firstName()
Returns the raw JSON value of firstName.
Unlike firstName, this method doesn't throw if the JSON field has an unexpected type.
-
_flsaStatus
final JsonField<SandboxDirectoryCreateParams.IndividualOrEmployment.FlsaStatus> _flsaStatus()
Returns the raw JSON value of flsaStatus.
Unlike flsaStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_gender
final JsonField<SandboxDirectoryCreateParams.IndividualOrEmployment.Gender> _gender()
Returns the raw JSON value of gender.
Unlike gender, this method doesn't throw if the JSON field has an unexpected type.
-
_income
final JsonField<Income> _income()
Returns the raw JSON value of income.
Unlike income, this method doesn't throw if the JSON field has an unexpected type.
-
_incomeHistory
final JsonField<List<Income>> _incomeHistory()
Returns the raw JSON value of incomeHistory.
Unlike incomeHistory, this method doesn't throw if the JSON field has an unexpected type.
-
_isActive
final JsonField<Boolean> _isActive()
Returns the raw JSON value of isActive.
Unlike isActive, this method doesn't throw if the JSON field has an unexpected type.
-
_lastName
final JsonField<String> _lastName()
Returns the raw JSON value of lastName.
Unlike lastName, this method doesn't throw if the JSON field has an unexpected type.
-
_latestRehireDate
final JsonField<String> _latestRehireDate()
Returns the raw JSON value of latestRehireDate.
Unlike latestRehireDate, this method doesn't throw if the JSON field has an unexpected type.
-
_location
final JsonField<Location> _location()
Returns the raw JSON value of location.
Unlike location, this method doesn't throw if the JSON field has an unexpected type.
-
_manager
final JsonField<SandboxDirectoryCreateParams.IndividualOrEmployment.Manager> _manager()
Returns the raw JSON value of manager.
Unlike manager, this method doesn't throw if the JSON field has an unexpected type.
-
_middleName
final JsonField<String> _middleName()
Returns the raw JSON value of middleName.
Unlike middleName, this method doesn't throw if the JSON field has an unexpected type.
-
_phoneNumbers
final JsonField<List<SandboxDirectoryCreateParams.IndividualOrEmployment.PhoneNumber>> _phoneNumbers()
Returns the raw JSON value of phoneNumbers.
Unlike phoneNumbers, this method doesn't throw if the JSON field has an unexpected type.
-
_preferredName
final JsonField<String> _preferredName()
Returns the raw JSON value of preferredName.
Unlike preferredName, this method doesn't throw if the JSON field has an unexpected type.
-
_residence
final JsonField<Location> _residence()
Returns the raw JSON value of residence.
Unlike residence, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceId
final JsonField<String> _sourceId()
Returns the raw JSON value of sourceId.
Unlike sourceId, this method doesn't throw if the JSON field has an unexpected type.
-
_ssn
final JsonField<String> _ssn()
Returns the raw JSON value of ssn.
Unlike ssn, this method doesn't throw if the JSON field has an unexpected type.
-
_startDate
final JsonField<String> _startDate()
Returns the raw JSON value of startDate.
Unlike startDate, this method doesn't throw if the JSON field has an unexpected type.
-
_title
final JsonField<String> _title()
Returns the raw JSON value of title.
Unlike title, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SandboxDirectoryCreateParams.IndividualOrEmployment.Builder toBuilder()
-
validate
final SandboxDirectoryCreateParams.IndividualOrEmployment validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SandboxDirectoryCreateParams.IndividualOrEmployment.Builder builder()
Returns a mutable builder for constructing an instance of IndividualOrEmployment.
-
-
-
-