Package com.tryfinch.api.models
Class SandboxDirectoryCreateParams.IndividualOrEmployment.CustomField
-
- All Implemented Interfaces:
public final class SandboxDirectoryCreateParams.IndividualOrEmployment.CustomField
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSandboxDirectoryCreateParams.IndividualOrEmployment.CustomField.BuilderA builder for CustomField.
public final classSandboxDirectoryCreateParams.IndividualOrEmployment.CustomField.Value
-
Method Summary
Modifier and Type Method Description final Optional<String>name()final Optional<SandboxDirectoryCreateParams.IndividualOrEmployment.CustomField.Value>value()final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<SandboxDirectoryCreateParams.IndividualOrEmployment.CustomField.Value>_value()Returns the raw JSON value of value. final Map<String, JsonValue>_additionalProperties()final SandboxDirectoryCreateParams.IndividualOrEmployment.CustomField.BuildertoBuilder()final SandboxDirectoryCreateParams.IndividualOrEmployment.CustomFieldvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SandboxDirectoryCreateParams.IndividualOrEmployment.CustomField.Builderbuilder()Returns a mutable builder for constructing an instance of CustomField. -
-
Method Detail
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_value
final JsonField<SandboxDirectoryCreateParams.IndividualOrEmployment.CustomField.Value> _value()
Returns the raw JSON value of value.
Unlike value, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final SandboxDirectoryCreateParams.IndividualOrEmployment.CustomField validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SandboxDirectoryCreateParams.IndividualOrEmployment.CustomField.Builder builder()
Returns a mutable builder for constructing an instance of CustomField.
-
-
-
-