Class SandboxEmploymentUpdateParams
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Params
public final class SandboxEmploymentUpdateParams implements Params
Update sandbox employment
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSandboxEmploymentUpdateParams.BuilderA builder for SandboxEmploymentUpdateParams.
public final classSandboxEmploymentUpdateParams.EmploymentWithoutIdpublic final classSandboxEmploymentUpdateParams.CustomFieldpublic final classSandboxEmploymentUpdateParams.DepartmentThe department object.
public final classSandboxEmploymentUpdateParams.EmploymentThe employment object.
public final classSandboxEmploymentUpdateParams.EmploymentStatusThe detailed employment status of the individual.
public final classSandboxEmploymentUpdateParams.FlsaStatusThe FLSA status of the individual. Available options:
exempt,non_exempt,unknown.public final classSandboxEmploymentUpdateParams.ManagerThe manager object representing the manager of the individual within the org.
-
Method Summary
Modifier and Type Method Description final Optional<String>individualId()final Optional<String>classCode()Worker's compensation classification code for this employee final Optional<List<SandboxEmploymentUpdateParams.CustomField>>customFields()Custom fields for the individual. final Optional<SandboxEmploymentUpdateParams.Department>department()The department object. final Optional<SandboxEmploymentUpdateParams.Employment>employment()The employment object. final Optional<SandboxEmploymentUpdateParams.EmploymentStatus>employmentStatus()The detailed employment status of the individual. final Optional<String>endDate()final Optional<String>firstName()The legal first name of the individual. final Optional<SandboxEmploymentUpdateParams.FlsaStatus>flsaStatus()The FLSA status of the individual. final Optional<Income>income()The employee's income as reported by the provider. final Optional<List<Income>>incomeHistory()The array of income history. final Optional<Boolean>isActive()trueif the individual an an active employee or contractor at the company.final Optional<String>lastName()The legal last name of the individual. final Optional<String>latestRehireDate()final Optional<Location>location()final Optional<SandboxEmploymentUpdateParams.Manager>manager()The manager object representing the manager of the individual within the org. final Optional<String>middleName()The legal middle name of the individual. final Optional<String>sourceId()The source system's unique employment identifier for this individual final Optional<String>startDate()final Optional<String>title()The current title of the individual. final JsonField<String>_classCode()Returns the raw JSON value of classCode. final JsonField<List<SandboxEmploymentUpdateParams.CustomField>>_customFields()Returns the raw JSON value of customFields. final JsonField<SandboxEmploymentUpdateParams.Department>_department()Returns the raw JSON value of department. final JsonField<SandboxEmploymentUpdateParams.Employment>_employment()Returns the raw JSON value of employment. final JsonField<SandboxEmploymentUpdateParams.EmploymentStatus>_employmentStatus()Returns the raw JSON value of employmentStatus. final JsonField<String>_endDate()Returns the raw JSON value of endDate. final JsonField<String>_firstName()Returns the raw JSON value of firstName. final JsonField<SandboxEmploymentUpdateParams.FlsaStatus>_flsaStatus()Returns the raw JSON value of flsaStatus. final JsonField<Income>_income()Returns the raw JSON value of income. final JsonField<List<Income>>_incomeHistory()Returns the raw JSON value of incomeHistory. final JsonField<Boolean>_isActive()Returns the raw JSON value of isActive. final JsonField<String>_lastName()Returns the raw JSON value of lastName. final JsonField<String>_latestRehireDate()Returns the raw JSON value of latestRehireDate. final JsonField<Location>_location()Returns the raw JSON value of location. final JsonField<SandboxEmploymentUpdateParams.Manager>_manager()Returns the raw JSON value of manager. final JsonField<String>_middleName()Returns the raw JSON value of middleName. final JsonField<String>_sourceId()Returns the raw JSON value of sourceId. final JsonField<String>_startDate()Returns the raw JSON value of startDate. final JsonField<String>_title()Returns the raw JSON value of title. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final SandboxEmploymentUpdateParams.BuildertoBuilder()final SandboxEmploymentUpdateParams.EmploymentWithoutId_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static SandboxEmploymentUpdateParamsnone()final static SandboxEmploymentUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of SandboxEmploymentUpdateParams. -
-
Method Detail
-
individualId
final Optional<String> individualId()
-
classCode
final Optional<String> classCode()
Worker's compensation classification code for this employee
-
customFields
final Optional<List<SandboxEmploymentUpdateParams.CustomField>> customFields()
Custom fields for the individual. These are fields which are defined by the employer in the system. Custom fields are not currently supported for assisted connections.
-
department
final Optional<SandboxEmploymentUpdateParams.Department> department()
The department object.
-
employment
final Optional<SandboxEmploymentUpdateParams.Employment> employment()
The employment object.
-
employmentStatus
final Optional<SandboxEmploymentUpdateParams.EmploymentStatus> employmentStatus()
The detailed employment status of the individual.
-
flsaStatus
final Optional<SandboxEmploymentUpdateParams.FlsaStatus> flsaStatus()
The FLSA status of the individual. Available options:
exempt,non_exempt,unknown.
-
income
final Optional<Income> income()
The employee's income as reported by the provider. This may not always be annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc, depending on what information the provider returns.
-
incomeHistory
final Optional<List<Income>> incomeHistory()
The array of income history.
-
isActive
final Optional<Boolean> isActive()
trueif the individual an an active employee or contractor at the company.
-
latestRehireDate
final Optional<String> latestRehireDate()
-
manager
final Optional<SandboxEmploymentUpdateParams.Manager> manager()
The manager object representing the manager of the individual within the org.
-
middleName
final Optional<String> middleName()
The legal middle name of the individual.
-
sourceId
final Optional<String> sourceId()
The source system's unique employment identifier for this individual
-
_classCode
final JsonField<String> _classCode()
Returns the raw JSON value of classCode.
Unlike classCode, this method doesn't throw if the JSON field has an unexpected type.
-
_customFields
final JsonField<List<SandboxEmploymentUpdateParams.CustomField>> _customFields()
Returns the raw JSON value of customFields.
Unlike customFields, this method doesn't throw if the JSON field has an unexpected type.
-
_department
final JsonField<SandboxEmploymentUpdateParams.Department> _department()
Returns the raw JSON value of department.
Unlike department, this method doesn't throw if the JSON field has an unexpected type.
-
_employment
final JsonField<SandboxEmploymentUpdateParams.Employment> _employment()
Returns the raw JSON value of employment.
Unlike employment, this method doesn't throw if the JSON field has an unexpected type.
-
_employmentStatus
final JsonField<SandboxEmploymentUpdateParams.EmploymentStatus> _employmentStatus()
Returns the raw JSON value of employmentStatus.
Unlike employmentStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_endDate
final JsonField<String> _endDate()
Returns the raw JSON value of endDate.
Unlike endDate, this method doesn't throw if the JSON field has an unexpected type.
-
_firstName
final JsonField<String> _firstName()
Returns the raw JSON value of firstName.
Unlike firstName, this method doesn't throw if the JSON field has an unexpected type.
-
_flsaStatus
final JsonField<SandboxEmploymentUpdateParams.FlsaStatus> _flsaStatus()
Returns the raw JSON value of flsaStatus.
Unlike flsaStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_income
final JsonField<Income> _income()
Returns the raw JSON value of income.
Unlike income, this method doesn't throw if the JSON field has an unexpected type.
-
_incomeHistory
final JsonField<List<Income>> _incomeHistory()
Returns the raw JSON value of incomeHistory.
Unlike incomeHistory, this method doesn't throw if the JSON field has an unexpected type.
-
_isActive
final JsonField<Boolean> _isActive()
Returns the raw JSON value of isActive.
Unlike isActive, this method doesn't throw if the JSON field has an unexpected type.
-
_lastName
final JsonField<String> _lastName()
Returns the raw JSON value of lastName.
Unlike lastName, this method doesn't throw if the JSON field has an unexpected type.
-
_latestRehireDate
final JsonField<String> _latestRehireDate()
Returns the raw JSON value of latestRehireDate.
Unlike latestRehireDate, this method doesn't throw if the JSON field has an unexpected type.
-
_location
final JsonField<Location> _location()
Returns the raw JSON value of location.
Unlike location, this method doesn't throw if the JSON field has an unexpected type.
-
_manager
final JsonField<SandboxEmploymentUpdateParams.Manager> _manager()
Returns the raw JSON value of manager.
Unlike manager, this method doesn't throw if the JSON field has an unexpected type.
-
_middleName
final JsonField<String> _middleName()
Returns the raw JSON value of middleName.
Unlike middleName, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceId
final JsonField<String> _sourceId()
Returns the raw JSON value of sourceId.
Unlike sourceId, this method doesn't throw if the JSON field has an unexpected type.
-
_startDate
final JsonField<String> _startDate()
Returns the raw JSON value of startDate.
Unlike startDate, this method doesn't throw if the JSON field has an unexpected type.
-
_title
final JsonField<String> _title()
Returns the raw JSON value of title.
Unlike title, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final SandboxEmploymentUpdateParams.Builder toBuilder()
-
_body
final SandboxEmploymentUpdateParams.EmploymentWithoutId _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static SandboxEmploymentUpdateParams none()
-
builder
final static SandboxEmploymentUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of SandboxEmploymentUpdateParams.
-
-
-
-