Package com.tryfinch.api.models
Class SandboxEmploymentUpdateParams.CustomField
-
- All Implemented Interfaces:
public final class SandboxEmploymentUpdateParams.CustomField
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSandboxEmploymentUpdateParams.CustomField.BuilderA builder for CustomField.
public final classSandboxEmploymentUpdateParams.CustomField.Value
-
Method Summary
Modifier and Type Method Description final Optional<String>name()final Optional<SandboxEmploymentUpdateParams.CustomField.Value>value()final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<SandboxEmploymentUpdateParams.CustomField.Value>_value()Returns the raw JSON value of value. final Map<String, JsonValue>_additionalProperties()final SandboxEmploymentUpdateParams.CustomField.BuildertoBuilder()final SandboxEmploymentUpdateParams.CustomFieldvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SandboxEmploymentUpdateParams.CustomField.Builderbuilder()Returns a mutable builder for constructing an instance of CustomField. -
-
Method Detail
-
value
final Optional<SandboxEmploymentUpdateParams.CustomField.Value> value()
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_value
final JsonField<SandboxEmploymentUpdateParams.CustomField.Value> _value()
Returns the raw JSON value of value.
Unlike value, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SandboxEmploymentUpdateParams.CustomField.Builder toBuilder()
-
validate
final SandboxEmploymentUpdateParams.CustomField validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SandboxEmploymentUpdateParams.CustomField.Builder builder()
Returns a mutable builder for constructing an instance of CustomField.
-
-
-
-