Package com.tryfinch.api.models
Class SandboxEmploymentUpdateParams.CustomField.Value
-
- All Implemented Interfaces:
public final class SandboxEmploymentUpdateParams.CustomField.Value
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSandboxEmploymentUpdateParams.CustomField.Value.VisitorAn interface that defines how to map each variant of Value to a value of type T.
-
Method Summary
-
-
Method Detail
-
jsonValues
final Optional<List<JsonValue>> jsonValues()
-
isJsonValues
final Boolean isJsonValues()
-
asJsonValues
final List<JsonValue> asJsonValues()
-
accept
final <T extends Any> T accept(SandboxEmploymentUpdateParams.CustomField.Value.Visitor<T> visitor)
Maps this instance's current variant to a value of type T using the given visitor.
Note that this method is not forwards compatible with new variants from the API, unless visitor overrides Visitor.unknown. To handle variants not known to this version of the SDK gracefully, consider overriding Visitor.unknown:
import com.tryfinch.api.core.JsonValue; import java.util.Optional; Optional<String> result = value.accept(new Value.Visitor<Optional<String>>() { @Override public Optional<String> visitString(String string) { return Optional.of(string.toString()); } // ... @Override public Optional<String> unknown(JsonValue json) { // Or inspect the `json`. return Optional.empty(); } });
-
validate
final SandboxEmploymentUpdateParams.CustomField.Value validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
ofString
final static SandboxEmploymentUpdateParams.CustomField.Value ofString(String string)
-
ofJsonValues
final static SandboxEmploymentUpdateParams.CustomField.Value ofJsonValues(List<JsonValue> jsonValues)
-
ofJson
final static SandboxEmploymentUpdateParams.CustomField.Value ofJson(JsonValue json)
-
ofNumber
final static SandboxEmploymentUpdateParams.CustomField.Value ofNumber(Double number)
-
ofBool
final static SandboxEmploymentUpdateParams.CustomField.Value ofBool(Boolean bool)
-
-
-
-