Package com.tryfinch.api.models
Class SandboxEmploymentUpdateParams.Department
-
- All Implemented Interfaces:
public final class SandboxEmploymentUpdateParams.DepartmentThe department object.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSandboxEmploymentUpdateParams.Department.BuilderA builder for Department.
-
Method Summary
Modifier and Type Method Description final Optional<String>name()The name of the department associated with the individual. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final SandboxEmploymentUpdateParams.Department.BuildertoBuilder()final SandboxEmploymentUpdateParams.Departmentvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SandboxEmploymentUpdateParams.Department.Builderbuilder()Returns a mutable builder for constructing an instance of Department. -
-
Method Detail
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SandboxEmploymentUpdateParams.Department.Builder toBuilder()
-
validate
final SandboxEmploymentUpdateParams.Department validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SandboxEmploymentUpdateParams.Department.Builder builder()
Returns a mutable builder for constructing an instance of Department.
-
-
-
-