Package com.tryfinch.api.models
Class SandboxEmploymentUpdateParams.Manager
-
- All Implemented Interfaces:
public final class SandboxEmploymentUpdateParams.ManagerThe manager object representing the manager of the individual within the org.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSandboxEmploymentUpdateParams.Manager.BuilderA builder for Manager.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()A stable Finch id(UUID v4) for an individual in the company.final JsonField<String>_id()Returns the raw JSON value of id. final Map<String, JsonValue>_additionalProperties()final SandboxEmploymentUpdateParams.Manager.BuildertoBuilder()final SandboxEmploymentUpdateParams.Managervalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SandboxEmploymentUpdateParams.Manager.Builderbuilder()Returns a mutable builder for constructing an instance of Manager. -
-
Method Detail
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SandboxEmploymentUpdateParams.Manager.Builder toBuilder()
-
validate
final SandboxEmploymentUpdateParams.Manager validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SandboxEmploymentUpdateParams.Manager.Builder builder()
Returns a mutable builder for constructing an instance of Manager.
-
-
-
-