Class SandboxIndividualUpdateParams
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Params
public final class SandboxIndividualUpdateParams implements Params
Update sandbox individual
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSandboxIndividualUpdateParams.BuilderA builder for SandboxIndividualUpdateParams.
public final classSandboxIndividualUpdateParams.IndividualWithoutIdpublic final classSandboxIndividualUpdateParams.Emailpublic final classSandboxIndividualUpdateParams.EthnicityThe EEOC-defined ethnicity of the individual.
public final classSandboxIndividualUpdateParams.GenderThe gender of the individual.
public final classSandboxIndividualUpdateParams.PhoneNumber
-
Method Summary
Modifier and Type Method Description final Optional<String>individualId()final Optional<String>dob()final Optional<List<SandboxIndividualUpdateParams.Email>>emails()final Optional<String>encryptedSsn()Social Security Number of the individual in encrypted format. final Optional<SandboxIndividualUpdateParams.Ethnicity>ethnicity()The EEOC-defined ethnicity of the individual. final Optional<String>firstName()The legal first name of the individual. final Optional<SandboxIndividualUpdateParams.Gender>gender()The gender of the individual. final Optional<String>lastName()The legal last name of the individual. final Optional<String>middleName()The legal middle name of the individual. final Optional<List<SandboxIndividualUpdateParams.PhoneNumber>>phoneNumbers()final Optional<String>preferredName()The preferred name of the individual. final Optional<Location>residence()final Optional<String>ssn()Social Security Number of the individual. final JsonField<String>_dob()Returns the raw JSON value of dob. final JsonField<List<SandboxIndividualUpdateParams.Email>>_emails()Returns the raw JSON value of emails. final JsonField<String>_encryptedSsn()Returns the raw JSON value of encryptedSsn. final JsonField<SandboxIndividualUpdateParams.Ethnicity>_ethnicity()Returns the raw JSON value of ethnicity. final JsonField<String>_firstName()Returns the raw JSON value of firstName. final JsonField<SandboxIndividualUpdateParams.Gender>_gender()Returns the raw JSON value of gender. final JsonField<String>_lastName()Returns the raw JSON value of lastName. final JsonField<String>_middleName()Returns the raw JSON value of middleName. final JsonField<List<SandboxIndividualUpdateParams.PhoneNumber>>_phoneNumbers()Returns the raw JSON value of phoneNumbers. final JsonField<String>_preferredName()Returns the raw JSON value of preferredName. final JsonField<Location>_residence()Returns the raw JSON value of residence. final JsonField<String>_ssn()Returns the raw JSON value of ssn. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final SandboxIndividualUpdateParams.BuildertoBuilder()final SandboxIndividualUpdateParams.IndividualWithoutId_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static SandboxIndividualUpdateParamsnone()final static SandboxIndividualUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of SandboxIndividualUpdateParams. -
-
Method Detail
-
individualId
final Optional<String> individualId()
-
emails
final Optional<List<SandboxIndividualUpdateParams.Email>> emails()
-
encryptedSsn
final Optional<String> encryptedSsn()
Social Security Number of the individual in encrypted format. This field is only available with the
ssnscope enabled and theoptions: { include: ['ssn'] }param set in the body.
-
ethnicity
final Optional<SandboxIndividualUpdateParams.Ethnicity> ethnicity()
The EEOC-defined ethnicity of the individual.
-
gender
final Optional<SandboxIndividualUpdateParams.Gender> gender()
The gender of the individual.
-
middleName
final Optional<String> middleName()
The legal middle name of the individual.
-
phoneNumbers
final Optional<List<SandboxIndividualUpdateParams.PhoneNumber>> phoneNumbers()
-
preferredName
final Optional<String> preferredName()
The preferred name of the individual.
-
ssn
final Optional<String> ssn()
Social Security Number of the individual. This field is only available with the
ssnscope enabled and theoptions: { include: ['ssn'] }param set in the body. /developer-resources/Enable-SSN-Field.
-
_dob
final JsonField<String> _dob()
Returns the raw JSON value of dob.
Unlike dob, this method doesn't throw if the JSON field has an unexpected type.
-
_emails
final JsonField<List<SandboxIndividualUpdateParams.Email>> _emails()
Returns the raw JSON value of emails.
Unlike emails, this method doesn't throw if the JSON field has an unexpected type.
-
_encryptedSsn
final JsonField<String> _encryptedSsn()
Returns the raw JSON value of encryptedSsn.
Unlike encryptedSsn, this method doesn't throw if the JSON field has an unexpected type.
-
_ethnicity
final JsonField<SandboxIndividualUpdateParams.Ethnicity> _ethnicity()
Returns the raw JSON value of ethnicity.
Unlike ethnicity, this method doesn't throw if the JSON field has an unexpected type.
-
_firstName
final JsonField<String> _firstName()
Returns the raw JSON value of firstName.
Unlike firstName, this method doesn't throw if the JSON field has an unexpected type.
-
_gender
final JsonField<SandboxIndividualUpdateParams.Gender> _gender()
Returns the raw JSON value of gender.
Unlike gender, this method doesn't throw if the JSON field has an unexpected type.
-
_lastName
final JsonField<String> _lastName()
Returns the raw JSON value of lastName.
Unlike lastName, this method doesn't throw if the JSON field has an unexpected type.
-
_middleName
final JsonField<String> _middleName()
Returns the raw JSON value of middleName.
Unlike middleName, this method doesn't throw if the JSON field has an unexpected type.
-
_phoneNumbers
final JsonField<List<SandboxIndividualUpdateParams.PhoneNumber>> _phoneNumbers()
Returns the raw JSON value of phoneNumbers.
Unlike phoneNumbers, this method doesn't throw if the JSON field has an unexpected type.
-
_preferredName
final JsonField<String> _preferredName()
Returns the raw JSON value of preferredName.
Unlike preferredName, this method doesn't throw if the JSON field has an unexpected type.
-
_residence
final JsonField<Location> _residence()
Returns the raw JSON value of residence.
Unlike residence, this method doesn't throw if the JSON field has an unexpected type.
-
_ssn
final JsonField<String> _ssn()
Returns the raw JSON value of ssn.
Unlike ssn, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final SandboxIndividualUpdateParams.Builder toBuilder()
-
_body
final SandboxIndividualUpdateParams.IndividualWithoutId _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static SandboxIndividualUpdateParams none()
-
builder
final static SandboxIndividualUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of SandboxIndividualUpdateParams.
-
-
-
-