Package com.tryfinch.api.models
Enum SandboxIndividualUpdateParams.Gender.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum SandboxIndividualUpdateParams.Gender.Known extends Enum<SandboxIndividualUpdateParams.Gender.Known>
An enum containing Gender's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<SandboxIndividualUpdateParams.Gender.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description FEMALEMALEOTHERDECLINE_TO_SPECIFY
-
Method Summary
Modifier and Type Method Description final SandboxIndividualUpdateParams.Gender.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<SandboxIndividualUpdateParams.Gender.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<SandboxIndividualUpdateParams.Gender.Known>getEntries()An enum containing Gender's known values. -
-
Method Detail
-
valueOf
final SandboxIndividualUpdateParams.Gender.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<SandboxIndividualUpdateParams.Gender.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<SandboxIndividualUpdateParams.Gender.Known> getEntries()
An enum containing Gender's known values.
-
-
-
-