Class SandboxIndividualUpdateParams.IndividualWithoutId
-
- All Implemented Interfaces:
public final class SandboxIndividualUpdateParams.IndividualWithoutId
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSandboxIndividualUpdateParams.IndividualWithoutId.BuilderA builder for IndividualWithoutId.
-
Method Summary
-
-
Method Detail
-
emails
final Optional<List<SandboxIndividualUpdateParams.Email>> emails()
-
encryptedSsn
final Optional<String> encryptedSsn()
Social Security Number of the individual in encrypted format. This field is only available with the
ssnscope enabled and theoptions: { include: ['ssn'] }param set in the body.
-
ethnicity
final Optional<SandboxIndividualUpdateParams.Ethnicity> ethnicity()
The EEOC-defined ethnicity of the individual.
-
gender
final Optional<SandboxIndividualUpdateParams.Gender> gender()
The gender of the individual.
-
middleName
final Optional<String> middleName()
The legal middle name of the individual.
-
phoneNumbers
final Optional<List<SandboxIndividualUpdateParams.PhoneNumber>> phoneNumbers()
-
preferredName
final Optional<String> preferredName()
The preferred name of the individual.
-
ssn
final Optional<String> ssn()
Social Security Number of the individual. This field is only available with the
ssnscope enabled and theoptions: { include: ['ssn'] }param set in the body. /developer-resources/Enable-SSN-Field.
-
_dob
final JsonField<String> _dob()
Returns the raw JSON value of dob.
Unlike dob, this method doesn't throw if the JSON field has an unexpected type.
-
_emails
final JsonField<List<SandboxIndividualUpdateParams.Email>> _emails()
Returns the raw JSON value of emails.
Unlike emails, this method doesn't throw if the JSON field has an unexpected type.
-
_encryptedSsn
final JsonField<String> _encryptedSsn()
Returns the raw JSON value of encryptedSsn.
Unlike encryptedSsn, this method doesn't throw if the JSON field has an unexpected type.
-
_ethnicity
final JsonField<SandboxIndividualUpdateParams.Ethnicity> _ethnicity()
Returns the raw JSON value of ethnicity.
Unlike ethnicity, this method doesn't throw if the JSON field has an unexpected type.
-
_firstName
final JsonField<String> _firstName()
Returns the raw JSON value of firstName.
Unlike firstName, this method doesn't throw if the JSON field has an unexpected type.
-
_gender
final JsonField<SandboxIndividualUpdateParams.Gender> _gender()
Returns the raw JSON value of gender.
Unlike gender, this method doesn't throw if the JSON field has an unexpected type.
-
_lastName
final JsonField<String> _lastName()
Returns the raw JSON value of lastName.
Unlike lastName, this method doesn't throw if the JSON field has an unexpected type.
-
_middleName
final JsonField<String> _middleName()
Returns the raw JSON value of middleName.
Unlike middleName, this method doesn't throw if the JSON field has an unexpected type.
-
_phoneNumbers
final JsonField<List<SandboxIndividualUpdateParams.PhoneNumber>> _phoneNumbers()
Returns the raw JSON value of phoneNumbers.
Unlike phoneNumbers, this method doesn't throw if the JSON field has an unexpected type.
-
_preferredName
final JsonField<String> _preferredName()
Returns the raw JSON value of preferredName.
Unlike preferredName, this method doesn't throw if the JSON field has an unexpected type.
-
_residence
final JsonField<Location> _residence()
Returns the raw JSON value of residence.
Unlike residence, this method doesn't throw if the JSON field has an unexpected type.
-
_ssn
final JsonField<String> _ssn()
Returns the raw JSON value of ssn.
Unlike ssn, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SandboxIndividualUpdateParams.IndividualWithoutId.Builder toBuilder()
-
validate
final SandboxIndividualUpdateParams.IndividualWithoutId validate()
-
builder
final static SandboxIndividualUpdateParams.IndividualWithoutId.Builder builder()
Returns a mutable builder for constructing an instance of IndividualWithoutId.
-
-
-
-