Package com.tryfinch.api.models
Class SandboxIndividualUpdateParams.PhoneNumber
-
- All Implemented Interfaces:
public final class SandboxIndividualUpdateParams.PhoneNumber
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSandboxIndividualUpdateParams.PhoneNumber.BuilderA builder for PhoneNumber.
public final classSandboxIndividualUpdateParams.PhoneNumber.Type
-
Method Summary
Modifier and Type Method Description final Optional<String>data()final Optional<SandboxIndividualUpdateParams.PhoneNumber.Type>type()final JsonField<String>_data()Returns the raw JSON value of data. final JsonField<SandboxIndividualUpdateParams.PhoneNumber.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final SandboxIndividualUpdateParams.PhoneNumber.BuildertoBuilder()final SandboxIndividualUpdateParams.PhoneNumbervalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SandboxIndividualUpdateParams.PhoneNumber.Builderbuilder()Returns a mutable builder for constructing an instance of PhoneNumber. -
-
Method Detail
-
type
final Optional<SandboxIndividualUpdateParams.PhoneNumber.Type> type()
-
_data
final JsonField<String> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<SandboxIndividualUpdateParams.PhoneNumber.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SandboxIndividualUpdateParams.PhoneNumber.Builder toBuilder()
-
validate
final SandboxIndividualUpdateParams.PhoneNumber validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SandboxIndividualUpdateParams.PhoneNumber.Builder builder()
Returns a mutable builder for constructing an instance of PhoneNumber.
-
-
-
-