Enum SandboxJobConfiguration.CompletionStatus.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum SandboxJobConfiguration.CompletionStatus.Value extends Enum<SandboxJobConfiguration.CompletionStatus.Value>
An enum containing CompletionStatus's known values, as well as an _UNKNOWN member.
An instance of CompletionStatus can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<SandboxJobConfiguration.CompletionStatus.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description COMPLETEREAUTH_ERRORPERMISSIONS_ERRORERROR_UNKNOWNAn enum member indicating that CompletionStatus was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final SandboxJobConfiguration.CompletionStatus.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<SandboxJobConfiguration.CompletionStatus.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<SandboxJobConfiguration.CompletionStatus.Value>getEntries()An enum containing CompletionStatus's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final SandboxJobConfiguration.CompletionStatus.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<SandboxJobConfiguration.CompletionStatus.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<SandboxJobConfiguration.CompletionStatus.Value> getEntries()
An enum containing CompletionStatus's known values, as well as an _UNKNOWN member.
An instance of CompletionStatus can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-