Package com.tryfinch.api.models
Class SandboxJobConfigurationUpdateParams
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Params
public final class SandboxJobConfigurationUpdateParams implements Params
Update configurations for sandbox jobs
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSandboxJobConfigurationUpdateParams.BuilderA builder for SandboxJobConfigurationUpdateParams.
-
Method Summary
Modifier and Type Method Description final SandboxJobConfigurationsandboxJobConfiguration()final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final SandboxJobConfigurationUpdateParams.BuildertoBuilder()final SandboxJobConfiguration_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static SandboxJobConfigurationUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of SandboxJobConfigurationUpdateParams. -
-
Method Detail
-
sandboxJobConfiguration
final SandboxJobConfiguration sandboxJobConfiguration()
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final SandboxJobConfigurationUpdateParams.Builder toBuilder()
-
_body
final SandboxJobConfiguration _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static SandboxJobConfigurationUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of SandboxJobConfigurationUpdateParams.
The following fields are required:
.sandboxJobConfiguration()
-
-
-
-