Package com.tryfinch.api.models
Class SandboxJobCreateParams
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Params
public final class SandboxJobCreateParams implements Params
Enqueue a new sandbox job
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSandboxJobCreateParams.BuilderA builder for SandboxJobCreateParams.
public final classSandboxJobCreateParams.Bodypublic final classSandboxJobCreateParams.TypeThe type of job to start. Currently the only supported type is
data_sync_all
-
Method Summary
Modifier and Type Method Description final SandboxJobCreateParams.Typetype()The type of job to start. final JsonField<SandboxJobCreateParams.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final SandboxJobCreateParams.BuildertoBuilder()final SandboxJobCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static SandboxJobCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of SandboxJobCreateParams. -
-
Method Detail
-
type
final SandboxJobCreateParams.Type type()
The type of job to start. Currently the only supported type is
data_sync_all
-
_type
final JsonField<SandboxJobCreateParams.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final SandboxJobCreateParams.Builder toBuilder()
-
_body
final SandboxJobCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static SandboxJobCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of SandboxJobCreateParams.
The following fields are required:
.type()
-
-
-
-