Package com.tryfinch.api.models
Class SandboxJobCreateParams.Body
-
- All Implemented Interfaces:
public final class SandboxJobCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSandboxJobCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final SandboxJobCreateParams.Typetype()The type of job to start. final JsonField<SandboxJobCreateParams.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final SandboxJobCreateParams.Body.BuildertoBuilder()final SandboxJobCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SandboxJobCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
type
final SandboxJobCreateParams.Type type()
The type of job to start. Currently the only supported type is
data_sync_all
-
_type
final JsonField<SandboxJobCreateParams.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SandboxJobCreateParams.Body.Builder toBuilder()
-
validate
final SandboxJobCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SandboxJobCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.type()
-
-
-
-