Class SandboxPaymentCreateParams.PayStatement
-
- All Implemented Interfaces:
public final class SandboxPaymentCreateParams.PayStatement
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSandboxPaymentCreateParams.PayStatement.BuilderA builder for PayStatement.
public final classSandboxPaymentCreateParams.PayStatement.Earningpublic final classSandboxPaymentCreateParams.PayStatement.EmployeeDeductionpublic final classSandboxPaymentCreateParams.PayStatement.EmployerContributionpublic final classSandboxPaymentCreateParams.PayStatement.PaymentMethodpublic final classSandboxPaymentCreateParams.PayStatement.Taxpublic final classSandboxPaymentCreateParams.PayStatement.Type
-
Method Summary
-
-
Method Detail
-
individualId
final String individualId()
-
earnings
final Optional<List<SandboxPaymentCreateParams.PayStatement.Earning>> earnings()
-
employeeDeductions
final Optional<List<SandboxPaymentCreateParams.PayStatement.EmployeeDeduction>> employeeDeductions()
-
employerContributions
final Optional<List<SandboxPaymentCreateParams.PayStatement.EmployerContribution>> employerContributions()
-
paymentMethod
final Optional<SandboxPaymentCreateParams.PayStatement.PaymentMethod> paymentMethod()
-
taxes
final Optional<List<SandboxPaymentCreateParams.PayStatement.Tax>> taxes()
-
totalHours
final Optional<Double> totalHours()
-
type
final Optional<SandboxPaymentCreateParams.PayStatement.Type> type()
-
_individualId
final JsonField<String> _individualId()
Returns the raw JSON value of individualId.
Unlike individualId, this method doesn't throw if the JSON field has an unexpected type.
-
_earnings
final JsonField<List<SandboxPaymentCreateParams.PayStatement.Earning>> _earnings()
Returns the raw JSON value of earnings.
Unlike earnings, this method doesn't throw if the JSON field has an unexpected type.
-
_employeeDeductions
final JsonField<List<SandboxPaymentCreateParams.PayStatement.EmployeeDeduction>> _employeeDeductions()
Returns the raw JSON value of employeeDeductions.
Unlike employeeDeductions, this method doesn't throw if the JSON field has an unexpected type.
-
_employerContributions
final JsonField<List<SandboxPaymentCreateParams.PayStatement.EmployerContribution>> _employerContributions()
Returns the raw JSON value of employerContributions.
Unlike employerContributions, this method doesn't throw if the JSON field has an unexpected type.
-
_grossPay
final JsonField<Long> _grossPay()
Returns the raw JSON value of grossPay.
Unlike grossPay, this method doesn't throw if the JSON field has an unexpected type.
-
_netPay
final JsonField<Long> _netPay()
Returns the raw JSON value of netPay.
Unlike netPay, this method doesn't throw if the JSON field has an unexpected type.
-
_paymentMethod
final JsonField<SandboxPaymentCreateParams.PayStatement.PaymentMethod> _paymentMethod()
Returns the raw JSON value of paymentMethod.
Unlike paymentMethod, this method doesn't throw if the JSON field has an unexpected type.
-
_taxes
final JsonField<List<SandboxPaymentCreateParams.PayStatement.Tax>> _taxes()
Returns the raw JSON value of taxes.
Unlike taxes, this method doesn't throw if the JSON field has an unexpected type.
-
_totalHours
final JsonField<Double> _totalHours()
Returns the raw JSON value of totalHours.
Unlike totalHours, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<SandboxPaymentCreateParams.PayStatement.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SandboxPaymentCreateParams.PayStatement.Builder toBuilder()
-
validate
final SandboxPaymentCreateParams.PayStatement validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SandboxPaymentCreateParams.PayStatement.Builder builder()
Returns a mutable builder for constructing an instance of PayStatement.
The following fields are required:
.individualId()
-
-
-
-