Class SandboxPaymentCreateParams.PayStatement.Earning
-
- All Implemented Interfaces:
public final class SandboxPaymentCreateParams.PayStatement.Earning
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSandboxPaymentCreateParams.PayStatement.Earning.BuilderA builder for Earning.
public final classSandboxPaymentCreateParams.PayStatement.Earning.Attributespublic final classSandboxPaymentCreateParams.PayStatement.Earning.TypeThe type of earning.
-
Method Summary
-
-
Method Detail
-
attributes
final Optional<SandboxPaymentCreateParams.PayStatement.Earning.Attributes> attributes()
-
hours
final Optional<Double> hours()
The number of hours associated with this earning. (For salaried employees, this could be hours per pay period,
0ornull, depending on the provider).
-
type
final Optional<SandboxPaymentCreateParams.PayStatement.Earning.Type> type()
The type of earning.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_attributes
final JsonField<SandboxPaymentCreateParams.PayStatement.Earning.Attributes> _attributes()
Returns the raw JSON value of attributes.
Unlike attributes, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_hours
final JsonField<Double> _hours()
Returns the raw JSON value of hours.
Unlike hours, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<SandboxPaymentCreateParams.PayStatement.Earning.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SandboxPaymentCreateParams.PayStatement.Earning.Builder toBuilder()
-
validate
final SandboxPaymentCreateParams.PayStatement.Earning validate()
-
builder
final static SandboxPaymentCreateParams.PayStatement.Earning.Builder builder()
Returns a mutable builder for constructing an instance of Earning.
-
-
-
-