Package com.tryfinch.api.models
Class SandboxPaymentCreateParams.PayStatement.EmployerContribution
-
- All Implemented Interfaces:
public final class SandboxPaymentCreateParams.PayStatement.EmployerContribution
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSandboxPaymentCreateParams.PayStatement.EmployerContribution.BuilderA builder for EmployerContribution.
public final classSandboxPaymentCreateParams.PayStatement.EmployerContribution.Attributes
-
Method Summary
-
-
Method Detail
-
attributes
final Optional<SandboxPaymentCreateParams.PayStatement.EmployerContribution.Attributes> attributes()
-
type
final Optional<BenefitType> type()
Type of benefit.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_attributes
final JsonField<SandboxPaymentCreateParams.PayStatement.EmployerContribution.Attributes> _attributes()
Returns the raw JSON value of attributes.
Unlike attributes, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<BenefitType> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final SandboxPaymentCreateParams.PayStatement.EmployerContribution validate()
-
builder
final static SandboxPaymentCreateParams.PayStatement.EmployerContribution.Builder builder()
Returns a mutable builder for constructing an instance of EmployerContribution.
-
-
-
-