Package com.tryfinch.api.models
Class SandboxPaymentCreateParams.PayStatement.EmployerContribution.Attributes
-
- All Implemented Interfaces:
public final class SandboxPaymentCreateParams.PayStatement.EmployerContribution.Attributes
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSandboxPaymentCreateParams.PayStatement.EmployerContribution.Attributes.BuilderA builder for Attributes.
public final classSandboxPaymentCreateParams.PayStatement.EmployerContribution.Attributes.Metadata
-
Method Summary
Modifier and Type Method Description final Optional<SandboxPaymentCreateParams.PayStatement.EmployerContribution.Attributes.Metadata>metadata()final JsonField<SandboxPaymentCreateParams.PayStatement.EmployerContribution.Attributes.Metadata>_metadata()Returns the raw JSON value of metadata. final Map<String, JsonValue>_additionalProperties()final SandboxPaymentCreateParams.PayStatement.EmployerContribution.Attributes.BuildertoBuilder()final SandboxPaymentCreateParams.PayStatement.EmployerContribution.Attributesvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SandboxPaymentCreateParams.PayStatement.EmployerContribution.Attributes.Builderbuilder()Returns a mutable builder for constructing an instance of Attributes. -
-
Method Detail
-
metadata
final Optional<SandboxPaymentCreateParams.PayStatement.EmployerContribution.Attributes.Metadata> metadata()
-
_metadata
final JsonField<SandboxPaymentCreateParams.PayStatement.EmployerContribution.Attributes.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SandboxPaymentCreateParams.PayStatement.EmployerContribution.Attributes.Builder toBuilder()
-
builder
final static SandboxPaymentCreateParams.PayStatement.EmployerContribution.Attributes.Builder builder()
Returns a mutable builder for constructing an instance of Attributes.
-
-
-
-