Package com.tryfinch.api.models
Class SessionNewResponse
-
- All Implemented Interfaces:
public final class SessionNewResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSessionNewResponse.BuilderA builder for SessionNewResponse.
-
Method Summary
Modifier and Type Method Description final StringconnectUrl()The Connect URL to redirect the user to for authentication final StringsessionId()The unique identifier for the created connect session final JsonField<String>_connectUrl()Returns the raw JSON value of connectUrl. final JsonField<String>_sessionId()Returns the raw JSON value of sessionId. final Map<String, JsonValue>_additionalProperties()final SessionNewResponse.BuildertoBuilder()final SessionNewResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SessionNewResponse.Builderbuilder()Returns a mutable builder for constructing an instance of SessionNewResponse. -
-
Method Detail
-
connectUrl
final String connectUrl()
The Connect URL to redirect the user to for authentication
-
_connectUrl
final JsonField<String> _connectUrl()
Returns the raw JSON value of connectUrl.
Unlike connectUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_sessionId
final JsonField<String> _sessionId()
Returns the raw JSON value of sessionId.
Unlike sessionId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SessionNewResponse.Builder toBuilder()
-
validate
final SessionNewResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SessionNewResponse.Builder builder()
Returns a mutable builder for constructing an instance of SessionNewResponse.
The following fields are required:
.connectUrl() .sessionId()
-
-
-
-