Package com.tryfinch.api.models
Class SessionReauthenticateResponse
-
- All Implemented Interfaces:
public final class SessionReauthenticateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSessionReauthenticateResponse.BuilderA builder for SessionReauthenticateResponse.
-
Method Summary
Modifier and Type Method Description final StringconnectUrl()The Connect URL to redirect the user to for reauthentication final StringsessionId()The unique identifier for the created connect session final JsonField<String>_connectUrl()Returns the raw JSON value of connectUrl. final JsonField<String>_sessionId()Returns the raw JSON value of sessionId. final Map<String, JsonValue>_additionalProperties()final SessionReauthenticateResponse.BuildertoBuilder()final SessionReauthenticateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SessionReauthenticateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of SessionReauthenticateResponse. -
-
Method Detail
-
connectUrl
final String connectUrl()
The Connect URL to redirect the user to for reauthentication
-
_connectUrl
final JsonField<String> _connectUrl()
Returns the raw JSON value of connectUrl.
Unlike connectUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_sessionId
final JsonField<String> _sessionId()
Returns the raw JSON value of sessionId.
Unlike sessionId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SessionReauthenticateResponse.Builder toBuilder()
-
validate
final SessionReauthenticateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SessionReauthenticateResponse.Builder builder()
Returns a mutable builder for constructing an instance of SessionReauthenticateResponse.
The following fields are required:
.connectUrl() .sessionId()
-
-
-
-