Class SessionReauthenticateResponse.Builder
-
- All Implemented Interfaces:
public final class SessionReauthenticateResponse.BuilderA builder for SessionReauthenticateResponse.
-
-
Method Summary
-
-
Method Detail
-
connectUrl
final SessionReauthenticateResponse.Builder connectUrl(String connectUrl)
The Connect URL to redirect the user to for reauthentication
-
connectUrl
final SessionReauthenticateResponse.Builder connectUrl(JsonField<String> connectUrl)
Sets Builder.connectUrl to an arbitrary JSON value.
You should usually call Builder.connectUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sessionId
final SessionReauthenticateResponse.Builder sessionId(String sessionId)
The unique identifier for the created connect session
-
sessionId
final SessionReauthenticateResponse.Builder sessionId(JsonField<String> sessionId)
Sets Builder.sessionId to an arbitrary JSON value.
You should usually call Builder.sessionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final SessionReauthenticateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SessionReauthenticateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SessionReauthenticateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SessionReauthenticateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SessionReauthenticateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SessionReauthenticateResponse build()
Returns an immutable instance of SessionReauthenticateResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.connectUrl() .sessionId()
-
-
-
-