Class SupportedBenefit
-
- All Implemented Interfaces:
public final class SupportedBenefit
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSupportedBenefit.BuilderA builder for SupportedBenefit.
public final classSupportedBenefit.CompanyContributionpublic final classSupportedBenefit.EmployeeDeductionpublic final classSupportedBenefit.HsaContributionLimit
-
Method Summary
Modifier and Type Method Description final Optional<Boolean>annualMaximum()Whether the provider supports an annual maximum for this benefit. final Optional<List<SupportedBenefit.CompanyContribution>>companyContribution()Supported contribution types. final Optional<String>description()final Optional<List<SupportedBenefit.EmployeeDeduction>>employeeDeduction()Supported deduction types. final List<BenefitFrequency>frequencies()The list of frequencies supported by the provider for this benefit final Optional<Boolean>catchUp()Whether the provider supports catch up for this benefit. final Optional<List<SupportedBenefit.HsaContributionLimit>>hsaContributionLimit()Whether the provider supports HSA contribution limits. final JsonField<Boolean>_annualMaximum()Returns the raw JSON value of annualMaximum. final JsonField<List<SupportedBenefit.CompanyContribution>>_companyContribution()Returns the raw JSON value of companyContribution. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<List<SupportedBenefit.EmployeeDeduction>>_employeeDeduction()Returns the raw JSON value of employeeDeduction. final JsonField<List<BenefitFrequency>>_frequencies()Returns the raw JSON value of frequencies. final JsonField<Boolean>_catchUp()Returns the raw JSON value of catchUp. final JsonField<List<SupportedBenefit.HsaContributionLimit>>_hsaContributionLimit()Returns the raw JSON value of hsaContributionLimit. final Map<String, JsonValue>_additionalProperties()final SupportedBenefit.BuildertoBuilder()final SupportedBenefitvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SupportedBenefit.Builderbuilder()Returns a mutable builder for constructing an instance of SupportedBenefit. -
-
Method Detail
-
annualMaximum
final Optional<Boolean> annualMaximum()
Whether the provider supports an annual maximum for this benefit.
-
companyContribution
final Optional<List<SupportedBenefit.CompanyContribution>> companyContribution()
Supported contribution types. An empty array indicates contributions are not supported.
-
description
final Optional<String> description()
-
employeeDeduction
final Optional<List<SupportedBenefit.EmployeeDeduction>> employeeDeduction()
Supported deduction types. An empty array indicates deductions are not supported.
-
frequencies
final List<BenefitFrequency> frequencies()
The list of frequencies supported by the provider for this benefit
-
catchUp
final Optional<Boolean> catchUp()
Whether the provider supports catch up for this benefit. This field will only be true for retirement benefits.
-
hsaContributionLimit
final Optional<List<SupportedBenefit.HsaContributionLimit>> hsaContributionLimit()
Whether the provider supports HSA contribution limits. Empty if this feature is not supported for the benefit. This array only has values for HSA benefits.
-
_annualMaximum
final JsonField<Boolean> _annualMaximum()
Returns the raw JSON value of annualMaximum.
Unlike annualMaximum, this method doesn't throw if the JSON field has an unexpected type.
-
_companyContribution
final JsonField<List<SupportedBenefit.CompanyContribution>> _companyContribution()
Returns the raw JSON value of companyContribution.
Unlike companyContribution, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_employeeDeduction
final JsonField<List<SupportedBenefit.EmployeeDeduction>> _employeeDeduction()
Returns the raw JSON value of employeeDeduction.
Unlike employeeDeduction, this method doesn't throw if the JSON field has an unexpected type.
-
_frequencies
final JsonField<List<BenefitFrequency>> _frequencies()
Returns the raw JSON value of frequencies.
Unlike frequencies, this method doesn't throw if the JSON field has an unexpected type.
-
_catchUp
final JsonField<Boolean> _catchUp()
Returns the raw JSON value of catchUp.
Unlike catchUp, this method doesn't throw if the JSON field has an unexpected type.
-
_hsaContributionLimit
final JsonField<List<SupportedBenefit.HsaContributionLimit>> _hsaContributionLimit()
Returns the raw JSON value of hsaContributionLimit.
Unlike hsaContributionLimit, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SupportedBenefit.Builder toBuilder()
-
validate
final SupportedBenefit validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SupportedBenefit.Builder builder()
Returns a mutable builder for constructing an instance of SupportedBenefit.
The following fields are required:
.annualMaximum() .companyContribution() .description() .employeeDeduction() .frequencies()
-
-
-
-