Class SupportedBenefit.Builder
-
- All Implemented Interfaces:
public final class SupportedBenefit.BuilderA builder for SupportedBenefit.
-
-
Method Summary
-
-
Method Detail
-
annualMaximum
final SupportedBenefit.Builder annualMaximum(Boolean annualMaximum)
Whether the provider supports an annual maximum for this benefit.
-
annualMaximum
final SupportedBenefit.Builder annualMaximum(Boolean annualMaximum)
Alias for Builder.annualMaximum.
This unboxed primitive overload exists for backwards compatibility.
-
annualMaximum
final SupportedBenefit.Builder annualMaximum(Optional<Boolean> annualMaximum)
Alias for calling Builder.annualMaximum with
annualMaximum.orElse(null).
-
annualMaximum
final SupportedBenefit.Builder annualMaximum(JsonField<Boolean> annualMaximum)
Sets Builder.annualMaximum to an arbitrary JSON value.
You should usually call Builder.annualMaximum with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
companyContribution
final SupportedBenefit.Builder companyContribution(List<SupportedBenefit.CompanyContribution> companyContribution)
Supported contribution types. An empty array indicates contributions are not supported.
-
companyContribution
final SupportedBenefit.Builder companyContribution(Optional<List<SupportedBenefit.CompanyContribution>> companyContribution)
Alias for calling Builder.companyContribution with
companyContribution.orElse(null).
-
companyContribution
final SupportedBenefit.Builder companyContribution(JsonField<List<SupportedBenefit.CompanyContribution>> companyContribution)
Sets Builder.companyContribution to an arbitrary JSON value.
You should usually call Builder.companyContribution with a well-typed
List<CompanyContribution?>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addCompanyContribution
final SupportedBenefit.Builder addCompanyContribution(SupportedBenefit.CompanyContribution companyContribution)
Adds a single CompanyContribution to Builder.companyContribution.
-
description
final SupportedBenefit.Builder description(String description)
-
description
final SupportedBenefit.Builder description(Optional<String> description)
Alias for calling Builder.description with
description.orElse(null).
-
description
final SupportedBenefit.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
employeeDeduction
final SupportedBenefit.Builder employeeDeduction(List<SupportedBenefit.EmployeeDeduction> employeeDeduction)
Supported deduction types. An empty array indicates deductions are not supported.
-
employeeDeduction
final SupportedBenefit.Builder employeeDeduction(Optional<List<SupportedBenefit.EmployeeDeduction>> employeeDeduction)
Alias for calling Builder.employeeDeduction with
employeeDeduction.orElse(null).
-
employeeDeduction
final SupportedBenefit.Builder employeeDeduction(JsonField<List<SupportedBenefit.EmployeeDeduction>> employeeDeduction)
Sets Builder.employeeDeduction to an arbitrary JSON value.
You should usually call Builder.employeeDeduction with a well-typed
List<EmployeeDeduction?>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEmployeeDeduction
final SupportedBenefit.Builder addEmployeeDeduction(SupportedBenefit.EmployeeDeduction employeeDeduction)
Adds a single EmployeeDeduction to Builder.employeeDeduction.
-
frequencies
final SupportedBenefit.Builder frequencies(List<BenefitFrequency> frequencies)
The list of frequencies supported by the provider for this benefit
-
frequencies
final SupportedBenefit.Builder frequencies(JsonField<List<BenefitFrequency>> frequencies)
Sets Builder.frequencies to an arbitrary JSON value.
You should usually call Builder.frequencies with a well-typed
List<BenefitFrequency?>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addFrequency
final SupportedBenefit.Builder addFrequency(BenefitFrequency frequency)
Adds a single BenefitFrequency to frequencies.
-
catchUp
final SupportedBenefit.Builder catchUp(Boolean catchUp)
Whether the provider supports catch up for this benefit. This field will only be true for retirement benefits.
-
catchUp
final SupportedBenefit.Builder catchUp(Boolean catchUp)
Alias for Builder.catchUp.
This unboxed primitive overload exists for backwards compatibility.
-
catchUp
final SupportedBenefit.Builder catchUp(Optional<Boolean> catchUp)
Alias for calling Builder.catchUp with
catchUp.orElse(null).
-
catchUp
final SupportedBenefit.Builder catchUp(JsonField<Boolean> catchUp)
Sets Builder.catchUp to an arbitrary JSON value.
You should usually call Builder.catchUp with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
hsaContributionLimit
final SupportedBenefit.Builder hsaContributionLimit(List<SupportedBenefit.HsaContributionLimit> hsaContributionLimit)
Whether the provider supports HSA contribution limits. Empty if this feature is not supported for the benefit. This array only has values for HSA benefits.
-
hsaContributionLimit
final SupportedBenefit.Builder hsaContributionLimit(Optional<List<SupportedBenefit.HsaContributionLimit>> hsaContributionLimit)
Alias for calling Builder.hsaContributionLimit with
hsaContributionLimit.orElse(null).
-
hsaContributionLimit
final SupportedBenefit.Builder hsaContributionLimit(JsonField<List<SupportedBenefit.HsaContributionLimit>> hsaContributionLimit)
Sets Builder.hsaContributionLimit to an arbitrary JSON value.
You should usually call Builder.hsaContributionLimit with a well-typed
List<HsaContributionLimit?>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addHsaContributionLimit
final SupportedBenefit.Builder addHsaContributionLimit(SupportedBenefit.HsaContributionLimit hsaContributionLimit)
Adds a single HsaContributionLimit to Builder.hsaContributionLimit.
-
additionalProperties
final SupportedBenefit.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SupportedBenefit.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SupportedBenefit.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SupportedBenefit.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SupportedBenefit.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SupportedBenefit build()
Returns an immutable instance of SupportedBenefit.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.annualMaximum() .companyContribution() .description() .employeeDeduction() .frequencies()
-
-
-
-