Package com.tryfinch.api.models
Class UnenrolledIndividualBenefitResponse
-
- All Implemented Interfaces:
public final class UnenrolledIndividualBenefitResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUnenrolledIndividualBenefitResponse.BuilderA builder for UnenrolledIndividualBenefitResponse.
-
Method Summary
Modifier and Type Method Description final StringjobId()final JsonField<String>_jobId()Returns the raw JSON value of jobId. final Map<String, JsonValue>_additionalProperties()final UnenrolledIndividualBenefitResponse.BuildertoBuilder()final UnenrolledIndividualBenefitResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static UnenrolledIndividualBenefitResponse.Builderbuilder()Returns a mutable builder for constructing an instance of UnenrolledIndividualBenefitResponse. -
-
Method Detail
-
_jobId
final JsonField<String> _jobId()
Returns the raw JSON value of jobId.
Unlike jobId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UnenrolledIndividualBenefitResponse.Builder toBuilder()
-
validate
final UnenrolledIndividualBenefitResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static UnenrolledIndividualBenefitResponse.Builder builder()
Returns a mutable builder for constructing an instance of UnenrolledIndividualBenefitResponse.
The following fields are required:
.jobId()
-
-
-
-