Class W42005.Builder
-
- All Implemented Interfaces:
public final class W42005.BuilderA builder for W42005.
-
-
Method Summary
Modifier and Type Method Description final W42005.Builderdata(W42005.Data data)Detailed information specific to the 2005 W4 form. final W42005.Builderdata(JsonField<W42005.Data> data)Sets Builder.data to an arbitrary JSON value. final W42005.Buildertype(W42005.Type type)Specifies the form type, indicating that this document is a 2005 W4 form. final W42005.Buildertype(JsonField<W42005.Type> type)Sets Builder.type to an arbitrary JSON value. final W42005.Builderyear(Double year)The tax year this W4 document applies to. final W42005.Builderyear(JsonField<Double> year)Sets Builder.year to an arbitrary JSON value. final W42005.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final W42005.BuilderputAdditionalProperty(String key, JsonValue value)final W42005.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final W42005.BuilderremoveAdditionalProperty(String key)final W42005.BuilderremoveAllAdditionalProperties(Set<String> keys)final W42005build()Returns an immutable instance of W42005. -
-
Method Detail
-
data
final W42005.Builder data(W42005.Data data)
Detailed information specific to the 2005 W4 form.
-
data
final W42005.Builder data(JsonField<W42005.Data> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed Data value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final W42005.Builder type(W42005.Type type)
Specifies the form type, indicating that this document is a 2005 W4 form.
-
type
final W42005.Builder type(JsonField<W42005.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
year
final W42005.Builder year(Double year)
The tax year this W4 document applies to.
-
year
final W42005.Builder year(JsonField<Double> year)
Sets Builder.year to an arbitrary JSON value.
You should usually call Builder.year with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final W42005.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final W42005.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final W42005.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final W42005.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final W42005.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-