Class W42005.Data
-
- All Implemented Interfaces:
public final class W42005.DataDetailed information specific to the 2005 W4 form.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classW42005.Data.BuilderA builder for Data.
public final classW42005.Data.ExemptionIndicates exemption status from federal tax withholding.
public final classW42005.Data.FilingStatusThe individual's filing status for tax purposes.
-
Method Summary
Modifier and Type Method Description final LongadditionalWithholding()Additional withholding amount (in cents). final Optional<W42005.Data.Exemption>exemption()Indicates exemption status from federal tax withholding. final Optional<W42005.Data.FilingStatus>filingStatus()The individual's filing status for tax purposes. final StringindividualId()The unique identifier for the individual associated with this 2005 W4 form. final LongtotalNumberOfAllowances()Total number of allowances claimed (in cents). final JsonField<Long>_additionalWithholding()Returns the raw JSON value of additionalWithholding. final JsonField<W42005.Data.Exemption>_exemption()Returns the raw JSON value of exemption. final JsonField<W42005.Data.FilingStatus>_filingStatus()Returns the raw JSON value of filingStatus. final JsonField<String>_individualId()Returns the raw JSON value of individualId. final JsonField<Long>_totalNumberOfAllowances()Returns the raw JSON value of totalNumberOfAllowances. final Map<String, JsonValue>_additionalProperties()final W42005.Data.BuildertoBuilder()final W42005.Datavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static W42005.Data.Builderbuilder()Returns a mutable builder for constructing an instance of Data. -
-
Method Detail
-
additionalWithholding
final Long additionalWithholding()
Additional withholding amount (in cents).
-
exemption
final Optional<W42005.Data.Exemption> exemption()
Indicates exemption status from federal tax withholding.
-
filingStatus
final Optional<W42005.Data.FilingStatus> filingStatus()
The individual's filing status for tax purposes.
-
individualId
final String individualId()
The unique identifier for the individual associated with this 2005 W4 form.
-
totalNumberOfAllowances
final Long totalNumberOfAllowances()
Total number of allowances claimed (in cents).
-
_additionalWithholding
final JsonField<Long> _additionalWithholding()
Returns the raw JSON value of additionalWithholding.
Unlike additionalWithholding, this method doesn't throw if the JSON field has an unexpected type.
-
_exemption
final JsonField<W42005.Data.Exemption> _exemption()
Returns the raw JSON value of exemption.
Unlike exemption, this method doesn't throw if the JSON field has an unexpected type.
-
_filingStatus
final JsonField<W42005.Data.FilingStatus> _filingStatus()
Returns the raw JSON value of filingStatus.
Unlike filingStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_individualId
final JsonField<String> _individualId()
Returns the raw JSON value of individualId.
Unlike individualId, this method doesn't throw if the JSON field has an unexpected type.
-
_totalNumberOfAllowances
final JsonField<Long> _totalNumberOfAllowances()
Returns the raw JSON value of totalNumberOfAllowances.
Unlike totalNumberOfAllowances, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final W42005.Data.Builder toBuilder()
-
validate
final W42005.Data validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static W42005.Data.Builder builder()
Returns a mutable builder for constructing an instance of Data.
The following fields are required:
.additionalWithholding() .exemption() .filingStatus() .individualId() .totalNumberOfAllowances()
-
-
-
-