Class W42005.Data.FilingStatus
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Enum
public final class W42005.Data.FilingStatus implements EnumThe individual's filing status for tax purposes.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumW42005.Data.FilingStatus.KnownAn enum containing FilingStatus's known values.
public enumW42005.Data.FilingStatus.ValueAn enum containing FilingStatus's known values, as well as an _UNKNOWN member.
An instance of FilingStatus can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static W42005.Data.FilingStatusMARRIEDpublic final static W42005.Data.FilingStatusMARRIED_BUT_WITHHOLD_AT_HIGHER_SINGLE_RATEpublic final static W42005.Data.FilingStatusSINGLE
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final W42005.Data.FilingStatus.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final W42005.Data.FilingStatus.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. final W42005.Data.FilingStatusvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static W42005.Data.FilingStatusof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final W42005.Data.FilingStatus.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final W42005.Data.FilingStatus.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
validate
final W42005.Data.FilingStatus validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
of
final static W42005.Data.FilingStatus of(String value)
-
-
-
-