Class W42020
-
- All Implemented Interfaces:
public final class W42020A 2020 version of the W-4 tax form containing information on an individual's filing status, dependents, and withholding details.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classW42020.BuilderA builder for W42020.
public final classW42020.DataDetailed information specific to the 2020 W4 form.
public final classW42020.TypeSpecifies the form type, indicating that this document is a 2020 W4 form.
-
Method Summary
Modifier and Type Method Description final W42020.Datadata()Detailed information specific to the 2020 W4 form. final W42020.Typetype()Specifies the form type, indicating that this document is a 2020 W4 form. final Doubleyear()The tax year this W4 document applies to. final JsonField<W42020.Data>_data()Returns the raw JSON value of data. final JsonField<W42020.Type>_type()Returns the raw JSON value of type. final JsonField<Double>_year()Returns the raw JSON value of year. final Map<String, JsonValue>_additionalProperties()final W42020.BuildertoBuilder()final W42020validate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static W42020.Builderbuilder()Returns a mutable builder for constructing an instance of W42020. -
-
Method Detail
-
data
final W42020.Data data()
Detailed information specific to the 2020 W4 form.
-
type
final W42020.Type type()
Specifies the form type, indicating that this document is a 2020 W4 form.
-
_data
final JsonField<W42020.Data> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<W42020.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_year
final JsonField<Double> _year()
Returns the raw JSON value of year.
Unlike year, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final W42020.Builder toBuilder()
-
validate
final W42020 validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static W42020.Builder builder()
Returns a mutable builder for constructing an instance of W42020.
The following fields are required:
.data() .type() .year()
-
-
-
-