Class W42020.Data.Builder
-
- All Implemented Interfaces:
public final class W42020.Data.BuilderA builder for Data.
-
-
Method Summary
Modifier and Type Method Description final W42020.Data.BuilderamountForOtherDependents(Long amountForOtherDependents)Amount claimed for dependents other than qualifying children under 17 (in cents). final W42020.Data.BuilderamountForOtherDependents(Long amountForOtherDependents)Alias for Builder.amountForOtherDependents. final W42020.Data.BuilderamountForOtherDependents(Optional<Long> amountForOtherDependents)Alias for calling Builder.amountForOtherDependents with amountForOtherDependents.orElse(null).final W42020.Data.BuilderamountForOtherDependents(JsonField<Long> amountForOtherDependents)Sets Builder.amountForOtherDependents to an arbitrary JSON value. final W42020.Data.BuilderamountForQualifyingChildrenUnder17(Long amountForQualifyingChildrenUnder17)Amount claimed for dependents under 17 years old (in cents). final W42020.Data.BuilderamountForQualifyingChildrenUnder17(Long amountForQualifyingChildrenUnder17)Alias for Builder.amountForQualifyingChildrenUnder17. final W42020.Data.BuilderamountForQualifyingChildrenUnder17(Optional<Long> amountForQualifyingChildrenUnder17)Alias for calling Builder.amountForQualifyingChildrenUnder17 with amountForQualifyingChildrenUnder17.orElse(null).final W42020.Data.BuilderamountForQualifyingChildrenUnder17(JsonField<Long> amountForQualifyingChildrenUnder17)Sets Builder.amountForQualifyingChildrenUnder17 to an arbitrary JSON value. final W42020.Data.Builderdeductions(Long deductions)Deductible expenses (in cents). final W42020.Data.Builderdeductions(Long deductions)Alias for Builder.deductions. final W42020.Data.Builderdeductions(Optional<Long> deductions)Alias for calling Builder.deductions with deductions.orElse(null).final W42020.Data.Builderdeductions(JsonField<Long> deductions)Sets Builder.deductions to an arbitrary JSON value. final W42020.Data.BuilderextraWithholding(Long extraWithholding)Additional withholding amount (in cents). final W42020.Data.BuilderextraWithholding(Long extraWithholding)Alias for Builder.extraWithholding. final W42020.Data.BuilderextraWithholding(Optional<Long> extraWithholding)Alias for calling Builder.extraWithholding with extraWithholding.orElse(null).final W42020.Data.BuilderextraWithholding(JsonField<Long> extraWithholding)Sets Builder.extraWithholding to an arbitrary JSON value. final W42020.Data.BuilderfilingStatus(W42020.Data.FilingStatus filingStatus)The individual's filing status for tax purposes. final W42020.Data.BuilderfilingStatus(Optional<W42020.Data.FilingStatus> filingStatus)Alias for calling Builder.filingStatus with filingStatus.orElse(null).final W42020.Data.BuilderfilingStatus(JsonField<W42020.Data.FilingStatus> filingStatus)Sets Builder.filingStatus to an arbitrary JSON value. final W42020.Data.BuilderindividualId(String individualId)The unique identifier for the individual associated with this document. final W42020.Data.BuilderindividualId(JsonField<String> individualId)Sets Builder.individualId to an arbitrary JSON value. final W42020.Data.BuilderotherIncome(Long otherIncome)Additional income from sources outside of primary employment (in cents). final W42020.Data.BuilderotherIncome(Long otherIncome)Alias for Builder.otherIncome. final W42020.Data.BuilderotherIncome(Optional<Long> otherIncome)Alias for calling Builder.otherIncome with otherIncome.orElse(null).final W42020.Data.BuilderotherIncome(JsonField<Long> otherIncome)Sets Builder.otherIncome to an arbitrary JSON value. final W42020.Data.BuildertotalClaimDependentAndOtherCredits(Long totalClaimDependentAndOtherCredits)Total amount claimed for dependents and other credits (in cents). final W42020.Data.BuildertotalClaimDependentAndOtherCredits(Long totalClaimDependentAndOtherCredits)Alias for Builder.totalClaimDependentAndOtherCredits. final W42020.Data.BuildertotalClaimDependentAndOtherCredits(Optional<Long> totalClaimDependentAndOtherCredits)Alias for calling Builder.totalClaimDependentAndOtherCredits with totalClaimDependentAndOtherCredits.orElse(null).final W42020.Data.BuildertotalClaimDependentAndOtherCredits(JsonField<Long> totalClaimDependentAndOtherCredits)Sets Builder.totalClaimDependentAndOtherCredits to an arbitrary JSON value. final W42020.Data.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final W42020.Data.BuilderputAdditionalProperty(String key, JsonValue value)final W42020.Data.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final W42020.Data.BuilderremoveAdditionalProperty(String key)final W42020.Data.BuilderremoveAllAdditionalProperties(Set<String> keys)final W42020.Databuild()Returns an immutable instance of Data. -
-
Method Detail
-
amountForOtherDependents
final W42020.Data.Builder amountForOtherDependents(Long amountForOtherDependents)
Amount claimed for dependents other than qualifying children under 17 (in cents).
-
amountForOtherDependents
final W42020.Data.Builder amountForOtherDependents(Long amountForOtherDependents)
Alias for Builder.amountForOtherDependents.
This unboxed primitive overload exists for backwards compatibility.
-
amountForOtherDependents
final W42020.Data.Builder amountForOtherDependents(Optional<Long> amountForOtherDependents)
Alias for calling Builder.amountForOtherDependents with
amountForOtherDependents.orElse(null).
-
amountForOtherDependents
final W42020.Data.Builder amountForOtherDependents(JsonField<Long> amountForOtherDependents)
Sets Builder.amountForOtherDependents to an arbitrary JSON value.
You should usually call Builder.amountForOtherDependents with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amountForQualifyingChildrenUnder17
final W42020.Data.Builder amountForQualifyingChildrenUnder17(Long amountForQualifyingChildrenUnder17)
Amount claimed for dependents under 17 years old (in cents).
-
amountForQualifyingChildrenUnder17
final W42020.Data.Builder amountForQualifyingChildrenUnder17(Long amountForQualifyingChildrenUnder17)
Alias for Builder.amountForQualifyingChildrenUnder17.
This unboxed primitive overload exists for backwards compatibility.
-
amountForQualifyingChildrenUnder17
final W42020.Data.Builder amountForQualifyingChildrenUnder17(Optional<Long> amountForQualifyingChildrenUnder17)
Alias for calling Builder.amountForQualifyingChildrenUnder17 with
amountForQualifyingChildrenUnder17.orElse(null).
-
amountForQualifyingChildrenUnder17
final W42020.Data.Builder amountForQualifyingChildrenUnder17(JsonField<Long> amountForQualifyingChildrenUnder17)
Sets Builder.amountForQualifyingChildrenUnder17 to an arbitrary JSON value.
You should usually call Builder.amountForQualifyingChildrenUnder17 with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
deductions
final W42020.Data.Builder deductions(Long deductions)
Deductible expenses (in cents).
-
deductions
final W42020.Data.Builder deductions(Long deductions)
Alias for Builder.deductions.
This unboxed primitive overload exists for backwards compatibility.
-
deductions
final W42020.Data.Builder deductions(Optional<Long> deductions)
Alias for calling Builder.deductions with
deductions.orElse(null).
-
deductions
final W42020.Data.Builder deductions(JsonField<Long> deductions)
Sets Builder.deductions to an arbitrary JSON value.
You should usually call Builder.deductions with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
extraWithholding
final W42020.Data.Builder extraWithholding(Long extraWithholding)
Additional withholding amount (in cents).
-
extraWithholding
final W42020.Data.Builder extraWithholding(Long extraWithholding)
Alias for Builder.extraWithholding.
This unboxed primitive overload exists for backwards compatibility.
-
extraWithholding
final W42020.Data.Builder extraWithholding(Optional<Long> extraWithholding)
Alias for calling Builder.extraWithholding with
extraWithholding.orElse(null).
-
extraWithholding
final W42020.Data.Builder extraWithholding(JsonField<Long> extraWithholding)
Sets Builder.extraWithholding to an arbitrary JSON value.
You should usually call Builder.extraWithholding with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
filingStatus
final W42020.Data.Builder filingStatus(W42020.Data.FilingStatus filingStatus)
The individual's filing status for tax purposes.
-
filingStatus
final W42020.Data.Builder filingStatus(Optional<W42020.Data.FilingStatus> filingStatus)
Alias for calling Builder.filingStatus with
filingStatus.orElse(null).
-
filingStatus
final W42020.Data.Builder filingStatus(JsonField<W42020.Data.FilingStatus> filingStatus)
Sets Builder.filingStatus to an arbitrary JSON value.
You should usually call Builder.filingStatus with a well-typed FilingStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
individualId
final W42020.Data.Builder individualId(String individualId)
The unique identifier for the individual associated with this document.
-
individualId
final W42020.Data.Builder individualId(JsonField<String> individualId)
Sets Builder.individualId to an arbitrary JSON value.
You should usually call Builder.individualId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
otherIncome
final W42020.Data.Builder otherIncome(Long otherIncome)
Additional income from sources outside of primary employment (in cents).
-
otherIncome
final W42020.Data.Builder otherIncome(Long otherIncome)
Alias for Builder.otherIncome.
This unboxed primitive overload exists for backwards compatibility.
-
otherIncome
final W42020.Data.Builder otherIncome(Optional<Long> otherIncome)
Alias for calling Builder.otherIncome with
otherIncome.orElse(null).
-
otherIncome
final W42020.Data.Builder otherIncome(JsonField<Long> otherIncome)
Sets Builder.otherIncome to an arbitrary JSON value.
You should usually call Builder.otherIncome with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalClaimDependentAndOtherCredits
final W42020.Data.Builder totalClaimDependentAndOtherCredits(Long totalClaimDependentAndOtherCredits)
Total amount claimed for dependents and other credits (in cents).
-
totalClaimDependentAndOtherCredits
final W42020.Data.Builder totalClaimDependentAndOtherCredits(Long totalClaimDependentAndOtherCredits)
Alias for Builder.totalClaimDependentAndOtherCredits.
This unboxed primitive overload exists for backwards compatibility.
-
totalClaimDependentAndOtherCredits
final W42020.Data.Builder totalClaimDependentAndOtherCredits(Optional<Long> totalClaimDependentAndOtherCredits)
Alias for calling Builder.totalClaimDependentAndOtherCredits with
totalClaimDependentAndOtherCredits.orElse(null).
-
totalClaimDependentAndOtherCredits
final W42020.Data.Builder totalClaimDependentAndOtherCredits(JsonField<Long> totalClaimDependentAndOtherCredits)
Sets Builder.totalClaimDependentAndOtherCredits to an arbitrary JSON value.
You should usually call Builder.totalClaimDependentAndOtherCredits with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final W42020.Data.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final W42020.Data.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final W42020.Data.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final W42020.Data.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final W42020.Data.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final W42020.Data build()
Returns an immutable instance of Data.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-