Package com.tryfinch.api.services.async
Interface AccessTokenServiceAsync
-
- All Implemented Interfaces:
public interface AccessTokenServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAccessTokenServiceAsync.WithRawResponseA view of AccessTokenServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AccessTokenServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract AccessTokenServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CreateAccessTokenResponse>create(AccessTokenCreateParams params)Exchange the authorization code for an access token abstract CompletableFuture<CreateAccessTokenResponse>create(AccessTokenCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract AccessTokenServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract AccessTokenServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<CreateAccessTokenResponse> create(AccessTokenCreateParams params)
Exchange the authorization code for an access token
-
create
abstract CompletableFuture<CreateAccessTokenResponse> create(AccessTokenCreateParams params, RequestOptions requestOptions)
-
-
-
-