Package com.tryfinch.api.services.async
Class AccessTokenServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.AccessTokenServiceAsync
public final class AccessTokenServiceAsyncImpl implements AccessTokenServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccessTokenServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AccessTokenServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AccessTokenServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CreateAccessTokenResponse>create(AccessTokenCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
AccessTokenServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
AccessTokenServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<CreateAccessTokenResponse> create(AccessTokenCreateParams params, RequestOptions requestOptions)
-
-
-
-