Package com.tryfinch.api.services.async
Class AccessTokenServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.AccessTokenServiceAsync.WithRawResponse
public final class AccessTokenServiceAsyncImpl.WithRawResponseImpl implements AccessTokenServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description AccessTokenServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<CreateAccessTokenResponse>>create(AccessTokenCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
AccessTokenServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<CreateAccessTokenResponse>> create(AccessTokenCreateParams params, RequestOptions requestOptions)
-
-
-
-