Package com.tryfinch.api.services.async
Interface AccountServiceAsync
-
- All Implemented Interfaces:
public interface AccountServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAccountServiceAsync.WithRawResponseA view of AccountServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract AccountServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract AccountServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
disconnect
CompletableFuture<DisconnectResponse> disconnect()
Disconnect one or more
access_tokens from your application.
-
disconnect
abstract CompletableFuture<DisconnectResponse> disconnect(AccountDisconnectParams params, RequestOptions requestOptions)
-
disconnect
CompletableFuture<DisconnectResponse> disconnect(AccountDisconnectParams params)
-
disconnect
CompletableFuture<DisconnectResponse> disconnect(RequestOptions requestOptions)
-
disconnectEntity
CompletableFuture<DisconnectEntityResponse> disconnectEntity(AccountDisconnectEntityParams params)
Disconnect entity(s) from a connection without affecting other entities associated with the same connection.
-
disconnectEntity
abstract CompletableFuture<DisconnectEntityResponse> disconnectEntity(AccountDisconnectEntityParams params, RequestOptions requestOptions)
-
introspect
CompletableFuture<Introspection> introspect()
Read account information associated with an
access_token
-
introspect
abstract CompletableFuture<Introspection> introspect(AccountIntrospectParams params, RequestOptions requestOptions)
-
introspect
CompletableFuture<Introspection> introspect(AccountIntrospectParams params)
-
introspect
CompletableFuture<Introspection> introspect(RequestOptions requestOptions)
-
-
-
-