Package com.tryfinch.api.services.async
Class AccountServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.AccountServiceAsync.WithRawResponse
public final class AccountServiceAsyncImpl.WithRawResponseImpl implements AccountServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description AccountServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<DisconnectResponse>>disconnect(AccountDisconnectParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<DisconnectEntityResponse>>disconnectEntity(AccountDisconnectEntityParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<Introspection>>introspect(AccountIntrospectParams params, RequestOptions requestOptions)-
Methods inherited from class com.tryfinch.api.services.async.AccountServiceAsync.WithRawResponse
disconnect, disconnect, disconnect, disconnectEntity, introspect, introspect, introspect -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
AccountServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
disconnect
CompletableFuture<HttpResponseFor<DisconnectResponse>> disconnect(AccountDisconnectParams params, RequestOptions requestOptions)
-
disconnectEntity
CompletableFuture<HttpResponseFor<DisconnectEntityResponse>> disconnectEntity(AccountDisconnectEntityParams params, RequestOptions requestOptions)
-
introspect
CompletableFuture<HttpResponseFor<Introspection>> introspect(AccountIntrospectParams params, RequestOptions requestOptions)
-
-
-
-