Package com.tryfinch.api.services.async
Interface ConnectServiceAsync
-
- All Implemented Interfaces:
public interface ConnectServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceConnectServiceAsync.WithRawResponseA view of ConnectServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ConnectServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract ConnectServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract SessionServiceAsyncsessions()-
-
Method Detail
-
withRawResponse
abstract ConnectServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ConnectServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
sessions
abstract SessionServiceAsync sessions()
-
-
-
-