Package com.tryfinch.api.services.async
Interface ConnectServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface ConnectServiceAsync.WithRawResponseA view of ConnectServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract ConnectServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract SessionServiceAsync.WithRawResponsesessions()-
-
Method Detail
-
withOptions
abstract ConnectServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
sessions
abstract SessionServiceAsync.WithRawResponse sessions()
-
-
-
-