Package com.tryfinch.api.services.async
Class ConnectServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.ConnectServiceAsync
public final class ConnectServiceAsyncImpl implements ConnectServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classConnectServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ConnectServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. ConnectServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. SessionServiceAsyncsessions()-
-
Method Detail
-
withRawResponse
ConnectServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ConnectServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
sessions
SessionServiceAsync sessions()
-
-
-
-