Package com.tryfinch.api.services.async
Class ConnectServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.ConnectServiceAsync.WithRawResponse
public final class ConnectServiceAsyncImpl.WithRawResponseImpl implements ConnectServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description ConnectServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. SessionServiceAsync.WithRawResponsesessions()-
-
Method Detail
-
withOptions
ConnectServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
sessions
SessionServiceAsync.WithRawResponse sessions()
-
-
-
-