Package com.tryfinch.api.services.async
Interface HrisServiceAsync
-
- All Implemented Interfaces:
public interface HrisServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceHrisServiceAsync.WithRawResponseA view of HrisServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract HrisServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract HrisServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract CompanyServiceAsynccompany()abstract DirectoryServiceAsyncdirectory()abstract IndividualServiceAsyncindividuals()abstract EmploymentServiceAsyncemployments()abstract PaymentServiceAsyncpayments()abstract PayStatementServiceAsyncpayStatements()abstract DocumentServiceAsyncdocuments()abstract BenefitServiceAsyncbenefits()-
-
Method Detail
-
withRawResponse
abstract HrisServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract HrisServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
company
abstract CompanyServiceAsync company()
-
directory
abstract DirectoryServiceAsync directory()
-
individuals
abstract IndividualServiceAsync individuals()
-
employments
abstract EmploymentServiceAsync employments()
-
payments
abstract PaymentServiceAsync payments()
-
payStatements
abstract PayStatementServiceAsync payStatements()
-
documents
abstract DocumentServiceAsync documents()
-
benefits
abstract BenefitServiceAsync benefits()
-
-
-
-