Package com.tryfinch.api.services.async
Interface HrisServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface HrisServiceAsync.WithRawResponseA view of HrisServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract HrisServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract CompanyServiceAsync.WithRawResponsecompany()abstract PayStatementItemServiceAsync.WithRawResponsepayStatementItem()abstract DirectoryServiceAsync.WithRawResponsedirectory()abstract IndividualServiceAsync.WithRawResponseindividuals()abstract EmploymentServiceAsync.WithRawResponseemployments()abstract PaymentServiceAsync.WithRawResponsepayments()abstract PayStatementServiceAsync.WithRawResponsepayStatements()abstract DocumentServiceAsync.WithRawResponsedocuments()abstract BenefitServiceAsync.WithRawResponsebenefits()-
-
Method Detail
-
withOptions
abstract HrisServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
company
abstract CompanyServiceAsync.WithRawResponse company()
-
payStatementItem
abstract PayStatementItemServiceAsync.WithRawResponse payStatementItem()
-
directory
abstract DirectoryServiceAsync.WithRawResponse directory()
-
individuals
abstract IndividualServiceAsync.WithRawResponse individuals()
-
employments
abstract EmploymentServiceAsync.WithRawResponse employments()
-
payments
abstract PaymentServiceAsync.WithRawResponse payments()
-
payStatements
abstract PayStatementServiceAsync.WithRawResponse payStatements()
-
documents
abstract DocumentServiceAsync.WithRawResponse documents()
-
benefits
abstract BenefitServiceAsync.WithRawResponse benefits()
-
-
-
-