Package com.tryfinch.api.services.async
Class HrisServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.HrisServiceAsync
public final class HrisServiceAsyncImpl implements HrisServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description HrisServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. HrisServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompanyServiceAsynccompany()DirectoryServiceAsyncdirectory()IndividualServiceAsyncindividuals()EmploymentServiceAsyncemployments()PaymentServiceAsyncpayments()PayStatementServiceAsyncpayStatements()DocumentServiceAsyncdocuments()BenefitServiceAsyncbenefits()-
-
Method Detail
-
withRawResponse
HrisServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
HrisServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
company
CompanyServiceAsync company()
-
directory
DirectoryServiceAsync directory()
-
individuals
IndividualServiceAsync individuals()
-
employments
EmploymentServiceAsync employments()
-
payments
PaymentServiceAsync payments()
-
payStatements
PayStatementServiceAsync payStatements()
-
documents
DocumentServiceAsync documents()
-
benefits
BenefitServiceAsync benefits()
-
-
-
-