Package com.tryfinch.api.services.async
Class HrisServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.HrisServiceAsync.WithRawResponse
public final class HrisServiceAsyncImpl.WithRawResponseImpl implements HrisServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description HrisServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompanyServiceAsync.WithRawResponsecompany()DirectoryServiceAsync.WithRawResponsedirectory()IndividualServiceAsync.WithRawResponseindividuals()EmploymentServiceAsync.WithRawResponseemployments()PaymentServiceAsync.WithRawResponsepayments()PayStatementServiceAsync.WithRawResponsepayStatements()DocumentServiceAsync.WithRawResponsedocuments()BenefitServiceAsync.WithRawResponsebenefits()-
-
Method Detail
-
withOptions
HrisServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
company
CompanyServiceAsync.WithRawResponse company()
-
directory
DirectoryServiceAsync.WithRawResponse directory()
-
individuals
IndividualServiceAsync.WithRawResponse individuals()
-
employments
EmploymentServiceAsync.WithRawResponse employments()
-
payments
PaymentServiceAsync.WithRawResponse payments()
-
payStatements
PayStatementServiceAsync.WithRawResponse payStatements()
-
documents
DocumentServiceAsync.WithRawResponse documents()
-
benefits
BenefitServiceAsync.WithRawResponse benefits()
-
-
-
-