Package com.tryfinch.api.services.async
Interface JobServiceAsync
-
- All Implemented Interfaces:
public interface JobServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceJobServiceAsync.WithRawResponseA view of JobServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract JobServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract JobServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract AutomatedServiceAsyncautomated()abstract ManualServiceAsyncmanual()-
-
Method Detail
-
withRawResponse
abstract JobServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract JobServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
automated
abstract AutomatedServiceAsync automated()
-
manual
abstract ManualServiceAsync manual()
-
-
-
-