Package com.tryfinch.api.services.async
Interface JobServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface JobServiceAsync.WithRawResponseA view of JobServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract JobServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract AutomatedServiceAsync.WithRawResponseautomated()abstract ManualServiceAsync.WithRawResponsemanual()-
-
Method Detail
-
withOptions
abstract JobServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
automated
abstract AutomatedServiceAsync.WithRawResponse automated()
-
manual
abstract ManualServiceAsync.WithRawResponse manual()
-
-
-
-