Package com.tryfinch.api.services.async
Class JobServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.JobServiceAsync.WithRawResponse
public final class JobServiceAsyncImpl.WithRawResponseImpl implements JobServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description JobServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. AutomatedServiceAsync.WithRawResponseautomated()ManualServiceAsync.WithRawResponsemanual()-
-
Method Detail
-
withOptions
JobServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
automated
AutomatedServiceAsync.WithRawResponse automated()
-
manual
ManualServiceAsync.WithRawResponse manual()
-
-
-
-