Package com.tryfinch.api.services.async
Interface PayrollServiceAsync
-
- All Implemented Interfaces:
public interface PayrollServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfacePayrollServiceAsync.WithRawResponseA view of PayrollServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract PayrollServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract PayrollServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract PayGroupServiceAsyncpayGroups()-
-
Method Detail
-
withRawResponse
abstract PayrollServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract PayrollServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
payGroups
abstract PayGroupServiceAsync payGroups()
-
-
-
-