Package com.tryfinch.api.services.async
Interface PayrollServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface PayrollServiceAsync.WithRawResponseA view of PayrollServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract PayrollServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract PayGroupServiceAsync.WithRawResponsepayGroups()-
-
Method Detail
-
withOptions
abstract PayrollServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
payGroups
abstract PayGroupServiceAsync.WithRawResponse payGroups()
-
-
-
-