Package com.tryfinch.api.services.async
Class PayrollServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.PayrollServiceAsync
public final class PayrollServiceAsyncImpl implements PayrollServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayrollServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description PayrollServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. PayrollServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. PayGroupServiceAsyncpayGroups()-
-
Method Detail
-
withRawResponse
PayrollServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
PayrollServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
payGroups
PayGroupServiceAsync payGroups()
-
-
-
-