Package com.tryfinch.api.services.async
Class PayrollServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.PayrollServiceAsync.WithRawResponse
public final class PayrollServiceAsyncImpl.WithRawResponseImpl implements PayrollServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description PayrollServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. PayGroupServiceAsync.WithRawResponsepayGroups()-
-
Method Detail
-
withOptions
PayrollServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
payGroups
PayGroupServiceAsync.WithRawResponse payGroups()
-
-
-
-