Package com.tryfinch.api.services.async
Interface ProviderServiceAsync
-
- All Implemented Interfaces:
public interface ProviderServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceProviderServiceAsync.WithRawResponseA view of ProviderServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ProviderServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract ProviderServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<ProviderListPageAsync>list()Return details on all available payroll and HR systems. abstract CompletableFuture<ProviderListPageAsync>list(ProviderListParams params, RequestOptions requestOptions)CompletableFuture<ProviderListPageAsync>list(ProviderListParams params)CompletableFuture<ProviderListPageAsync>list(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract ProviderServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ProviderServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<ProviderListPageAsync> list()
Return details on all available payroll and HR systems.
-
list
abstract CompletableFuture<ProviderListPageAsync> list(ProviderListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<ProviderListPageAsync> list(ProviderListParams params)
-
list
CompletableFuture<ProviderListPageAsync> list(RequestOptions requestOptions)
-
-
-
-