Package com.tryfinch.api.services.async
Interface ProviderServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface ProviderServiceAsync.WithRawResponseA view of ProviderServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract ProviderServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<ProviderListPageAsync>>list()Returns a raw HTTP response for get /providers, but is otherwise the same as ProviderServiceAsync.list.abstract CompletableFuture<HttpResponseFor<ProviderListPageAsync>>list(ProviderListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<ProviderListPageAsync>>list(ProviderListParams params)CompletableFuture<HttpResponseFor<ProviderListPageAsync>>list(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract ProviderServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<HttpResponseFor<ProviderListPageAsync>> list()
Returns a raw HTTP response for
get /providers, but is otherwise the same as ProviderServiceAsync.list.
-
list
abstract CompletableFuture<HttpResponseFor<ProviderListPageAsync>> list(ProviderListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<ProviderListPageAsync>> list(ProviderListParams params)
-
list
CompletableFuture<HttpResponseFor<ProviderListPageAsync>> list(RequestOptions requestOptions)
-
-
-
-