Package com.tryfinch.api.services.async
Class ProviderServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.ProviderServiceAsync
public final class ProviderServiceAsyncImpl implements ProviderServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProviderServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ProviderServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. ProviderServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<ProviderListPageAsync>list(ProviderListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
ProviderServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ProviderServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<ProviderListPageAsync> list(ProviderListParams params, RequestOptions requestOptions)
-
-
-
-