Package com.tryfinch.api.services.async
Class ProviderServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.ProviderServiceAsync.WithRawResponse
public final class ProviderServiceAsyncImpl.WithRawResponseImpl implements ProviderServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description ProviderServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<ProviderListPageAsync>>list(ProviderListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
ProviderServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<HttpResponseFor<ProviderListPageAsync>> list(ProviderListParams params, RequestOptions requestOptions)
-
-
-
-