Package com.tryfinch.api.services.async
Interface RequestForwardingServiceAsync
-
- All Implemented Interfaces:
public interface RequestForwardingServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceRequestForwardingServiceAsync.WithRawResponseA view of RequestForwardingServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract RequestForwardingServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract RequestForwardingServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<RequestForwardingForwardResponse>forward(RequestForwardingForwardParams params)The Forward API allows you to make direct requests to an employment system. abstract CompletableFuture<RequestForwardingForwardResponse>forward(RequestForwardingForwardParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract RequestForwardingServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract RequestForwardingServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
forward
CompletableFuture<RequestForwardingForwardResponse> forward(RequestForwardingForwardParams params)
The Forward API allows you to make direct requests to an employment system. If Finch's unified API doesn't have a data model that cleanly fits your needs, then Forward allows you to push or pull data models directly against an integration's API.
-
forward
abstract CompletableFuture<RequestForwardingForwardResponse> forward(RequestForwardingForwardParams params, RequestOptions requestOptions)
-
-
-
-