Package com.tryfinch.api.services.async
Interface RequestForwardingServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface RequestForwardingServiceAsync.WithRawResponseA view of RequestForwardingServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract RequestForwardingServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<RequestForwardingForwardResponse>>forward(RequestForwardingForwardParams params)Returns a raw HTTP response for post /forward, but is otherwise the same as RequestForwardingServiceAsync.forward.abstract CompletableFuture<HttpResponseFor<RequestForwardingForwardResponse>>forward(RequestForwardingForwardParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract RequestForwardingServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
forward
CompletableFuture<HttpResponseFor<RequestForwardingForwardResponse>> forward(RequestForwardingForwardParams params)
Returns a raw HTTP response for
post /forward, but is otherwise the same as RequestForwardingServiceAsync.forward.
-
forward
abstract CompletableFuture<HttpResponseFor<RequestForwardingForwardResponse>> forward(RequestForwardingForwardParams params, RequestOptions requestOptions)
-
-
-
-