Package com.tryfinch.api.services.async
Class RequestForwardingServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.RequestForwardingServiceAsync
public final class RequestForwardingServiceAsyncImpl implements RequestForwardingServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRequestForwardingServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description RequestForwardingServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. RequestForwardingServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<RequestForwardingForwardResponse>forward(RequestForwardingForwardParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
RequestForwardingServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
RequestForwardingServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
forward
CompletableFuture<RequestForwardingForwardResponse> forward(RequestForwardingForwardParams params, RequestOptions requestOptions)
-
-
-
-