Package com.tryfinch.api.services.async
Class RequestForwardingServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.RequestForwardingServiceAsync.WithRawResponse
public final class RequestForwardingServiceAsyncImpl.WithRawResponseImpl implements RequestForwardingServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description RequestForwardingServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<RequestForwardingForwardResponse>>forward(RequestForwardingForwardParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
RequestForwardingServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
forward
CompletableFuture<HttpResponseFor<RequestForwardingForwardResponse>> forward(RequestForwardingForwardParams params, RequestOptions requestOptions)
-
-
-
-