Package com.tryfinch.api.services.async
Interface SandboxServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface SandboxServiceAsync.WithRawResponseA view of SandboxServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract SandboxServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract ConnectionServiceAsync.WithRawResponseconnections()abstract CompanyServiceAsync.WithRawResponsecompany()abstract DirectoryServiceAsync.WithRawResponsedirectory()abstract IndividualServiceAsync.WithRawResponseindividual()abstract EmploymentServiceAsync.WithRawResponseemployment()abstract PaymentServiceAsync.WithRawResponsepayment()abstract JobServiceAsync.WithRawResponsejobs()-
-
Method Detail
-
withOptions
abstract SandboxServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
connections
abstract ConnectionServiceAsync.WithRawResponse connections()
-
company
abstract CompanyServiceAsync.WithRawResponse company()
-
directory
abstract DirectoryServiceAsync.WithRawResponse directory()
-
individual
abstract IndividualServiceAsync.WithRawResponse individual()
-
employment
abstract EmploymentServiceAsync.WithRawResponse employment()
-
payment
abstract PaymentServiceAsync.WithRawResponse payment()
-
jobs
abstract JobServiceAsync.WithRawResponse jobs()
-
-
-
-