Package com.tryfinch.api.services.async
Class SandboxServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.SandboxServiceAsync
public final class SandboxServiceAsyncImpl implements SandboxServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSandboxServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description SandboxServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SandboxServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. ConnectionServiceAsyncconnections()CompanyServiceAsynccompany()DirectoryServiceAsyncdirectory()IndividualServiceAsyncindividual()EmploymentServiceAsyncemployment()PaymentServiceAsyncpayment()JobServiceAsyncjobs()-
-
Method Detail
-
withRawResponse
SandboxServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SandboxServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
connections
ConnectionServiceAsync connections()
-
company
CompanyServiceAsync company()
-
directory
DirectoryServiceAsync directory()
-
individual
IndividualServiceAsync individual()
-
employment
EmploymentServiceAsync employment()
-
payment
PaymentServiceAsync payment()
-
jobs
JobServiceAsync jobs()
-
-
-
-