Package com.tryfinch.api.services.async
Class SandboxServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.SandboxServiceAsync.WithRawResponse
public final class SandboxServiceAsyncImpl.WithRawResponseImpl implements SandboxServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description SandboxServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. ConnectionServiceAsync.WithRawResponseconnections()CompanyServiceAsync.WithRawResponsecompany()DirectoryServiceAsync.WithRawResponsedirectory()IndividualServiceAsync.WithRawResponseindividual()EmploymentServiceAsync.WithRawResponseemployment()PaymentServiceAsync.WithRawResponsepayment()JobServiceAsync.WithRawResponsejobs()-
-
Method Detail
-
withOptions
SandboxServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
connections
ConnectionServiceAsync.WithRawResponse connections()
-
company
CompanyServiceAsync.WithRawResponse company()
-
directory
DirectoryServiceAsync.WithRawResponse directory()
-
individual
IndividualServiceAsync.WithRawResponse individual()
-
employment
EmploymentServiceAsync.WithRawResponse employment()
-
payment
PaymentServiceAsync.WithRawResponse payment()
-
-
-
-