Package com.tryfinch.api.services.async
Class WebhookServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.WebhookServiceAsync
public final class WebhookServiceAsyncImpl implements WebhookServiceAsync
-
-
Method Summary
Modifier and Type Method Description WebhookServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. WebhookEventunwrap(String payload, Headers headers, String secret)UnitverifySignature(String payload, Headers headers, String secret)-
-
Method Detail
-
withOptions
WebhookServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
unwrap
WebhookEvent unwrap(String payload, Headers headers, String secret)
-
verifySignature
Unit verifySignature(String payload, Headers headers, String secret)
-
-
-
-