Interface SessionServiceAsync
-
- All Implemented Interfaces:
public interface SessionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSessionServiceAsync.WithRawResponseA view of SessionServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract SessionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract SessionServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<SessionNewResponse>new_(ConnectSessionNewParams params)Create a new connect session for an employer abstract CompletableFuture<SessionNewResponse>new_(ConnectSessionNewParams params, RequestOptions requestOptions)CompletableFuture<SessionReauthenticateResponse>reauthenticate(ConnectSessionReauthenticateParams params)Create a new Connect session for reauthenticating an existing connection abstract CompletableFuture<SessionReauthenticateResponse>reauthenticate(ConnectSessionReauthenticateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract SessionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract SessionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
new_
CompletableFuture<SessionNewResponse> new_(ConnectSessionNewParams params)
Create a new connect session for an employer
-
new_
abstract CompletableFuture<SessionNewResponse> new_(ConnectSessionNewParams params, RequestOptions requestOptions)
-
reauthenticate
CompletableFuture<SessionReauthenticateResponse> reauthenticate(ConnectSessionReauthenticateParams params)
Create a new Connect session for reauthenticating an existing connection
-
reauthenticate
abstract CompletableFuture<SessionReauthenticateResponse> reauthenticate(ConnectSessionReauthenticateParams params, RequestOptions requestOptions)
-
-
-
-