Interface SessionServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface SessionServiceAsync.WithRawResponseA view of SessionServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract SessionServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<SessionNewResponse>>new_(ConnectSessionNewParams params)Returns a raw HTTP response for post /connect/sessions, but is otherwise the same as SessionServiceAsync.new_.abstract CompletableFuture<HttpResponseFor<SessionNewResponse>>new_(ConnectSessionNewParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<SessionReauthenticateResponse>>reauthenticate(ConnectSessionReauthenticateParams params)Returns a raw HTTP response for post /connect/sessions/reauthenticate, but is otherwise the same as SessionServiceAsync.reauthenticate.abstract CompletableFuture<HttpResponseFor<SessionReauthenticateResponse>>reauthenticate(ConnectSessionReauthenticateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract SessionServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
new_
CompletableFuture<HttpResponseFor<SessionNewResponse>> new_(ConnectSessionNewParams params)
Returns a raw HTTP response for
post /connect/sessions, but is otherwise the same as SessionServiceAsync.new_.
-
new_
abstract CompletableFuture<HttpResponseFor<SessionNewResponse>> new_(ConnectSessionNewParams params, RequestOptions requestOptions)
-
reauthenticate
CompletableFuture<HttpResponseFor<SessionReauthenticateResponse>> reauthenticate(ConnectSessionReauthenticateParams params)
Returns a raw HTTP response for
post /connect/sessions/reauthenticate, but is otherwise the same as SessionServiceAsync.reauthenticate.
-
reauthenticate
abstract CompletableFuture<HttpResponseFor<SessionReauthenticateResponse>> reauthenticate(ConnectSessionReauthenticateParams params, RequestOptions requestOptions)
-
-
-
-