Class SessionServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.connect.SessionServiceAsync
public final class SessionServiceAsyncImpl implements SessionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSessionServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description SessionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SessionServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<SessionNewResponse>new_(ConnectSessionNewParams params, RequestOptions requestOptions)CompletableFuture<SessionReauthenticateResponse>reauthenticate(ConnectSessionReauthenticateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
SessionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SessionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
new_
CompletableFuture<SessionNewResponse> new_(ConnectSessionNewParams params, RequestOptions requestOptions)
-
reauthenticate
CompletableFuture<SessionReauthenticateResponse> reauthenticate(ConnectSessionReauthenticateParams params, RequestOptions requestOptions)
-
-
-
-