Interface DirectoryServiceAsync
-
- All Implemented Interfaces:
public interface DirectoryServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceDirectoryServiceAsync.WithRawResponseA view of DirectoryServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract DirectoryServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract DirectoryServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<HrisDirectoryListPageAsync> list()
Read company directory and organization structure
-
list
abstract CompletableFuture<HrisDirectoryListPageAsync> list(HrisDirectoryListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HrisDirectoryListPageAsync> list(RequestOptions requestOptions)
-
listIndividuals
@Deprecated(message = "use `list` instead") CompletableFuture<HrisDirectoryListIndividualsPageAsync> listIndividuals()
Read company directory and organization structure
-
listIndividuals
@Deprecated(message = "use `list` instead") abstract CompletableFuture<HrisDirectoryListIndividualsPageAsync> listIndividuals(HrisDirectoryListIndividualsParams params, RequestOptions requestOptions)
-
listIndividuals
@Deprecated(message = "use `list` instead") CompletableFuture<HrisDirectoryListIndividualsPageAsync> listIndividuals(HrisDirectoryListIndividualsParams params)
-
listIndividuals
@Deprecated(message = "use `list` instead") CompletableFuture<HrisDirectoryListIndividualsPageAsync> listIndividuals(RequestOptions requestOptions)
-
-
-
-