Class DirectoryServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.hris.DirectoryServiceAsync
public final class DirectoryServiceAsyncImpl implements DirectoryServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDirectoryServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description DirectoryServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. DirectoryServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HrisDirectoryListPageAsync>list(HrisDirectoryListParams params, RequestOptions requestOptions)CompletableFuture<DirectoryListIndividualsResponse>listIndividuals(HrisDirectoryListIndividualsParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
DirectoryServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
DirectoryServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<HrisDirectoryListPageAsync> list(HrisDirectoryListParams params, RequestOptions requestOptions)
-
listIndividuals
@Deprecated(message = "use `list` instead") CompletableFuture<DirectoryListIndividualsResponse> listIndividuals(HrisDirectoryListIndividualsParams params, RequestOptions requestOptions)
-
-
-
-