Class DirectoryServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.hris.DirectoryServiceAsync.WithRawResponse
public final class DirectoryServiceAsyncImpl.WithRawResponseImpl implements DirectoryServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description DirectoryServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<HrisDirectoryListPageAsync>>list(HrisDirectoryListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<HrisDirectoryListIndividualsPageAsync>>listIndividuals(HrisDirectoryListIndividualsParams params, RequestOptions requestOptions)-
Methods inherited from class com.tryfinch.api.services.async.hris.DirectoryServiceAsync.WithRawResponse
list, list, list, listIndividuals, listIndividuals, listIndividuals -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
DirectoryServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<HttpResponseFor<HrisDirectoryListPageAsync>> list(HrisDirectoryListParams params, RequestOptions requestOptions)
-
listIndividuals
@Deprecated(message = "use `list` instead") CompletableFuture<HttpResponseFor<HrisDirectoryListIndividualsPageAsync>> listIndividuals(HrisDirectoryListIndividualsParams params, RequestOptions requestOptions)
-
-
-
-