Interface DocumentServiceAsync
-
- All Implemented Interfaces:
public interface DocumentServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceDocumentServiceAsync.WithRawResponseA view of DocumentServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract DocumentServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<DocumentListResponse>list()Beta: This endpoint is in beta and may change. abstract CompletableFuture<DocumentListResponse>list(HrisDocumentListParams params, RequestOptions requestOptions)CompletableFuture<DocumentListResponse>list(HrisDocumentListParams params)CompletableFuture<DocumentListResponse>list(RequestOptions requestOptions)CompletableFuture<DocumentRetreiveResponse>retreive(HrisDocumentRetreiveParams params)Beta: This endpoint is in beta and may change. abstract CompletableFuture<DocumentRetreiveResponse>retreive(HrisDocumentRetreiveParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract DocumentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
list
CompletableFuture<DocumentListResponse> list()
Beta: This endpoint is in beta and may change. Retrieve a list of company-wide documents.
-
list
abstract CompletableFuture<DocumentListResponse> list(HrisDocumentListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<DocumentListResponse> list(HrisDocumentListParams params)
-
list
CompletableFuture<DocumentListResponse> list(RequestOptions requestOptions)
-
retreive
CompletableFuture<DocumentRetreiveResponse> retreive(HrisDocumentRetreiveParams params)
Beta: This endpoint is in beta and may change. Retrieve details of a specific document by its ID.
-
retreive
abstract CompletableFuture<DocumentRetreiveResponse> retreive(HrisDocumentRetreiveParams params, RequestOptions requestOptions)
-
-
-
-