Class DocumentServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.hris.DocumentServiceAsync
public final class DocumentServiceAsyncImpl implements DocumentServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDocumentServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description DocumentServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. DocumentServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<DocumentListResponse>list(HrisDocumentListParams params, RequestOptions requestOptions)CompletableFuture<DocumentRetreiveResponse>retreive(HrisDocumentRetreiveParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
DocumentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
DocumentServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<DocumentListResponse> list(HrisDocumentListParams params, RequestOptions requestOptions)
-
retreive
CompletableFuture<DocumentRetreiveResponse> retreive(HrisDocumentRetreiveParams params, RequestOptions requestOptions)
-
-
-
-