Class DocumentServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.hris.DocumentServiceAsync.WithRawResponse
public final class DocumentServiceAsyncImpl.WithRawResponseImpl implements DocumentServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description DocumentServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<DocumentListResponse>>list(HrisDocumentListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<DocumentRetreiveResponse>>retreive(HrisDocumentRetreiveParams params, RequestOptions requestOptions)-
Methods inherited from class com.tryfinch.api.services.async.hris.DocumentServiceAsync.WithRawResponse
list, list, list, retreive, retreive, retreive, retreive, retreive -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
DocumentServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<HttpResponseFor<DocumentListResponse>> list(HrisDocumentListParams params, RequestOptions requestOptions)
-
retreive
CompletableFuture<HttpResponseFor<DocumentRetreiveResponse>> retreive(HrisDocumentRetreiveParams params, RequestOptions requestOptions)
-
-
-
-