Class PayStatementItemServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.hris.PayStatementItemServiceAsync
public final class PayStatementItemServiceAsyncImpl implements PayStatementItemServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayStatementItemServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description PayStatementItemServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. PayStatementItemServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. RuleServiceAsyncrules()CompletableFuture<HrisPayStatementItemListPageAsync>list(HrisPayStatementItemListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
PayStatementItemServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
PayStatementItemServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
rules
RuleServiceAsync rules()
-
list
CompletableFuture<HrisPayStatementItemListPageAsync> list(HrisPayStatementItemListParams params, RequestOptions requestOptions)
-
-
-
-