Interface PayStatementServiceAsync
-
- All Implemented Interfaces:
public interface PayStatementServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfacePayStatementServiceAsync.WithRawResponseA view of PayStatementServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract PayStatementServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract PayStatementServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HrisPayStatementRetrieveManyPageAsync>retrieveMany(HrisPayStatementRetrieveManyParams params)Read detailed pay statements for each individual. abstract CompletableFuture<HrisPayStatementRetrieveManyPageAsync>retrieveMany(HrisPayStatementRetrieveManyParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract PayStatementServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract PayStatementServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieveMany
CompletableFuture<HrisPayStatementRetrieveManyPageAsync> retrieveMany(HrisPayStatementRetrieveManyParams params)
Read detailed pay statements for each individual.
Deduction and contribution types are supported by the payroll systems that supports Benefits.
-
retrieveMany
abstract CompletableFuture<HrisPayStatementRetrieveManyPageAsync> retrieveMany(HrisPayStatementRetrieveManyParams params, RequestOptions requestOptions)
-
-
-
-