Class PayStatementServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.hris.PayStatementServiceAsync
public final class PayStatementServiceAsyncImpl implements PayStatementServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayStatementServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description PayStatementServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. PayStatementServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HrisPayStatementRetrieveManyPageAsync>retrieveMany(HrisPayStatementRetrieveManyParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
PayStatementServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
PayStatementServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieveMany
CompletableFuture<HrisPayStatementRetrieveManyPageAsync> retrieveMany(HrisPayStatementRetrieveManyParams params, RequestOptions requestOptions)
-
-
-
-