Interface PayGroupServiceAsync
-
- All Implemented Interfaces:
public interface PayGroupServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfacePayGroupServiceAsync.WithRawResponseA view of PayGroupServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract PayGroupServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract PayGroupServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<PayGroupRetrieveResponse> retrieve(String payGroupId)
Read information from a single pay group
-
retrieve
CompletableFuture<PayGroupRetrieveResponse> retrieve(String payGroupId, PayrollPayGroupRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<PayGroupRetrieveResponse> retrieve(String payGroupId, PayrollPayGroupRetrieveParams params)
-
retrieve
abstract CompletableFuture<PayGroupRetrieveResponse> retrieve(PayrollPayGroupRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<PayGroupRetrieveResponse> retrieve(PayrollPayGroupRetrieveParams params)
-
retrieve
CompletableFuture<PayGroupRetrieveResponse> retrieve(String payGroupId, RequestOptions requestOptions)
-
list
CompletableFuture<PayrollPayGroupListPageAsync> list()
Read company pay groups and frequencies
-
list
abstract CompletableFuture<PayrollPayGroupListPageAsync> list(PayrollPayGroupListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<PayrollPayGroupListPageAsync> list(RequestOptions requestOptions)
-
-
-
-