Class PayGroupServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.payroll.PayGroupServiceAsync
public final class PayGroupServiceAsyncImpl implements PayGroupServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayGroupServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description PayGroupServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. PayGroupServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<PayGroupRetrieveResponse>retrieve(PayrollPayGroupRetrieveParams params, RequestOptions requestOptions)CompletableFuture<PayrollPayGroupListPageAsync>list(PayrollPayGroupListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
PayGroupServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
PayGroupServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<PayGroupRetrieveResponse> retrieve(PayrollPayGroupRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<PayrollPayGroupListPageAsync> list(PayrollPayGroupListParams params, RequestOptions requestOptions)
-
-
-
-