Interface CompanyServiceAsync
-
- All Implemented Interfaces:
public interface CompanyServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCompanyServiceAsync.WithRawResponseA view of CompanyServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CompanyServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CompanyServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CompanyUpdateResponse>update(SandboxCompanyUpdateParams params)Update a sandbox company's data abstract CompletableFuture<CompanyUpdateResponse>update(SandboxCompanyUpdateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CompanyServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CompanyServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
update
CompletableFuture<CompanyUpdateResponse> update(SandboxCompanyUpdateParams params)
Update a sandbox company's data
-
update
abstract CompletableFuture<CompanyUpdateResponse> update(SandboxCompanyUpdateParams params, RequestOptions requestOptions)
-
-
-
-