Interface ConnectionServiceAsync
-
- All Implemented Interfaces:
public interface ConnectionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceConnectionServiceAsync.WithRawResponseA view of ConnectionServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ConnectionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract ConnectionServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract AccountServiceAsyncaccounts()CompletableFuture<ConnectionCreateResponse>create(SandboxConnectionCreateParams params)Create a new connection (new company/provider pair) with a new account abstract CompletableFuture<ConnectionCreateResponse>create(SandboxConnectionCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract ConnectionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ConnectionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
accounts
abstract AccountServiceAsync accounts()
-
create
CompletableFuture<ConnectionCreateResponse> create(SandboxConnectionCreateParams params)
Create a new connection (new company/provider pair) with a new account
-
create
abstract CompletableFuture<ConnectionCreateResponse> create(SandboxConnectionCreateParams params, RequestOptions requestOptions)
-
-
-
-