Interface ConnectionServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface ConnectionServiceAsync.WithRawResponseA view of ConnectionServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract ConnectionServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract AccountServiceAsync.WithRawResponseaccounts()CompletableFuture<HttpResponseFor<ConnectionCreateResponse>>create(SandboxConnectionCreateParams params)Returns a raw HTTP response for post /sandbox/connections, but is otherwise the same as ConnectionServiceAsync.create.abstract CompletableFuture<HttpResponseFor<ConnectionCreateResponse>>create(SandboxConnectionCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract ConnectionServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
accounts
abstract AccountServiceAsync.WithRawResponse accounts()
-
create
CompletableFuture<HttpResponseFor<ConnectionCreateResponse>> create(SandboxConnectionCreateParams params)
Returns a raw HTTP response for
post /sandbox/connections, but is otherwise the same as ConnectionServiceAsync.create.
-
create
abstract CompletableFuture<HttpResponseFor<ConnectionCreateResponse>> create(SandboxConnectionCreateParams params, RequestOptions requestOptions)
-
-
-
-