Class ConnectionServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.sandbox.ConnectionServiceAsync
public final class ConnectionServiceAsyncImpl implements ConnectionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classConnectionServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ConnectionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. ConnectionServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. AccountServiceAsyncaccounts()CompletableFuture<ConnectionCreateResponse>create(SandboxConnectionCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
ConnectionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ConnectionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
accounts
AccountServiceAsync accounts()
-
create
CompletableFuture<ConnectionCreateResponse> create(SandboxConnectionCreateParams params, RequestOptions requestOptions)
-
-
-
-