Class ConnectionServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.sandbox.ConnectionServiceAsync.WithRawResponse
public final class ConnectionServiceAsyncImpl.WithRawResponseImpl implements ConnectionServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description ConnectionServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. AccountServiceAsync.WithRawResponseaccounts()CompletableFuture<HttpResponseFor<ConnectionCreateResponse>>create(SandboxConnectionCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
ConnectionServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
accounts
AccountServiceAsync.WithRawResponse accounts()
-
create
CompletableFuture<HttpResponseFor<ConnectionCreateResponse>> create(SandboxConnectionCreateParams params, RequestOptions requestOptions)
-
-
-
-