Interface DirectoryServiceAsync
-
- All Implemented Interfaces:
public interface DirectoryServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceDirectoryServiceAsync.WithRawResponseA view of DirectoryServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract DirectoryServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract DirectoryServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<List<DirectoryCreateResponse>> create()
Add new individuals to a sandbox company
-
create
abstract CompletableFuture<List<DirectoryCreateResponse>> create(SandboxDirectoryCreateParams params, RequestOptions requestOptions)
-
create
CompletableFuture<List<DirectoryCreateResponse>> create(SandboxDirectoryCreateParams params)
-
create
CompletableFuture<List<DirectoryCreateResponse>> create(List<SandboxDirectoryCreateParams.IndividualOrEmployment> body, RequestOptions requestOptions)
-
create
CompletableFuture<List<DirectoryCreateResponse>> create(List<SandboxDirectoryCreateParams.IndividualOrEmployment> body)
-
create
CompletableFuture<List<DirectoryCreateResponse>> create(RequestOptions requestOptions)
-
-
-
-