Class DirectoryServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.sandbox.DirectoryServiceAsync.WithRawResponse
public final class DirectoryServiceAsyncImpl.WithRawResponseImpl implements DirectoryServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description DirectoryServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<List<DirectoryCreateResponse>>>create(SandboxDirectoryCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
DirectoryServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<List<DirectoryCreateResponse>>> create(SandboxDirectoryCreateParams params, RequestOptions requestOptions)
-
-
-
-