Interface EmploymentServiceAsync
-
- All Implemented Interfaces:
public interface EmploymentServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceEmploymentServiceAsync.WithRawResponseA view of EmploymentServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract EmploymentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract EmploymentServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
update
CompletableFuture<EmploymentUpdateResponse> update(String individualId)
Update sandbox employment
-
update
CompletableFuture<EmploymentUpdateResponse> update(String individualId, SandboxEmploymentUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<EmploymentUpdateResponse> update(String individualId, SandboxEmploymentUpdateParams params)
-
update
abstract CompletableFuture<EmploymentUpdateResponse> update(SandboxEmploymentUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<EmploymentUpdateResponse> update(SandboxEmploymentUpdateParams params)
-
update
CompletableFuture<EmploymentUpdateResponse> update(String individualId, RequestOptions requestOptions)
-
-
-
-