Class EmploymentServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.sandbox.EmploymentServiceAsync
public final class EmploymentServiceAsyncImpl implements EmploymentServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEmploymentServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description EmploymentServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. EmploymentServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<EmploymentUpdateResponse>update(SandboxEmploymentUpdateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
EmploymentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
EmploymentServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
update
CompletableFuture<EmploymentUpdateResponse> update(SandboxEmploymentUpdateParams params, RequestOptions requestOptions)
-
-
-
-