Interface IndividualServiceAsync
-
- All Implemented Interfaces:
public interface IndividualServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceIndividualServiceAsync.WithRawResponseA view of IndividualServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract IndividualServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract IndividualServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
update
CompletableFuture<IndividualUpdateResponse> update(String individualId)
Update sandbox individual
-
update
CompletableFuture<IndividualUpdateResponse> update(String individualId, SandboxIndividualUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<IndividualUpdateResponse> update(String individualId, SandboxIndividualUpdateParams params)
-
update
abstract CompletableFuture<IndividualUpdateResponse> update(SandboxIndividualUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<IndividualUpdateResponse> update(SandboxIndividualUpdateParams params)
-
update
CompletableFuture<IndividualUpdateResponse> update(String individualId, RequestOptions requestOptions)
-
-
-
-