Class IndividualServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.sandbox.IndividualServiceAsync
public final class IndividualServiceAsyncImpl implements IndividualServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIndividualServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description IndividualServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<IndividualUpdateResponse>update(SandboxIndividualUpdateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
IndividualServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
update
CompletableFuture<IndividualUpdateResponse> update(SandboxIndividualUpdateParams params, RequestOptions requestOptions)
-
-
-
-