Class IndividualServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.sandbox.IndividualServiceAsync.WithRawResponse
public final class IndividualServiceAsyncImpl.WithRawResponseImpl implements IndividualServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description IndividualServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<IndividualUpdateResponse>>update(SandboxIndividualUpdateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
IndividualServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
update
CompletableFuture<HttpResponseFor<IndividualUpdateResponse>> update(SandboxIndividualUpdateParams params, RequestOptions requestOptions)
-
-
-
-