Interface JobServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface JobServiceAsync.WithRawResponseA view of JobServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract JobServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract ConfigurationServiceAsync.WithRawResponseconfiguration()CompletableFuture<HttpResponseFor<JobCreateResponse>>create(SandboxJobCreateParams params)Returns a raw HTTP response for post /sandbox/jobs, but is otherwise the same as JobServiceAsync.create.abstract CompletableFuture<HttpResponseFor<JobCreateResponse>>create(SandboxJobCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract JobServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
configuration
abstract ConfigurationServiceAsync.WithRawResponse configuration()
-
create
CompletableFuture<HttpResponseFor<JobCreateResponse>> create(SandboxJobCreateParams params)
Returns a raw HTTP response for
post /sandbox/jobs, but is otherwise the same as JobServiceAsync.create.
-
create
abstract CompletableFuture<HttpResponseFor<JobCreateResponse>> create(SandboxJobCreateParams params, RequestOptions requestOptions)
-
-
-
-