Class JobServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.sandbox.JobServiceAsync
public final class JobServiceAsyncImpl implements JobServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classJobServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description JobServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. JobServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. ConfigurationServiceAsyncconfiguration()CompletableFuture<JobCreateResponse>create(SandboxJobCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
JobServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
JobServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
configuration
ConfigurationServiceAsync configuration()
-
create
CompletableFuture<JobCreateResponse> create(SandboxJobCreateParams params, RequestOptions requestOptions)
-
-
-
-