Class JobServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.sandbox.JobServiceAsync.WithRawResponse
public final class JobServiceAsyncImpl.WithRawResponseImpl implements JobServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description JobServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. ConfigurationServiceAsync.WithRawResponseconfiguration()CompletableFuture<HttpResponseFor<JobCreateResponse>>create(SandboxJobCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
JobServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
configuration
ConfigurationServiceAsync.WithRawResponse configuration()
-
create
CompletableFuture<HttpResponseFor<JobCreateResponse>> create(SandboxJobCreateParams params, RequestOptions requestOptions)
-
-
-
-