Interface PaymentServiceAsync
-
- All Implemented Interfaces:
public interface PaymentServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfacePaymentServiceAsync.WithRawResponseA view of PaymentServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract PaymentServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<PaymentCreateResponse>create()Add a new sandbox payment abstract CompletableFuture<PaymentCreateResponse>create(SandboxPaymentCreateParams params, RequestOptions requestOptions)CompletableFuture<PaymentCreateResponse>create(SandboxPaymentCreateParams params)CompletableFuture<PaymentCreateResponse>create(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract PaymentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<PaymentCreateResponse> create()
Add a new sandbox payment
-
create
abstract CompletableFuture<PaymentCreateResponse> create(SandboxPaymentCreateParams params, RequestOptions requestOptions)
-
create
CompletableFuture<PaymentCreateResponse> create(SandboxPaymentCreateParams params)
-
create
CompletableFuture<PaymentCreateResponse> create(RequestOptions requestOptions)
-
-
-
-