Class AccessTokenServiceImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.AccessTokenService
public final class AccessTokenServiceImpl implements AccessTokenService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccessTokenServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AccessTokenService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AccessTokenServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CreateAccessTokenResponsecreate(AccessTokenCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
AccessTokenService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
AccessTokenService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CreateAccessTokenResponse create(AccessTokenCreateParams params, RequestOptions requestOptions)
-
-
-
-