Class AccessTokenServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.AccessTokenService.WithRawResponse
public final class AccessTokenServiceImpl.WithRawResponseImpl implements AccessTokenService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description AccessTokenService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<CreateAccessTokenResponse>create(AccessTokenCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
AccessTokenService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponseFor<CreateAccessTokenResponse> create(AccessTokenCreateParams params, RequestOptions requestOptions)
-
-
-
-