Interface AccountService
-
- All Implemented Interfaces:
public interface AccountService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAccountService.WithRawResponseA view of AccountService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AccountService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract AccountServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. DisconnectResponsedisconnect()Disconnect one or more access_tokens from your application.abstract DisconnectResponsedisconnect(AccountDisconnectParams params, RequestOptions requestOptions)DisconnectResponsedisconnect(AccountDisconnectParams params)DisconnectResponsedisconnect(RequestOptions requestOptions)DisconnectEntityResponsedisconnectEntity(AccountDisconnectEntityParams params)Disconnect entity(s) from a connection without affecting other entities associated with the same connection. abstract DisconnectEntityResponsedisconnectEntity(AccountDisconnectEntityParams params, RequestOptions requestOptions)Introspectionintrospect()Read account information associated with an access_tokenabstract Introspectionintrospect(AccountIntrospectParams params, RequestOptions requestOptions)Introspectionintrospect(AccountIntrospectParams params)Introspectionintrospect(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract AccountService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract AccountService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
disconnect
DisconnectResponse disconnect()
Disconnect one or more
access_tokens from your application.
-
disconnect
abstract DisconnectResponse disconnect(AccountDisconnectParams params, RequestOptions requestOptions)
-
disconnect
DisconnectResponse disconnect(AccountDisconnectParams params)
-
disconnect
DisconnectResponse disconnect(RequestOptions requestOptions)
-
disconnectEntity
DisconnectEntityResponse disconnectEntity(AccountDisconnectEntityParams params)
Disconnect entity(s) from a connection without affecting other entities associated with the same connection.
-
disconnectEntity
abstract DisconnectEntityResponse disconnectEntity(AccountDisconnectEntityParams params, RequestOptions requestOptions)
-
introspect
Introspection introspect()
Read account information associated with an
access_token
-
introspect
abstract Introspection introspect(AccountIntrospectParams params, RequestOptions requestOptions)
-
introspect
Introspection introspect(AccountIntrospectParams params)
-
introspect
Introspection introspect(RequestOptions requestOptions)
-
-
-
-