Class AccountServiceImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.AccountService
public final class AccountServiceImpl implements AccountService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AccountService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AccountServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. DisconnectResponsedisconnect(AccountDisconnectParams params, RequestOptions requestOptions)DisconnectEntityResponsedisconnectEntity(AccountDisconnectEntityParams params, RequestOptions requestOptions)Introspectionintrospect(AccountIntrospectParams params, RequestOptions requestOptions)-
Methods inherited from class com.tryfinch.api.services.blocking.AccountService
disconnect, disconnect, disconnect, disconnectEntity, introspect, introspect, introspect -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
AccountService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
AccountService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
disconnect
DisconnectResponse disconnect(AccountDisconnectParams params, RequestOptions requestOptions)
-
disconnectEntity
DisconnectEntityResponse disconnectEntity(AccountDisconnectEntityParams params, RequestOptions requestOptions)
-
introspect
Introspection introspect(AccountIntrospectParams params, RequestOptions requestOptions)
-
-
-
-