Class AccountServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.AccountService.WithRawResponse
public final class AccountServiceImpl.WithRawResponseImpl implements AccountService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description AccountService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<DisconnectResponse>disconnect(AccountDisconnectParams params, RequestOptions requestOptions)HttpResponseFor<DisconnectEntityResponse>disconnectEntity(AccountDisconnectEntityParams params, RequestOptions requestOptions)HttpResponseFor<Introspection>introspect(AccountIntrospectParams params, RequestOptions requestOptions)-
Methods inherited from class com.tryfinch.api.services.blocking.AccountService.WithRawResponse
disconnect, disconnect, disconnect, disconnectEntity, introspect, introspect, introspect -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
AccountService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
disconnect
HttpResponseFor<DisconnectResponse> disconnect(AccountDisconnectParams params, RequestOptions requestOptions)
-
disconnectEntity
HttpResponseFor<DisconnectEntityResponse> disconnectEntity(AccountDisconnectEntityParams params, RequestOptions requestOptions)
-
introspect
HttpResponseFor<Introspection> introspect(AccountIntrospectParams params, RequestOptions requestOptions)
-
-
-
-