Interface ConnectService
-
- All Implemented Interfaces:
public interface ConnectService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceConnectService.WithRawResponseA view of ConnectService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ConnectService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract ConnectServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract SessionServicesessions()-
-
Method Detail
-
withRawResponse
abstract ConnectService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ConnectService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
sessions
abstract SessionService sessions()
-
-
-
-