Interface ConnectService.WithRawResponse
-
- All Implemented Interfaces:
public interface ConnectService.WithRawResponseA view of ConnectService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract ConnectService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract SessionService.WithRawResponsesessions()-
-
Method Detail
-
withOptions
abstract ConnectService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
sessions
abstract SessionService.WithRawResponse sessions()
-
-
-
-