Class ConnectServiceImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.ConnectService
public final class ConnectServiceImpl implements ConnectService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classConnectServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ConnectService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. ConnectServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. SessionServicesessions()-
-
Method Detail
-
withRawResponse
ConnectService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ConnectService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
sessions
SessionService sessions()
-
-
-
-