Class ConnectServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.ConnectService.WithRawResponse
public final class ConnectServiceImpl.WithRawResponseImpl implements ConnectService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description ConnectService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. SessionService.WithRawResponsesessions()-
-
Method Detail
-
withOptions
ConnectService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
sessions
SessionService.WithRawResponse sessions()
-
-
-
-