Interface HrisService
-
- All Implemented Interfaces:
public interface HrisService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceHrisService.WithRawResponseA view of HrisService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract HrisService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract HrisServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract CompanyServicecompany()abstract DirectoryServicedirectory()abstract IndividualServiceindividuals()abstract EmploymentServiceemployments()abstract PaymentServicepayments()abstract PayStatementServicepayStatements()abstract DocumentServicedocuments()abstract BenefitServicebenefits()-
-
Method Detail
-
withRawResponse
abstract HrisService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract HrisService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
company
abstract CompanyService company()
-
directory
abstract DirectoryService directory()
-
individuals
abstract IndividualService individuals()
-
employments
abstract EmploymentService employments()
-
payments
abstract PaymentService payments()
-
payStatements
abstract PayStatementService payStatements()
-
documents
abstract DocumentService documents()
-
benefits
abstract BenefitService benefits()
-
-
-
-