Class HrisServiceImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.HrisService
public final class HrisServiceImpl implements HrisService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description HrisService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. HrisServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompanyServicecompany()DirectoryServicedirectory()IndividualServiceindividuals()EmploymentServiceemployments()PaymentServicepayments()PayStatementServicepayStatements()DocumentServicedocuments()BenefitServicebenefits()-
-
Method Detail
-
withRawResponse
HrisService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
HrisService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
company
CompanyService company()
-
directory
DirectoryService directory()
-
individuals
IndividualService individuals()
-
employments
EmploymentService employments()
-
payments
PaymentService payments()
-
payStatements
PayStatementService payStatements()
-
documents
DocumentService documents()
-
benefits
BenefitService benefits()
-
-
-
-