Class HrisServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.HrisService.WithRawResponse
public final class HrisServiceImpl.WithRawResponseImpl implements HrisService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description HrisService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompanyService.WithRawResponsecompany()DirectoryService.WithRawResponsedirectory()IndividualService.WithRawResponseindividuals()EmploymentService.WithRawResponseemployments()PaymentService.WithRawResponsepayments()PayStatementService.WithRawResponsepayStatements()DocumentService.WithRawResponsedocuments()BenefitService.WithRawResponsebenefits()-
-
Method Detail
-
withOptions
HrisService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
company
CompanyService.WithRawResponse company()
-
directory
DirectoryService.WithRawResponse directory()
-
individuals
IndividualService.WithRawResponse individuals()
-
employments
EmploymentService.WithRawResponse employments()
-
payments
PaymentService.WithRawResponse payments()
-
payStatements
PayStatementService.WithRawResponse payStatements()
-
documents
DocumentService.WithRawResponse documents()
-
benefits
BenefitService.WithRawResponse benefits()
-
-
-
-