Interface JobService
-
- All Implemented Interfaces:
public interface JobService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceJobService.WithRawResponseA view of JobService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract JobService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract JobServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract AutomatedServiceautomated()abstract ManualServicemanual()-
-
Method Detail
-
withRawResponse
abstract JobService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract JobService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
automated
abstract AutomatedService automated()
-
manual
abstract ManualService manual()
-
-
-
-