Interface JobService.WithRawResponse
-
- All Implemented Interfaces:
public interface JobService.WithRawResponseA view of JobService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract JobService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract AutomatedService.WithRawResponseautomated()abstract ManualService.WithRawResponsemanual()-
-
Method Detail
-
withOptions
abstract JobService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
automated
abstract AutomatedService.WithRawResponse automated()
-
manual
abstract ManualService.WithRawResponse manual()
-
-
-
-