Class JobServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.JobService.WithRawResponse
public final class JobServiceImpl.WithRawResponseImpl implements JobService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description JobService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. AutomatedService.WithRawResponseautomated()ManualService.WithRawResponsemanual()-
-
Method Detail
-
withOptions
JobService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
automated
AutomatedService.WithRawResponse automated()
-
manual
ManualService.WithRawResponse manual()
-
-
-
-