Class PayrollServiceImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.PayrollService
public final class PayrollServiceImpl implements PayrollService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayrollServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description PayrollService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. PayrollServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. PayGroupServicepayGroups()-
-
Method Detail
-
withRawResponse
PayrollService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
PayrollService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
payGroups
PayGroupService payGroups()
-
-
-
-