Interface ProviderService
-
- All Implemented Interfaces:
public interface ProviderService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceProviderService.WithRawResponseA view of ProviderService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ProviderService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract ProviderServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. ProviderListPagelist()Return details on all available payroll and HR systems. abstract ProviderListPagelist(ProviderListParams params, RequestOptions requestOptions)ProviderListPagelist(ProviderListParams params)ProviderListPagelist(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract ProviderService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ProviderService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
ProviderListPage list()
Return details on all available payroll and HR systems.
-
list
abstract ProviderListPage list(ProviderListParams params, RequestOptions requestOptions)
-
list
ProviderListPage list(ProviderListParams params)
-
list
ProviderListPage list(RequestOptions requestOptions)
-
-
-
-