Interface ProviderService.WithRawResponse
-
- All Implemented Interfaces:
public interface ProviderService.WithRawResponseA view of ProviderService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract ProviderService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<ProviderListPage>list()Returns a raw HTTP response for get /providers, but is otherwise the same as ProviderService.list.abstract HttpResponseFor<ProviderListPage>list(ProviderListParams params, RequestOptions requestOptions)HttpResponseFor<ProviderListPage>list(ProviderListParams params)HttpResponseFor<ProviderListPage>list(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract ProviderService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
@MustBeClosed() HttpResponseFor<ProviderListPage> list()
Returns a raw HTTP response for
get /providers, but is otherwise the same as ProviderService.list.
-
list
@MustBeClosed() abstract HttpResponseFor<ProviderListPage> list(ProviderListParams params, RequestOptions requestOptions)
-
list
@MustBeClosed() HttpResponseFor<ProviderListPage> list(ProviderListParams params)
-
list
@MustBeClosed() HttpResponseFor<ProviderListPage> list(RequestOptions requestOptions)
-
-
-
-