Class ProviderServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.ProviderService.WithRawResponse
public final class ProviderServiceImpl.WithRawResponseImpl implements ProviderService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description ProviderService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<ProviderListPage>list(ProviderListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
ProviderService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
HttpResponseFor<ProviderListPage> list(ProviderListParams params, RequestOptions requestOptions)
-
-
-
-