Interface RequestForwardingService
-
- All Implemented Interfaces:
public interface RequestForwardingService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceRequestForwardingService.WithRawResponseA view of RequestForwardingService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract RequestForwardingService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. RequestForwardingForwardResponseforward(RequestForwardingForwardParams params)The Forward API allows you to make direct requests to an employment system. abstract RequestForwardingForwardResponseforward(RequestForwardingForwardParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract RequestForwardingService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
forward
RequestForwardingForwardResponse forward(RequestForwardingForwardParams params)
The Forward API allows you to make direct requests to an employment system. If Finch’s unified API doesn’t have a data model that cleanly fits your needs, then Forward allows you to push or pull data models directly against an integration’s API.
-
forward
abstract RequestForwardingForwardResponse forward(RequestForwardingForwardParams params, RequestOptions requestOptions)
-
-
-
-