Interface RequestForwardingService.WithRawResponse
-
- All Implemented Interfaces:
public interface RequestForwardingService.WithRawResponseA view of RequestForwardingService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract RequestForwardingService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<RequestForwardingForwardResponse>forward(RequestForwardingForwardParams params)Returns a raw HTTP response for post /forward, but is otherwise the same as RequestForwardingService.forward.abstract HttpResponseFor<RequestForwardingForwardResponse>forward(RequestForwardingForwardParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract RequestForwardingService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
forward
@MustBeClosed() HttpResponseFor<RequestForwardingForwardResponse> forward(RequestForwardingForwardParams params)
Returns a raw HTTP response for
post /forward, but is otherwise the same as RequestForwardingService.forward.
-
forward
@MustBeClosed() abstract HttpResponseFor<RequestForwardingForwardResponse> forward(RequestForwardingForwardParams params, RequestOptions requestOptions)
-
-
-
-