Class RequestForwardingServiceImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.RequestForwardingService
public final class RequestForwardingServiceImpl implements RequestForwardingService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRequestForwardingServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description RequestForwardingService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. RequestForwardingServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. RequestForwardingForwardResponseforward(RequestForwardingForwardParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
RequestForwardingService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
RequestForwardingService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
forward
RequestForwardingForwardResponse forward(RequestForwardingForwardParams params, RequestOptions requestOptions)
-
-
-
-