Interface SandboxService
-
- All Implemented Interfaces:
public interface SandboxService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSandboxService.WithRawResponseA view of SandboxService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract SandboxService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract ConnectionServiceconnections()abstract CompanyServicecompany()abstract DirectoryServicedirectory()abstract IndividualServiceindividual()abstract EmploymentServiceemployment()abstract PaymentServicepayment()abstract JobServicejobs()-
-
Method Detail
-
withRawResponse
abstract SandboxService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
connections
abstract ConnectionService connections()
-
company
abstract CompanyService company()
-
directory
abstract DirectoryService directory()
-
individual
abstract IndividualService individual()
-
employment
abstract EmploymentService employment()
-
payment
abstract PaymentService payment()
-
jobs
abstract JobService jobs()
-
-
-
-