Class SandboxServiceImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.SandboxService
public final class SandboxServiceImpl implements SandboxService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSandboxServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description SandboxService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SandboxServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. ConnectionServiceconnections()CompanyServicecompany()DirectoryServicedirectory()IndividualServiceindividual()EmploymentServiceemployment()PaymentServicepayment()JobServicejobs()-
-
Method Detail
-
withRawResponse
SandboxService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SandboxService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
connections
ConnectionService connections()
-
company
CompanyService company()
-
directory
DirectoryService directory()
-
individual
IndividualService individual()
-
employment
EmploymentService employment()
-
payment
PaymentService payment()
-
jobs
JobService jobs()
-
-
-
-