Class SandboxServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.SandboxService.WithRawResponse
public final class SandboxServiceImpl.WithRawResponseImpl implements SandboxService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description SandboxService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. ConnectionService.WithRawResponseconnections()CompanyService.WithRawResponsecompany()DirectoryService.WithRawResponsedirectory()IndividualService.WithRawResponseindividual()EmploymentService.WithRawResponseemployment()PaymentService.WithRawResponsepayment()JobService.WithRawResponsejobs()-
-
Method Detail
-
withOptions
SandboxService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
connections
ConnectionService.WithRawResponse connections()
-
company
CompanyService.WithRawResponse company()
-
directory
DirectoryService.WithRawResponse directory()
-
individual
IndividualService.WithRawResponse individual()
-
employment
EmploymentService.WithRawResponse employment()
-
payment
PaymentService.WithRawResponse payment()
-
jobs
JobService.WithRawResponse jobs()
-
-
-
-