Interface WebhookService
-
- All Implemented Interfaces:
public interface WebhookService
-
-
Method Summary
Modifier and Type Method Description abstract WebhookServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract WebhookEventunwrap(String payload, Headers headers, String secret)abstract UnitverifySignature(String payload, Headers headers, String secret)-
-
Method Detail
-
withOptions
abstract WebhookService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
unwrap
abstract WebhookEvent unwrap(String payload, Headers headers, String secret)
-
verifySignature
abstract Unit verifySignature(String payload, Headers headers, String secret)
-
-
-
-