Class WebhookServiceImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.WebhookService
public final class WebhookServiceImpl implements WebhookService
-
-
Method Summary
Modifier and Type Method Description WebhookServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. WebhookEventunwrap(String payload, Headers headers, String secret)UnitverifySignature(String payload, Headers headers, String secret)-
-
Method Detail
-
withOptions
WebhookService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
unwrap
WebhookEvent unwrap(String payload, Headers headers, String secret)
-
verifySignature
Unit verifySignature(String payload, Headers headers, String secret)
-
-
-
-