Interface SessionService
-
- All Implemented Interfaces:
public interface SessionService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSessionService.WithRawResponseA view of SessionService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract SessionService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract SessionServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. SessionNewResponsenew_(ConnectSessionNewParams params)Create a new connect session for an employer abstract SessionNewResponsenew_(ConnectSessionNewParams params, RequestOptions requestOptions)SessionReauthenticateResponsereauthenticate(ConnectSessionReauthenticateParams params)Create a new Connect session for reauthenticating an existing connection abstract SessionReauthenticateResponsereauthenticate(ConnectSessionReauthenticateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract SessionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract SessionService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
new_
SessionNewResponse new_(ConnectSessionNewParams params)
Create a new connect session for an employer
-
new_
abstract SessionNewResponse new_(ConnectSessionNewParams params, RequestOptions requestOptions)
-
reauthenticate
SessionReauthenticateResponse reauthenticate(ConnectSessionReauthenticateParams params)
Create a new Connect session for reauthenticating an existing connection
-
reauthenticate
abstract SessionReauthenticateResponse reauthenticate(ConnectSessionReauthenticateParams params, RequestOptions requestOptions)
-
-
-
-