Interface SessionService.WithRawResponse
-
- All Implemented Interfaces:
public interface SessionService.WithRawResponseA view of SessionService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract SessionService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<SessionNewResponse>new_(ConnectSessionNewParams params)Returns a raw HTTP response for post /connect/sessions, but is otherwise the same as SessionService.new_.abstract HttpResponseFor<SessionNewResponse>new_(ConnectSessionNewParams params, RequestOptions requestOptions)HttpResponseFor<SessionReauthenticateResponse>reauthenticate(ConnectSessionReauthenticateParams params)Returns a raw HTTP response for post /connect/sessions/reauthenticate, but is otherwise the same as SessionService.reauthenticate.abstract HttpResponseFor<SessionReauthenticateResponse>reauthenticate(ConnectSessionReauthenticateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract SessionService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
new_
@MustBeClosed() HttpResponseFor<SessionNewResponse> new_(ConnectSessionNewParams params)
Returns a raw HTTP response for
post /connect/sessions, but is otherwise the same as SessionService.new_.
-
new_
@MustBeClosed() abstract HttpResponseFor<SessionNewResponse> new_(ConnectSessionNewParams params, RequestOptions requestOptions)
-
reauthenticate
@MustBeClosed() HttpResponseFor<SessionReauthenticateResponse> reauthenticate(ConnectSessionReauthenticateParams params)
Returns a raw HTTP response for
post /connect/sessions/reauthenticate, but is otherwise the same as SessionService.reauthenticate.
-
reauthenticate
@MustBeClosed() abstract HttpResponseFor<SessionReauthenticateResponse> reauthenticate(ConnectSessionReauthenticateParams params, RequestOptions requestOptions)
-
-
-
-