Class SessionServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.connect.SessionService.WithRawResponse
public final class SessionServiceImpl.WithRawResponseImpl implements SessionService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description SessionService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<SessionNewResponse>new_(ConnectSessionNewParams params, RequestOptions requestOptions)HttpResponseFor<SessionReauthenticateResponse>reauthenticate(ConnectSessionReauthenticateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
SessionService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
new_
HttpResponseFor<SessionNewResponse> new_(ConnectSessionNewParams params, RequestOptions requestOptions)
-
reauthenticate
HttpResponseFor<SessionReauthenticateResponse> reauthenticate(ConnectSessionReauthenticateParams params, RequestOptions requestOptions)
-
-
-
-