Interface DirectoryService
-
- All Implemented Interfaces:
public interface DirectoryService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceDirectoryService.WithRawResponseA view of DirectoryService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract DirectoryService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. HrisDirectoryListPagelist()Read company directory and organization structure abstract HrisDirectoryListPagelist(HrisDirectoryListParams params, RequestOptions requestOptions)HrisDirectoryListPagelist(HrisDirectoryListParams params)HrisDirectoryListPagelist(RequestOptions requestOptions)HrisDirectoryListIndividualsPagelistIndividuals()Read company directory and organization structure abstract HrisDirectoryListIndividualsPagelistIndividuals(HrisDirectoryListIndividualsParams params, RequestOptions requestOptions)HrisDirectoryListIndividualsPagelistIndividuals(HrisDirectoryListIndividualsParams params)HrisDirectoryListIndividualsPagelistIndividuals(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract DirectoryService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
list
HrisDirectoryListPage list()
Read company directory and organization structure
-
list
abstract HrisDirectoryListPage list(HrisDirectoryListParams params, RequestOptions requestOptions)
-
list
HrisDirectoryListPage list(HrisDirectoryListParams params)
-
list
HrisDirectoryListPage list(RequestOptions requestOptions)
-
listIndividuals
@Deprecated(message = "use `list` instead") HrisDirectoryListIndividualsPage listIndividuals()
Read company directory and organization structure
-
listIndividuals
@Deprecated(message = "use `list` instead") abstract HrisDirectoryListIndividualsPage listIndividuals(HrisDirectoryListIndividualsParams params, RequestOptions requestOptions)
-
listIndividuals
@Deprecated(message = "use `list` instead") HrisDirectoryListIndividualsPage listIndividuals(HrisDirectoryListIndividualsParams params)
-
listIndividuals
@Deprecated(message = "use `list` instead") HrisDirectoryListIndividualsPage listIndividuals(RequestOptions requestOptions)
-
-
-
-