Class DirectoryServiceImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.hris.DirectoryService
public final class DirectoryServiceImpl implements DirectoryService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDirectoryServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description DirectoryService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. DirectoryServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HrisDirectoryListPagelist(HrisDirectoryListParams params, RequestOptions requestOptions)DirectoryListIndividualsResponselistIndividuals(HrisDirectoryListIndividualsParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
DirectoryService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
DirectoryService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
HrisDirectoryListPage list(HrisDirectoryListParams params, RequestOptions requestOptions)
-
listIndividuals
@Deprecated(message = "use `list` instead") DirectoryListIndividualsResponse listIndividuals(HrisDirectoryListIndividualsParams params, RequestOptions requestOptions)
-
-
-
-