Class DirectoryServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.hris.DirectoryService.WithRawResponse
public final class DirectoryServiceImpl.WithRawResponseImpl implements DirectoryService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description DirectoryService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<HrisDirectoryListPage>list(HrisDirectoryListParams params, RequestOptions requestOptions)HttpResponseFor<HrisDirectoryListIndividualsPage>listIndividuals(HrisDirectoryListIndividualsParams params, RequestOptions requestOptions)-
Methods inherited from class com.tryfinch.api.services.blocking.hris.DirectoryService.WithRawResponse
list, list, list, listIndividuals, listIndividuals, listIndividuals -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
DirectoryService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
HttpResponseFor<HrisDirectoryListPage> list(HrisDirectoryListParams params, RequestOptions requestOptions)
-
listIndividuals
@Deprecated(message = "use `list` instead") HttpResponseFor<HrisDirectoryListIndividualsPage> listIndividuals(HrisDirectoryListIndividualsParams params, RequestOptions requestOptions)
-
-
-
-