Interface DocumentService
-
- All Implemented Interfaces:
public interface DocumentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceDocumentService.WithRawResponseA view of DocumentService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract DocumentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract DocumentService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
DocumentListResponse list()
Beta: This endpoint is in beta and may change. Retrieve a list of company-wide documents.
-
list
abstract DocumentListResponse list(HrisDocumentListParams params, RequestOptions requestOptions)
-
list
DocumentListResponse list(HrisDocumentListParams params)
-
list
DocumentListResponse list(RequestOptions requestOptions)
-
retreive
DocumentRetreiveResponse retreive(String documentId)
Beta: This endpoint is in beta and may change. Retrieve details of a specific document by its ID.
-
retreive
DocumentRetreiveResponse retreive(String documentId, HrisDocumentRetreiveParams params, RequestOptions requestOptions)
-
retreive
DocumentRetreiveResponse retreive(String documentId, HrisDocumentRetreiveParams params)
-
retreive
abstract DocumentRetreiveResponse retreive(HrisDocumentRetreiveParams params, RequestOptions requestOptions)
-
retreive
DocumentRetreiveResponse retreive(HrisDocumentRetreiveParams params)
-
retreive
DocumentRetreiveResponse retreive(String documentId, RequestOptions requestOptions)
-
-
-
-