Class DocumentServiceImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.hris.DocumentService
public final class DocumentServiceImpl implements DocumentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDocumentServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description DocumentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. DocumentListResponselist(HrisDocumentListParams params, RequestOptions requestOptions)DocumentRetreiveResponseretreive(HrisDocumentRetreiveParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
DocumentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
list
DocumentListResponse list(HrisDocumentListParams params, RequestOptions requestOptions)
-
retreive
DocumentRetreiveResponse retreive(HrisDocumentRetreiveParams params, RequestOptions requestOptions)
-
-
-
-