Class DocumentServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.hris.DocumentService.WithRawResponse
public final class DocumentServiceImpl.WithRawResponseImpl implements DocumentService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description DocumentService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<DocumentListResponse>list(HrisDocumentListParams params, RequestOptions requestOptions)HttpResponseFor<DocumentRetreiveResponse>retreive(HrisDocumentRetreiveParams params, RequestOptions requestOptions)-
Methods inherited from class com.tryfinch.api.services.blocking.hris.DocumentService.WithRawResponse
list, list, list, retreive, retreive, retreive, retreive, retreive -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
DocumentService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
HttpResponseFor<DocumentListResponse> list(HrisDocumentListParams params, RequestOptions requestOptions)
-
retreive
HttpResponseFor<DocumentRetreiveResponse> retreive(HrisDocumentRetreiveParams params, RequestOptions requestOptions)
-
-
-
-