Interface EmploymentService
-
- All Implemented Interfaces:
public interface EmploymentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceEmploymentService.WithRawResponseA view of EmploymentService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract EmploymentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract EmploymentServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HrisEmploymentRetrieveManyPageretrieveMany(HrisEmploymentRetrieveManyParams params)Read individual employment and income data abstract HrisEmploymentRetrieveManyPageretrieveMany(HrisEmploymentRetrieveManyParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract EmploymentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract EmploymentService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieveMany
HrisEmploymentRetrieveManyPage retrieveMany(HrisEmploymentRetrieveManyParams params)
Read individual employment and income data
-
retrieveMany
abstract HrisEmploymentRetrieveManyPage retrieveMany(HrisEmploymentRetrieveManyParams params, RequestOptions requestOptions)
-
-
-
-