Interface PayStatementService
-
- All Implemented Interfaces:
public interface PayStatementService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfacePayStatementService.WithRawResponseA view of PayStatementService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract PayStatementService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract PayStatementServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HrisPayStatementRetrieveManyPageretrieveMany(HrisPayStatementRetrieveManyParams params)Read detailed pay statements for each individual. abstract HrisPayStatementRetrieveManyPageretrieveMany(HrisPayStatementRetrieveManyParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract PayStatementService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract PayStatementService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieveMany
HrisPayStatementRetrieveManyPage retrieveMany(HrisPayStatementRetrieveManyParams params)
Read detailed pay statements for each individual.
Deduction and contribution types are supported by the payroll systems that supports Benefits.
-
retrieveMany
abstract HrisPayStatementRetrieveManyPage retrieveMany(HrisPayStatementRetrieveManyParams params, RequestOptions requestOptions)
-
-
-
-