Class PayStatementServiceImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.hris.PayStatementService
public final class PayStatementServiceImpl implements PayStatementService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayStatementServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description PayStatementService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. HrisPayStatementRetrieveManyPageretrieveMany(HrisPayStatementRetrieveManyParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
PayStatementService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieveMany
HrisPayStatementRetrieveManyPage retrieveMany(HrisPayStatementRetrieveManyParams params, RequestOptions requestOptions)
-
-
-
-