Class PayStatementServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.hris.PayStatementService.WithRawResponse
public final class PayStatementServiceImpl.WithRawResponseImpl implements PayStatementService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description PayStatementService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<HrisPayStatementRetrieveManyPage>retrieveMany(HrisPayStatementRetrieveManyParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
PayStatementService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieveMany
HttpResponseFor<HrisPayStatementRetrieveManyPage> retrieveMany(HrisPayStatementRetrieveManyParams params, RequestOptions requestOptions)
-
-
-
-