Interface PaymentService
-
- All Implemented Interfaces:
public interface PaymentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfacePaymentService.WithRawResponseA view of PaymentService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract PaymentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. HrisPaymentListPagelist(HrisPaymentListParams params)Read payroll and contractor related payments by the company. abstract HrisPaymentListPagelist(HrisPaymentListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract PaymentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
list
HrisPaymentListPage list(HrisPaymentListParams params)
Read payroll and contractor related payments by the company.
-
list
abstract HrisPaymentListPage list(HrisPaymentListParams params, RequestOptions requestOptions)
-
-
-
-