Interface AutomatedService
-
- All Implemented Interfaces:
public interface AutomatedService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAutomatedService.WithRawResponseA view of AutomatedService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract AutomatedService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract AutomatedService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
AutomatedCreateResponse create()
Enqueue an automated job.
data_sync_all: Enqueue a job to re-sync all data for a connection.data_sync_allhas a concurrency limit of 1 job at a time per connection. This means that if this endpoint is called while a job is already in progress for this connection, Finch will return thejob_idof the job that is currently in progress. Finch allows a fixed window rate limit of 1 forced refresh per hour per connection.w4_form_employee_sync: Enqueues a job for sync W-4 data for a particular individual, identified byindividual_id. This feature is currently in beta.This endpoint is available for Scale tier customers as an add-on. To request access to this endpoint, please contact your Finch account manager.
-
create
abstract AutomatedCreateResponse create(JobAutomatedCreateParams params, RequestOptions requestOptions)
-
create
AutomatedCreateResponse create(JobAutomatedCreateParams params)
-
create
AutomatedCreateResponse create(RequestOptions requestOptions)
-
retrieve
AutomatedAsyncJob retrieve(String jobId)
Get an automated job by
job_id.
-
retrieve
AutomatedAsyncJob retrieve(String jobId, JobAutomatedRetrieveParams params, RequestOptions requestOptions)
-
retrieve
AutomatedAsyncJob retrieve(String jobId, JobAutomatedRetrieveParams params)
-
retrieve
abstract AutomatedAsyncJob retrieve(JobAutomatedRetrieveParams params, RequestOptions requestOptions)
-
retrieve
AutomatedAsyncJob retrieve(JobAutomatedRetrieveParams params)
-
retrieve
AutomatedAsyncJob retrieve(String jobId, RequestOptions requestOptions)
-
list
AutomatedListResponse list()
Get all automated jobs. Automated jobs are completed by a machine. By default, jobs are sorted in descending order by submission time. For scheduled jobs such as data syncs, only the next scheduled job is shown.
-
list
abstract AutomatedListResponse list(JobAutomatedListParams params, RequestOptions requestOptions)
-
list
AutomatedListResponse list(JobAutomatedListParams params)
-
list
AutomatedListResponse list(RequestOptions requestOptions)
-
-
-
-