Class AutomatedServiceImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.jobs.AutomatedService
public final class AutomatedServiceImpl implements AutomatedService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAutomatedServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AutomatedService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AutomatedCreateResponsecreate(JobAutomatedCreateParams params, RequestOptions requestOptions)AutomatedAsyncJobretrieve(JobAutomatedRetrieveParams params, RequestOptions requestOptions)AutomatedListResponselist(JobAutomatedListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
AutomatedService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
AutomatedCreateResponse create(JobAutomatedCreateParams params, RequestOptions requestOptions)
-
retrieve
AutomatedAsyncJob retrieve(JobAutomatedRetrieveParams params, RequestOptions requestOptions)
-
list
AutomatedListResponse list(JobAutomatedListParams params, RequestOptions requestOptions)
-
-
-
-