Interface PayGroupService
-
- All Implemented Interfaces:
public interface PayGroupService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfacePayGroupService.WithRawResponseA view of PayGroupService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract PayGroupService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract PayGroupService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
PayGroupRetrieveResponse retrieve(String payGroupId)
Read information from a single pay group
-
retrieve
PayGroupRetrieveResponse retrieve(String payGroupId, PayrollPayGroupRetrieveParams params, RequestOptions requestOptions)
-
retrieve
PayGroupRetrieveResponse retrieve(String payGroupId, PayrollPayGroupRetrieveParams params)
-
retrieve
abstract PayGroupRetrieveResponse retrieve(PayrollPayGroupRetrieveParams params, RequestOptions requestOptions)
-
retrieve
PayGroupRetrieveResponse retrieve(PayrollPayGroupRetrieveParams params)
-
retrieve
PayGroupRetrieveResponse retrieve(String payGroupId, RequestOptions requestOptions)
-
list
PayrollPayGroupListPage list()
Read company pay groups and frequencies
-
list
abstract PayrollPayGroupListPage list(PayrollPayGroupListParams params, RequestOptions requestOptions)
-
list
PayrollPayGroupListPage list(PayrollPayGroupListParams params)
-
list
PayrollPayGroupListPage list(RequestOptions requestOptions)
-
-
-
-