Class PayGroupServiceImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.payroll.PayGroupService
public final class PayGroupServiceImpl implements PayGroupService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayGroupServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description PayGroupService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. PayGroupServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. PayGroupRetrieveResponseretrieve(PayrollPayGroupRetrieveParams params, RequestOptions requestOptions)PayrollPayGroupListPagelist(PayrollPayGroupListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
PayGroupService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
PayGroupService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
PayGroupRetrieveResponse retrieve(PayrollPayGroupRetrieveParams params, RequestOptions requestOptions)
-
list
PayrollPayGroupListPage list(PayrollPayGroupListParams params, RequestOptions requestOptions)
-
-
-
-