Interface CompanyService
-
- All Implemented Interfaces:
public interface CompanyService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCompanyService.WithRawResponseA view of CompanyService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CompanyService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CompanyServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompanyUpdateResponseupdate(SandboxCompanyUpdateParams params)Update a sandbox company's data abstract CompanyUpdateResponseupdate(SandboxCompanyUpdateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CompanyService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CompanyService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
update
CompanyUpdateResponse update(SandboxCompanyUpdateParams params)
Update a sandbox company's data
-
update
abstract CompanyUpdateResponse update(SandboxCompanyUpdateParams params, RequestOptions requestOptions)
-
-
-
-