Class CompanyServiceImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.sandbox.CompanyService
public final class CompanyServiceImpl implements CompanyService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCompanyServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CompanyService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompanyUpdateResponseupdate(SandboxCompanyUpdateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CompanyService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
update
CompanyUpdateResponse update(SandboxCompanyUpdateParams params, RequestOptions requestOptions)
-
-
-
-