Class ConnectionServiceImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.sandbox.ConnectionService
public final class ConnectionServiceImpl implements ConnectionService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classConnectionServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ConnectionService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. ConnectionServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. AccountServiceaccounts()ConnectionCreateResponsecreate(SandboxConnectionCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
ConnectionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ConnectionService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
accounts
AccountService accounts()
-
create
ConnectionCreateResponse create(SandboxConnectionCreateParams params, RequestOptions requestOptions)
-
-
-
-