Interface DirectoryService
-
- All Implemented Interfaces:
public interface DirectoryService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceDirectoryService.WithRawResponseA view of DirectoryService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract DirectoryService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract DirectoryServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. List<DirectoryCreateResponse>create()Add new individuals to a sandbox company abstract List<DirectoryCreateResponse>create(SandboxDirectoryCreateParams params, RequestOptions requestOptions)List<DirectoryCreateResponse>create(SandboxDirectoryCreateParams params)List<DirectoryCreateResponse>create(List<SandboxDirectoryCreateParams.IndividualOrEmployment> body, RequestOptions requestOptions)List<DirectoryCreateResponse>create(List<SandboxDirectoryCreateParams.IndividualOrEmployment> body)List<DirectoryCreateResponse>create(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract DirectoryService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract DirectoryService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
List<DirectoryCreateResponse> create()
Add new individuals to a sandbox company
-
create
abstract List<DirectoryCreateResponse> create(SandboxDirectoryCreateParams params, RequestOptions requestOptions)
-
create
List<DirectoryCreateResponse> create(SandboxDirectoryCreateParams params)
-
create
List<DirectoryCreateResponse> create(List<SandboxDirectoryCreateParams.IndividualOrEmployment> body, RequestOptions requestOptions)
-
create
List<DirectoryCreateResponse> create(List<SandboxDirectoryCreateParams.IndividualOrEmployment> body)
-
create
List<DirectoryCreateResponse> create(RequestOptions requestOptions)
-
-
-
-