Interface DirectoryService.WithRawResponse
-
- All Implemented Interfaces:
public interface DirectoryService.WithRawResponseA view of DirectoryService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract DirectoryService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<List<DirectoryCreateResponse>>create()Returns a raw HTTP response for post /sandbox/directory, but is otherwise the same as DirectoryService.create.abstract HttpResponseFor<List<DirectoryCreateResponse>>create(SandboxDirectoryCreateParams params, RequestOptions requestOptions)HttpResponseFor<List<DirectoryCreateResponse>>create(SandboxDirectoryCreateParams params)HttpResponseFor<List<DirectoryCreateResponse>>create(List<SandboxDirectoryCreateParams.IndividualOrEmployment> body, RequestOptions requestOptions)HttpResponseFor<List<DirectoryCreateResponse>>create(List<SandboxDirectoryCreateParams.IndividualOrEmployment> body)HttpResponseFor<List<DirectoryCreateResponse>>create(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract DirectoryService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
@MustBeClosed() HttpResponseFor<List<DirectoryCreateResponse>> create()
Returns a raw HTTP response for
post /sandbox/directory, but is otherwise the same as DirectoryService.create.
-
create
@MustBeClosed() abstract HttpResponseFor<List<DirectoryCreateResponse>> create(SandboxDirectoryCreateParams params, RequestOptions requestOptions)
-
create
@MustBeClosed() HttpResponseFor<List<DirectoryCreateResponse>> create(SandboxDirectoryCreateParams params)
-
create
@MustBeClosed() HttpResponseFor<List<DirectoryCreateResponse>> create(List<SandboxDirectoryCreateParams.IndividualOrEmployment> body, RequestOptions requestOptions)
-
create
@MustBeClosed() HttpResponseFor<List<DirectoryCreateResponse>> create(List<SandboxDirectoryCreateParams.IndividualOrEmployment> body)
-
create
@MustBeClosed() HttpResponseFor<List<DirectoryCreateResponse>> create(RequestOptions requestOptions)
-
-
-
-