Class DirectoryServiceImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.sandbox.DirectoryService
public final class DirectoryServiceImpl implements DirectoryService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDirectoryServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description DirectoryService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. DirectoryServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. List<DirectoryCreateResponse>create(SandboxDirectoryCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
DirectoryService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
DirectoryService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
List<DirectoryCreateResponse> create(SandboxDirectoryCreateParams params, RequestOptions requestOptions)
-
-
-
-