Interface EmploymentService
-
- All Implemented Interfaces:
public interface EmploymentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceEmploymentService.WithRawResponseA view of EmploymentService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract EmploymentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract EmploymentServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. EmploymentUpdateResponseupdate(String individualId)Update sandbox employment EmploymentUpdateResponseupdate(String individualId, SandboxEmploymentUpdateParams params, RequestOptions requestOptions)EmploymentUpdateResponseupdate(String individualId, SandboxEmploymentUpdateParams params)abstract EmploymentUpdateResponseupdate(SandboxEmploymentUpdateParams params, RequestOptions requestOptions)EmploymentUpdateResponseupdate(SandboxEmploymentUpdateParams params)EmploymentUpdateResponseupdate(String individualId, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract EmploymentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract EmploymentService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
update
EmploymentUpdateResponse update(String individualId)
Update sandbox employment
-
update
EmploymentUpdateResponse update(String individualId, SandboxEmploymentUpdateParams params, RequestOptions requestOptions)
-
update
EmploymentUpdateResponse update(String individualId, SandboxEmploymentUpdateParams params)
-
update
abstract EmploymentUpdateResponse update(SandboxEmploymentUpdateParams params, RequestOptions requestOptions)
-
update
EmploymentUpdateResponse update(SandboxEmploymentUpdateParams params)
-
update
EmploymentUpdateResponse update(String individualId, RequestOptions requestOptions)
-
-
-
-