Class EmploymentServiceImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.sandbox.EmploymentService
public final class EmploymentServiceImpl implements EmploymentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEmploymentServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description EmploymentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. EmploymentUpdateResponseupdate(SandboxEmploymentUpdateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
EmploymentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
update
EmploymentUpdateResponse update(SandboxEmploymentUpdateParams params, RequestOptions requestOptions)
-
-
-
-