Interface IndividualService
-
- All Implemented Interfaces:
public interface IndividualService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceIndividualService.WithRawResponseA view of IndividualService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract IndividualService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract IndividualServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. IndividualUpdateResponseupdate(String individualId)Update sandbox individual IndividualUpdateResponseupdate(String individualId, SandboxIndividualUpdateParams params, RequestOptions requestOptions)IndividualUpdateResponseupdate(String individualId, SandboxIndividualUpdateParams params)abstract IndividualUpdateResponseupdate(SandboxIndividualUpdateParams params, RequestOptions requestOptions)IndividualUpdateResponseupdate(SandboxIndividualUpdateParams params)IndividualUpdateResponseupdate(String individualId, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract IndividualService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract IndividualService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
update
IndividualUpdateResponse update(String individualId)
Update sandbox individual
-
update
IndividualUpdateResponse update(String individualId, SandboxIndividualUpdateParams params, RequestOptions requestOptions)
-
update
IndividualUpdateResponse update(String individualId, SandboxIndividualUpdateParams params)
-
update
abstract IndividualUpdateResponse update(SandboxIndividualUpdateParams params, RequestOptions requestOptions)
-
update
IndividualUpdateResponse update(SandboxIndividualUpdateParams params)
-
update
IndividualUpdateResponse update(String individualId, RequestOptions requestOptions)
-
-
-
-