Interface IndividualService.WithRawResponse
-
- All Implemented Interfaces:
public interface IndividualService.WithRawResponseA view of IndividualService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract IndividualService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<IndividualUpdateResponse>update(String individualId)Returns a raw HTTP response for put /sandbox/individual/{individual_id}, but is otherwise the same as IndividualService.update.HttpResponseFor<IndividualUpdateResponse>update(String individualId, SandboxIndividualUpdateParams params, RequestOptions requestOptions)HttpResponseFor<IndividualUpdateResponse>update(String individualId, SandboxIndividualUpdateParams params)abstract HttpResponseFor<IndividualUpdateResponse>update(SandboxIndividualUpdateParams params, RequestOptions requestOptions)HttpResponseFor<IndividualUpdateResponse>update(SandboxIndividualUpdateParams params)HttpResponseFor<IndividualUpdateResponse>update(String individualId, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract IndividualService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
update
@MustBeClosed() HttpResponseFor<IndividualUpdateResponse> update(String individualId)
Returns a raw HTTP response for
put /sandbox/individual/{individual_id}, but is otherwise the same as IndividualService.update.
-
update
@MustBeClosed() HttpResponseFor<IndividualUpdateResponse> update(String individualId, SandboxIndividualUpdateParams params, RequestOptions requestOptions)
-
update
@MustBeClosed() HttpResponseFor<IndividualUpdateResponse> update(String individualId, SandboxIndividualUpdateParams params)
-
update
@MustBeClosed() abstract HttpResponseFor<IndividualUpdateResponse> update(SandboxIndividualUpdateParams params, RequestOptions requestOptions)
-
update
@MustBeClosed() HttpResponseFor<IndividualUpdateResponse> update(SandboxIndividualUpdateParams params)
-
update
@MustBeClosed() HttpResponseFor<IndividualUpdateResponse> update(String individualId, RequestOptions requestOptions)
-
-
-
-