Class IndividualServiceImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.sandbox.IndividualService
public final class IndividualServiceImpl implements IndividualService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIndividualServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description IndividualService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. IndividualServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. IndividualUpdateResponseupdate(SandboxIndividualUpdateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
IndividualService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
IndividualService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
update
IndividualUpdateResponse update(SandboxIndividualUpdateParams params, RequestOptions requestOptions)
-
-
-
-