Class IndividualServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.sandbox.IndividualService.WithRawResponse
public final class IndividualServiceImpl.WithRawResponseImpl implements IndividualService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description IndividualService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<IndividualUpdateResponse>update(SandboxIndividualUpdateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
IndividualService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
update
HttpResponseFor<IndividualUpdateResponse> update(SandboxIndividualUpdateParams params, RequestOptions requestOptions)
-
-
-
-