Interface JobService.WithRawResponse
-
- All Implemented Interfaces:
public interface JobService.WithRawResponseA view of JobService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract JobService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract ConfigurationService.WithRawResponseconfiguration()HttpResponseFor<JobCreateResponse>create(SandboxJobCreateParams params)Returns a raw HTTP response for post /sandbox/jobs, but is otherwise the same as JobService.create.abstract HttpResponseFor<JobCreateResponse>create(SandboxJobCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract JobService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
configuration
abstract ConfigurationService.WithRawResponse configuration()
-
create
@MustBeClosed() HttpResponseFor<JobCreateResponse> create(SandboxJobCreateParams params)
Returns a raw HTTP response for
post /sandbox/jobs, but is otherwise the same as JobService.create.
-
create
@MustBeClosed() abstract HttpResponseFor<JobCreateResponse> create(SandboxJobCreateParams params, RequestOptions requestOptions)
-
-
-
-