Class JobServiceImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.sandbox.JobService
public final class JobServiceImpl implements JobService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classJobServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description JobService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. JobServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. ConfigurationServiceconfiguration()JobCreateResponsecreate(SandboxJobCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
JobService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
JobService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
configuration
ConfigurationService configuration()
-
create
JobCreateResponse create(SandboxJobCreateParams params, RequestOptions requestOptions)
-
-
-
-