Class PaymentServiceImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.sandbox.PaymentService
public final class PaymentServiceImpl implements PaymentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPaymentServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description PaymentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. PaymentServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. PaymentCreateResponsecreate(SandboxPaymentCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
PaymentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
PaymentService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
PaymentCreateResponse create(SandboxPaymentCreateParams params, RequestOptions requestOptions)
-
-
-
-