Methods
| Method |
Description |
|
com.tryfinch.api.client.getAccessToken(java.lang.String,java.lang.String,java.lang.String,java.lang.String)
|
|
|
com.tryfinch.api.client.getAccessToken(java.lang.String,java.lang.String,java.lang.String,java.lang.String)
|
|
|
com.tryfinch.api.client.getAccessToken(java.lang.String,java.lang.String,java.lang.String,java.lang.String)
|
|
|
com.tryfinch.api.client.getAccessToken(java.lang.String,java.lang.String,java.lang.String,java.lang.String)
|
|
|
com.fasterxml.jackson.databind.getNullValue()
|
|
|
com.fasterxml.jackson.databind.getEmptyValue()
|
|
|
com.fasterxml.jackson.databind.deser.std.getValueClass()
|
|
|
com.fasterxml.jackson.databind.isEmpty(T)
|
|
|
com.fasterxml.jackson.databind.isEmpty(com.tryfinch.api.core.JsonMissing)
|
|
|
com.tryfinch.api.models.accountId(java.lang.String)
|
DEPRECATED Use connection_id to associate a connection with an access token |
|
com.tryfinch.api.models.accountId(com.tryfinch.api.core.JsonField)
|
Sets Builder.accountId to an arbitrary JSON value. |
|
com.tryfinch.api.models.companyId(java.lang.String)
|
DEPRECATED Use connection_id to associate a connection with an access token |
|
com.tryfinch.api.models.companyId(com.tryfinch.api.core.JsonField)
|
Sets Builder.companyId to an arbitrary JSON value. |
|
com.tryfinch.api.models.accountId()
|
DEPRECATED Use connection_id to associate a connection with an access token |
|
com.tryfinch.api.models.companyId()
|
DEPRECATED Use connection_id to associate a connection with an access token |
|
com.tryfinch.api.models._accountId()
|
Returns the raw JSON value of accountId. |
|
com.tryfinch.api.models._companyId()
|
Returns the raw JSON value of companyId. |
|
com.tryfinch.api.models.accountId(java.lang.String)
|
DEPRECATED Unique Finch ID of the employer account used to make this connection. |
|
com.tryfinch.api.models.accountId(com.tryfinch.api.core.JsonField)
|
Sets Builder.accountId to an arbitrary JSON value. |
|
com.tryfinch.api.models.companyId(java.lang.String)
|
DEPRECATED Unique Finch ID of the company for which data has been updated. |
|
com.tryfinch.api.models.companyId(com.tryfinch.api.core.JsonField)
|
Sets Builder.companyId to an arbitrary JSON value. |
|
com.tryfinch.api.models.accountId()
|
DEPRECATED Unique Finch ID of the employer account used to make this connection. |
|
com.tryfinch.api.models.companyId()
|
DEPRECATED Unique Finch ID of the company for which data has been updated. |
|
com.tryfinch.api.models._accountId()
|
Returns the raw JSON value of accountId. |
|
com.tryfinch.api.models._companyId()
|
Returns the raw JSON value of companyId. |
|
com.tryfinch.api.models.accountId(java.lang.String)
|
DEPRECATED Use connection_id to associate a connection with an access token |
|
com.tryfinch.api.models.accountId(com.tryfinch.api.core.JsonField)
|
Sets Builder.accountId to an arbitrary JSON value. |
|
com.tryfinch.api.models.companyId(java.lang.String)
|
DEPRECATED Use connection_id to associate a connection with an access token |
|
com.tryfinch.api.models.companyId(com.tryfinch.api.core.JsonField)
|
Sets Builder.companyId to an arbitrary JSON value. |
|
com.tryfinch.api.models.accountId()
|
DEPRECATED Use connection_id to associate a connection with an access token |
|
com.tryfinch.api.models.companyId()
|
DEPRECATED Use connection_id to associate a connection with an access token |
|
com.tryfinch.api.models._accountId()
|
Returns the raw JSON value of accountId. |
|
com.tryfinch.api.models._companyId()
|
Returns the raw JSON value of companyId. |
|
com.tryfinch.api.models.accountId(java.lang.String)
|
DEPRECATED Unique Finch ID of the employer account used to make this connection. |
|
com.tryfinch.api.models.accountId(com.tryfinch.api.core.JsonField)
|
Sets Builder.accountId to an arbitrary JSON value. |
|
com.tryfinch.api.models.companyId(java.lang.String)
|
DEPRECATED Unique Finch ID of the company for which data has been updated. |
|
com.tryfinch.api.models.companyId(com.tryfinch.api.core.JsonField)
|
Sets Builder.companyId to an arbitrary JSON value. |
|
com.tryfinch.api.models.accountId()
|
DEPRECATED Unique Finch ID of the employer account used to make this connection. |
|
com.tryfinch.api.models.companyId()
|
DEPRECATED Unique Finch ID of the company for which data has been updated. |
|
com.tryfinch.api.models._accountId()
|
Returns the raw JSON value of accountId. |
|
com.tryfinch.api.models._companyId()
|
Returns the raw JSON value of companyId. |
|
com.tryfinch.api.models.accountId(java.lang.String)
|
DEPRECATED Unique Finch ID of the employer account used to make this connection. |
|
com.tryfinch.api.models.accountId(com.tryfinch.api.core.JsonField)
|
Sets Builder.accountId to an arbitrary JSON value. |
|
com.tryfinch.api.models.companyId(java.lang.String)
|
DEPRECATED Unique Finch ID of the company for which data has been updated. |
|
com.tryfinch.api.models.companyId(com.tryfinch.api.core.JsonField)
|
Sets Builder.companyId to an arbitrary JSON value. |
|
com.tryfinch.api.models.accountId()
|
DEPRECATED Unique Finch ID of the employer account used to make this connection. |
|
com.tryfinch.api.models.companyId()
|
DEPRECATED Unique Finch ID of the company for which data has been updated. |
|
com.tryfinch.api.models._accountId()
|
Returns the raw JSON value of accountId. |
|
com.tryfinch.api.models._companyId()
|
Returns the raw JSON value of companyId. |
|
com.tryfinch.api.models.accountId(java.lang.String)
|
DEPRECATED Use connection_id to associate a connection with an access token |
|
com.tryfinch.api.models.accountId(com.tryfinch.api.core.JsonField)
|
Sets Builder.accountId to an arbitrary JSON value. |
|
com.tryfinch.api.models.companyId(java.lang.String)
|
DEPRECATED Use connection_id to associate a connection with an access token |
|
com.tryfinch.api.models.companyId(com.tryfinch.api.core.JsonField)
|
Sets Builder.companyId to an arbitrary JSON value. |
|
com.tryfinch.api.models.accountId()
|
DEPRECATED Use connection_id to associate a connection with an access token |
|
com.tryfinch.api.models.companyId()
|
DEPRECATED Use connection_id to associate a connection with an access token |
|
com.tryfinch.api.models._accountId()
|
Returns the raw JSON value of accountId. |
|
com.tryfinch.api.models._companyId()
|
Returns the raw JSON value of companyId. |
|
com.tryfinch.api.models.accountId(java.lang.String)
|
DEPRECATED Use connection_id to identify the connection instead of this account ID |
|
com.tryfinch.api.models.accountId(com.tryfinch.api.core.JsonField)
|
Sets Builder.accountId to an arbitrary JSON value. |
|
com.tryfinch.api.models.companyId(java.lang.String)
|
DEPRECATED Use connection_id to identify the connection instead of this company ID |
|
com.tryfinch.api.models.companyId(com.tryfinch.api.core.JsonField)
|
Sets Builder.companyId to an arbitrary JSON value. |
|
com.tryfinch.api.models.accountId()
|
DEPRECATED Use connection_id to identify the connection instead of this account ID |
|
com.tryfinch.api.models.companyId()
|
DEPRECATED Use connection_id to identify the connection instead of this company ID |
|
com.tryfinch.api.models._accountId()
|
Returns the raw JSON value of accountId. |
|
com.tryfinch.api.models._companyId()
|
Returns the raw JSON value of companyId. |
|
com.tryfinch.api.models.accountId(java.lang.String)
|
DEPRECATED Unique Finch ID of the employer account used to make this connection. |
|
com.tryfinch.api.models.accountId(com.tryfinch.api.core.JsonField)
|
Sets Builder.accountId to an arbitrary JSON value. |
|
com.tryfinch.api.models.companyId(java.lang.String)
|
DEPRECATED Unique Finch ID of the company for which data has been updated. |
|
com.tryfinch.api.models.companyId(com.tryfinch.api.core.JsonField)
|
Sets Builder.companyId to an arbitrary JSON value. |
|
com.tryfinch.api.models.accountId()
|
DEPRECATED Unique Finch ID of the employer account used to make this connection. |
|
com.tryfinch.api.models.companyId()
|
DEPRECATED Unique Finch ID of the company for which data has been updated. |
|
com.tryfinch.api.models._accountId()
|
Returns the raw JSON value of accountId. |
|
com.tryfinch.api.models._companyId()
|
Returns the raw JSON value of companyId. |
|
com.tryfinch.api.models.workId(java.lang.String)
|
This field is deprecated in favour of source_id |
|
com.tryfinch.api.models.workId(java.util.Optional)
|
Alias for calling Builder.workId with workId.orElse(null). |
|
com.tryfinch.api.models.workId(com.tryfinch.api.core.JsonField)
|
Sets Builder.workId to an arbitrary JSON value. |
|
com.tryfinch.api.models.workId()
|
This field is deprecated in favour of source_id |
|
com.tryfinch.api.models._workId()
|
Returns the raw JSON value of workId. |
|
com.tryfinch.api.models.accountId(java.lang.String)
|
DEPRECATED Unique Finch ID of the employer account used to make this connection. |
|
com.tryfinch.api.models.accountId(com.tryfinch.api.core.JsonField)
|
Sets Builder.accountId to an arbitrary JSON value. |
|
com.tryfinch.api.models.companyId(java.lang.String)
|
DEPRECATED Unique Finch ID of the company for which data has been updated. |
|
com.tryfinch.api.models.companyId(com.tryfinch.api.core.JsonField)
|
Sets Builder.companyId to an arbitrary JSON value. |
|
com.tryfinch.api.models.accountId()
|
DEPRECATED Unique Finch ID of the employer account used to make this connection. |
|
com.tryfinch.api.models.companyId()
|
DEPRECATED Unique Finch ID of the company for which data has been updated. |
|
com.tryfinch.api.models._accountId()
|
Returns the raw JSON value of accountId. |
|
com.tryfinch.api.models._companyId()
|
Returns the raw JSON value of companyId. |
|
com.tryfinch.api.models.accountId(java.lang.String)
|
DEPRECATED Unique Finch ID of the employer account used to make this connection. |
|
com.tryfinch.api.models.accountId(com.tryfinch.api.core.JsonField)
|
Sets Builder.accountId to an arbitrary JSON value. |
|
com.tryfinch.api.models.companyId(java.lang.String)
|
DEPRECATED Unique Finch ID of the company for which data has been updated. |
|
com.tryfinch.api.models.companyId(com.tryfinch.api.core.JsonField)
|
Sets Builder.companyId to an arbitrary JSON value. |
|
com.tryfinch.api.models.accountId()
|
DEPRECATED Unique Finch ID of the employer account used to make this connection. |
|
com.tryfinch.api.models.companyId()
|
DEPRECATED Unique Finch ID of the company for which data has been updated. |
|
com.tryfinch.api.models._accountId()
|
Returns the raw JSON value of accountId. |
|
com.tryfinch.api.models._companyId()
|
Returns the raw JSON value of companyId. |
|
com.tryfinch.api.models.accountId(java.lang.String)
|
DEPRECATED Use connection_id to associate tokens with a Finch connection instead of this account ID |
|
com.tryfinch.api.models.accountId(com.tryfinch.api.core.JsonField)
|
Sets Builder.accountId to an arbitrary JSON value. |
|
com.tryfinch.api.models.companyId(java.lang.String)
|
DEPRECATED Use connection_id to associate tokens with a Finch connection instead of this company ID |
|
com.tryfinch.api.models.companyId(com.tryfinch.api.core.JsonField)
|
Sets Builder.companyId to an arbitrary JSON value. |
|
com.tryfinch.api.models.payrollProviderId(java.lang.String)
|
DEPRECATED Use provider_id to identify the provider instead of this payroll provider ID. |
|
com.tryfinch.api.models.payrollProviderId(com.tryfinch.api.core.JsonField)
|
Sets Builder.payrollProviderId to an arbitrary JSON value. |
|
com.tryfinch.api.models.accountId()
|
DEPRECATED Use connection_id to associate tokens with a Finch connection instead of this account ID |
|
com.tryfinch.api.models.companyId()
|
DEPRECATED Use connection_id to associate tokens with a Finch connection instead of this company ID |
|
com.tryfinch.api.models.payrollProviderId()
|
DEPRECATED Use provider_id to identify the provider instead of this payroll provider ID. |
|
com.tryfinch.api.models._accountId()
|
Returns the raw JSON value of accountId. |
|
com.tryfinch.api.models._companyId()
|
Returns the raw JSON value of companyId. |
|
com.tryfinch.api.models._payrollProviderId()
|
Returns the raw JSON value of payrollProviderId. |
|
com.tryfinch.api.models.accountId(java.lang.String)
|
DEPRECATED Unique Finch ID of the employer account used to make this connection. |
|
com.tryfinch.api.models.accountId(com.tryfinch.api.core.JsonField)
|
Sets Builder.accountId to an arbitrary JSON value. |
|
com.tryfinch.api.models.companyId(java.lang.String)
|
DEPRECATED Unique Finch ID of the company for which data has been updated. |
|
com.tryfinch.api.models.companyId(com.tryfinch.api.core.JsonField)
|
Sets Builder.companyId to an arbitrary JSON value. |
|
com.tryfinch.api.models.accountId()
|
DEPRECATED Unique Finch ID of the employer account used to make this connection. |
|
com.tryfinch.api.models.companyId()
|
DEPRECATED Unique Finch ID of the company for which data has been updated. |
|
com.tryfinch.api.models._accountId()
|
Returns the raw JSON value of accountId. |
|
com.tryfinch.api.models._companyId()
|
Returns the raw JSON value of companyId. |
|
com.tryfinch.api.models.accountId(java.lang.String)
|
DEPRECATED Unique Finch ID of the employer account used to make this connection. |
|
com.tryfinch.api.models.accountId(com.tryfinch.api.core.JsonField)
|
Sets Builder.accountId to an arbitrary JSON value. |
|
com.tryfinch.api.models.companyId(java.lang.String)
|
DEPRECATED Unique Finch ID of the company for which data has been updated. |
|
com.tryfinch.api.models.companyId(com.tryfinch.api.core.JsonField)
|
Sets Builder.companyId to an arbitrary JSON value. |
|
com.tryfinch.api.models.accountId()
|
DEPRECATED Unique Finch ID of the employer account used to make this connection. |
|
com.tryfinch.api.models.companyId()
|
DEPRECATED Unique Finch ID of the company for which data has been updated. |
|
com.tryfinch.api.models._accountId()
|
Returns the raw JSON value of accountId. |
|
com.tryfinch.api.models._companyId()
|
Returns the raw JSON value of companyId. |
|
com.tryfinch.api.models.accountId(java.lang.String)
|
DEPRECATED Unique Finch ID of the employer account used to make this connection. |
|
com.tryfinch.api.models.accountId(com.tryfinch.api.core.JsonField)
|
Sets Builder.accountId to an arbitrary JSON value. |
|
com.tryfinch.api.models.companyId(java.lang.String)
|
DEPRECATED Unique Finch ID of the company for which data has been updated. |
|
com.tryfinch.api.models.companyId(com.tryfinch.api.core.JsonField)
|
Sets Builder.companyId to an arbitrary JSON value. |
|
com.tryfinch.api.models.accountId()
|
DEPRECATED Unique Finch ID of the employer account used to make this connection. |
|
com.tryfinch.api.models.companyId()
|
DEPRECATED Unique Finch ID of the company for which data has been updated. |
|
com.tryfinch.api.models._accountId()
|
Returns the raw JSON value of accountId. |
|
com.tryfinch.api.models._companyId()
|
Returns the raw JSON value of companyId. |
|
com.tryfinch.api.models.manual(java.lang.Boolean)
|
DEPRECATED Whether the Finch integration with this provider uses the Assisted Connect Flow by default. |
|
com.tryfinch.api.models.manual(com.tryfinch.api.core.JsonField)
|
Sets Builder.manual to an arbitrary JSON value. |
|
com.tryfinch.api.models.manual()
|
DEPRECATED Whether the Finch integration with this provider uses the Assisted Connect Flow by default. |
|
com.tryfinch.api.models._manual()
|
Returns the raw JSON value of manual. |
|
com.tryfinch.api.models.manual(java.lang.Boolean)
|
DEPRECATED Whether the Finch integration with this provider uses the Assisted Connect Flow by default. |
|
com.tryfinch.api.models.manual(com.tryfinch.api.core.JsonField)
|
Sets Builder.manual to an arbitrary JSON value. |
|
com.tryfinch.api.models.manual()
|
DEPRECATED Whether the Finch integration with this provider uses the Assisted Connect Flow by default. |
|
com.tryfinch.api.models._manual()
|
Returns the raw JSON value of manual. |
|
com.tryfinch.api.services.async.hris.listIndividuals()
|
Returns a raw HTTP response for get /employer/directory, but is otherwise the same as DirectoryServiceAsync.listIndividuals. |
|
com.tryfinch.api.services.async.hris.listIndividuals(com.tryfinch.api.models.HrisDirectoryListIndividualsParams,com.tryfinch.api.core.RequestOptions)
|
|
|
com.tryfinch.api.services.async.hris.listIndividuals(com.tryfinch.api.models.HrisDirectoryListIndividualsParams)
|
|
|
com.tryfinch.api.services.async.hris.listIndividuals(com.tryfinch.api.core.RequestOptions)
|
|
|
com.tryfinch.api.services.async.hris.listIndividuals()
|
Read company directory and organization structure |
|
com.tryfinch.api.services.async.hris.listIndividuals(com.tryfinch.api.models.HrisDirectoryListIndividualsParams,com.tryfinch.api.core.RequestOptions)
|
|
|
com.tryfinch.api.services.async.hris.listIndividuals(com.tryfinch.api.models.HrisDirectoryListIndividualsParams)
|
|
|
com.tryfinch.api.services.async.hris.listIndividuals(com.tryfinch.api.core.RequestOptions)
|
|
|
com.tryfinch.api.services.async.hris.listIndividuals(com.tryfinch.api.models.HrisDirectoryListIndividualsParams,com.tryfinch.api.core.RequestOptions)
|
|
|
com.tryfinch.api.services.async.hris.listIndividuals(com.tryfinch.api.models.HrisDirectoryListIndividualsParams,com.tryfinch.api.core.RequestOptions)
|
|
|
com.tryfinch.api.services.blocking.hris.listIndividuals()
|
Returns a raw HTTP response for get /employer/directory, but is otherwise the same as DirectoryService.listIndividuals. |
|
com.tryfinch.api.services.blocking.hris.listIndividuals(com.tryfinch.api.models.HrisDirectoryListIndividualsParams,com.tryfinch.api.core.RequestOptions)
|
|
|
com.tryfinch.api.services.blocking.hris.listIndividuals(com.tryfinch.api.models.HrisDirectoryListIndividualsParams)
|
|
|
com.tryfinch.api.services.blocking.hris.listIndividuals(com.tryfinch.api.core.RequestOptions)
|
|
|
com.tryfinch.api.services.blocking.hris.listIndividuals()
|
Read company directory and organization structure |
|
com.tryfinch.api.services.blocking.hris.listIndividuals(com.tryfinch.api.models.HrisDirectoryListIndividualsParams,com.tryfinch.api.core.RequestOptions)
|
|
|
com.tryfinch.api.services.blocking.hris.listIndividuals(com.tryfinch.api.models.HrisDirectoryListIndividualsParams)
|
|
|
com.tryfinch.api.services.blocking.hris.listIndividuals(com.tryfinch.api.core.RequestOptions)
|
|
|
com.tryfinch.api.services.blocking.hris.listIndividuals(com.tryfinch.api.models.HrisDirectoryListIndividualsParams,com.tryfinch.api.core.RequestOptions)
|
|
|
com.tryfinch.api.services.blocking.hris.listIndividuals(com.tryfinch.api.models.HrisDirectoryListIndividualsParams,com.tryfinch.api.core.RequestOptions)
|
|