Package com.tryfinch.api.client.okhttp
Class FinchOkHttpClientAsync
-
- All Implemented Interfaces:
public final class FinchOkHttpClientAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinchOkHttpClientAsync.BuilderA builder for FinchOkHttpClientAsync.
-
Method Summary
Modifier and Type Method Description final static FinchOkHttpClientAsync.Builderbuilder()Returns a mutable builder for constructing an instance of FinchOkHttpClientAsync. final static FinchClientAsyncfromEnv()-
-
Method Detail
-
builder
final static FinchOkHttpClientAsync.Builder builder()
Returns a mutable builder for constructing an instance of FinchOkHttpClientAsync.
-
fromEnv
final static FinchClientAsync fromEnv()
-
-
-
-