Class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accounts
-
- All Implemented Interfaces:
public final class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accounts
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accounts.BuilderA builder for Accounts.
-
Method Summary
-
-
Method Detail
-
accountName
final Optional<Boolean> accountName()
-
accountNumber
final Optional<Boolean> accountNumber()
-
accountType
final Optional<Boolean> accountType()
-
institutionName
final Optional<Boolean> institutionName()
-
routingNumber
final Optional<Boolean> routingNumber()
-
_accountName
final JsonField<Boolean> _accountName()
Returns the raw JSON value of accountName.
Unlike accountName, this method doesn't throw if the JSON field has an unexpected type.
-
_accountNumber
final JsonField<Boolean> _accountNumber()
Returns the raw JSON value of accountNumber.
Unlike accountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_accountType
final JsonField<Boolean> _accountType()
Returns the raw JSON value of accountType.
Unlike accountType, this method doesn't throw if the JSON field has an unexpected type.
-
_institutionName
final JsonField<Boolean> _institutionName()
Returns the raw JSON value of institutionName.
Unlike institutionName, this method doesn't throw if the JSON field has an unexpected type.
-
_routingNumber
final JsonField<Boolean> _routingNumber()
Returns the raw JSON value of routingNumber.
Unlike routingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accounts.Builder toBuilder()
-
validate
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accounts validate()
-
builder
final static AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedCompanyFields.Accounts.Builder builder()
Returns a mutable builder for constructing an instance of Accounts.
-
-
-
-