Package com.tryfinch.api.models
Class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Income
-
- All Implemented Interfaces:
public final class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Income
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Income.BuilderA builder for Income.
-
Method Summary
Modifier and Type Method Description final Optional<Boolean>amount()final Optional<Boolean>currency()final Optional<Boolean>unit()final JsonField<Boolean>_amount()Returns the raw JSON value of amount. final JsonField<Boolean>_currency()Returns the raw JSON value of currency. final JsonField<Boolean>_unit()Returns the raw JSON value of unit. final Map<String, JsonValue>_additionalProperties()final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Income.BuildertoBuilder()final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Incomevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Income.Builderbuilder()Returns a mutable builder for constructing an instance of Income. -
-
Method Detail
-
_amount
final JsonField<Boolean> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<Boolean> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_unit
final JsonField<Boolean> _unit()
Returns the raw JSON value of unit.
Unlike unit, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Income.Builder toBuilder()
-
validate
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Income validate()
-
builder
final static AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedEmploymentFields.Income.Builder builder()
Returns a mutable builder for constructing an instance of Income.
-
-
-
-