Class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields
-
- All Implemented Interfaces:
public final class AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.BuilderA builder for SupportedPaymentFields.
public final classAccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.PayPeriod
-
Method Summary
-
-
Method Detail
-
companyDebit
final Optional<Boolean> companyDebit()
-
employeeTaxes
final Optional<Boolean> employeeTaxes()
-
employerTaxes
final Optional<Boolean> employerTaxes()
-
individualIds
final Optional<Boolean> individualIds()
-
payFrequencies
final Optional<Boolean> payFrequencies()
-
payGroupIds
final Optional<Boolean> payGroupIds()
-
payPeriod
final Optional<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.PayPeriod> payPeriod()
-
_id
final JsonField<Boolean> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_companyDebit
final JsonField<Boolean> _companyDebit()
Returns the raw JSON value of companyDebit.
Unlike companyDebit, this method doesn't throw if the JSON field has an unexpected type.
-
_debitDate
final JsonField<Boolean> _debitDate()
Returns the raw JSON value of debitDate.
Unlike debitDate, this method doesn't throw if the JSON field has an unexpected type.
-
_employeeTaxes
final JsonField<Boolean> _employeeTaxes()
Returns the raw JSON value of employeeTaxes.
Unlike employeeTaxes, this method doesn't throw if the JSON field has an unexpected type.
-
_employerTaxes
final JsonField<Boolean> _employerTaxes()
Returns the raw JSON value of employerTaxes.
Unlike employerTaxes, this method doesn't throw if the JSON field has an unexpected type.
-
_grossPay
final JsonField<Boolean> _grossPay()
Returns the raw JSON value of grossPay.
Unlike grossPay, this method doesn't throw if the JSON field has an unexpected type.
-
_individualIds
final JsonField<Boolean> _individualIds()
Returns the raw JSON value of individualIds.
Unlike individualIds, this method doesn't throw if the JSON field has an unexpected type.
-
_netPay
final JsonField<Boolean> _netPay()
Returns the raw JSON value of netPay.
Unlike netPay, this method doesn't throw if the JSON field has an unexpected type.
-
_payDate
final JsonField<Boolean> _payDate()
Returns the raw JSON value of payDate.
Unlike payDate, this method doesn't throw if the JSON field has an unexpected type.
-
_payFrequencies
final JsonField<Boolean> _payFrequencies()
Returns the raw JSON value of payFrequencies.
Unlike payFrequencies, this method doesn't throw if the JSON field has an unexpected type.
-
_payGroupIds
final JsonField<Boolean> _payGroupIds()
Returns the raw JSON value of payGroupIds.
Unlike payGroupIds, this method doesn't throw if the JSON field has an unexpected type.
-
_payPeriod
final JsonField<AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.PayPeriod> _payPeriod()
Returns the raw JSON value of payPeriod.
Unlike payPeriod, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder toBuilder()
-
validate
final AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields validate()
-
builder
final static AccountUpdateEvent.Data.AuthenticationMethod.SupportedFields.SupportedPaymentFields.Builder builder()
Returns a mutable builder for constructing an instance of SupportedPaymentFields.
-
-
-
-