Class AccountUpdateResponse
-
- All Implemented Interfaces:
public final class AccountUpdateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountUpdateResponse.BuilderA builder for AccountUpdateResponse.
public final classAccountUpdateResponse.AuthenticationType
-
Method Summary
Modifier and Type Method Description final StringaccountId()DEPRECATED Use connection_idto associate a connection with an access tokenfinal AccountUpdateResponse.AuthenticationTypeauthenticationType()final StringcompanyId()DEPRECATED Use connection_idto associate a connection with an access tokenfinal StringconnectionId()The ID of the new connection final StringentityId()The ID of the entity whose status was updated final List<String>products()final StringproviderId()The ID of the provider associated with the access_tokenfinal JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<AccountUpdateResponse.AuthenticationType>_authenticationType()Returns the raw JSON value of authenticationType. final JsonField<String>_companyId()Returns the raw JSON value of companyId. final JsonField<String>_connectionId()Returns the raw JSON value of connectionId. final JsonField<String>_entityId()Returns the raw JSON value of entityId. final JsonField<List<String>>_products()Returns the raw JSON value of products. final JsonField<String>_providerId()Returns the raw JSON value of providerId. final Map<String, JsonValue>_additionalProperties()final AccountUpdateResponse.BuildertoBuilder()final AccountUpdateResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountUpdateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of AccountUpdateResponse. -
-
Method Detail
-
accountId
@Deprecated(message = "deprecated") final String accountId()
DEPRECATED Use
connection_idto associate a connection with an access token
-
authenticationType
final AccountUpdateResponse.AuthenticationType authenticationType()
-
companyId
@Deprecated(message = "deprecated") final String companyId()
DEPRECATED Use
connection_idto associate a connection with an access token
-
connectionId
final String connectionId()
The ID of the new connection
-
providerId
final String providerId()
The ID of the provider associated with the
access_token
-
_accountId
@Deprecated(message = "deprecated") final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_authenticationType
final JsonField<AccountUpdateResponse.AuthenticationType> _authenticationType()
Returns the raw JSON value of authenticationType.
Unlike authenticationType, this method doesn't throw if the JSON field has an unexpected type.
-
_companyId
@Deprecated(message = "deprecated") final JsonField<String> _companyId()
Returns the raw JSON value of companyId.
Unlike companyId, this method doesn't throw if the JSON field has an unexpected type.
-
_connectionId
final JsonField<String> _connectionId()
Returns the raw JSON value of connectionId.
Unlike connectionId, this method doesn't throw if the JSON field has an unexpected type.
-
_entityId
final JsonField<String> _entityId()
Returns the raw JSON value of entityId.
Unlike entityId, this method doesn't throw if the JSON field has an unexpected type.
-
_products
final JsonField<List<String>> _products()
Returns the raw JSON value of products.
Unlike products, this method doesn't throw if the JSON field has an unexpected type.
-
_providerId
final JsonField<String> _providerId()
Returns the raw JSON value of providerId.
Unlike providerId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountUpdateResponse.Builder toBuilder()
-
validate
final AccountUpdateResponse validate()
-
builder
final static AccountUpdateResponse.Builder builder()
Returns a mutable builder for constructing an instance of AccountUpdateResponse.
The following fields are required:
.accountId() .authenticationType() .companyId() .connectionId() .entityId() .products() .providerId()
-
-
-
-