Package com.tryfinch.api.models
Class AutomatedListResponse.Meta.Quotas.DataSyncAll
-
- All Implemented Interfaces:
public final class AutomatedListResponse.Meta.Quotas.DataSyncAll
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAutomatedListResponse.Meta.Quotas.DataSyncAll.BuilderA builder for DataSyncAll.
-
Method Summary
Modifier and Type Method Description final Optional<Long>allowedRefreshes()final Optional<Long>remainingRefreshes()final JsonField<Long>_allowedRefreshes()Returns the raw JSON value of allowedRefreshes. final JsonField<Long>_remainingRefreshes()Returns the raw JSON value of remainingRefreshes. final Map<String, JsonValue>_additionalProperties()final AutomatedListResponse.Meta.Quotas.DataSyncAll.BuildertoBuilder()final AutomatedListResponse.Meta.Quotas.DataSyncAllvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AutomatedListResponse.Meta.Quotas.DataSyncAll.Builderbuilder()Returns a mutable builder for constructing an instance of DataSyncAll. -
-
Method Detail
-
allowedRefreshes
final Optional<Long> allowedRefreshes()
-
remainingRefreshes
final Optional<Long> remainingRefreshes()
-
_allowedRefreshes
final JsonField<Long> _allowedRefreshes()
Returns the raw JSON value of allowedRefreshes.
Unlike allowedRefreshes, this method doesn't throw if the JSON field has an unexpected type.
-
_remainingRefreshes
final JsonField<Long> _remainingRefreshes()
Returns the raw JSON value of remainingRefreshes.
Unlike remainingRefreshes, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AutomatedListResponse.Meta.Quotas.DataSyncAll.Builder toBuilder()
-
validate
final AutomatedListResponse.Meta.Quotas.DataSyncAll validate()
-
builder
final static AutomatedListResponse.Meta.Quotas.DataSyncAll.Builder builder()
Returns a mutable builder for constructing an instance of DataSyncAll.
-
-
-
-