Class BaseWebhookEvent
-
- All Implemented Interfaces:
public final class BaseWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBaseWebhookEvent.BuilderA builder for BaseWebhookEvent.
-
Method Summary
Modifier and Type Method Description final StringaccountId()DEPRECATED Unique Finch ID of the employer account used to make this connection. final StringcompanyId()DEPRECATED Unique Finch ID of the company for which data has been updated. final Optional<String>connectionId()Unique Finch ID of the connection associated with the webhook event. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<String>_companyId()Returns the raw JSON value of companyId. final JsonField<String>_connectionId()Returns the raw JSON value of connectionId. final Map<String, JsonValue>_additionalProperties()final BaseWebhookEvent.BuildertoBuilder()final BaseWebhookEventvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BaseWebhookEvent.Builderbuilder()Returns a mutable builder for constructing an instance of BaseWebhookEvent. -
-
Method Detail
-
accountId
@Deprecated(message = "deprecated") final String accountId()
DEPRECATED Unique Finch ID of the employer account used to make this connection. Use
connection_idinstead to identify the connection associated with this event.
-
companyId
@Deprecated(message = "deprecated") final String companyId()
DEPRECATED Unique Finch ID of the company for which data has been updated. Use
connection_idinstead to identify the connection associated with this event.
-
connectionId
final Optional<String> connectionId()
Unique Finch ID of the connection associated with the webhook event.
-
_accountId
@Deprecated(message = "deprecated") final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_companyId
@Deprecated(message = "deprecated") final JsonField<String> _companyId()
Returns the raw JSON value of companyId.
Unlike companyId, this method doesn't throw if the JSON field has an unexpected type.
-
_connectionId
final JsonField<String> _connectionId()
Returns the raw JSON value of connectionId.
Unlike connectionId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BaseWebhookEvent.Builder toBuilder()
-
validate
final BaseWebhookEvent validate()
-
builder
final static BaseWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of BaseWebhookEvent.
The following fields are required:
.accountId() .companyId()
-
-
-
-