Package com.tryfinch.api.models
Class BenefitFeaturesAndOperations
-
- All Implemented Interfaces:
public final class BenefitFeaturesAndOperations
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBenefitFeaturesAndOperations.BuilderA builder for BenefitFeaturesAndOperations.
-
Method Summary
Modifier and Type Method Description final Optional<SupportedBenefit>supportedFeatures()final Optional<SupportPerBenefitType>supportedOperations()final JsonField<SupportedBenefit>_supportedFeatures()Returns the raw JSON value of supportedFeatures. final JsonField<SupportPerBenefitType>_supportedOperations()Returns the raw JSON value of supportedOperations. final Map<String, JsonValue>_additionalProperties()final BenefitFeaturesAndOperations.BuildertoBuilder()final BenefitFeaturesAndOperationsvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BenefitFeaturesAndOperations.Builderbuilder()Returns a mutable builder for constructing an instance of BenefitFeaturesAndOperations. -
-
Method Detail
-
supportedFeatures
final Optional<SupportedBenefit> supportedFeatures()
-
supportedOperations
final Optional<SupportPerBenefitType> supportedOperations()
-
_supportedFeatures
final JsonField<SupportedBenefit> _supportedFeatures()
Returns the raw JSON value of supportedFeatures.
Unlike supportedFeatures, this method doesn't throw if the JSON field has an unexpected type.
-
_supportedOperations
final JsonField<SupportPerBenefitType> _supportedOperations()
Returns the raw JSON value of supportedOperations.
Unlike supportedOperations, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BenefitFeaturesAndOperations.Builder toBuilder()
-
validate
final BenefitFeaturesAndOperations validate()
-
builder
final static BenefitFeaturesAndOperations.Builder builder()
Returns a mutable builder for constructing an instance of BenefitFeaturesAndOperations.
-
-
-
-