Class BenefitsSupport
-
- All Implemented Interfaces:
public final class BenefitsSupportEach benefit type and their supported features. If the benefit type is not supported, the property will be null
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBenefitsSupport.BuilderA builder for BenefitsSupport.
-
Method Summary
-
-
Method Detail
-
commuter
final Optional<BenefitFeaturesAndOperations> commuter()
-
customPostTax
final Optional<BenefitFeaturesAndOperations> customPostTax()
-
customPreTax
final Optional<BenefitFeaturesAndOperations> customPreTax()
-
fsaDependentCare
final Optional<BenefitFeaturesAndOperations> fsaDependentCare()
-
fsaMedical
final Optional<BenefitFeaturesAndOperations> fsaMedical()
-
hsaPost
final Optional<BenefitFeaturesAndOperations> hsaPost()
-
hsaPre
final Optional<BenefitFeaturesAndOperations> hsaPre()
-
s125Dental
final Optional<BenefitFeaturesAndOperations> s125Dental()
-
s125Medical
final Optional<BenefitFeaturesAndOperations> s125Medical()
-
s125Vision
final Optional<BenefitFeaturesAndOperations> s125Vision()
-
simple
final Optional<BenefitFeaturesAndOperations> simple()
-
simpleIra
final Optional<BenefitFeaturesAndOperations> simpleIra()
-
_commuter
final JsonField<BenefitFeaturesAndOperations> _commuter()
Returns the raw JSON value of commuter.
Unlike commuter, this method doesn't throw if the JSON field has an unexpected type.
-
_customPostTax
final JsonField<BenefitFeaturesAndOperations> _customPostTax()
Returns the raw JSON value of customPostTax.
Unlike customPostTax, this method doesn't throw if the JSON field has an unexpected type.
-
_customPreTax
final JsonField<BenefitFeaturesAndOperations> _customPreTax()
Returns the raw JSON value of customPreTax.
Unlike customPreTax, this method doesn't throw if the JSON field has an unexpected type.
-
_fsaDependentCare
final JsonField<BenefitFeaturesAndOperations> _fsaDependentCare()
Returns the raw JSON value of fsaDependentCare.
Unlike fsaDependentCare, this method doesn't throw if the JSON field has an unexpected type.
-
_fsaMedical
final JsonField<BenefitFeaturesAndOperations> _fsaMedical()
Returns the raw JSON value of fsaMedical.
Unlike fsaMedical, this method doesn't throw if the JSON field has an unexpected type.
-
_hsaPost
final JsonField<BenefitFeaturesAndOperations> _hsaPost()
Returns the raw JSON value of hsaPost.
Unlike hsaPost, this method doesn't throw if the JSON field has an unexpected type.
-
_hsaPre
final JsonField<BenefitFeaturesAndOperations> _hsaPre()
Returns the raw JSON value of hsaPre.
Unlike hsaPre, this method doesn't throw if the JSON field has an unexpected type.
-
_s125Dental
final JsonField<BenefitFeaturesAndOperations> _s125Dental()
Returns the raw JSON value of s125Dental.
Unlike s125Dental, this method doesn't throw if the JSON field has an unexpected type.
-
_s125Medical
final JsonField<BenefitFeaturesAndOperations> _s125Medical()
Returns the raw JSON value of s125Medical.
Unlike s125Medical, this method doesn't throw if the JSON field has an unexpected type.
-
_s125Vision
final JsonField<BenefitFeaturesAndOperations> _s125Vision()
Returns the raw JSON value of s125Vision.
Unlike s125Vision, this method doesn't throw if the JSON field has an unexpected type.
-
_simple
final JsonField<BenefitFeaturesAndOperations> _simple()
Returns the raw JSON value of simple.
Unlike simple, this method doesn't throw if the JSON field has an unexpected type.
-
_simpleIra
final JsonField<BenefitFeaturesAndOperations> _simpleIra()
Returns the raw JSON value of simpleIra.
Unlike simpleIra, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BenefitsSupport.Builder toBuilder()
-
validate
final BenefitsSupport validate()
-
builder
final static BenefitsSupport.Builder builder()
Returns a mutable builder for constructing an instance of BenefitsSupport.
-
-
-
-