Class ConnectSessionNewParams
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Params
public final class ConnectSessionNewParams implements Params
Create a new connect session for an employer
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classConnectSessionNewParams.BuilderA builder for ConnectSessionNewParams.
public final classConnectSessionNewParams.Bodypublic final classConnectSessionNewParams.ConnectProductsThe Finch products that can be requested during the Connect flow.
public final classConnectSessionNewParams.Integrationpublic final classConnectSessionNewParams.Sandbox
-
Method Summary
Modifier and Type Method Description final StringcustomerId()final StringcustomerName()final List<ConnectSessionNewParams.ConnectProducts>products()final Optional<String>customerEmail()final Optional<ConnectSessionNewParams.Integration>integration()final Optional<Boolean>manual()final Optional<Double>minutesToExpire()The number of minutes until the session expires (defaults to 129,600, which is 90 days) final Optional<String>redirectUri()final Optional<ConnectSessionNewParams.Sandbox>sandbox()final JsonField<String>_customerId()Returns the raw JSON value of customerId. final JsonField<String>_customerName()Returns the raw JSON value of customerName. final JsonField<List<ConnectSessionNewParams.ConnectProducts>>_products()Returns the raw JSON value of products. final JsonField<String>_customerEmail()Returns the raw JSON value of customerEmail. final JsonField<ConnectSessionNewParams.Integration>_integration()Returns the raw JSON value of integration. final JsonField<Boolean>_manual()Returns the raw JSON value of manual. final JsonField<Double>_minutesToExpire()Returns the raw JSON value of minutesToExpire. final JsonField<String>_redirectUri()Returns the raw JSON value of redirectUri. final JsonField<ConnectSessionNewParams.Sandbox>_sandbox()Returns the raw JSON value of sandbox. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ConnectSessionNewParams.BuildertoBuilder()final ConnectSessionNewParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ConnectSessionNewParams.Builderbuilder()Returns a mutable builder for constructing an instance of ConnectSessionNewParams. -
-
Method Detail
-
customerId
final String customerId()
-
customerName
final String customerName()
-
products
final List<ConnectSessionNewParams.ConnectProducts> products()
-
customerEmail
final Optional<String> customerEmail()
-
integration
final Optional<ConnectSessionNewParams.Integration> integration()
-
minutesToExpire
final Optional<Double> minutesToExpire()
The number of minutes until the session expires (defaults to 129,600, which is 90 days)
-
redirectUri
final Optional<String> redirectUri()
-
sandbox
final Optional<ConnectSessionNewParams.Sandbox> sandbox()
-
_customerId
final JsonField<String> _customerId()
Returns the raw JSON value of customerId.
Unlike customerId, this method doesn't throw if the JSON field has an unexpected type.
-
_customerName
final JsonField<String> _customerName()
Returns the raw JSON value of customerName.
Unlike customerName, this method doesn't throw if the JSON field has an unexpected type.
-
_products
final JsonField<List<ConnectSessionNewParams.ConnectProducts>> _products()
Returns the raw JSON value of products.
Unlike products, this method doesn't throw if the JSON field has an unexpected type.
-
_customerEmail
final JsonField<String> _customerEmail()
Returns the raw JSON value of customerEmail.
Unlike customerEmail, this method doesn't throw if the JSON field has an unexpected type.
-
_integration
final JsonField<ConnectSessionNewParams.Integration> _integration()
Returns the raw JSON value of integration.
Unlike integration, this method doesn't throw if the JSON field has an unexpected type.
-
_manual
final JsonField<Boolean> _manual()
Returns the raw JSON value of manual.
Unlike manual, this method doesn't throw if the JSON field has an unexpected type.
-
_minutesToExpire
final JsonField<Double> _minutesToExpire()
Returns the raw JSON value of minutesToExpire.
Unlike minutesToExpire, this method doesn't throw if the JSON field has an unexpected type.
-
_redirectUri
final JsonField<String> _redirectUri()
Returns the raw JSON value of redirectUri.
Unlike redirectUri, this method doesn't throw if the JSON field has an unexpected type.
-
_sandbox
final JsonField<ConnectSessionNewParams.Sandbox> _sandbox()
Returns the raw JSON value of sandbox.
Unlike sandbox, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ConnectSessionNewParams.Builder toBuilder()
-
_body
final ConnectSessionNewParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static ConnectSessionNewParams.Builder builder()
Returns a mutable builder for constructing an instance of ConnectSessionNewParams.
The following fields are required:
.customerId() .customerName() .products()
-
-
-
-