Class ConnectSessionNewParams.CreateConnectSessionRequest
-
- All Implemented Interfaces:
public final class ConnectSessionNewParams.CreateConnectSessionRequest
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classConnectSessionNewParams.CreateConnectSessionRequest.BuilderA builder for CreateConnectSessionRequest.
-
Method Summary
Modifier and Type Method Description final StringcustomerId()Unique identifier for the customer final StringcustomerName()Name of the customer final List<ConnectSessionNewParams.ConnectProducts>products()The Finch products to request access to final Optional<String>customerEmail()Email address of the customer final Optional<ConnectSessionNewParams.Integration>integration()Integration configuration for the connect session final Optional<Boolean>manual()Enable manual authentication mode final Optional<Double>minutesToExpire()The number of minutes until the session expires (defaults to 129,600, which is 90 days) final Optional<String>redirectUri()The URI to redirect to after the Connect flow is completed final Optional<ConnectSessionNewParams.Sandbox>sandbox()Sandbox mode for testing final JsonField<String>_customerId()Returns the raw JSON value of customerId. final JsonField<String>_customerName()Returns the raw JSON value of customerName. final JsonField<List<ConnectSessionNewParams.ConnectProducts>>_products()Returns the raw JSON value of products. final JsonField<String>_customerEmail()Returns the raw JSON value of customerEmail. final JsonField<ConnectSessionNewParams.Integration>_integration()Returns the raw JSON value of integration. final JsonField<Boolean>_manual()Returns the raw JSON value of manual. final JsonField<Double>_minutesToExpire()Returns the raw JSON value of minutesToExpire. final JsonField<String>_redirectUri()Returns the raw JSON value of redirectUri. final JsonField<ConnectSessionNewParams.Sandbox>_sandbox()Returns the raw JSON value of sandbox. final Map<String, JsonValue>_additionalProperties()final ConnectSessionNewParams.CreateConnectSessionRequest.BuildertoBuilder()final ConnectSessionNewParams.CreateConnectSessionRequestvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ConnectSessionNewParams.CreateConnectSessionRequest.Builderbuilder()Returns a mutable builder for constructing an instance of CreateConnectSessionRequest. -
-
Method Detail
-
customerId
final String customerId()
Unique identifier for the customer
-
customerName
final String customerName()
Name of the customer
-
products
final List<ConnectSessionNewParams.ConnectProducts> products()
The Finch products to request access to
-
customerEmail
final Optional<String> customerEmail()
Email address of the customer
-
integration
final Optional<ConnectSessionNewParams.Integration> integration()
Integration configuration for the connect session
-
minutesToExpire
final Optional<Double> minutesToExpire()
The number of minutes until the session expires (defaults to 129,600, which is 90 days)
-
redirectUri
final Optional<String> redirectUri()
The URI to redirect to after the Connect flow is completed
-
sandbox
final Optional<ConnectSessionNewParams.Sandbox> sandbox()
Sandbox mode for testing
-
_customerId
final JsonField<String> _customerId()
Returns the raw JSON value of customerId.
Unlike customerId, this method doesn't throw if the JSON field has an unexpected type.
-
_customerName
final JsonField<String> _customerName()
Returns the raw JSON value of customerName.
Unlike customerName, this method doesn't throw if the JSON field has an unexpected type.
-
_products
final JsonField<List<ConnectSessionNewParams.ConnectProducts>> _products()
Returns the raw JSON value of products.
Unlike products, this method doesn't throw if the JSON field has an unexpected type.
-
_customerEmail
final JsonField<String> _customerEmail()
Returns the raw JSON value of customerEmail.
Unlike customerEmail, this method doesn't throw if the JSON field has an unexpected type.
-
_integration
final JsonField<ConnectSessionNewParams.Integration> _integration()
Returns the raw JSON value of integration.
Unlike integration, this method doesn't throw if the JSON field has an unexpected type.
-
_manual
final JsonField<Boolean> _manual()
Returns the raw JSON value of manual.
Unlike manual, this method doesn't throw if the JSON field has an unexpected type.
-
_minutesToExpire
final JsonField<Double> _minutesToExpire()
Returns the raw JSON value of minutesToExpire.
Unlike minutesToExpire, this method doesn't throw if the JSON field has an unexpected type.
-
_redirectUri
final JsonField<String> _redirectUri()
Returns the raw JSON value of redirectUri.
Unlike redirectUri, this method doesn't throw if the JSON field has an unexpected type.
-
_sandbox
final JsonField<ConnectSessionNewParams.Sandbox> _sandbox()
Returns the raw JSON value of sandbox.
Unlike sandbox, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ConnectSessionNewParams.CreateConnectSessionRequest.Builder toBuilder()
-
validate
final ConnectSessionNewParams.CreateConnectSessionRequest validate()
-
builder
final static ConnectSessionNewParams.CreateConnectSessionRequest.Builder builder()
Returns a mutable builder for constructing an instance of CreateConnectSessionRequest.
The following fields are required:
.customerId() .customerName() .products()
-
-
-
-