Package com.tryfinch.api.models
Class ConnectSessionNewParams.Integration
-
- All Implemented Interfaces:
public final class ConnectSessionNewParams.IntegrationIntegration configuration for the connect session
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classConnectSessionNewParams.Integration.BuilderA builder for Integration.
public final classConnectSessionNewParams.Integration.AuthMethodThe authentication method to use
-
Method Summary
Modifier and Type Method Description final Stringprovider()The provider to integrate with final Optional<ConnectSessionNewParams.Integration.AuthMethod>authMethod()The authentication method to use final JsonField<String>_provider()Returns the raw JSON value of provider. final JsonField<ConnectSessionNewParams.Integration.AuthMethod>_authMethod()Returns the raw JSON value of authMethod. final Map<String, JsonValue>_additionalProperties()final ConnectSessionNewParams.Integration.BuildertoBuilder()final ConnectSessionNewParams.Integrationvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ConnectSessionNewParams.Integration.Builderbuilder()Returns a mutable builder for constructing an instance of Integration. -
-
Method Detail
-
authMethod
final Optional<ConnectSessionNewParams.Integration.AuthMethod> authMethod()
The authentication method to use
-
_provider
final JsonField<String> _provider()
Returns the raw JSON value of provider.
Unlike provider, this method doesn't throw if the JSON field has an unexpected type.
-
_authMethod
final JsonField<ConnectSessionNewParams.Integration.AuthMethod> _authMethod()
Returns the raw JSON value of authMethod.
Unlike authMethod, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ConnectSessionNewParams.Integration.Builder toBuilder()
-
validate
final ConnectSessionNewParams.Integration validate()
-
builder
final static ConnectSessionNewParams.Integration.Builder builder()
Returns a mutable builder for constructing an instance of Integration.
The following fields are required:
.provider()
-
-
-
-