Package com.tryfinch.api.models
Class ConnectSessionNewParams.Integration
-
- All Implemented Interfaces:
public final class ConnectSessionNewParams.Integration
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classConnectSessionNewParams.Integration.BuilderA builder for Integration.
public final classConnectSessionNewParams.Integration.AuthMethod
-
Method Summary
Modifier and Type Method Description final Optional<ConnectSessionNewParams.Integration.AuthMethod>authMethod()final Optional<String>provider()final JsonField<ConnectSessionNewParams.Integration.AuthMethod>_authMethod()Returns the raw JSON value of authMethod. final JsonField<String>_provider()Returns the raw JSON value of provider. final Map<String, JsonValue>_additionalProperties()final ConnectSessionNewParams.Integration.BuildertoBuilder()final ConnectSessionNewParams.Integrationvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ConnectSessionNewParams.Integration.Builderbuilder()Returns a mutable builder for constructing an instance of Integration. -
-
Method Detail
-
authMethod
final Optional<ConnectSessionNewParams.Integration.AuthMethod> authMethod()
-
_authMethod
final JsonField<ConnectSessionNewParams.Integration.AuthMethod> _authMethod()
Returns the raw JSON value of authMethod.
Unlike authMethod, this method doesn't throw if the JSON field has an unexpected type.
-
_provider
final JsonField<String> _provider()
Returns the raw JSON value of provider.
Unlike provider, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ConnectSessionNewParams.Integration.Builder toBuilder()
-
validate
final ConnectSessionNewParams.Integration validate()
-
builder
final static ConnectSessionNewParams.Integration.Builder builder()
Returns a mutable builder for constructing an instance of Integration.
-
-
-
-