Class CreateAccessTokenResponse
-
- All Implemented Interfaces:
public final class CreateAccessTokenResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCreateAccessTokenResponse.BuilderA builder for CreateAccessTokenResponse.
public final classCreateAccessTokenResponse.ClientTypeThe type of application associated with a token.
public final classCreateAccessTokenResponse.ConnectionTypeThe type of the connection associated with the token.
provider- connection to an external providerfinch- finch-generated data.
-
Method Summary
Modifier and Type Method Description final StringaccessToken()The access token for the connection final CreateAccessTokenResponse.ClientTypeclientType()The type of application associated with a token. final StringconnectionId()The Finch UUID of the connection associated with the access_tokenfinal CreateAccessTokenResponse.ConnectionTypeconnectionType()The type of the connection associated with the token. final List<String>entityIds()An array of entity IDs that can be accessed with this access token final List<String>products()An array of the authorized products associated with the access_tokenfinal StringproviderId()The ID of the provider associated with the access_tokenfinal StringtokenType()The RFC 8693 token type (Finch uses bearertokens)final Optional<String>accountId()DEPRECATED Use connection_idto identify the connection instead of this account IDfinal Optional<String>companyId()DEPRECATED Use connection_idto identify the connection instead of this company IDfinal Optional<String>customerId()The ID of your customer you provided to Finch when a connect session was created for this connection final JsonField<String>_accessToken()Returns the raw JSON value of accessToken. final JsonField<CreateAccessTokenResponse.ClientType>_clientType()Returns the raw JSON value of clientType. final JsonField<String>_connectionId()Returns the raw JSON value of connectionId. final JsonField<CreateAccessTokenResponse.ConnectionType>_connectionType()Returns the raw JSON value of connectionType. final JsonField<List<String>>_entityIds()Returns the raw JSON value of entityIds. final JsonField<List<String>>_products()Returns the raw JSON value of products. final JsonField<String>_providerId()Returns the raw JSON value of providerId. final JsonField<String>_tokenType()Returns the raw JSON value of tokenType. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<String>_companyId()Returns the raw JSON value of companyId. final JsonField<String>_customerId()Returns the raw JSON value of customerId. final Map<String, JsonValue>_additionalProperties()final CreateAccessTokenResponse.BuildertoBuilder()final CreateAccessTokenResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CreateAccessTokenResponse.Builderbuilder()Returns a mutable builder for constructing an instance of CreateAccessTokenResponse. -
-
Method Detail
-
accessToken
final String accessToken()
The access token for the connection
-
clientType
final CreateAccessTokenResponse.ClientType clientType()
The type of application associated with a token.
-
connectionId
final String connectionId()
The Finch UUID of the connection associated with the
access_token
-
connectionType
final CreateAccessTokenResponse.ConnectionType connectionType()
The type of the connection associated with the token.
provider- connection to an external providerfinch- finch-generated data.
-
entityIds
final List<String> entityIds()
An array of entity IDs that can be accessed with this access token
-
products
final List<String> products()
An array of the authorized products associated with the
access_token
-
providerId
final String providerId()
The ID of the provider associated with the
access_token
-
accountId
@Deprecated(message = "deprecated") final Optional<String> accountId()
DEPRECATED Use
connection_idto identify the connection instead of this account ID
-
companyId
@Deprecated(message = "deprecated") final Optional<String> companyId()
DEPRECATED Use
connection_idto identify the connection instead of this company ID
-
customerId
final Optional<String> customerId()
The ID of your customer you provided to Finch when a connect session was created for this connection
-
_accessToken
final JsonField<String> _accessToken()
Returns the raw JSON value of accessToken.
Unlike accessToken, this method doesn't throw if the JSON field has an unexpected type.
-
_clientType
final JsonField<CreateAccessTokenResponse.ClientType> _clientType()
Returns the raw JSON value of clientType.
Unlike clientType, this method doesn't throw if the JSON field has an unexpected type.
-
_connectionId
final JsonField<String> _connectionId()
Returns the raw JSON value of connectionId.
Unlike connectionId, this method doesn't throw if the JSON field has an unexpected type.
-
_connectionType
final JsonField<CreateAccessTokenResponse.ConnectionType> _connectionType()
Returns the raw JSON value of connectionType.
Unlike connectionType, this method doesn't throw if the JSON field has an unexpected type.
-
_entityIds
final JsonField<List<String>> _entityIds()
Returns the raw JSON value of entityIds.
Unlike entityIds, this method doesn't throw if the JSON field has an unexpected type.
-
_products
final JsonField<List<String>> _products()
Returns the raw JSON value of products.
Unlike products, this method doesn't throw if the JSON field has an unexpected type.
-
_providerId
final JsonField<String> _providerId()
Returns the raw JSON value of providerId.
Unlike providerId, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenType
final JsonField<String> _tokenType()
Returns the raw JSON value of tokenType.
Unlike tokenType, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
@Deprecated(message = "deprecated") final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_companyId
@Deprecated(message = "deprecated") final JsonField<String> _companyId()
Returns the raw JSON value of companyId.
Unlike companyId, this method doesn't throw if the JSON field has an unexpected type.
-
_customerId
final JsonField<String> _customerId()
Returns the raw JSON value of customerId.
Unlike customerId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CreateAccessTokenResponse.Builder toBuilder()
-
validate
final CreateAccessTokenResponse validate()
-
builder
final static CreateAccessTokenResponse.Builder builder()
Returns a mutable builder for constructing an instance of CreateAccessTokenResponse.
The following fields are required:
.accessToken() .clientType() .connectionId() .connectionType() .entityIds() .products() .providerId() .tokenType()
-
-
-
-