Class DocumentResponse
-
- All Implemented Interfaces:
public final class DocumentResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDocumentResponse.BuilderA builder for DocumentResponse.
public final classDocumentResponse.TypeThe type of document.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()A stable Finch id for the document. final Optional<String>individualId()The ID of the individual associated with the document. final Optional<DocumentResponse.Type>type()The type of document. final Optional<String>url()A URL to access the document. final Optional<Double>year()The year the document applies to, if available. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_individualId()Returns the raw JSON value of individualId. final JsonField<DocumentResponse.Type>_type()Returns the raw JSON value of type. final JsonField<String>_url()Returns the raw JSON value of url. final JsonField<Double>_year()Returns the raw JSON value of year. final Map<String, JsonValue>_additionalProperties()final DocumentResponse.BuildertoBuilder()final DocumentResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DocumentResponse.Builderbuilder()Returns a mutable builder for constructing an instance of DocumentResponse. -
-
Method Detail
-
individualId
final Optional<String> individualId()
The ID of the individual associated with the document. This will be null for employer-level documents.
-
type
final Optional<DocumentResponse.Type> type()
The type of document.
-
url
final Optional<String> url()
A URL to access the document. Format:
https://api.tryfinch.com/employer/documents/:document_id.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_individualId
final JsonField<String> _individualId()
Returns the raw JSON value of individualId.
Unlike individualId, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<DocumentResponse.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_year
final JsonField<Double> _year()
Returns the raw JSON value of year.
Unlike year, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DocumentResponse.Builder toBuilder()
-
validate
final DocumentResponse validate()
-
builder
final static DocumentResponse.Builder builder()
Returns a mutable builder for constructing an instance of DocumentResponse.
-
-
-
-