Package com.tryfinch.api.models
Class EmploymentData.BatchError
-
- All Implemented Interfaces:
public final class EmploymentData.BatchError
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEmploymentData.BatchError.BuilderA builder for BatchError.
-
Method Summary
Modifier and Type Method Description final Doublecode()final Stringmessage()final Stringname()final Optional<String>finchCode()final JsonField<Double>_code()Returns the raw JSON value of code. final JsonField<String>_message()Returns the raw JSON value of message. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_finchCode()Returns the raw JSON value of finchCode. final Map<String, JsonValue>_additionalProperties()final EmploymentData.BatchError.BuildertoBuilder()final EmploymentData.BatchErrorvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EmploymentData.BatchError.Builderbuilder()Returns a mutable builder for constructing an instance of BatchError. -
-
Method Detail
-
_code
final JsonField<Double> _code()
Returns the raw JSON value of code.
Unlike code, this method doesn't throw if the JSON field has an unexpected type.
-
_message
final JsonField<String> _message()
Returns the raw JSON value of message.
Unlike message, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_finchCode
final JsonField<String> _finchCode()
Returns the raw JSON value of finchCode.
Unlike finchCode, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EmploymentData.BatchError.Builder toBuilder()
-
validate
final EmploymentData.BatchError validate()
-
builder
final static EmploymentData.BatchError.Builder builder()
Returns a mutable builder for constructing an instance of BatchError.
The following fields are required:
.code() .message() .name()
-
-
-
-