Package com.tryfinch.api.models
Class EmploymentUpdateResponse.Employment
-
- All Implemented Interfaces:
public final class EmploymentUpdateResponse.EmploymentThe employment object.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEmploymentUpdateResponse.Employment.BuilderA builder for Employment.
public final classEmploymentUpdateResponse.Employment.SubtypeThe secondary employment type of the individual. Options:
full_time,part_time,intern,temp,seasonalandindividual_contractor.public final classEmploymentUpdateResponse.Employment.TypeThe main employment type of the individual.
-
Method Summary
Modifier and Type Method Description final Optional<EmploymentUpdateResponse.Employment.Subtype>subtype()The secondary employment type of the individual. final Optional<EmploymentUpdateResponse.Employment.Type>type()The main employment type of the individual. final JsonField<EmploymentUpdateResponse.Employment.Subtype>_subtype()Returns the raw JSON value of subtype. final JsonField<EmploymentUpdateResponse.Employment.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final EmploymentUpdateResponse.Employment.BuildertoBuilder()final EmploymentUpdateResponse.Employmentvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EmploymentUpdateResponse.Employment.Builderbuilder()Returns a mutable builder for constructing an instance of Employment. -
-
Method Detail
-
subtype
final Optional<EmploymentUpdateResponse.Employment.Subtype> subtype()
The secondary employment type of the individual. Options:
full_time,part_time,intern,temp,seasonalandindividual_contractor.
-
type
final Optional<EmploymentUpdateResponse.Employment.Type> type()
The main employment type of the individual.
-
_subtype
final JsonField<EmploymentUpdateResponse.Employment.Subtype> _subtype()
Returns the raw JSON value of subtype.
Unlike subtype, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<EmploymentUpdateResponse.Employment.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EmploymentUpdateResponse.Employment.Builder toBuilder()
-
validate
final EmploymentUpdateResponse.Employment validate()
-
builder
final static EmploymentUpdateResponse.Employment.Builder builder()
Returns a mutable builder for constructing an instance of Employment.
-
-
-
-