Package com.tryfinch.api.models
Class HrisBenefitCreateParams.Body
-
- All Implemented Interfaces:
public final class HrisBenefitCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisBenefitCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>description()Name of the benefit as it appears in the provider and pay statements. final Optional<BenefitFrequency>frequency()The frequency of the benefit deduction/contribution. final Optional<BenefitType>type()Type of benefit. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<BenefitFrequency>_frequency()Returns the raw JSON value of frequency. final JsonField<BenefitType>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final HrisBenefitCreateParams.Body.BuildertoBuilder()final HrisBenefitCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static HrisBenefitCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
description
final Optional<String> description()
Name of the benefit as it appears in the provider and pay statements. Recommend limiting this to <30 characters due to limitations in specific providers (e.g. Justworks).
-
frequency
final Optional<BenefitFrequency> frequency()
The frequency of the benefit deduction/contribution.
-
type
final Optional<BenefitType> type()
Type of benefit.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_frequency
final JsonField<BenefitFrequency> _frequency()
Returns the raw JSON value of frequency.
Unlike frequency, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<BenefitType> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final HrisBenefitCreateParams.Body.Builder toBuilder()
-
validate
final HrisBenefitCreateParams.Body validate()
-
builder
final static HrisBenefitCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-