Class HrisCompanyPayStatementItemRuleCreateParams
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Params
public final class HrisCompanyPayStatementItemRuleCreateParams implements Params
Beta: this endpoint currently serves employers onboarded after March 4th and historical support will be added soon Custom rules can be created to associate specific attributes to pay statement items depending on the use case. For example, pay statement items that meet certain conditions can be labeled as a pre-tax 401k. This metadata can be retrieved where pay statement item information is available.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisCompanyPayStatementItemRuleCreateParams.BuilderA builder for HrisCompanyPayStatementItemRuleCreateParams.
public final classHrisCompanyPayStatementItemRuleCreateParams.CreateRuleRequestpublic final classHrisCompanyPayStatementItemRuleCreateParams.AttributesSpecifies the fields to be applied when the condition is met.
public final classHrisCompanyPayStatementItemRuleCreateParams.Conditionpublic final classHrisCompanyPayStatementItemRuleCreateParams.EntityTypeThe entity type to which the rule is applied.
-
Method Summary
-
-
Method Detail
-
attributes
final Optional<HrisCompanyPayStatementItemRuleCreateParams.Attributes> attributes()
Specifies the fields to be applied when the condition is met.
-
conditions
final Optional<List<HrisCompanyPayStatementItemRuleCreateParams.Condition>> conditions()
-
effectiveEndDate
final Optional<String> effectiveEndDate()
Specifies when the rules should stop applying rules based on the date.
-
effectiveStartDate
final Optional<String> effectiveStartDate()
Specifies when the rule should begin applying based on the date.
-
entityType
final Optional<HrisCompanyPayStatementItemRuleCreateParams.EntityType> entityType()
The entity type to which the rule is applied.
-
_attributes
final JsonField<HrisCompanyPayStatementItemRuleCreateParams.Attributes> _attributes()
Returns the raw JSON value of attributes.
Unlike attributes, this method doesn't throw if the JSON field has an unexpected type.
-
_conditions
final JsonField<List<HrisCompanyPayStatementItemRuleCreateParams.Condition>> _conditions()
Returns the raw JSON value of conditions.
Unlike conditions, this method doesn't throw if the JSON field has an unexpected type.
-
_effectiveEndDate
final JsonField<String> _effectiveEndDate()
Returns the raw JSON value of effectiveEndDate.
Unlike effectiveEndDate, this method doesn't throw if the JSON field has an unexpected type.
-
_effectiveStartDate
final JsonField<String> _effectiveStartDate()
Returns the raw JSON value of effectiveStartDate.
Unlike effectiveStartDate, this method doesn't throw if the JSON field has an unexpected type.
-
_entityType
final JsonField<HrisCompanyPayStatementItemRuleCreateParams.EntityType> _entityType()
Returns the raw JSON value of entityType.
Unlike entityType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
toBuilder
final HrisCompanyPayStatementItemRuleCreateParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static HrisCompanyPayStatementItemRuleCreateParams none()
-
builder
final static HrisCompanyPayStatementItemRuleCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of HrisCompanyPayStatementItemRuleCreateParams.
-
-
-
-