Package com.tryfinch.api.models
Class HrisDirectoryListIndividualsPageAsync
-
- All Implemented Interfaces:
@Deprecated(message = "use `list` instead") public final class HrisDirectoryListIndividualsPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisDirectoryListIndividualsPageAsync.BuilderA builder for HrisDirectoryListIndividualsPageAsync.
public final classHrisDirectoryListIndividualsPageAsync.AutoPager
-
Method Summary
-
-
Method Detail
-
individuals
final List<IndividualInDirectory> individuals()
Delegates to HrisDirectoryListIndividualsPageResponse, but gracefully handles missing data.
-
paging
final Optional<Paging> paging()
Delegates to HrisDirectoryListIndividualsPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<HrisDirectoryListIndividualsParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<HrisDirectoryListIndividualsPageAsync>> getNextPage()
-
autoPager
final HrisDirectoryListIndividualsPageAsync.AutoPager autoPager()
-
params
final HrisDirectoryListIndividualsParams params()
The parameters that were used to request this page.
-
response
final HrisDirectoryListIndividualsPageResponse response()
The response that this page was parsed from.
-
toBuilder
final HrisDirectoryListIndividualsPageAsync.Builder toBuilder()
-
builder
final static HrisDirectoryListIndividualsPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of HrisDirectoryListIndividualsPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-