Package com.tryfinch.api.models
Class HrisDirectoryListPageAsync
-
- All Implemented Interfaces:
public final class HrisDirectoryListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisDirectoryListPageAsync.BuilderA builder for HrisDirectoryListPageAsync.
public final classHrisDirectoryListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<IndividualInDirectory>individuals()Delegates to HrisDirectoryListPageResponse, but gracefully handles missing data. final Optional<Paging>paging()Delegates to HrisDirectoryListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<HrisDirectoryListParams>getNextPageParams()final CompletableFuture<Optional<HrisDirectoryListPageAsync>>getNextPage()final HrisDirectoryListPageAsync.AutoPagerautoPager()final HrisDirectoryListParamsparams()The parameters that were used to request this page. final HrisDirectoryListPageResponseresponse()The response that this page was parsed from. final HrisDirectoryListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static HrisDirectoryListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of HrisDirectoryListPageAsync. -
-
Method Detail
-
individuals
final List<IndividualInDirectory> individuals()
Delegates to HrisDirectoryListPageResponse, but gracefully handles missing data.
-
paging
final Optional<Paging> paging()
Delegates to HrisDirectoryListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<HrisDirectoryListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<HrisDirectoryListPageAsync>> getNextPage()
-
autoPager
final HrisDirectoryListPageAsync.AutoPager autoPager()
-
params
final HrisDirectoryListParams params()
The parameters that were used to request this page.
-
response
final HrisDirectoryListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final HrisDirectoryListPageAsync.Builder toBuilder()
-
builder
final static HrisDirectoryListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of HrisDirectoryListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-