Package com.tryfinch.api.models
Class HrisEmploymentRetrieveManyPage
-
- All Implemented Interfaces:
public final class HrisEmploymentRetrieveManyPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisEmploymentRetrieveManyPage.BuilderA builder for HrisEmploymentRetrieveManyPage.
public final classHrisEmploymentRetrieveManyPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<EmploymentDataResponse>responses()Delegates to HrisEmploymentRetrieveManyPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<HrisEmploymentRetrieveManyParams>getNextPageParams()final Optional<HrisEmploymentRetrieveManyPage>getNextPage()final HrisEmploymentRetrieveManyPage.AutoPagerautoPager()final HrisEmploymentRetrieveManyParamsparams()The parameters that were used to request this page. final HrisEmploymentRetrieveManyPageResponseresponse()The response that this page was parsed from. final HrisEmploymentRetrieveManyPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static HrisEmploymentRetrieveManyPage.Builderbuilder()Returns a mutable builder for constructing an instance of HrisEmploymentRetrieveManyPage. -
-
Method Detail
-
responses
final List<EmploymentDataResponse> responses()
Delegates to HrisEmploymentRetrieveManyPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<HrisEmploymentRetrieveManyParams> getNextPageParams()
-
getNextPage
final Optional<HrisEmploymentRetrieveManyPage> getNextPage()
-
autoPager
final HrisEmploymentRetrieveManyPage.AutoPager autoPager()
-
params
final HrisEmploymentRetrieveManyParams params()
The parameters that were used to request this page.
-
response
final HrisEmploymentRetrieveManyPageResponse response()
The response that this page was parsed from.
-
toBuilder
final HrisEmploymentRetrieveManyPage.Builder toBuilder()
-
builder
final static HrisEmploymentRetrieveManyPage.Builder builder()
Returns a mutable builder for constructing an instance of HrisEmploymentRetrieveManyPage.
The following fields are required:
.service() .params() .response()
-
-
-
-