Class HrisPayStatementItemRuleCreateParams

  • All Implemented Interfaces:
    com.tryfinch.api.core.Params

    
    public final class HrisPayStatementItemRuleCreateParams
     implements Params
                        

    Custom rules can be created to associate specific attributes to pay statement items depending on the use case. For example, pay statement items that meet certain conditions can be labeled as a pre-tax 401k. This metadata can be retrieved where pay statement item information is available.