Package com.tryfinch.api.models
Class HrisPayStatementRetrieveManyPageAsync
-
- All Implemented Interfaces:
public final class HrisPayStatementRetrieveManyPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisPayStatementRetrieveManyPageAsync.BuilderA builder for HrisPayStatementRetrieveManyPageAsync.
public final classHrisPayStatementRetrieveManyPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<PayStatementResponse>responses()Delegates to HrisPayStatementRetrieveManyPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<HrisPayStatementRetrieveManyParams>getNextPageParams()final CompletableFuture<Optional<HrisPayStatementRetrieveManyPageAsync>>getNextPage()final HrisPayStatementRetrieveManyPageAsync.AutoPagerautoPager()final HrisPayStatementRetrieveManyParamsparams()The parameters that were used to request this page. final HrisPayStatementRetrieveManyPageResponseresponse()The response that this page was parsed from. final HrisPayStatementRetrieveManyPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static HrisPayStatementRetrieveManyPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of HrisPayStatementRetrieveManyPageAsync. -
-
Method Detail
-
responses
final List<PayStatementResponse> responses()
Delegates to HrisPayStatementRetrieveManyPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<HrisPayStatementRetrieveManyParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<HrisPayStatementRetrieveManyPageAsync>> getNextPage()
-
autoPager
final HrisPayStatementRetrieveManyPageAsync.AutoPager autoPager()
-
params
final HrisPayStatementRetrieveManyParams params()
The parameters that were used to request this page.
-
response
final HrisPayStatementRetrieveManyPageResponse response()
The response that this page was parsed from.
-
toBuilder
final HrisPayStatementRetrieveManyPageAsync.Builder toBuilder()
-
builder
final static HrisPayStatementRetrieveManyPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of HrisPayStatementRetrieveManyPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-