Package com.tryfinch.api.models
Class HrisPayStatementRetrieveManyParams.Request
-
- All Implemented Interfaces:
public final class HrisPayStatementRetrieveManyParams.Request
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHrisPayStatementRetrieveManyParams.Request.BuilderA builder for Request.
-
Method Summary
Modifier and Type Method Description final StringpaymentId()A stable Finch id(UUID v4) for a payment.final Optional<Long>limit()Number of pay statements to return (defaults to all). final Optional<Long>offset()Index to start from. final JsonField<String>_paymentId()Returns the raw JSON value of paymentId. final JsonField<Long>_limit()Returns the raw JSON value of limit. final JsonField<Long>_offset()Returns the raw JSON value of offset. final Map<String, JsonValue>_additionalProperties()final HrisPayStatementRetrieveManyParams.Request.BuildertoBuilder()final HrisPayStatementRetrieveManyParams.Requestvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static HrisPayStatementRetrieveManyParams.Request.Builderbuilder()Returns a mutable builder for constructing an instance of Request. -
-
Method Detail
-
_paymentId
final JsonField<String> _paymentId()
Returns the raw JSON value of paymentId.
Unlike paymentId, this method doesn't throw if the JSON field has an unexpected type.
-
_limit
final JsonField<Long> _limit()
Returns the raw JSON value of limit.
Unlike limit, this method doesn't throw if the JSON field has an unexpected type.
-
_offset
final JsonField<Long> _offset()
Returns the raw JSON value of offset.
Unlike offset, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final HrisPayStatementRetrieveManyParams.Request.Builder toBuilder()
-
validate
final HrisPayStatementRetrieveManyParams.Request validate()
-
builder
final static HrisPayStatementRetrieveManyParams.Request.Builder builder()
Returns a mutable builder for constructing an instance of Request.
The following fields are required:
.paymentId()
-
-
-
-