Class Income
-
- All Implemented Interfaces:
public final class IncomeThe employee's income as reported by the provider. This may not always be annualized income, but may be in units of bi-weekly, semi-monthly, daily, etc, depending on what information the provider returns.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIncome.BuilderA builder for Income.
public final classIncome.UnitThe income unit of payment. Options:
yearly,quarterly,monthly,semi_monthly,bi_weekly,weekly,daily,hourly, andfixed.
-
Method Summary
Modifier and Type Method Description final Optional<Long>amount()The income amount in cents. final Optional<String>currency()The currency code. final Optional<LocalDate>effectiveDate()The date the income amount went into effect. final Optional<Income.Unit>unit()The income unit of payment. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_currency()Returns the raw JSON value of currency. final JsonField<LocalDate>_effectiveDate()Returns the raw JSON value of effectiveDate. final JsonField<Income.Unit>_unit()Returns the raw JSON value of unit. final Map<String, JsonValue>_additionalProperties()final Income.BuildertoBuilder()final Incomevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Income.Builderbuilder()Returns a mutable builder for constructing an instance of Income. -
-
Method Detail
-
effectiveDate
final Optional<LocalDate> effectiveDate()
The date the income amount went into effect.
-
unit
final Optional<Income.Unit> unit()
The income unit of payment. Options:
yearly,quarterly,monthly,semi_monthly,bi_weekly,weekly,daily,hourly, andfixed.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_effectiveDate
final JsonField<LocalDate> _effectiveDate()
Returns the raw JSON value of effectiveDate.
Unlike effectiveDate, this method doesn't throw if the JSON field has an unexpected type.
-
_unit
final JsonField<Income.Unit> _unit()
Returns the raw JSON value of unit.
Unlike unit, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Income.Builder toBuilder()
-
builder
final static Income.Builder builder()
Returns a mutable builder for constructing an instance of Income.
The following fields are required:
.amount() .currency() .effectiveDate() .unit()
-
-
-
-