Package com.tryfinch.api.models
Class IndividualBenefit
-
- All Implemented Interfaces:
public final class IndividualBenefit
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIndividualBenefit.BuilderA builder for IndividualBenefit.
public final classIndividualBenefit.Body
-
Method Summary
Modifier and Type Method Description final IndividualBenefit.Bodybody()final Longcode()final StringindividualId()final JsonField<IndividualBenefit.Body>_body()Returns the raw JSON value of body. final JsonField<Long>_code()Returns the raw JSON value of code. final JsonField<String>_individualId()Returns the raw JSON value of individualId. final Map<String, JsonValue>_additionalProperties()final IndividualBenefit.BuildertoBuilder()final IndividualBenefitvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static IndividualBenefit.Builderbuilder()Returns a mutable builder for constructing an instance of IndividualBenefit. -
-
Method Detail
-
body
final IndividualBenefit.Body body()
-
individualId
final String individualId()
-
_body
final JsonField<IndividualBenefit.Body> _body()
Returns the raw JSON value of body.
Unlike body, this method doesn't throw if the JSON field has an unexpected type.
-
_code
final JsonField<Long> _code()
Returns the raw JSON value of code.
Unlike code, this method doesn't throw if the JSON field has an unexpected type.
-
_individualId
final JsonField<String> _individualId()
Returns the raw JSON value of individualId.
Unlike individualId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final IndividualBenefit.Builder toBuilder()
-
validate
final IndividualBenefit validate()
-
builder
final static IndividualBenefit.Builder builder()
Returns a mutable builder for constructing an instance of IndividualBenefit.
The following fields are required:
.body() .code() .individualId()
-
-
-
-