Package com.tryfinch.api.models
Class IndividualEnrolledIdsResponse
-
- All Implemented Interfaces:
public final class IndividualEnrolledIdsResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIndividualEnrolledIdsResponse.BuilderA builder for IndividualEnrolledIdsResponse.
-
Method Summary
Modifier and Type Method Description final StringbenefitId()The id of the benefit. final List<String>individualIds()final JsonField<String>_benefitId()Returns the raw JSON value of benefitId. final JsonField<List<String>>_individualIds()Returns the raw JSON value of individualIds. final Map<String, JsonValue>_additionalProperties()final IndividualEnrolledIdsResponse.BuildertoBuilder()final IndividualEnrolledIdsResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static IndividualEnrolledIdsResponse.Builderbuilder()Returns a mutable builder for constructing an instance of IndividualEnrolledIdsResponse. -
-
Method Detail
-
individualIds
final List<String> individualIds()
-
_benefitId
final JsonField<String> _benefitId()
Returns the raw JSON value of benefitId.
Unlike benefitId, this method doesn't throw if the JSON field has an unexpected type.
-
_individualIds
final JsonField<List<String>> _individualIds()
Returns the raw JSON value of individualIds.
Unlike individualIds, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final IndividualEnrolledIdsResponse.Builder toBuilder()
-
validate
final IndividualEnrolledIdsResponse validate()
-
builder
final static IndividualEnrolledIdsResponse.Builder builder()
Returns a mutable builder for constructing an instance of IndividualEnrolledIdsResponse.
The following fields are required:
.benefitId() .individualIds()
-
-
-
-