Package com.tryfinch.api.models
Class IndividualResponse
-
- All Implemented Interfaces:
public final class IndividualResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIndividualResponse.BuilderA builder for IndividualResponse.
-
Method Summary
Modifier and Type Method Description final Individualbody()final Longcode()final StringindividualId()final JsonField<Individual>_body()Returns the raw JSON value of body. final JsonField<Long>_code()Returns the raw JSON value of code. final JsonField<String>_individualId()Returns the raw JSON value of individualId. final Map<String, JsonValue>_additionalProperties()final IndividualResponse.BuildertoBuilder()final IndividualResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static IndividualResponse.Builderbuilder()Returns a mutable builder for constructing an instance of IndividualResponse. -
-
Method Detail
-
body
final Individual body()
-
individualId
final String individualId()
-
_body
final JsonField<Individual> _body()
Returns the raw JSON value of body.
Unlike body, this method doesn't throw if the JSON field has an unexpected type.
-
_code
final JsonField<Long> _code()
Returns the raw JSON value of code.
Unlike code, this method doesn't throw if the JSON field has an unexpected type.
-
_individualId
final JsonField<String> _individualId()
Returns the raw JSON value of individualId.
Unlike individualId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final IndividualResponse.Builder toBuilder()
-
validate
final IndividualResponse validate()
-
builder
final static IndividualResponse.Builder builder()
Returns a mutable builder for constructing an instance of IndividualResponse.
The following fields are required:
.body() .code() .individualId()
-
-
-
-