Class IndividualUpdateResponse
-
- All Implemented Interfaces:
public final class IndividualUpdateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIndividualUpdateResponse.BuilderA builder for IndividualUpdateResponse.
public final classIndividualUpdateResponse.Emailpublic final classIndividualUpdateResponse.EthnicityThe EEOC-defined ethnicity of the individual.
public final classIndividualUpdateResponse.GenderThe gender of the individual.
public final classIndividualUpdateResponse.PhoneNumber
-
Method Summary
Modifier and Type Method Description final Optional<String>id()A stable Finch id(UUID v4) for an individual in the company.final Optional<String>dob()final Optional<List<IndividualUpdateResponse.Email>>emails()final Optional<String>encryptedSsn()Social Security Number of the individual in encrypted format. final Optional<IndividualUpdateResponse.Ethnicity>ethnicity()The EEOC-defined ethnicity of the individual. final Optional<String>firstName()The legal first name of the individual. final Optional<IndividualUpdateResponse.Gender>gender()The gender of the individual. final Optional<String>lastName()The legal last name of the individual. final Optional<String>middleName()The legal middle name of the individual. final Optional<List<IndividualUpdateResponse.PhoneNumber>>phoneNumbers()final Optional<String>preferredName()The preferred name of the individual. final Optional<Location>residence()final Optional<String>ssn()Social Security Number of the individual. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_dob()Returns the raw JSON value of dob. final JsonField<List<IndividualUpdateResponse.Email>>_emails()Returns the raw JSON value of emails. final JsonField<String>_encryptedSsn()Returns the raw JSON value of encryptedSsn. final JsonField<IndividualUpdateResponse.Ethnicity>_ethnicity()Returns the raw JSON value of ethnicity. final JsonField<String>_firstName()Returns the raw JSON value of firstName. final JsonField<IndividualUpdateResponse.Gender>_gender()Returns the raw JSON value of gender. final JsonField<String>_lastName()Returns the raw JSON value of lastName. final JsonField<String>_middleName()Returns the raw JSON value of middleName. final JsonField<List<IndividualUpdateResponse.PhoneNumber>>_phoneNumbers()Returns the raw JSON value of phoneNumbers. final JsonField<String>_preferredName()Returns the raw JSON value of preferredName. final JsonField<Location>_residence()Returns the raw JSON value of residence. final JsonField<String>_ssn()Returns the raw JSON value of ssn. final Map<String, JsonValue>_additionalProperties()final IndividualUpdateResponse.BuildertoBuilder()final IndividualUpdateResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static IndividualUpdateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of IndividualUpdateResponse. -
-
Method Detail
-
emails
final Optional<List<IndividualUpdateResponse.Email>> emails()
-
encryptedSsn
final Optional<String> encryptedSsn()
Social Security Number of the individual in encrypted format. This field is only available with the
ssnscope enabled and theoptions: { include: ['ssn'] }param set in the body.
-
ethnicity
final Optional<IndividualUpdateResponse.Ethnicity> ethnicity()
The EEOC-defined ethnicity of the individual.
-
gender
final Optional<IndividualUpdateResponse.Gender> gender()
The gender of the individual.
-
middleName
final Optional<String> middleName()
The legal middle name of the individual.
-
phoneNumbers
final Optional<List<IndividualUpdateResponse.PhoneNumber>> phoneNumbers()
-
preferredName
final Optional<String> preferredName()
The preferred name of the individual.
-
ssn
final Optional<String> ssn()
Social Security Number of the individual. This field is only available with the
ssnscope enabled and theoptions: { include: ['ssn'] }param set in the body. /developer-resources/Enable-SSN-Field.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_dob
final JsonField<String> _dob()
Returns the raw JSON value of dob.
Unlike dob, this method doesn't throw if the JSON field has an unexpected type.
-
_emails
final JsonField<List<IndividualUpdateResponse.Email>> _emails()
Returns the raw JSON value of emails.
Unlike emails, this method doesn't throw if the JSON field has an unexpected type.
-
_encryptedSsn
final JsonField<String> _encryptedSsn()
Returns the raw JSON value of encryptedSsn.
Unlike encryptedSsn, this method doesn't throw if the JSON field has an unexpected type.
-
_ethnicity
final JsonField<IndividualUpdateResponse.Ethnicity> _ethnicity()
Returns the raw JSON value of ethnicity.
Unlike ethnicity, this method doesn't throw if the JSON field has an unexpected type.
-
_firstName
final JsonField<String> _firstName()
Returns the raw JSON value of firstName.
Unlike firstName, this method doesn't throw if the JSON field has an unexpected type.
-
_gender
final JsonField<IndividualUpdateResponse.Gender> _gender()
Returns the raw JSON value of gender.
Unlike gender, this method doesn't throw if the JSON field has an unexpected type.
-
_lastName
final JsonField<String> _lastName()
Returns the raw JSON value of lastName.
Unlike lastName, this method doesn't throw if the JSON field has an unexpected type.
-
_middleName
final JsonField<String> _middleName()
Returns the raw JSON value of middleName.
Unlike middleName, this method doesn't throw if the JSON field has an unexpected type.
-
_phoneNumbers
final JsonField<List<IndividualUpdateResponse.PhoneNumber>> _phoneNumbers()
Returns the raw JSON value of phoneNumbers.
Unlike phoneNumbers, this method doesn't throw if the JSON field has an unexpected type.
-
_preferredName
final JsonField<String> _preferredName()
Returns the raw JSON value of preferredName.
Unlike preferredName, this method doesn't throw if the JSON field has an unexpected type.
-
_residence
final JsonField<Location> _residence()
Returns the raw JSON value of residence.
Unlike residence, this method doesn't throw if the JSON field has an unexpected type.
-
_ssn
final JsonField<String> _ssn()
Returns the raw JSON value of ssn.
Unlike ssn, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final IndividualUpdateResponse.Builder toBuilder()
-
validate
final IndividualUpdateResponse validate()
-
builder
final static IndividualUpdateResponse.Builder builder()
Returns a mutable builder for constructing an instance of IndividualUpdateResponse.
-
-
-
-