Class Introspection
-
- All Implemented Interfaces:
public final class Introspection
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIntrospection.BuilderA builder for Introspection.
public final classIntrospection.AuthenticationMethodpublic final classIntrospection.ClientTypeThe type of application associated with a token.
public final classIntrospection.ConnectionStatuspublic final classIntrospection.ConnectionTypeThe type of the connection associated with the token.
provider- connection to an external providerfinch- finch-generated data.
-
Method Summary
Modifier and Type Method Description final Stringid()The Finch UUID of the token being introspected. final StringaccountId()DEPRECATED Use connection_idto associate tokens with a Finch connection instead of this account ID.final List<Introspection.AuthenticationMethod>authenticationMethods()final StringclientId()The client ID of the application associated with the access_token.final Introspection.ClientTypeclientType()The type of application associated with a token. final StringcompanyId()DEPRECATED Use connection_idto associate tokens with a Finch connection instead of this company ID.final StringconnectionId()The Finch UUID of the connection associated with the access_token.final Introspection.ConnectionStatusconnectionStatus()final Introspection.ConnectionTypeconnectionType()The type of the connection associated with the token. final Optional<String>customerEmail()The email of your customer you provided to Finch when a connect session was created for this connection. final Optional<String>customerId()The ID of your customer you provided to Finch when a connect session was created for this connection. final Optional<String>customerName()The name of your customer you provided to Finch when a connect session was created for this connection. final Booleanmanual()Whether the connection associated with the access_tokenuses the Assisted Connect Flow.final StringpayrollProviderId()DEPRECATED Use provider_idto identify the provider instead of this payroll provider ID.final List<String>products()An array of the authorized products associated with the access_token.final StringproviderId()The ID of the provider associated with the access_token.final Stringusername()The account username used for login associated with the access_token.final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<List<Introspection.AuthenticationMethod>>_authenticationMethods()Returns the raw JSON value of authenticationMethods. final JsonField<String>_clientId()Returns the raw JSON value of clientId. final JsonField<Introspection.ClientType>_clientType()Returns the raw JSON value of clientType. final JsonField<String>_companyId()Returns the raw JSON value of companyId. final JsonField<String>_connectionId()Returns the raw JSON value of connectionId. final JsonField<Introspection.ConnectionStatus>_connectionStatus()Returns the raw JSON value of connectionStatus. final JsonField<Introspection.ConnectionType>_connectionType()Returns the raw JSON value of connectionType. final JsonField<String>_customerEmail()Returns the raw JSON value of customerEmail. final JsonField<String>_customerId()Returns the raw JSON value of customerId. final JsonField<String>_customerName()Returns the raw JSON value of customerName. final JsonField<Boolean>_manual()Returns the raw JSON value of manual. final JsonField<String>_payrollProviderId()Returns the raw JSON value of payrollProviderId. final JsonField<List<String>>_products()Returns the raw JSON value of products. final JsonField<String>_providerId()Returns the raw JSON value of providerId. final JsonField<String>_username()Returns the raw JSON value of username. final Map<String, JsonValue>_additionalProperties()final Introspection.BuildertoBuilder()final Introspectionvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Introspection.Builderbuilder()Returns a mutable builder for constructing an instance of Introspection. -
-
Method Detail
-
accountId
@Deprecated(message = "deprecated") final String accountId()
DEPRECATED Use
connection_idto associate tokens with a Finch connection instead of this account ID.
-
authenticationMethods
final List<Introspection.AuthenticationMethod> authenticationMethods()
-
clientType
final Introspection.ClientType clientType()
The type of application associated with a token.
-
companyId
@Deprecated(message = "deprecated") final String companyId()
DEPRECATED Use
connection_idto associate tokens with a Finch connection instead of this company ID.
-
connectionId
final String connectionId()
The Finch UUID of the connection associated with the
access_token.
-
connectionStatus
final Introspection.ConnectionStatus connectionStatus()
-
connectionType
final Introspection.ConnectionType connectionType()
The type of the connection associated with the token.
provider- connection to an external providerfinch- finch-generated data.
-
customerEmail
final Optional<String> customerEmail()
The email of your customer you provided to Finch when a connect session was created for this connection.
-
customerId
final Optional<String> customerId()
The ID of your customer you provided to Finch when a connect session was created for this connection.
-
customerName
final Optional<String> customerName()
The name of your customer you provided to Finch when a connect session was created for this connection.
-
manual
final Boolean manual()
Whether the connection associated with the
access_tokenuses the Assisted Connect Flow. (trueif using Assisted Connect,falseif connection is automated)
-
payrollProviderId
@Deprecated(message = "deprecated") final String payrollProviderId()
DEPRECATED Use
provider_idto identify the provider instead of this payroll provider ID.
-
products
final List<String> products()
An array of the authorized products associated with the
access_token.
-
providerId
final String providerId()
The ID of the provider associated with the
access_token.
-
username
final String username()
The account username used for login associated with the
access_token.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
@Deprecated(message = "deprecated") final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_authenticationMethods
final JsonField<List<Introspection.AuthenticationMethod>> _authenticationMethods()
Returns the raw JSON value of authenticationMethods.
Unlike authenticationMethods, this method doesn't throw if the JSON field has an unexpected type.
-
_clientId
final JsonField<String> _clientId()
Returns the raw JSON value of clientId.
Unlike clientId, this method doesn't throw if the JSON field has an unexpected type.
-
_clientType
final JsonField<Introspection.ClientType> _clientType()
Returns the raw JSON value of clientType.
Unlike clientType, this method doesn't throw if the JSON field has an unexpected type.
-
_companyId
@Deprecated(message = "deprecated") final JsonField<String> _companyId()
Returns the raw JSON value of companyId.
Unlike companyId, this method doesn't throw if the JSON field has an unexpected type.
-
_connectionId
final JsonField<String> _connectionId()
Returns the raw JSON value of connectionId.
Unlike connectionId, this method doesn't throw if the JSON field has an unexpected type.
-
_connectionStatus
final JsonField<Introspection.ConnectionStatus> _connectionStatus()
Returns the raw JSON value of connectionStatus.
Unlike connectionStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_connectionType
final JsonField<Introspection.ConnectionType> _connectionType()
Returns the raw JSON value of connectionType.
Unlike connectionType, this method doesn't throw if the JSON field has an unexpected type.
-
_customerEmail
final JsonField<String> _customerEmail()
Returns the raw JSON value of customerEmail.
Unlike customerEmail, this method doesn't throw if the JSON field has an unexpected type.
-
_customerId
final JsonField<String> _customerId()
Returns the raw JSON value of customerId.
Unlike customerId, this method doesn't throw if the JSON field has an unexpected type.
-
_customerName
final JsonField<String> _customerName()
Returns the raw JSON value of customerName.
Unlike customerName, this method doesn't throw if the JSON field has an unexpected type.
-
_manual
final JsonField<Boolean> _manual()
Returns the raw JSON value of manual.
Unlike manual, this method doesn't throw if the JSON field has an unexpected type.
-
_payrollProviderId
@Deprecated(message = "deprecated") final JsonField<String> _payrollProviderId()
Returns the raw JSON value of payrollProviderId.
Unlike payrollProviderId, this method doesn't throw if the JSON field has an unexpected type.
-
_products
final JsonField<List<String>> _products()
Returns the raw JSON value of products.
Unlike products, this method doesn't throw if the JSON field has an unexpected type.
-
_providerId
final JsonField<String> _providerId()
Returns the raw JSON value of providerId.
Unlike providerId, this method doesn't throw if the JSON field has an unexpected type.
-
_username
final JsonField<String> _username()
Returns the raw JSON value of username.
Unlike username, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Introspection.Builder toBuilder()
-
validate
final Introspection validate()
-
builder
final static Introspection.Builder builder()
Returns a mutable builder for constructing an instance of Introspection.
The following fields are required:
.id() .accountId() .authenticationMethods() .clientId() .clientType() .companyId() .connectionId() .connectionStatus() .connectionType() .customerEmail() .customerId() .customerName() .manual() .payrollProviderId() .products() .providerId() .username()
-
-
-
-