Package com.tryfinch.api.models
Class Introspection.AuthenticationMethodDetail
-
- All Implemented Interfaces:
public final class Introspection.AuthenticationMethodDetail
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIntrospection.AuthenticationMethodDetail.BuilderA builder for AuthenticationMethodDetail.
public final classIntrospection.AuthenticationMethodDetail.TypeThe type of authentication method
public final classIntrospection.AuthenticationMethodDetail.ConnectionStatusDetail
-
Method Summary
-
-
Method Detail
-
type
final Introspection.AuthenticationMethodDetail.Type type()
The type of authentication method
-
connectionStatus
final Optional<Introspection.AuthenticationMethodDetail.ConnectionStatusDetail> connectionStatus()
-
products
final Optional<List<String>> products()
An array of the authorized products associated with the
access_token
-
_type
final JsonField<Introspection.AuthenticationMethodDetail.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_connectionStatus
final JsonField<Introspection.AuthenticationMethodDetail.ConnectionStatusDetail> _connectionStatus()
Returns the raw JSON value of connectionStatus.
Unlike connectionStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_products
final JsonField<List<String>> _products()
Returns the raw JSON value of products.
Unlike products, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Introspection.AuthenticationMethodDetail.Builder toBuilder()
-
validate
final Introspection.AuthenticationMethodDetail validate()
-
builder
final static Introspection.AuthenticationMethodDetail.Builder builder()
Returns a mutable builder for constructing an instance of AuthenticationMethodDetail.
The following fields are required:
.type()
-
-
-
-