Package com.tryfinch.api.models
Class Introspection.MultiAccountEntity
-
- All Implemented Interfaces:
public final class Introspection.MultiAccountEntity
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIntrospection.MultiAccountEntity.BuilderA builder for MultiAccountEntity.
-
Method Summary
Modifier and Type Method Description final Stringid()The connection account ID for this entity final Optional<String>name()The name of the entity (payroll provider company name) final Optional<String>sourceId()The source ID of the entity final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_sourceId()Returns the raw JSON value of sourceId. final Map<String, JsonValue>_additionalProperties()final Introspection.MultiAccountEntity.BuildertoBuilder()final Introspection.MultiAccountEntityvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Introspection.MultiAccountEntity.Builderbuilder()Returns a mutable builder for constructing an instance of MultiAccountEntity. -
-
Method Detail
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceId
final JsonField<String> _sourceId()
Returns the raw JSON value of sourceId.
Unlike sourceId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Introspection.MultiAccountEntity.Builder toBuilder()
-
validate
final Introspection.MultiAccountEntity validate()
-
builder
final static Introspection.MultiAccountEntity.Builder builder()
Returns a mutable builder for constructing an instance of MultiAccountEntity.
The following fields are required:
.id() .name() .sourceId()
-
-
-
-