Class JobAutomatedCreateParams
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Params
public final class JobAutomatedCreateParams implements Params
Enqueue an automated job.
data_sync_all: Enqueue a job to re-sync all data for a connection.data_sync_allhas a concurrency limit of 1 job at a time per connection. This means that if this endpoint is called while a job is already in progress for this connection, Finch will return thejob_idof the job that is currently in progress. Finch allows a fixed window rate limit of 1 forced refresh per hour per connection.w4_form_employee_sync: Enqueues a job for sync W-4 data for a particular individual, identified byindividual_id. This feature is currently in beta.This endpoint is available for Scale tier customers as an add-on. To request access to this endpoint, please contact your Finch account manager.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classJobAutomatedCreateParams.BuilderA builder for JobAutomatedCreateParams.
public final classJobAutomatedCreateParams.Body
-
Method Summary
Modifier and Type Method Description final JobAutomatedCreateParams.Bodybody()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final JobAutomatedCreateParams.BuildertoBuilder()final JobAutomatedCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static JobAutomatedCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of JobAutomatedCreateParams. -
-
Method Detail
-
body
final JobAutomatedCreateParams.Body body()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final JobAutomatedCreateParams.Builder toBuilder()
-
_body
final JobAutomatedCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static JobAutomatedCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of JobAutomatedCreateParams.
The following fields are required:
.body()
-
-
-
-