Package com.tryfinch.api.models
Class JobAutomatedCreateParams.Body.W4FormEmployeeSync
-
- All Implemented Interfaces:
public final class JobAutomatedCreateParams.Body.W4FormEmployeeSync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classJobAutomatedCreateParams.Body.W4FormEmployeeSync.BuilderA builder for W4FormEmployeeSync.
public final classJobAutomatedCreateParams.Body.W4FormEmployeeSync.Paramspublic final classJobAutomatedCreateParams.Body.W4FormEmployeeSync.TypeThe type of job to start.
-
Method Summary
Modifier and Type Method Description final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Paramsparams()final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Typetype()The type of job to start. final JsonField<JobAutomatedCreateParams.Body.W4FormEmployeeSync.Params>_params()Returns the raw JSON value of params. final JsonField<JobAutomatedCreateParams.Body.W4FormEmployeeSync.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final JobAutomatedCreateParams.Body.W4FormEmployeeSync.BuildertoBuilder()final JobAutomatedCreateParams.Body.W4FormEmployeeSyncvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static JobAutomatedCreateParams.Body.W4FormEmployeeSync.Builderbuilder()Returns a mutable builder for constructing an instance of W4FormEmployeeSync. -
-
Method Detail
-
params
final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Params params()
-
type
final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Type type()
The type of job to start.
-
_params
final JsonField<JobAutomatedCreateParams.Body.W4FormEmployeeSync.Params> _params()
Returns the raw JSON value of params.
Unlike params, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<JobAutomatedCreateParams.Body.W4FormEmployeeSync.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Builder toBuilder()
-
validate
final JobAutomatedCreateParams.Body.W4FormEmployeeSync validate()
-
builder
final static JobAutomatedCreateParams.Body.W4FormEmployeeSync.Builder builder()
Returns a mutable builder for constructing an instance of W4FormEmployeeSync.
The following fields are required:
.params() .type()
-
-
-
-