Package com.tryfinch.api.models
Class JobAutomatedCreateParams.Body.W4FormEmployeeSync.Builder
-
- All Implemented Interfaces:
public final class JobAutomatedCreateParams.Body.W4FormEmployeeSync.BuilderA builder for W4FormEmployeeSync.
-
-
Method Summary
-
-
Method Detail
-
params
final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Builder params(JobAutomatedCreateParams.Body.W4FormEmployeeSync.Params params)
-
params
final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Builder params(JsonField<JobAutomatedCreateParams.Body.W4FormEmployeeSync.Params> params)
Sets Builder.params to an arbitrary JSON value.
You should usually call Builder.params with a well-typed Params value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Builder type(JobAutomatedCreateParams.Body.W4FormEmployeeSync.Type type)
The type of job to start.
-
type
final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Builder type(JsonField<JobAutomatedCreateParams.Body.W4FormEmployeeSync.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final JobAutomatedCreateParams.Body.W4FormEmployeeSync.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final JobAutomatedCreateParams.Body.W4FormEmployeeSync build()
Returns an immutable instance of W4FormEmployeeSync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.params() .type()
-
-
-
-