Package com.tryfinch.api.models
Class JobAutomatedListParams
-
- All Implemented Interfaces:
-
com.tryfinch.api.core.Params
public final class JobAutomatedListParams implements Params
Get all automated jobs. Automated jobs are completed by a machine. By default, jobs are sorted in descending order by submission time. For scheduled jobs such as data syncs, only the next scheduled job is shown.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classJobAutomatedListParams.BuilderA builder for JobAutomatedListParams.
-
Method Summary
Modifier and Type Method Description final Optional<Long>limit()Number of items to return final Optional<Long>offset()Index to start from (defaults to 0) final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final JobAutomatedListParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static JobAutomatedListParamsnone()final static JobAutomatedListParams.Builderbuilder()Returns a mutable builder for constructing an instance of JobAutomatedListParams. -
-
Method Detail
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final JobAutomatedListParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static JobAutomatedListParams none()
-
builder
final static JobAutomatedListParams.Builder builder()
Returns a mutable builder for constructing an instance of JobAutomatedListParams.
-
-
-
-