Class Location
-
- All Implemented Interfaces:
public final class Location
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLocation.BuilderA builder for Location.
-
Method Summary
Modifier and Type Method Description final Optional<String>city()City, district, suburb, town, or village. final Optional<String>country()The 2-letter ISO 3166 country code. final Optional<String>line1()Street address or PO box. final Optional<String>line2()Apartment, suite, unit, or building. final Optional<String>postalCode()The postal code or zip code. final Optional<String>state()The state code. final Optional<String>name()final Optional<String>sourceId()final JsonField<String>_city()Returns the raw JSON value of city. final JsonField<String>_country()Returns the raw JSON value of country. final JsonField<String>_line1()Returns the raw JSON value of line1. final JsonField<String>_line2()Returns the raw JSON value of line2. final JsonField<String>_postalCode()Returns the raw JSON value of postalCode. final JsonField<String>_state()Returns the raw JSON value of state. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_sourceId()Returns the raw JSON value of sourceId. final Map<String, JsonValue>_additionalProperties()final Location.BuildertoBuilder()final Locationvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Location.Builderbuilder()Returns a mutable builder for constructing an instance of Location. -
-
Method Detail
-
postalCode
final Optional<String> postalCode()
The postal code or zip code.
-
_city
final JsonField<String> _city()
Returns the raw JSON value of city.
Unlike city, this method doesn't throw if the JSON field has an unexpected type.
-
_country
final JsonField<String> _country()
Returns the raw JSON value of country.
Unlike country, this method doesn't throw if the JSON field has an unexpected type.
-
_line1
final JsonField<String> _line1()
Returns the raw JSON value of line1.
Unlike line1, this method doesn't throw if the JSON field has an unexpected type.
-
_line2
final JsonField<String> _line2()
Returns the raw JSON value of line2.
Unlike line2, this method doesn't throw if the JSON field has an unexpected type.
-
_postalCode
final JsonField<String> _postalCode()
Returns the raw JSON value of postalCode.
Unlike postalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<String> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceId
final JsonField<String> _sourceId()
Returns the raw JSON value of sourceId.
Unlike sourceId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Location.Builder toBuilder()
-
builder
final static Location.Builder builder()
Returns a mutable builder for constructing an instance of Location.
The following fields are required:
.city() .country() .line1() .line2() .postalCode() .state()
-
-
-
-