Package com.tryfinch.api.models
Class ManualAsyncJob
-
- All Implemented Interfaces:
public final class ManualAsyncJob
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classManualAsyncJob.BuilderA builder for ManualAsyncJob.
public final classManualAsyncJob.Status
-
Method Summary
Modifier and Type Method Description final Optional<List<JsonValue>>body()Specific information about the job, such as individual statuses for batch jobs. final StringjobId()final ManualAsyncJob.Statusstatus()final JsonField<List<JsonValue>>_body()Returns the raw JSON value of body. final JsonField<String>_jobId()Returns the raw JSON value of jobId. final JsonField<ManualAsyncJob.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final ManualAsyncJob.BuildertoBuilder()final ManualAsyncJobvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ManualAsyncJob.Builderbuilder()Returns a mutable builder for constructing an instance of ManualAsyncJob. -
-
Method Detail
-
body
final Optional<List<JsonValue>> body()
Specific information about the job, such as individual statuses for batch jobs.
-
status
final ManualAsyncJob.Status status()
-
_body
final JsonField<List<JsonValue>> _body()
Returns the raw JSON value of body.
Unlike body, this method doesn't throw if the JSON field has an unexpected type.
-
_jobId
final JsonField<String> _jobId()
Returns the raw JSON value of jobId.
Unlike jobId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<ManualAsyncJob.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ManualAsyncJob.Builder toBuilder()
-
validate
final ManualAsyncJob validate()
-
builder
final static ManualAsyncJob.Builder builder()
Returns a mutable builder for constructing an instance of ManualAsyncJob.
The following fields are required:
.body() .jobId() .status()
-
-
-
-