Class OperationSupportMatrix
-
- All Implemented Interfaces:
public final class OperationSupportMatrix
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOperationSupportMatrix.BuilderA builder for OperationSupportMatrix.
-
Method Summary
Modifier and Type Method Description final Optional<OperationSupport>create()supported: This operation is supported by both the provider and Finchnot_supported_by_finch: This operation is not supported by Finch but supported by the providernot_supported_by_provider: This operation is not supported by the provider, so Finch cannot supportclient_access_only: This behavior is supported by the provider, but only available to the client and not to Finch
final Optional<OperationSupport>delete()supported: This operation is supported by both the provider and Finchnot_supported_by_finch: This operation is not supported by Finch but supported by the providernot_supported_by_provider: This operation is not supported by the provider, so Finch cannot supportclient_access_only: This behavior is supported by the provider, but only available to the client and not to Finch
final Optional<OperationSupport>read()supported: This operation is supported by both the provider and Finchnot_supported_by_finch: This operation is not supported by Finch but supported by the providernot_supported_by_provider: This operation is not supported by the provider, so Finch cannot supportclient_access_only: This behavior is supported by the provider, but only available to the client and not to Finch
final Optional<OperationSupport>update()supported: This operation is supported by both the provider and Finchnot_supported_by_finch: This operation is not supported by Finch but supported by the providernot_supported_by_provider: This operation is not supported by the provider, so Finch cannot supportclient_access_only: This behavior is supported by the provider, but only available to the client and not to Finch
final JsonField<OperationSupport>_create()Returns the raw JSON value of create. final JsonField<OperationSupport>_delete()Returns the raw JSON value of delete. final JsonField<OperationSupport>_read()Returns the raw JSON value of read. final JsonField<OperationSupport>_update()Returns the raw JSON value of update. final Map<String, JsonValue>_additionalProperties()final OperationSupportMatrix.BuildertoBuilder()final OperationSupportMatrixvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static OperationSupportMatrix.Builderbuilder()Returns a mutable builder for constructing an instance of OperationSupportMatrix. -
-
Method Detail
-
create
final Optional<OperationSupport> create()
supported: This operation is supported by both the provider and Finchnot_supported_by_finch: This operation is not supported by Finch but supported by the providernot_supported_by_provider: This operation is not supported by the provider, so Finch cannot supportclient_access_only: This behavior is supported by the provider, but only available to the client and not to Finch
-
delete
final Optional<OperationSupport> delete()
supported: This operation is supported by both the provider and Finchnot_supported_by_finch: This operation is not supported by Finch but supported by the providernot_supported_by_provider: This operation is not supported by the provider, so Finch cannot supportclient_access_only: This behavior is supported by the provider, but only available to the client and not to Finch
-
read
final Optional<OperationSupport> read()
supported: This operation is supported by both the provider and Finchnot_supported_by_finch: This operation is not supported by Finch but supported by the providernot_supported_by_provider: This operation is not supported by the provider, so Finch cannot supportclient_access_only: This behavior is supported by the provider, but only available to the client and not to Finch
-
update
final Optional<OperationSupport> update()
supported: This operation is supported by both the provider and Finchnot_supported_by_finch: This operation is not supported by Finch but supported by the providernot_supported_by_provider: This operation is not supported by the provider, so Finch cannot supportclient_access_only: This behavior is supported by the provider, but only available to the client and not to Finch
-
_create
final JsonField<OperationSupport> _create()
Returns the raw JSON value of create.
Unlike create, this method doesn't throw if the JSON field has an unexpected type.
-
_delete
final JsonField<OperationSupport> _delete()
Returns the raw JSON value of delete.
Unlike delete, this method doesn't throw if the JSON field has an unexpected type.
-
_read
final JsonField<OperationSupport> _read()
Returns the raw JSON value of read.
Unlike read, this method doesn't throw if the JSON field has an unexpected type.
-
_update
final JsonField<OperationSupport> _update()
Returns the raw JSON value of update.
Unlike update, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final OperationSupportMatrix.Builder toBuilder()
-
validate
final OperationSupportMatrix validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static OperationSupportMatrix.Builder builder()
Returns a mutable builder for constructing an instance of OperationSupportMatrix.
-
-
-