Class OperationSupportMatrix

    • Field Summary

      Fields 
      Modifier and Type Field Description
    • Constructor Summary

      Constructors 
      Constructor Description
    • Enum Constant Summary

      Enum Constants 
      Enum Constant Description
    • Method Summary

      Modifier and Type Method Description
      final Optional<OperationSupport> create()
      • supported: This operation is supported by both the provider and Finch

      • not_supported_by_finch: This operation is not supported by Finch but supported by the provider

      • not_supported_by_provider: This operation is not supported by the provider, so Finch cannot support

      • client_access_only: This behavior is supported by the provider, but only available to the client and not to Finch

      final Optional<OperationSupport> delete()
      • supported: This operation is supported by both the provider and Finch

      • not_supported_by_finch: This operation is not supported by Finch but supported by the provider

      • not_supported_by_provider: This operation is not supported by the provider, so Finch cannot support

      • client_access_only: This behavior is supported by the provider, but only available to the client and not to Finch

      final Optional<OperationSupport> read()
      • supported: This operation is supported by both the provider and Finch

      • not_supported_by_finch: This operation is not supported by Finch but supported by the provider

      • not_supported_by_provider: This operation is not supported by the provider, so Finch cannot support

      • client_access_only: This behavior is supported by the provider, but only available to the client and not to Finch

      final Optional<OperationSupport> update()
      • supported: This operation is supported by both the provider and Finch

      • not_supported_by_finch: This operation is not supported by Finch but supported by the provider

      • not_supported_by_provider: This operation is not supported by the provider, so Finch cannot support

      • client_access_only: This behavior is supported by the provider, but only available to the client and not to Finch

      final JsonField<OperationSupport> _create() Returns the raw JSON value of create.
      final JsonField<OperationSupport> _delete() Returns the raw JSON value of delete.
      final JsonField<OperationSupport> _read() Returns the raw JSON value of read.
      final JsonField<OperationSupport> _update() Returns the raw JSON value of update.
      final Map<String, JsonValue> _additionalProperties()
      final OperationSupportMatrix.Builder toBuilder()
      final OperationSupportMatrix validate()
      final Boolean isValid()
      Boolean equals(Object other)
      Integer hashCode()
      String toString()
      final static OperationSupportMatrix.Builder builder() Returns a mutable builder for constructing an instance of OperationSupportMatrix.
      • Methods inherited from class java.lang.Object

        clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
    • Constructor Detail

    • Method Detail

      • create

         final Optional<OperationSupport> create()
        • supported: This operation is supported by both the provider and Finch

        • not_supported_by_finch: This operation is not supported by Finch but supported by the provider

        • not_supported_by_provider: This operation is not supported by the provider, so Finch cannot support

        • client_access_only: This behavior is supported by the provider, but only available to the client and not to Finch

      • delete

         final Optional<OperationSupport> delete()
        • supported: This operation is supported by both the provider and Finch

        • not_supported_by_finch: This operation is not supported by Finch but supported by the provider

        • not_supported_by_provider: This operation is not supported by the provider, so Finch cannot support

        • client_access_only: This behavior is supported by the provider, but only available to the client and not to Finch

      • read

         final Optional<OperationSupport> read()
        • supported: This operation is supported by both the provider and Finch

        • not_supported_by_finch: This operation is not supported by Finch but supported by the provider

        • not_supported_by_provider: This operation is not supported by the provider, so Finch cannot support

        • client_access_only: This behavior is supported by the provider, but only available to the client and not to Finch

      • update

         final Optional<OperationSupport> update()
        • supported: This operation is supported by both the provider and Finch

        • not_supported_by_finch: This operation is not supported by Finch but supported by the provider

        • not_supported_by_provider: This operation is not supported by the provider, so Finch cannot support

        • client_access_only: This behavior is supported by the provider, but only available to the client and not to Finch