Package com.tryfinch.api.models
Class Paging
-
- All Implemented Interfaces:
public final class Paging
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPaging.BuilderA builder for Paging.
-
Method Summary
Modifier and Type Method Description final Longoffset()The current start index of the returned list of elements final Optional<Long>count()The total number of elements for the entire query (not just the given page) final JsonField<Long>_offset()Returns the raw JSON value of offset. final JsonField<Long>_count()Returns the raw JSON value of count. final Map<String, JsonValue>_additionalProperties()final Paging.BuildertoBuilder()final Pagingvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Paging.Builderbuilder()Returns a mutable builder for constructing an instance of Paging. -
-
Method Detail
-
count
final Optional<Long> count()
The total number of elements for the entire query (not just the given page)
-
_offset
final JsonField<Long> _offset()
Returns the raw JSON value of offset.
Unlike offset, this method doesn't throw if the JSON field has an unexpected type.
-
_count
final JsonField<Long> _count()
Returns the raw JSON value of count.
Unlike count, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Paging.Builder toBuilder()
-
builder
final static Paging.Builder builder()
Returns a mutable builder for constructing an instance of Paging.
The following fields are required:
.offset()
-
-
-
-