Package com.tryfinch.api.models
Class PayGroupListResponse
-
- All Implemented Interfaces:
public final class PayGroupListResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayGroupListResponse.BuilderA builder for PayGroupListResponse.
public final classPayGroupListResponse.PayFrequency
-
Method Summary
Modifier and Type Method Description final Stringid()Finch id (uuidv4) for the pay group final Stringname()Name of the pay group final List<PayGroupListResponse.PayFrequency>payFrequencies()List of pay frequencies associated with this pay group final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<List<PayGroupListResponse.PayFrequency>>_payFrequencies()Returns the raw JSON value of payFrequencies. final Map<String, JsonValue>_additionalProperties()final PayGroupListResponse.BuildertoBuilder()final PayGroupListResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PayGroupListResponse.Builderbuilder()Returns a mutable builder for constructing an instance of PayGroupListResponse. -
-
Method Detail
-
payFrequencies
final List<PayGroupListResponse.PayFrequency> payFrequencies()
List of pay frequencies associated with this pay group
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_payFrequencies
final JsonField<List<PayGroupListResponse.PayFrequency>> _payFrequencies()
Returns the raw JSON value of payFrequencies.
Unlike payFrequencies, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PayGroupListResponse.Builder toBuilder()
-
validate
final PayGroupListResponse validate()
-
builder
final static PayGroupListResponse.Builder builder()
Returns a mutable builder for constructing an instance of PayGroupListResponse.
The following fields are required:
.id() .name() .payFrequencies()
-
-
-
-