Package com.tryfinch.api.models
Class PayGroupRetrieveResponse
-
- All Implemented Interfaces:
public final class PayGroupRetrieveResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayGroupRetrieveResponse.BuilderA builder for PayGroupRetrieveResponse.
public final classPayGroupRetrieveResponse.PayFrequency
-
Method Summary
Modifier and Type Method Description final Stringid()Finch id (uuidv4) for the pay group final List<String>individualIds()final Stringname()Name of the pay group final List<PayGroupRetrieveResponse.PayFrequency>payFrequencies()List of pay frequencies associated with this pay group final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<List<String>>_individualIds()Returns the raw JSON value of individualIds. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<List<PayGroupRetrieveResponse.PayFrequency>>_payFrequencies()Returns the raw JSON value of payFrequencies. final Map<String, JsonValue>_additionalProperties()final PayGroupRetrieveResponse.BuildertoBuilder()final PayGroupRetrieveResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PayGroupRetrieveResponse.Builderbuilder()Returns a mutable builder for constructing an instance of PayGroupRetrieveResponse. -
-
Method Detail
-
individualIds
final List<String> individualIds()
-
payFrequencies
final List<PayGroupRetrieveResponse.PayFrequency> payFrequencies()
List of pay frequencies associated with this pay group
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_individualIds
final JsonField<List<String>> _individualIds()
Returns the raw JSON value of individualIds.
Unlike individualIds, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_payFrequencies
final JsonField<List<PayGroupRetrieveResponse.PayFrequency>> _payFrequencies()
Returns the raw JSON value of payFrequencies.
Unlike payFrequencies, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PayGroupRetrieveResponse.Builder toBuilder()
-
validate
final PayGroupRetrieveResponse validate()
-
builder
final static PayGroupRetrieveResponse.Builder builder()
Returns a mutable builder for constructing an instance of PayGroupRetrieveResponse.
The following fields are required:
.id() .individualIds() .name() .payFrequencies()
-
-
-
-