Class PayStatement.Earning
-
- All Implemented Interfaces:
public final class PayStatement.Earning
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayStatement.Earning.BuilderA builder for Earning.
public final classPayStatement.Earning.TypeThe type of earning.
public final classPayStatement.Earning.Attributes
-
Method Summary
Modifier and Type Method Description final Optional<Long>amount()The earnings amount in cents. final Optional<String>currency()The earnings currency code. final Optional<Double>hours()The number of hours associated with this earning. final Optional<String>name()The exact name of the deduction from the pay statement. final Optional<PayStatement.Earning.Type>type()The type of earning. final Optional<PayStatement.Earning.Attributes>attributes()final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_currency()Returns the raw JSON value of currency. final JsonField<Double>_hours()Returns the raw JSON value of hours. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<PayStatement.Earning.Type>_type()Returns the raw JSON value of type. final JsonField<PayStatement.Earning.Attributes>_attributes()Returns the raw JSON value of attributes. final Map<String, JsonValue>_additionalProperties()final PayStatement.Earning.BuildertoBuilder()final PayStatement.Earningvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PayStatement.Earning.Builderbuilder()Returns a mutable builder for constructing an instance of Earning. -
-
Method Detail
-
hours
final Optional<Double> hours()
The number of hours associated with this earning. (For salaried employees, this could be hours per pay period,
0ornull, depending on the provider).
-
type
final Optional<PayStatement.Earning.Type> type()
The type of earning.
-
attributes
final Optional<PayStatement.Earning.Attributes> attributes()
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_hours
final JsonField<Double> _hours()
Returns the raw JSON value of hours.
Unlike hours, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<PayStatement.Earning.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_attributes
final JsonField<PayStatement.Earning.Attributes> _attributes()
Returns the raw JSON value of attributes.
Unlike attributes, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PayStatement.Earning.Builder toBuilder()
-
validate
final PayStatement.Earning validate()
-
builder
final static PayStatement.Earning.Builder builder()
Returns a mutable builder for constructing an instance of Earning.
The following fields are required:
.amount() .currency() .hours() .name() .type()
-
-
-
-