Package com.tryfinch.api.models
Class PayStatement.Earning.Attributes
-
- All Implemented Interfaces:
public final class PayStatement.Earning.Attributes
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayStatement.Earning.Attributes.BuilderA builder for Attributes.
public final classPayStatement.Earning.Attributes.Metadata
-
Method Summary
Modifier and Type Method Description final PayStatement.Earning.Attributes.Metadatametadata()final JsonField<PayStatement.Earning.Attributes.Metadata>_metadata()Returns the raw JSON value of metadata. final Map<String, JsonValue>_additionalProperties()final PayStatement.Earning.Attributes.BuildertoBuilder()final PayStatement.Earning.Attributesvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PayStatement.Earning.Attributes.Builderbuilder()Returns a mutable builder for constructing an instance of Attributes. -
-
Method Detail
-
metadata
final PayStatement.Earning.Attributes.Metadata metadata()
-
_metadata
final JsonField<PayStatement.Earning.Attributes.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PayStatement.Earning.Attributes.Builder toBuilder()
-
validate
final PayStatement.Earning.Attributes validate()
-
builder
final static PayStatement.Earning.Attributes.Builder builder()
Returns a mutable builder for constructing an instance of Attributes.
The following fields are required:
.metadata()
-
-
-
-