Class PayStatement.EmployeeDeduction
-
- All Implemented Interfaces:
public final class PayStatement.EmployeeDeduction
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayStatement.EmployeeDeduction.BuilderA builder for EmployeeDeduction.
public final classPayStatement.EmployeeDeduction.Attributes
-
Method Summary
Modifier and Type Method Description final Optional<Long>amount()The deduction amount in cents. final Optional<String>currency()The deduction currency. final Optional<String>name()The deduction name from the pay statement. final Optional<Boolean>preTax()Boolean indicating if the deduction is pre-tax. final Optional<BenefitType>type()Type of benefit. final Optional<PayStatement.EmployeeDeduction.Attributes>attributes()final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_currency()Returns the raw JSON value of currency. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<Boolean>_preTax()Returns the raw JSON value of preTax. final JsonField<BenefitType>_type()Returns the raw JSON value of type. final JsonField<PayStatement.EmployeeDeduction.Attributes>_attributes()Returns the raw JSON value of attributes. final Map<String, JsonValue>_additionalProperties()final PayStatement.EmployeeDeduction.BuildertoBuilder()final PayStatement.EmployeeDeductionvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PayStatement.EmployeeDeduction.Builderbuilder()Returns a mutable builder for constructing an instance of EmployeeDeduction. -
-
Method Detail
-
type
final Optional<BenefitType> type()
Type of benefit.
-
attributes
final Optional<PayStatement.EmployeeDeduction.Attributes> attributes()
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_preTax
final JsonField<Boolean> _preTax()
Returns the raw JSON value of preTax.
Unlike preTax, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<BenefitType> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_attributes
final JsonField<PayStatement.EmployeeDeduction.Attributes> _attributes()
Returns the raw JSON value of attributes.
Unlike attributes, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PayStatement.EmployeeDeduction.Builder toBuilder()
-
validate
final PayStatement.EmployeeDeduction validate()
-
builder
final static PayStatement.EmployeeDeduction.Builder builder()
Returns a mutable builder for constructing an instance of EmployeeDeduction.
The following fields are required:
.amount() .currency() .name() .preTax() .type()
-
-
-
-