Class PayStatementItemListResponse.Attributes
-
- All Implemented Interfaces:
public final class PayStatementItemListResponse.AttributesThe attributes of the pay statement item.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayStatementItemListResponse.Attributes.BuilderA builder for Attributes.
public final classPayStatementItemListResponse.Attributes.MetadataThe metadata of the pay statement item derived by the rules engine if available. Each attribute will be a key-value pair defined by a rule.
-
Method Summary
Modifier and Type Method Description final Optional<PayStatementItemListResponse.Attributes.Metadata>metadata()The metadata of the pay statement item derived by the rules engine if available. final Optional<Boolean>employer()trueif the amount is paid by the employers.final Optional<Boolean>preTax()trueif the pay statement item is pre-tax.final Optional<String>type()The type of the pay statement item. final JsonField<PayStatementItemListResponse.Attributes.Metadata>_metadata()Returns the raw JSON value of metadata. final JsonField<Boolean>_employer()Returns the raw JSON value of employer. final JsonField<Boolean>_preTax()Returns the raw JSON value of preTax. final JsonField<String>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final PayStatementItemListResponse.Attributes.BuildertoBuilder()final PayStatementItemListResponse.Attributesvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PayStatementItemListResponse.Attributes.Builderbuilder()Returns a mutable builder for constructing an instance of Attributes. -
-
Method Detail
-
metadata
final Optional<PayStatementItemListResponse.Attributes.Metadata> metadata()
The metadata of the pay statement item derived by the rules engine if available. Each attribute will be a key-value pair defined by a rule.
-
employer
final Optional<Boolean> employer()
trueif the amount is paid by the employers. This field is only available for taxes.
-
preTax
final Optional<Boolean> preTax()
trueif the pay statement item is pre-tax. This field is only available for employee deductions.
-
_metadata
final JsonField<PayStatementItemListResponse.Attributes.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_employer
final JsonField<Boolean> _employer()
Returns the raw JSON value of employer.
Unlike employer, this method doesn't throw if the JSON field has an unexpected type.
-
_preTax
final JsonField<Boolean> _preTax()
Returns the raw JSON value of preTax.
Unlike preTax, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<String> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PayStatementItemListResponse.Attributes.Builder toBuilder()
-
validate
final PayStatementItemListResponse.Attributes validate()
-
builder
final static PayStatementItemListResponse.Attributes.Builder builder()
Returns a mutable builder for constructing an instance of Attributes.
The following fields are required:
.metadata()
-
-
-
-