Package com.tryfinch.api.models
Class PayStatementResponse
-
- All Implemented Interfaces:
public final class PayStatementResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayStatementResponse.BuilderA builder for PayStatementResponse.
public final classPayStatementResponse.Body
-
Method Summary
Modifier and Type Method Description final PayStatementResponse.Bodybody()final Longcode()final StringpaymentId()final JsonField<PayStatementResponse.Body>_body()Returns the raw JSON value of body. final JsonField<Long>_code()Returns the raw JSON value of code. final JsonField<String>_paymentId()Returns the raw JSON value of paymentId. final Map<String, JsonValue>_additionalProperties()final PayStatementResponse.BuildertoBuilder()final PayStatementResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PayStatementResponse.Builderbuilder()Returns a mutable builder for constructing an instance of PayStatementResponse. -
-
Method Detail
-
body
final PayStatementResponse.Body body()
-
_body
final JsonField<PayStatementResponse.Body> _body()
Returns the raw JSON value of body.
Unlike body, this method doesn't throw if the JSON field has an unexpected type.
-
_code
final JsonField<Long> _code()
Returns the raw JSON value of code.
Unlike code, this method doesn't throw if the JSON field has an unexpected type.
-
_paymentId
final JsonField<String> _paymentId()
Returns the raw JSON value of paymentId.
Unlike paymentId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PayStatementResponse.Builder toBuilder()
-
validate
final PayStatementResponse validate()
-
builder
final static PayStatementResponse.Builder builder()
Returns a mutable builder for constructing an instance of PayStatementResponse.
The following fields are required:
.body() .code() .paymentId()
-
-
-
-