Class Payment
-
- All Implemented Interfaces:
public final class Payment
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayment.BuilderA builder for Payment.
public final classPayment.PayFrequencypublic final classPayment.PayPeriodThe pay period object.
-
Method Summary
Modifier and Type Method Description final Stringid()The unique id for the payment. final Optional<Money>companyDebit()final Optional<String>debitDate()final Optional<Money>employeeTaxes()final Optional<Money>employerTaxes()final Optional<Money>grossPay()final Optional<List<String>>individualIds()Array of every individual on this payment. final Optional<Money>netPay()final Optional<String>payDate()final Optional<List<Payment.PayFrequency>>payFrequencies()List of pay frequencies associated with this payment. final Optional<List<String>>payGroupIds()Array of the Finch id (uuidv4) of every pay group associated with this payment. final Optional<Payment.PayPeriod>payPeriod()The pay period object. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Money>_companyDebit()Returns the raw JSON value of companyDebit. final JsonField<String>_debitDate()Returns the raw JSON value of debitDate. final JsonField<Money>_employeeTaxes()Returns the raw JSON value of employeeTaxes. final JsonField<Money>_employerTaxes()Returns the raw JSON value of employerTaxes. final JsonField<Money>_grossPay()Returns the raw JSON value of grossPay. final JsonField<List<String>>_individualIds()Returns the raw JSON value of individualIds. final JsonField<Money>_netPay()Returns the raw JSON value of netPay. final JsonField<String>_payDate()Returns the raw JSON value of payDate. final JsonField<List<Payment.PayFrequency>>_payFrequencies()Returns the raw JSON value of payFrequencies. final JsonField<List<String>>_payGroupIds()Returns the raw JSON value of payGroupIds. final JsonField<Payment.PayPeriod>_payPeriod()Returns the raw JSON value of payPeriod. final Map<String, JsonValue>_additionalProperties()final Payment.BuildertoBuilder()final Paymentvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Payment.Builderbuilder()Returns a mutable builder for constructing an instance of Payment. -
-
Method Detail
-
companyDebit
final Optional<Money> companyDebit()
-
employeeTaxes
final Optional<Money> employeeTaxes()
-
employerTaxes
final Optional<Money> employerTaxes()
-
individualIds
final Optional<List<String>> individualIds()
Array of every individual on this payment.
-
payFrequencies
final Optional<List<Payment.PayFrequency>> payFrequencies()
List of pay frequencies associated with this payment.
-
payGroupIds
final Optional<List<String>> payGroupIds()
Array of the Finch id (uuidv4) of every pay group associated with this payment.
-
payPeriod
final Optional<Payment.PayPeriod> payPeriod()
The pay period object.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_companyDebit
final JsonField<Money> _companyDebit()
Returns the raw JSON value of companyDebit.
Unlike companyDebit, this method doesn't throw if the JSON field has an unexpected type.
-
_debitDate
final JsonField<String> _debitDate()
Returns the raw JSON value of debitDate.
Unlike debitDate, this method doesn't throw if the JSON field has an unexpected type.
-
_employeeTaxes
final JsonField<Money> _employeeTaxes()
Returns the raw JSON value of employeeTaxes.
Unlike employeeTaxes, this method doesn't throw if the JSON field has an unexpected type.
-
_employerTaxes
final JsonField<Money> _employerTaxes()
Returns the raw JSON value of employerTaxes.
Unlike employerTaxes, this method doesn't throw if the JSON field has an unexpected type.
-
_grossPay
final JsonField<Money> _grossPay()
Returns the raw JSON value of grossPay.
Unlike grossPay, this method doesn't throw if the JSON field has an unexpected type.
-
_individualIds
final JsonField<List<String>> _individualIds()
Returns the raw JSON value of individualIds.
Unlike individualIds, this method doesn't throw if the JSON field has an unexpected type.
-
_netPay
final JsonField<Money> _netPay()
Returns the raw JSON value of netPay.
Unlike netPay, this method doesn't throw if the JSON field has an unexpected type.
-
_payDate
final JsonField<String> _payDate()
Returns the raw JSON value of payDate.
Unlike payDate, this method doesn't throw if the JSON field has an unexpected type.
-
_payFrequencies
final JsonField<List<Payment.PayFrequency>> _payFrequencies()
Returns the raw JSON value of payFrequencies.
Unlike payFrequencies, this method doesn't throw if the JSON field has an unexpected type.
-
_payGroupIds
final JsonField<List<String>> _payGroupIds()
Returns the raw JSON value of payGroupIds.
Unlike payGroupIds, this method doesn't throw if the JSON field has an unexpected type.
-
_payPeriod
final JsonField<Payment.PayPeriod> _payPeriod()
Returns the raw JSON value of payPeriod.
Unlike payPeriod, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Payment.Builder toBuilder()
-
builder
final static Payment.Builder builder()
Returns a mutable builder for constructing an instance of Payment.
The following fields are required:
.id() .companyDebit() .debitDate() .employeeTaxes() .employerTaxes() .grossPay() .individualIds() .netPay() .payDate() .payFrequencies() .payGroupIds() .payPeriod()
-
-
-
-