Package com.tryfinch.api.models
Class PayrollPayGroupListPage
-
- All Implemented Interfaces:
public final class PayrollPayGroupListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayrollPayGroupListPage.BuilderA builder for PayrollPayGroupListPage.
public final classPayrollPayGroupListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final BooleanhasNextPage()final Optional<PayrollPayGroupListParams>getNextPageParams()final Optional<PayrollPayGroupListPage>getNextPage()final PayrollPayGroupListPage.AutoPagerautoPager()final PayrollPayGroupListParamsparams()The parameters that were used to request this page. final List<PayGroupListResponse>items()The response that this page was parsed from. final PayrollPayGroupListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PayrollPayGroupListPage.Builderbuilder()Returns a mutable builder for constructing an instance of PayrollPayGroupListPage. -
-
Method Detail
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<PayrollPayGroupListParams> getNextPageParams()
-
getNextPage
final Optional<PayrollPayGroupListPage> getNextPage()
-
autoPager
final PayrollPayGroupListPage.AutoPager autoPager()
-
params
final PayrollPayGroupListParams params()
The parameters that were used to request this page.
-
items
final List<PayGroupListResponse> items()
The response that this page was parsed from.
-
toBuilder
final PayrollPayGroupListPage.Builder toBuilder()
-
builder
final static PayrollPayGroupListPage.Builder builder()
Returns a mutable builder for constructing an instance of PayrollPayGroupListPage.
The following fields are required:
.service() .params() .items()
-
-
-
-