Class Provider.AuthenticationMethod
-
- All Implemented Interfaces:
public final class Provider.AuthenticationMethod
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProvider.AuthenticationMethod.BuilderA builder for AuthenticationMethod.
public final classProvider.AuthenticationMethod.SupportedFieldsThe supported data fields returned by our HR and payroll endpoints
public final classProvider.AuthenticationMethod.TypeThe type of authentication method.
-
Method Summary
-
-
Method Detail
-
benefitsSupport
final Optional<BenefitsSupport> benefitsSupport()
Each benefit type and their supported features. If the benefit type is not supported, the property will be null
-
supportedFields
final Optional<Provider.AuthenticationMethod.SupportedFields> supportedFields()
The supported data fields returned by our HR and payroll endpoints
-
type
final Optional<Provider.AuthenticationMethod.Type> type()
The type of authentication method.
-
_benefitsSupport
final JsonField<BenefitsSupport> _benefitsSupport()
Returns the raw JSON value of benefitsSupport.
Unlike benefitsSupport, this method doesn't throw if the JSON field has an unexpected type.
-
_supportedFields
final JsonField<Provider.AuthenticationMethod.SupportedFields> _supportedFields()
Returns the raw JSON value of supportedFields.
Unlike supportedFields, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<Provider.AuthenticationMethod.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Provider.AuthenticationMethod.Builder toBuilder()
-
validate
final Provider.AuthenticationMethod validate()
-
builder
final static Provider.AuthenticationMethod.Builder builder()
Returns a mutable builder for constructing an instance of AuthenticationMethod.
-
-
-
-