Class ProviderListResponse.AuthenticationMethod
-
- All Implemented Interfaces:
public final class ProviderListResponse.AuthenticationMethod
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProviderListResponse.AuthenticationMethod.BuilderA builder for AuthenticationMethod.
public final classProviderListResponse.AuthenticationMethod.TypeThe type of authentication method
public final classProviderListResponse.AuthenticationMethod.BenefitsSupportThe supported benefit types and their configurations
public final classProviderListResponse.AuthenticationMethod.SupportedFieldsThe supported fields for each Finch product
-
Method Summary
-
-
Method Detail
-
type
final ProviderListResponse.AuthenticationMethod.Type type()
The type of authentication method
-
benefitsSupport
final Optional<ProviderListResponse.AuthenticationMethod.BenefitsSupport> benefitsSupport()
The supported benefit types and their configurations
-
supportedFields
final Optional<ProviderListResponse.AuthenticationMethod.SupportedFields> supportedFields()
The supported fields for each Finch product
-
_type
final JsonField<ProviderListResponse.AuthenticationMethod.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_benefitsSupport
final JsonField<ProviderListResponse.AuthenticationMethod.BenefitsSupport> _benefitsSupport()
Returns the raw JSON value of benefitsSupport.
Unlike benefitsSupport, this method doesn't throw if the JSON field has an unexpected type.
-
_supportedFields
final JsonField<ProviderListResponse.AuthenticationMethod.SupportedFields> _supportedFields()
Returns the raw JSON value of supportedFields.
Unlike supportedFields, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProviderListResponse.AuthenticationMethod.Builder toBuilder()
-
validate
final ProviderListResponse.AuthenticationMethod validate()
-
builder
final static ProviderListResponse.AuthenticationMethod.Builder builder()
Returns a mutable builder for constructing an instance of AuthenticationMethod.
The following fields are required:
.type()
-
-
-
-