Package com.tryfinch.api.models
Class ProviderListResponse.AuthenticationMethod.BenefitsSupport
-
- All Implemented Interfaces:
public final class ProviderListResponse.AuthenticationMethod.BenefitsSupportThe supported benefit types and their configurations
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProviderListResponse.AuthenticationMethod.BenefitsSupport.BuilderA builder for BenefitsSupport.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final ProviderListResponse.AuthenticationMethod.BenefitsSupport.BuildertoBuilder()final ProviderListResponse.AuthenticationMethod.BenefitsSupportvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProviderListResponse.AuthenticationMethod.BenefitsSupport.Builderbuilder()Returns a mutable builder for constructing an instance of BenefitsSupport. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProviderListResponse.AuthenticationMethod.BenefitsSupport.Builder toBuilder()
-
validate
final ProviderListResponse.AuthenticationMethod.BenefitsSupport validate()
-
builder
final static ProviderListResponse.AuthenticationMethod.BenefitsSupport.Builder builder()
Returns a mutable builder for constructing an instance of BenefitsSupport.
-
-
-
-