Class RequestForwardingForwardResponse.Request
-
- All Implemented Interfaces:
public final class RequestForwardingForwardResponse.RequestAn object containing details of your original forwarded request, for your ease of reference.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRequestForwardingForwardResponse.Request.BuilderA builder for Request.
-
Method Summary
Modifier and Type Method Description final Optional<String>data()The body that was specified for the forwarded request. final JsonValue_headers()The specified HTTP headers that were included in the forwarded request. final Stringmethod()The HTTP method that was specified for the forwarded request. final JsonValue_params()The query parameters that were included in the forwarded request. final Stringroute()The URL route path that was specified for the forwarded request. final JsonField<String>_data()Returns the raw JSON value of data. final JsonField<String>_method()Returns the raw JSON value of method. final JsonField<String>_route()Returns the raw JSON value of route. final Map<String, JsonValue>_additionalProperties()final RequestForwardingForwardResponse.Request.BuildertoBuilder()final RequestForwardingForwardResponse.Requestvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RequestForwardingForwardResponse.Request.Builderbuilder()Returns a mutable builder for constructing an instance of Request. -
-
Method Detail
-
data
final Optional<String> data()
The body that was specified for the forwarded request. If a value was not specified in the original request, this value will be returned as null ; otherwise, this value will always be returned as a string.
-
_headers
final JsonValue _headers()
The specified HTTP headers that were included in the forwarded request. If no headers were specified, this will be returned as
null.
-
method
final String method()
The HTTP method that was specified for the forwarded request. Valid values include:
GET,POST,PUT,DELETE, andPATCH.
-
_params
final JsonValue _params()
The query parameters that were included in the forwarded request. If no query parameters were specified, this will be returned as
null.
-
_data
final JsonField<String> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_method
final JsonField<String> _method()
Returns the raw JSON value of method.
Unlike method, this method doesn't throw if the JSON field has an unexpected type.
-
_route
final JsonField<String> _route()
Returns the raw JSON value of route.
Unlike route, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RequestForwardingForwardResponse.Request.Builder toBuilder()
-
validate
final RequestForwardingForwardResponse.Request validate()
-
builder
final static RequestForwardingForwardResponse.Request.Builder builder()
Returns a mutable builder for constructing an instance of Request.
The following fields are required:
.data() .headers() .method() .params() .route()
-
-
-
-