Class RequestForwardingForwardResponse.Request.Builder
-
- All Implemented Interfaces:
public final class RequestForwardingForwardResponse.Request.BuilderA builder for Request.
-
-
Method Summary
-
-
Method Detail
-
data
final RequestForwardingForwardResponse.Request.Builder data(String data)
The body that was specified for the forwarded request. If a value was not specified in the original request, this value will be returned as null ; otherwise, this value will always be returned as a string.
-
data
final RequestForwardingForwardResponse.Request.Builder data(Optional<String> data)
Alias for calling Builder.data with
data.orElse(null).
-
data
final RequestForwardingForwardResponse.Request.Builder data(JsonField<String> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
headers
final RequestForwardingForwardResponse.Request.Builder headers(JsonValue headers)
The specified HTTP headers that were included in the forwarded request. If no headers were specified, this will be returned as
null.
-
method
final RequestForwardingForwardResponse.Request.Builder method(String method)
The HTTP method that was specified for the forwarded request. Valid values include:
GET,POST,PUT,DELETE, andPATCH.
-
method
final RequestForwardingForwardResponse.Request.Builder method(JsonField<String> method)
Sets Builder.method to an arbitrary JSON value.
You should usually call Builder.method with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
params
final RequestForwardingForwardResponse.Request.Builder params(JsonValue params)
The query parameters that were included in the forwarded request. If no query parameters were specified, this will be returned as
null.
-
route
final RequestForwardingForwardResponse.Request.Builder route(String route)
The URL route path that was specified for the forwarded request.
-
route
final RequestForwardingForwardResponse.Request.Builder route(JsonField<String> route)
Sets Builder.route to an arbitrary JSON value.
You should usually call Builder.route with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RequestForwardingForwardResponse.Request.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RequestForwardingForwardResponse.Request.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RequestForwardingForwardResponse.Request.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RequestForwardingForwardResponse.Request.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RequestForwardingForwardResponse.Request.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RequestForwardingForwardResponse.Request build()
Returns an immutable instance of Request.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.data() .headers() .method() .params() .route()
-
-
-
-