Package com.tryfinch.api.models
Class RuleListResponse.Condition
-
- All Implemented Interfaces:
public final class RuleListResponse.Condition
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRuleListResponse.Condition.BuilderA builder for Condition.
public final classRuleListResponse.Condition.OperatorThe operator to be used in the rule.
-
Method Summary
Modifier and Type Method Description final Optional<String>field()The field to be checked in the rule. final Optional<RuleListResponse.Condition.Operator>operator()The operator to be used in the rule. final Optional<String>value()The value of the field to be checked in the rule. final JsonField<String>_field()Returns the raw JSON value of field. final JsonField<RuleListResponse.Condition.Operator>_operator()Returns the raw JSON value of operator. final JsonField<String>_value()Returns the raw JSON value of value. final Map<String, JsonValue>_additionalProperties()final RuleListResponse.Condition.BuildertoBuilder()final RuleListResponse.Conditionvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RuleListResponse.Condition.Builderbuilder()Returns a mutable builder for constructing an instance of Condition. -
-
Method Detail
-
operator
final Optional<RuleListResponse.Condition.Operator> operator()
The operator to be used in the rule.
-
_field
final JsonField<String> _field()
Returns the raw JSON value of field.
Unlike field, this method doesn't throw if the JSON field has an unexpected type.
-
_operator
final JsonField<RuleListResponse.Condition.Operator> _operator()
Returns the raw JSON value of operator.
Unlike operator, this method doesn't throw if the JSON field has an unexpected type.
-
_value
final JsonField<String> _value()
Returns the raw JSON value of value.
Unlike value, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RuleListResponse.Condition.Builder toBuilder()
-
validate
final RuleListResponse.Condition validate()
-
builder
final static RuleListResponse.Condition.Builder builder()
Returns a mutable builder for constructing an instance of Condition.
-
-
-
-