Class SandboxConnectionCreateParams.Body
-
- All Implemented Interfaces:
public final class SandboxConnectionCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSandboxConnectionCreateParams.Body.BuilderA builder for Body.
-
Method Summary
-
-
Method Detail
-
providerId
final String providerId()
The provider associated with the connection
-
authenticationType
final Optional<SandboxConnectionCreateParams.AuthenticationType> authenticationType()
-
employeeSize
final Optional<Long> employeeSize()
Optional: the size of the employer to be created with this connection. Defaults to 20. Note that if this is higher than 100, historical payroll data will not be generated, and instead only one pay period will be created.
-
_providerId
final JsonField<String> _providerId()
Returns the raw JSON value of providerId.
Unlike providerId, this method doesn't throw if the JSON field has an unexpected type.
-
_authenticationType
final JsonField<SandboxConnectionCreateParams.AuthenticationType> _authenticationType()
Returns the raw JSON value of authenticationType.
Unlike authenticationType, this method doesn't throw if the JSON field has an unexpected type.
-
_employeeSize
final JsonField<Long> _employeeSize()
Returns the raw JSON value of employeeSize.
Unlike employeeSize, this method doesn't throw if the JSON field has an unexpected type.
-
_products
final JsonField<List<String>> _products()
Returns the raw JSON value of products.
Unlike products, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SandboxConnectionCreateParams.Body.Builder toBuilder()
-
validate
final SandboxConnectionCreateParams.Body validate()
-
builder
final static SandboxConnectionCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.providerId()
-
-
-
-