Class W42020.Data
-
- All Implemented Interfaces:
public final class W42020.DataDetailed information specific to the 2020 W4 form.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classW42020.Data.BuilderA builder for Data.
public final classW42020.Data.FilingStatusThe individual's filing status for tax purposes.
-
Method Summary
Modifier and Type Method Description final Optional<Long>amountForOtherDependents()Amount claimed for dependents other than qualifying children under 17 (in cents). final Optional<Long>amountForQualifyingChildrenUnder17()Amount claimed for dependents under 17 years old (in cents). final Optional<Long>deductions()Deductible expenses (in cents). final Optional<Long>extraWithholding()Additional withholding amount (in cents). final Optional<W42020.Data.FilingStatus>filingStatus()The individual's filing status for tax purposes. final Optional<String>individualId()The unique identifier for the individual associated with this document. final Optional<Long>otherIncome()Additional income from sources outside of primary employment (in cents). final Optional<Long>totalClaimDependentAndOtherCredits()Total amount claimed for dependents and other credits (in cents). final JsonField<Long>_amountForOtherDependents()Returns the raw JSON value of amountForOtherDependents. final JsonField<Long>_amountForQualifyingChildrenUnder17()Returns the raw JSON value of amountForQualifyingChildrenUnder17. final JsonField<Long>_deductions()Returns the raw JSON value of deductions. final JsonField<Long>_extraWithholding()Returns the raw JSON value of extraWithholding. final JsonField<W42020.Data.FilingStatus>_filingStatus()Returns the raw JSON value of filingStatus. final JsonField<String>_individualId()Returns the raw JSON value of individualId. final JsonField<Long>_otherIncome()Returns the raw JSON value of otherIncome. final JsonField<Long>_totalClaimDependentAndOtherCredits()Returns the raw JSON value of totalClaimDependentAndOtherCredits. final Map<String, JsonValue>_additionalProperties()final W42020.Data.BuildertoBuilder()final W42020.Datavalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static W42020.Data.Builderbuilder()Returns a mutable builder for constructing an instance of Data. -
-
Method Detail
-
amountForOtherDependents
final Optional<Long> amountForOtherDependents()
Amount claimed for dependents other than qualifying children under 17 (in cents).
-
amountForQualifyingChildrenUnder17
final Optional<Long> amountForQualifyingChildrenUnder17()
Amount claimed for dependents under 17 years old (in cents).
-
deductions
final Optional<Long> deductions()
Deductible expenses (in cents).
-
extraWithholding
final Optional<Long> extraWithholding()
Additional withholding amount (in cents).
-
filingStatus
final Optional<W42020.Data.FilingStatus> filingStatus()
The individual's filing status for tax purposes.
-
individualId
final Optional<String> individualId()
The unique identifier for the individual associated with this document.
-
otherIncome
final Optional<Long> otherIncome()
Additional income from sources outside of primary employment (in cents).
-
totalClaimDependentAndOtherCredits
final Optional<Long> totalClaimDependentAndOtherCredits()
Total amount claimed for dependents and other credits (in cents).
-
_amountForOtherDependents
final JsonField<Long> _amountForOtherDependents()
Returns the raw JSON value of amountForOtherDependents.
Unlike amountForOtherDependents, this method doesn't throw if the JSON field has an unexpected type.
-
_amountForQualifyingChildrenUnder17
final JsonField<Long> _amountForQualifyingChildrenUnder17()
Returns the raw JSON value of amountForQualifyingChildrenUnder17.
Unlike amountForQualifyingChildrenUnder17, this method doesn't throw if the JSON field has an unexpected type.
-
_deductions
final JsonField<Long> _deductions()
Returns the raw JSON value of deductions.
Unlike deductions, this method doesn't throw if the JSON field has an unexpected type.
-
_extraWithholding
final JsonField<Long> _extraWithholding()
Returns the raw JSON value of extraWithholding.
Unlike extraWithholding, this method doesn't throw if the JSON field has an unexpected type.
-
_filingStatus
final JsonField<W42020.Data.FilingStatus> _filingStatus()
Returns the raw JSON value of filingStatus.
Unlike filingStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_individualId
final JsonField<String> _individualId()
Returns the raw JSON value of individualId.
Unlike individualId, this method doesn't throw if the JSON field has an unexpected type.
-
_otherIncome
final JsonField<Long> _otherIncome()
Returns the raw JSON value of otherIncome.
Unlike otherIncome, this method doesn't throw if the JSON field has an unexpected type.
-
_totalClaimDependentAndOtherCredits
final JsonField<Long> _totalClaimDependentAndOtherCredits()
Returns the raw JSON value of totalClaimDependentAndOtherCredits.
Unlike totalClaimDependentAndOtherCredits, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final W42020.Data.Builder toBuilder()
-
validate
final W42020.Data validate()
-
builder
final static W42020.Data.Builder builder()
Returns a mutable builder for constructing an instance of Data.
-
-
-
-