Package com.tryfinch.api.services.async
Interface AccountServiceAsync
-
- All Implemented Interfaces:
public interface AccountServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAccountServiceAsync.WithRawResponseA view of AccountServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AccountServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<DisconnectResponse>disconnect()Disconnect one or more access_tokens from your application.abstract CompletableFuture<DisconnectResponse>disconnect(AccountDisconnectParams params, RequestOptions requestOptions)CompletableFuture<DisconnectResponse>disconnect(AccountDisconnectParams params)CompletableFuture<DisconnectResponse>disconnect(RequestOptions requestOptions)CompletableFuture<Introspection>introspect()Read account information associated with an access_tokenabstract CompletableFuture<Introspection>introspect(AccountIntrospectParams params, RequestOptions requestOptions)CompletableFuture<Introspection>introspect(AccountIntrospectParams params)CompletableFuture<Introspection>introspect(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract AccountServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
disconnect
CompletableFuture<DisconnectResponse> disconnect()
Disconnect one or more
access_tokens from your application.
-
disconnect
abstract CompletableFuture<DisconnectResponse> disconnect(AccountDisconnectParams params, RequestOptions requestOptions)
-
disconnect
CompletableFuture<DisconnectResponse> disconnect(AccountDisconnectParams params)
-
disconnect
CompletableFuture<DisconnectResponse> disconnect(RequestOptions requestOptions)
-
introspect
CompletableFuture<Introspection> introspect()
Read account information associated with an
access_token
-
introspect
abstract CompletableFuture<Introspection> introspect(AccountIntrospectParams params, RequestOptions requestOptions)
-
introspect
CompletableFuture<Introspection> introspect(AccountIntrospectParams params)
-
introspect
CompletableFuture<Introspection> introspect(RequestOptions requestOptions)
-
-
-
-