Package com.tryfinch.api.services.async
Class AccountServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.AccountServiceAsync
public final class AccountServiceAsyncImpl implements AccountServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AccountServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AccountServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<DisconnectResponse>disconnect(AccountDisconnectParams params, RequestOptions requestOptions)CompletableFuture<Introspection>introspect(AccountIntrospectParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
AccountServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
AccountServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
disconnect
CompletableFuture<DisconnectResponse> disconnect(AccountDisconnectParams params, RequestOptions requestOptions)
-
introspect
CompletableFuture<Introspection> introspect(AccountIntrospectParams params, RequestOptions requestOptions)
-
-
-
-