Package com.tryfinch.api.services.async
Class RequestForwardingServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.RequestForwardingServiceAsync
public final class RequestForwardingServiceAsyncImpl implements RequestForwardingServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRequestForwardingServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description RequestForwardingServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<RequestForwardingForwardResponse>forward(RequestForwardingForwardParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
RequestForwardingServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
forward
CompletableFuture<RequestForwardingForwardResponse> forward(RequestForwardingForwardParams params, RequestOptions requestOptions)
-
-
-
-