Package com.tryfinch.api.services.async
Interface SandboxServiceAsync
-
- All Implemented Interfaces:
public interface SandboxServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSandboxServiceAsync.WithRawResponseA view of SandboxServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract SandboxServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract ConnectionServiceAsyncconnections()abstract CompanyServiceAsynccompany()abstract DirectoryServiceAsyncdirectory()abstract IndividualServiceAsyncindividual()abstract EmploymentServiceAsyncemployment()abstract PaymentServiceAsyncpayment()abstract JobServiceAsyncjobs()-
-
Method Detail
-
withRawResponse
abstract SandboxServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
connections
abstract ConnectionServiceAsync connections()
-
company
abstract CompanyServiceAsync company()
-
directory
abstract DirectoryServiceAsync directory()
-
individual
abstract IndividualServiceAsync individual()
-
employment
abstract EmploymentServiceAsync employment()
-
payment
abstract PaymentServiceAsync payment()
-
jobs
abstract JobServiceAsync jobs()
-
-
-
-