Class DirectoryServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.hris.DirectoryServiceAsync
public final class DirectoryServiceAsyncImpl implements DirectoryServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDirectoryServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description DirectoryServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<HrisDirectoryListPageAsync>list(HrisDirectoryListParams params, RequestOptions requestOptions)CompletableFuture<HrisDirectoryListIndividualsPageAsync>listIndividuals(HrisDirectoryListIndividualsParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
DirectoryServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
list
CompletableFuture<HrisDirectoryListPageAsync> list(HrisDirectoryListParams params, RequestOptions requestOptions)
-
listIndividuals
@Deprecated(message = "use `list` instead") CompletableFuture<HrisDirectoryListIndividualsPageAsync> listIndividuals(HrisDirectoryListIndividualsParams params, RequestOptions requestOptions)
-
-
-
-