Interface PayGroupServiceAsync
-
- All Implemented Interfaces:
public interface PayGroupServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfacePayGroupServiceAsync.WithRawResponseA view of PayGroupServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract PayGroupServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<PayGroupRetrieveResponse>retrieve(PayrollPayGroupRetrieveParams params)Read information from a single pay group abstract CompletableFuture<PayGroupRetrieveResponse>retrieve(PayrollPayGroupRetrieveParams params, RequestOptions requestOptions)CompletableFuture<PayrollPayGroupListPageAsync>list()Read company pay groups and frequencies abstract CompletableFuture<PayrollPayGroupListPageAsync>list(PayrollPayGroupListParams params, RequestOptions requestOptions)CompletableFuture<PayrollPayGroupListPageAsync>list(PayrollPayGroupListParams params)CompletableFuture<PayrollPayGroupListPageAsync>list(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract PayGroupServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<PayGroupRetrieveResponse> retrieve(PayrollPayGroupRetrieveParams params)
Read information from a single pay group
-
retrieve
abstract CompletableFuture<PayGroupRetrieveResponse> retrieve(PayrollPayGroupRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<PayrollPayGroupListPageAsync> list()
Read company pay groups and frequencies
-
list
abstract CompletableFuture<PayrollPayGroupListPageAsync> list(PayrollPayGroupListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<PayrollPayGroupListPageAsync> list(RequestOptions requestOptions)
-
-
-
-