Class CompanyServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.async.sandbox.CompanyServiceAsync
public final class CompanyServiceAsyncImpl implements CompanyServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCompanyServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CompanyServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<CompanyUpdateResponse>update(SandboxCompanyUpdateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CompanyServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
update
CompletableFuture<CompanyUpdateResponse> update(SandboxCompanyUpdateParams params, RequestOptions requestOptions)
-
-
-
-