Interface EmploymentServiceAsync
-
- All Implemented Interfaces:
public interface EmploymentServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceEmploymentServiceAsync.WithRawResponseA view of EmploymentServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract EmploymentServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<EmploymentUpdateResponse>update(SandboxEmploymentUpdateParams params)Update sandbox employment abstract CompletableFuture<EmploymentUpdateResponse>update(SandboxEmploymentUpdateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract EmploymentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
update
CompletableFuture<EmploymentUpdateResponse> update(SandboxEmploymentUpdateParams params)
Update sandbox employment
-
update
abstract CompletableFuture<EmploymentUpdateResponse> update(SandboxEmploymentUpdateParams params, RequestOptions requestOptions)
-
-
-
-