Interface AccessTokenService
-
- All Implemented Interfaces:
public interface AccessTokenService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAccessTokenService.WithRawResponseA view of AccessTokenService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AccessTokenService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CreateAccessTokenResponsecreate(AccessTokenCreateParams params)Exchange the authorization code for an access token abstract CreateAccessTokenResponsecreate(AccessTokenCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract AccessTokenService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CreateAccessTokenResponse create(AccessTokenCreateParams params)
Exchange the authorization code for an access token
-
create
abstract CreateAccessTokenResponse create(AccessTokenCreateParams params, RequestOptions requestOptions)
-
-
-
-