Class AccessTokenServiceImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.AccessTokenService
public final class AccessTokenServiceImpl implements AccessTokenService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccessTokenServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AccessTokenService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CreateAccessTokenResponsecreate(AccessTokenCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
AccessTokenService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CreateAccessTokenResponse create(AccessTokenCreateParams params, RequestOptions requestOptions)
-
-
-
-