Class AccountServiceImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.AccountService
public final class AccountServiceImpl implements AccountService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AccountService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. DisconnectResponsedisconnect(AccountDisconnectParams params, RequestOptions requestOptions)Introspectionintrospect(AccountIntrospectParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
AccountService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
disconnect
DisconnectResponse disconnect(AccountDisconnectParams params, RequestOptions requestOptions)
-
introspect
Introspection introspect(AccountIntrospectParams params, RequestOptions requestOptions)
-
-
-
-