Interface ConnectService
-
- All Implemented Interfaces:
public interface ConnectService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceConnectService.WithRawResponseA view of ConnectService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ConnectService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract SessionServicesessions()-
-
Method Detail
-
withRawResponse
abstract ConnectService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
sessions
abstract SessionService sessions()
-
-
-
-