Interface JobService
-
- All Implemented Interfaces:
public interface JobService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceJobService.WithRawResponseA view of JobService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract JobService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract AutomatedServiceautomated()abstract ManualServicemanual()-
-
Method Detail
-
withRawResponse
abstract JobService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
automated
abstract AutomatedService automated()
-
manual
abstract ManualService manual()
-
-
-
-