Interface PayrollService
-
- All Implemented Interfaces:
public interface PayrollService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfacePayrollService.WithRawResponseA view of PayrollService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract PayrollService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract PayGroupServicepayGroups()-
-
Method Detail
-
withRawResponse
abstract PayrollService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
payGroups
abstract PayGroupService payGroups()
-
-
-
-