Class RequestForwardingServiceImpl
-
- All Implemented Interfaces:
-
com.tryfinch.api.services.blocking.RequestForwardingService
public final class RequestForwardingServiceImpl implements RequestForwardingService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRequestForwardingServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description RequestForwardingService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. RequestForwardingForwardResponseforward(RequestForwardingForwardParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
RequestForwardingService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
forward
RequestForwardingForwardResponse forward(RequestForwardingForwardParams params, RequestOptions requestOptions)
-
-
-
-