Interface EmploymentService
-
- All Implemented Interfaces:
public interface EmploymentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceEmploymentService.WithRawResponseA view of EmploymentService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract EmploymentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. HrisEmploymentRetrieveManyPageretrieveMany(HrisEmploymentRetrieveManyParams params)Read individual employment and income data abstract HrisEmploymentRetrieveManyPageretrieveMany(HrisEmploymentRetrieveManyParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract EmploymentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieveMany
HrisEmploymentRetrieveManyPage retrieveMany(HrisEmploymentRetrieveManyParams params)
Read individual employment and income data
-
retrieveMany
abstract HrisEmploymentRetrieveManyPage retrieveMany(HrisEmploymentRetrieveManyParams params, RequestOptions requestOptions)
-
-
-
-