Interface PayStatementService
-
- All Implemented Interfaces:
public interface PayStatementService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfacePayStatementService.WithRawResponseA view of PayStatementService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract PayStatementService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. HrisPayStatementRetrieveManyPageretrieveMany(HrisPayStatementRetrieveManyParams params)Read detailed pay statements for each individual. abstract HrisPayStatementRetrieveManyPageretrieveMany(HrisPayStatementRetrieveManyParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract PayStatementService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieveMany
HrisPayStatementRetrieveManyPage retrieveMany(HrisPayStatementRetrieveManyParams params)
Read detailed pay statements for each individual.
Deduction and contribution types are supported by the payroll systems that supports Benefits.
-
retrieveMany
abstract HrisPayStatementRetrieveManyPage retrieveMany(HrisPayStatementRetrieveManyParams params, RequestOptions requestOptions)
-
-
-
-