Interface CompanyService
-
- All Implemented Interfaces:
public interface CompanyService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCompanyService.WithRawResponseA view of CompanyService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CompanyService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompanyUpdateResponseupdate(SandboxCompanyUpdateParams params)Update a sandbox company's data abstract CompanyUpdateResponseupdate(SandboxCompanyUpdateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CompanyService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
update
CompanyUpdateResponse update(SandboxCompanyUpdateParams params)
Update a sandbox company's data
-
update
abstract CompanyUpdateResponse update(SandboxCompanyUpdateParams params, RequestOptions requestOptions)
-
-
-
-