Interface DirectoryService
-
- All Implemented Interfaces:
public interface DirectoryService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceDirectoryService.WithRawResponseA view of DirectoryService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract DirectoryService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. List<DirectoryCreateResponse>create()Add new individuals to a sandbox company abstract List<DirectoryCreateResponse>create(SandboxDirectoryCreateParams params, RequestOptions requestOptions)List<DirectoryCreateResponse>create(SandboxDirectoryCreateParams params)List<DirectoryCreateResponse>create(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract DirectoryService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
List<DirectoryCreateResponse> create()
Add new individuals to a sandbox company
-
create
abstract List<DirectoryCreateResponse> create(SandboxDirectoryCreateParams params, RequestOptions requestOptions)
-
create
List<DirectoryCreateResponse> create(SandboxDirectoryCreateParams params)
-
create
List<DirectoryCreateResponse> create(RequestOptions requestOptions)
-
-
-
-