Interface IndividualService
-
- All Implemented Interfaces:
public interface IndividualService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceIndividualService.WithRawResponseA view of IndividualService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract IndividualService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. IndividualUpdateResponseupdate(SandboxIndividualUpdateParams params)Update sandbox individual abstract IndividualUpdateResponseupdate(SandboxIndividualUpdateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract IndividualService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
update
IndividualUpdateResponse update(SandboxIndividualUpdateParams params)
Update sandbox individual
-
update
abstract IndividualUpdateResponse update(SandboxIndividualUpdateParams params, RequestOptions requestOptions)
-
-
-
-