Interface PaymentService
-
- All Implemented Interfaces:
public interface PaymentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfacePaymentService.WithRawResponseA view of PaymentService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract PaymentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. PaymentCreateResponsecreate()Add a new sandbox payment abstract PaymentCreateResponsecreate(SandboxPaymentCreateParams params, RequestOptions requestOptions)PaymentCreateResponsecreate(SandboxPaymentCreateParams params)PaymentCreateResponsecreate(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract PaymentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
PaymentCreateResponse create()
Add a new sandbox payment
-
create
abstract PaymentCreateResponse create(SandboxPaymentCreateParams params, RequestOptions requestOptions)
-
create
PaymentCreateResponse create(SandboxPaymentCreateParams params)
-
create
PaymentCreateResponse create(RequestOptions requestOptions)
-
-
-
-